(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1646847,      33361]
NotebookOptionsPosition[   1633133,      32978]
NotebookOutlinePosition[   1633484,      32993]
CellTagsIndexPosition[   1633441,      32990]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Codes for preparing to plot the figures", "Text",
 CellChangeTimes->{{3.789797091402213*^9, 3.7897971031744423`*^9}, {
  3.8128763089684525`*^9, 3.812876325153076*^9}, {3.8128872806721416`*^9, 
  3.8128872853603244`*^9}, {3.8161513208983283`*^9, 3.8161513462122517`*^9}}],

Cell[CellGroupData[{

Cell["Functions", "Section",
 CellChangeTimes->{{3.787482251010126*^9, 3.787482254955355*^9}, {
  3.7880909454743395`*^9, 3.7880909640633664`*^9}, {3.788779526673837*^9, 
  3.788779528962552*^9}, {3.816151354016706*^9, 3.8161513553935566`*^9}}],

Cell["\<\
1. Find the position of the point/site of interest over the model grid:\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151548992342*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"findpos", "[", 
    RowBox[{"latin_", ",", "lonin_", ",", "latlon_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd", ",", "gp1", ",", "gp2"}], "}"}], ",", 
     RowBox[{
      RowBox[{"dd", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"latin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"lonin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp1", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"dd", ",", 
          RowBox[{"Min", "[", "dd", "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "gp1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"latlon", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"gp1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"gp1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"N", "[", "latin", "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"N", "[", "lonin", "]"}], "}"}]}], "]"}], ";", "gp1"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.431929480319173*^9, 3.431929623882592*^9}, {
  3.4385919407978373`*^9, 3.4385919487195096`*^9}}],

Cell["2. Calculate the direction", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151573042681*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ObtainDir", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
        RowBox[{"270", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ",", 
        RowBox[{"90", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ">", "0"}]}], ")"}], ",", "180", 
        ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "<", "0"}]}], ")"}], ",", "0"}], 
       "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4322803296540685`*^9, 3.4322803807946935`*^9}}],

Cell["\<\
3. Get the time series from the given position from the WRF output files, \
with input of the position, the WRF-file, wished data length and wished \
vertical level number\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.8161516548656297`*^9, 3.816151693175099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getwrfts", "[", 
    RowBox[{"pos_", ",", "fil_", ",", "dLen_", ",", "verL_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "id", ",", "u", ",", "v", ",", "Qke", ",", "ws", ",", "dir", ",", "T"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id", "=", 
       RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"u", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"v", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"T", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Qke", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ws", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"u", "^", "2"}], "+", 
         RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dir", "=", 
       RowBox[{"ObtainDir", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ";", 
      RowBox[{"{", 
       RowBox[{"ws", ",", "dir", ",", "T", ",", "Qke"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.7886014426837015`*^9, 
   3.7886015328228106`*^9}, {3.788601865896428*^9, 3.7886018688855944`*^9}, {
   3.7886742652759285`*^9, 3.788674269599454*^9}, {3.789190998737625*^9, 
   3.78919101026676*^9}, 3.8161516169609995`*^9}],

Cell["\<\
4. Get 2D data (x-y) for one or more z-levels and one or more time stamps \
from the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151772730195*^9}, {3.816151807435397*^9, 
  3.8161518267697444`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfAREA1", "[", 
     RowBox[{"fil_", ",", "startz_", ",", "startt_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "id", ",", "u", ",", "v", ",", "zidx", ",", "ws", ",", "dir", ",", "T",
         ",", "sst", ",", "T2", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"T", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"sst", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<SST\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"T2", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T2\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"dir", "=", 
          RowBox[{"ObtainDir", "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], ";"}], "*)"}], 
       RowBox[{"{", 
        RowBox[{"ws", ",", "T", ",", "sst", ",", "T2", ",", "qke"}], 
        "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.7898056049910245`*^9, 
   3.7898056490401936`*^9}, {3.790502325714153*^9, 3.790502354001898*^9}}],

Cell["\<\
5. Get a row of data for one or more z-levels and one time stamp from the WRF \
output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.8161518300820913`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfrow", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke", ",", "lat"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"lat", "=", 
        RowBox[{"latd03", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ";;", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "29"}]}], ",", 
           RowBox[{"pos", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke", ",", "lat"}], "}"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.7898159073342123`*^9, 
   3.7898160383490295`*^9}, {3.789816135301789*^9, 3.789816136288871*^9}, {
   3.789885704498333*^9, 3.789885710923794*^9}}],

Cell["\<\
6. Get a transect of data for one or more z-levels and one time stamp from \
the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151888717077*^9}, {3.816151931023254*^9, 
  3.816151948633963*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_", ",", "nLa_", ",", "nT_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke"}], "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.788698072256164*^9, 3.7886980757957983`*^9}, {
   3.788698117320114*^9, 3.788698130106768*^9}, {3.790423995331352*^9, 
   3.7904240173696747`*^9}, {3.7904245500353355`*^9, 3.790424568664999*^9}, {
   3.7904902252951813`*^9, 3.790490250107786*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fetch the relevant data ", "Section",
 CellChangeTimes->{{3.8169226115569353`*^9, 3.8169226182678227`*^9}, 
   3.8169228523021884`*^9}],

Cell[CellGroupData[{

Cell["\<\
1. Relevant data are extracted from the WRF output files (which are of huge \
size) and saved, which will be used in MATLAB scripts for making the plots \
for the paper\
\>", "Subsection",
 CellChangeTimes->{{3.788163918661662*^9, 3.788163931491914*^9}, {
  3.7881639716451907`*^9, 3.7881639777880516`*^9}, {3.789189898143958*^9, 
  3.7891899178443146`*^9}, {3.789301153246876*^9, 3.7893011536225786`*^9}, {
  3.7897970722829833`*^9, 3.7897970754730883`*^9}, {3.790338399121682*^9, 
  3.790338405441382*^9}, {3.8135744508878717`*^9, 3.8135744566540775`*^9}, {
  3.8169236017760177`*^9, 3.8169236816555943`*^9}, {3.816923719682855*^9, 
  3.8169237201915035`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<F:/OFFSHOREWAKE/LLJ/\>\"", "]"}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "THIS", " ", "IS", " ", "THE", " ", "DIRECTORY", " ", "WHERE", " ", "YOU", 
    " ", "HAVE", " ", "YOUR", " ", "WRF", " ", "OUTPUTS"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.787485621916165*^9, 3.7874856530469522`*^9}, {
   3.788090985513077*^9, 3.788091014475787*^9}, 3.7880910468156767`*^9, {
   3.788164107476652*^9, 3.7881641349431367`*^9}, {3.788600705558346*^9, 
   3.7886007056720085`*^9}, {3.7891899221637697`*^9, 3.789189923228917*^9}, {
   3.7893011589092956`*^9, 3.789301159370511*^9}, {3.790338622745055*^9, 
   3.7903386452483025`*^9}, {3.8135744865647793`*^9, 
   3.8135745065520997`*^9}, {3.813574577004174*^9, 3.813574582809127*^9}, {
   3.81580862877312*^9, 3.8158086291512046`*^9}, {3.815808717797425*^9, 
   3.815808734044216*^9}, {3.8158090708142705`*^9, 3.8158090761857433`*^9}, {
   3.81692324933827*^9, 3.8169232748970385`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<wrfinput*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.78748628641158*^9, 3.787486289535822*^9}, {
  3.788091051257616*^9, 3.7880910585262365`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"wrfinput_d01\"\>", ",", "\<\"wrfinput_d02\"\>", 
   ",", "\<\"wrfinput_d03\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.787486290259783*^9, 3.788091058888834*^9, 
  3.788162039033719*^9, 3.7881641375737686`*^9, 3.7886007195813303`*^9, 
  3.788666342038563*^9, 3.789189925469874*^9, 3.7893011763945246`*^9, 
  3.789725218142014*^9, 3.790338647084059*^9, 3.790501157163348*^9, 
  3.8063051283311567`*^9, 3.812876348906002*^9, 3.8130475682309647`*^9, 
  3.8135747848169456`*^9, 3.8158087364991465`*^9, 3.8158090784443574`*^9, 
  3.8158093625251756`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"latd03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<XLAT\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.727761284390641*^9, 3.7277613059998016`*^9}, 
   3.751859817894703*^9, {3.7874857105254774`*^9, 3.7874858157885103`*^9}, {
   3.788091144979847*^9, 3.788091161919414*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lond03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<XLONG\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091175163989*^9, 3.7880911807073693`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HGTd03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<HGT\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788162225205003*^9, 3.788162230351393*^9}, {
  3.7881622658781567`*^9, 3.7881622683280544`*^9}, {3.788162405143283*^9, 
  3.788162410037403*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.789805710103634*^9, 3.7898057101504865`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlatlongd03", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"latd03", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i", ",", "j"}], "]"}], "]"}], ",", 
       RowBox[{"lond03", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "300"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "300"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.438591350086874*^9, 3.4385914277599835`*^9}, {
  3.463471465095724*^9, 3.463471485282191*^9}, {3.4685789779027405`*^9, 
  3.468578980641263*^9}, {3.474964934386197*^9, 3.474964935823596*^9}, {
  3.4761781992397346`*^9, 3.4761782145362177`*^9}, {3.4761782544726954`*^9, 
  3.476178262613112*^9}, {3.486966161752035*^9, 3.486966171392598*^9}, {
  3.7518598448529286`*^9, 3.751859852612842*^9}, {3.7874862048472004`*^9, 
  3.787486222061079*^9}, {3.788091238829426*^9, 3.788091273846731*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FINO1pos", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"54.014", ",", "6.588", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"For", " ", "profile"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7874882053725214`*^9, 3.787488289123462*^9}, {
  3.788091432834153*^9, 3.7880914405155773`*^9}, {3.78809153779632*^9, 
  3.788091550913003*^9}, {3.7881693509177475`*^9, 3.7881693515028715`*^9}, {
  3.788601600541546*^9, 3.7886016130538993`*^9}, {3.788602146873712*^9, 
  3.7886021574134626`*^9}, {3.788602224710693*^9, 3.788602230057116*^9}, {
  3.7886678761851096`*^9, 3.7886678853755817`*^9}, {3.7886679948784237`*^9, 
  3.788667998790357*^9}, {3.7898157785803947`*^9, 3.7898157831077375`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"144", ",", "154"}], "}"}]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.8135748049191976`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.00916290283203`", ",", "6.5950927734375`"}], "}"}]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.8135748049231863`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "54.014`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "6.588`", "}"}]}],
  SequenceForm[{54.014}, {6.588}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.813574804926178*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"144", ",", "154"}], "}"}]], "Output",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705956563*^9, 
  3.789815343889019*^9, 3.79033910537649*^9, 3.7905051829294124`*^9, 
  3.8063051434527583`*^9, 3.8069834871708307`*^9, 3.807591424124873*^9, 
  3.8128763910300875`*^9, 3.8130475818663387`*^9, 3.813565775261674*^9, 
  3.813574804930169*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8075915308143263`*^9, 3.807591536843319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P2", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"54.0676", ",", "7.02", ",", "xlatlongd03"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.807591527126793*^9, 3.807591533694563*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147", ",", "168"}], "}"}]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.81304758460814*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.067630767822266`", ",", "7.023895263671875`"}], "}"}]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.8130475846111326`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "54.0676`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.02`", "}"}]}],
  SequenceForm[{54.0676}, {7.02}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.813047584614126*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147", ",", "168"}], "}"}]], "Output",
 CellChangeTimes->{3.807591538095969*^9, 3.8128763925453606`*^9, 
  3.8130475846181135`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pos1", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"53.85", ",", "7.02", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "For", " ", "the", " ", "row", " ", "to", " ", "the", " ", "right"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886926216680627`*^9, 3.7886926378725204`*^9}, {
  3.789815791206093*^9, 3.78981579535979*^9}, {3.78983453875928*^9, 
  3.7898345410110435`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "168"}], "}"}]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"53.85099411010742`", ",", "7.029022216796875`"}], "}"}]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "53.85`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.02`", "}"}]}],
  SequenceForm[{53.85}, {7.02}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "168"}], "}"}]], "Output",
 CellChangeTimes->{{3.788692623925606*^9, 3.7886926386048293`*^9}, 
   3.788692706637756*^9, 3.7886929849075737`*^9, 3.789190003695677*^9, 
   3.7898155979773655`*^9, 3.806983654051739*^9, 3.807591702870111*^9, 
   3.809423267506048*^9, 3.8128763949733973`*^9, 3.8130475867831235`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pos1", "=", 
   RowBox[{"{", 
    RowBox[{"135", ",", "168"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815809299784129*^9, 3.8158093065088987`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pos2", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"53.85", ",", "7.0", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "For", " ", "the", " ", "row", " ", "to", " ", "the", " ", "left"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886926216680627`*^9, 3.7886926378725204`*^9}, {
  3.7886960865741806`*^9, 3.7886960942504654`*^9}, {3.7898157973334923`*^9, 
  3.7898158017008862`*^9}, {3.7898345339642544`*^9, 3.7898345362157593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "167"}], "}"}]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587470873*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"53.85074234008789`", ",", "6.9984130859375`"}], "}"}]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587470873*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "53.85`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.`", "}"}]}],
  SequenceForm[{53.85}, {7.}],
  Editable->False]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587486539*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "167"}], "}"}]], "Output",
 CellChangeTimes->{3.7886960946823254`*^9, 3.789190004724923*^9, 
  3.7898155996580715`*^9, 3.8069836551647644`*^9, 3.8075917036290092`*^9, 
  3.812876396009966*^9, 3.813047587486539*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415A", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_old_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "GO", " ", "FETCH", " ", "DATA", " ", "FROM", " ", "THE", " ", 
    "RESPECTIVE", " ", "SIMULATION", " ", "DIRECTORY"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.813574947430013*^9, 3.813574986868154*^9}, {
  3.816923286997261*^9, 3.8169233087285337`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_025_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_1_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", "24", 
     ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414A", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_old_off_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.813574947430013*^9, 3.813574986868154*^9}, {
  3.815809143738614*^9, 3.8158091509505634`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_025_new_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}, {3.815809146104535*^9, 
  3.8158091533651614`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_1_new_rep/wrfout_d03_20171014_140000.nc\>\"", ",", "24", 
     ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}, {
  3.8158091480122805`*^9, 3.81580915578129*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea141710at10m", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{"\"\<EWP/wrfout_d03_20171014_170000.nc\>\"", ",", "0", ",", "1"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.812883647486104*^9, 3.8128836934832554`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.789805697410384*^9, 3.7898056995142746`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8075916100398293`*^9, 3.8075916132808275`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7886927462914467`*^9, 3.788692760004053*^9}, {
   3.7886929006146355`*^9, 3.7886929428832655`*^9}, {3.7886943602561107`*^9, 
   3.7886943688530006`*^9}, {3.788694459329028*^9, 3.788694459929224*^9}, {
   3.788694522813609*^9, 3.7886945251053*^9}, {3.7886969914063473`*^9, 
   3.788696991991601*^9}, {3.788697159319125*^9, 3.7886971595193686`*^9}, 
   3.7891900629592266`*^9, {3.789191857999507*^9, 3.789191858093261*^9}, {
   3.7891932866420135`*^9, 3.789193287463812*^9}, {3.78919345991912*^9, 
   3.7891934600318036`*^9}, {3.7893012493390903`*^9, 
   3.7893012497833767`*^9}, {3.7898155098779955`*^9, 
   3.7898155276774983`*^9}, {3.7898156170844946`*^9, 
   3.7898156326345716`*^9}, {3.7898156689731517`*^9, 
   3.7898156690951447`*^9}, {3.789816435179263*^9, 3.789816444854946*^9}, {
   3.789834848908347*^9, 3.789834851701147*^9}, {3.7898755209135647`*^9, 
   3.789875521075776*^9}, {3.789876534962718*^9, 3.789876539160125*^9}, 
   3.790338967979514*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlatd03ToPlot", "=", 
   RowBox[{"latd03", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", 
      RowBox[{"91", ";;", "240"}], ",", 
      RowBox[{"96", ";;", "245"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xlond03ToPlot", "=", 
   RowBox[{"lond03", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", 
      RowBox[{"91", ";;", "240"}], ",", 
      RowBox[{"96", ";;", "245"}]}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.789192765130715*^9, 3.789192832256183*^9}, {
  3.7891928996319675`*^9, 3.7891929053726234`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HGTd03ToPlot", "=", 
   RowBox[{"HGTd03", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", 
      RowBox[{"91", ";;", "240"}], ",", 
      RowBox[{"96", ";;", "245"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7898031220747375`*^9, 3.789803141317986*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.8169227618582916`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PL1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"140", "-", "5"}], ",", "168"}], "}"}]}], ";", 
  RowBox[{"PL2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"144", "-", "5"}], ",", "174"}], "}"}]}], ";", 
  RowBox[{"PL3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"148", "-", "5"}], ",", "180"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7904240398813066`*^9, 3.790424070387413*^9}, {
  3.7904242273466377`*^9, 3.790424246035637*^9}, {3.7904249630882735`*^9, 
  3.7904249917825966`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchA", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_fit_old_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.813577561496483*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchB", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_fit_025_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775919690084`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchC", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_fit_1_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", "1",
       ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775977124696`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X1", "=", 
   RowBox[{
    RowBox[{"xlatlongd03", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"PL1", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ";;", 
        RowBox[{
         RowBox[{"PL1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "NLA", "-", "1"}]}], ",", 
       RowBox[{"PL1", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y1", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"z", ",", "39"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"X1", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Y1", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "X1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "Y1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7904244359100437`*^9, 3.79042454348353*^9}, {
  3.790424586903467*^9, 3.7904246151183257`*^9}, {3.7904249193160133`*^9, 
  3.7904249288616333`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchABlue", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_fit_old_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904254882007647`*^9, 3.7904254907550197`*^9}, {
   3.7904903298449454`*^9, 3.790490330767485*^9}, {3.790490994895703*^9, 
   3.790490995026791*^9}, {3.813579647352767*^9, 3.8135796523289037`*^9}, 
   3.813579707118021*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchBBlue", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_fit_025_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904254882007647`*^9, 3.7904254907550197`*^9}, {
   3.7904903298449454`*^9, 3.790490330767485*^9}, {3.790490994895703*^9, 
   3.790490995026791*^9}, {3.813579647352767*^9, 3.81357966784217*^9}, 
   3.813579713950808*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchCBlue", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_fit_1_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", "1",
       ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904254882007647`*^9, 3.7904254907550197`*^9}, {
   3.7904903298449454`*^9, 3.790490330767485*^9}, {3.790490994895703*^9, 
   3.790490995026791*^9}, {3.813579647352767*^9, 3.813579670909622*^9}, 
   3.8135797207596703`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"startLevel", "=", "19"}], ";"}]], "Input",
 CellChangeTimes->{{3.789903495127555*^9, 3.7899035011675043`*^9}, {
  3.7906722551025305`*^9, 3.790672256173534*^9}, {3.7906723075468593`*^9, 
  3.7906723085102525`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414A", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_old_off_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886927462914467`*^9, 3.788692760004053*^9}, {
   3.7886929006146355`*^9, 3.7886929428832655`*^9}, {3.7886943602561107`*^9, 
   3.7886943688530006`*^9}, {3.788694459329028*^9, 3.788694459929224*^9}, {
   3.788694522813609*^9, 3.7886945251053*^9}, {3.7886969914063473`*^9, 
   3.788696991991601*^9}, {3.788697159319125*^9, 3.7886971595193686`*^9}, 
   3.7891900629592266`*^9, {3.789191857999507*^9, 3.789191858093261*^9}, {
   3.7891932866420135`*^9, 3.789193287463812*^9}, {3.78919345991912*^9, 
   3.7891934600318036`*^9}, {3.7893012493390903`*^9, 
   3.7893012497833767`*^9}, {3.7898155098779955`*^9, 
   3.7898155276774983`*^9}, {3.7898156223158035`*^9, 3.789815624121286*^9}, {
   3.7898164304572725`*^9, 3.7898164410612955`*^9}, {3.789903468157399*^9, 
   3.7899034684272676`*^9}, 3.789903516377197*^9, {3.790671975648992*^9, 
   3.7906719764724855`*^9}, {3.8135850828511972`*^9, 3.813585089702593*^9}, {
   3.813585927985389*^9, 3.8135859359720216`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414B", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_025_new_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135850997681913`*^9, 3.813585117848398*^9}, {
  3.813585930496923*^9, 3.813585938277906*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_1_new_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}, {
  3.8135859328515596`*^9, 3.813585940500039*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415A", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_old_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886927462914467`*^9, 3.788692760004053*^9}, {
   3.7886929006146355`*^9, 3.7886929428832655`*^9}, {3.7886943602561107`*^9, 
   3.7886943688530006`*^9}, {3.788694459329028*^9, 3.788694459929224*^9}, {
   3.788694522813609*^9, 3.7886945251053*^9}, {3.7886969914063473`*^9, 
   3.788696991991601*^9}, {3.788697159319125*^9, 3.7886971595193686`*^9}, 
   3.7891900629592266`*^9, {3.789191857999507*^9, 3.789191858093261*^9}, {
   3.7891932866420135`*^9, 3.789193287463812*^9}, {3.78919345991912*^9, 
   3.7891934600318036`*^9}, {3.7893012493390903`*^9, 
   3.7893012497833767`*^9}, {3.7898155098779955`*^9, 
   3.7898155276774983`*^9}, {3.7898156223158035`*^9, 3.789815624121286*^9}, {
   3.7898164304572725`*^9, 3.7898164410612955`*^9}, {3.789903468157399*^9, 
   3.7899034684272676`*^9}, 3.789903516377197*^9, {3.790671975648992*^9, 
   3.7906719764724855`*^9}, {3.8135850828511972`*^9, 3.813585089702593*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415B", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_025_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135850997681913`*^9, 3.813585117848398*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_1_new_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/fitch_ws10m_1710.dat\>\"", ",", 
    RowBox[{
     RowBox[{"fitcharea141710at10m", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ewp_ws10m_1710.dat\>\"", ",", 
    RowBox[{
     RowBox[{"ewparea141710at10m", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/nofarms_ws10m_1710.dat\>\"", ",", 
    RowBox[{
     RowBox[{"nwfarea141710at10m", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7905013656361103`*^9, 3.7905014442929783`*^9}, {
  3.8128837854034815`*^9, 3.8128838189552054`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv000.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415A", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775023289895`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv025.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415B", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775050472994`*^9}, {3.813577603276939*^9, 
  3.813577605571189*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv100.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415C", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775106915092`*^9}, {3.8135776081008635`*^9, 
  3.813577609764115*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv000.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchA", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv025.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchB", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv100.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchC", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv000.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchA", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv025.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchB", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv100.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchC", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7904908002208557`*^9, 3.790490887334777*^9}, {
  3.7904909219215293`*^9, 3.7904909503071537`*^9}, {3.790494804332694*^9, 
  3.7904948078573165`*^9}, {3.8135777407632656`*^9, 3.813577843976175*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv000.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchABlue", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv025.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchBBlue", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv100.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchCBlue", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv000.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchABlue", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv025.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchBBlue", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv100.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchCBlue", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7904908002208557`*^9, 3.790490887334777*^9}, {
  3.7904909219215293`*^9, 3.7904909503071537`*^9}, {3.7904910110557795`*^9, 
  3.790491022494419*^9}, {3.790491530846312*^9, 3.7904915532611685`*^9}, {
  3.79049481867085*^9, 3.7904948241523657`*^9}, {3.813579739507495*^9, 
  3.8135798159118032`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"II", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158200015750113`*^9, 3.8158200060490084`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158200091128645`*^9, 3.815820009659403*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158200116891165`*^9, 3.8158200121867847`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810187966623*^9}, {
  3.815820014508116*^9, 3.8158200151563816`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810185913125*^9}, {
  3.8158200174241033`*^9, 3.8158200180005283`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158102023562*^9, 3.815810223244505*^9}, {3.81582002020265*^9, 
  3.8158200207033105`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158200227129345`*^9, 
  3.8158200232345395`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
  3.8158200252238398`*^9, 3.8158200257503967`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
  3.815820028866631*^9, 3.815820029389234*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158102023562*^9, 3.815810223244505*^9}, {3.815810261406502*^9, 
  3.815810278822443*^9}, {3.81582003138354*^9, 3.815820031937092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158102649129915`*^9, 
  3.8158102836780014`*^9}, {3.8158200341377716`*^9, 3.815820034667324*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
  3.8158102684974656`*^9, 3.815810289222659*^9}, {3.815820036705963*^9, 
  3.815820037191662*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
  3.815810272121211*^9, 3.8158102944079022`*^9}, {3.8158200392374225`*^9, 
  3.815820039717166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"II", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158200015750113`*^9, 3.8158200060490084`*^9}, {
  3.815820110116048*^9, 3.8158201105479155`*^9}, {3.8158201915961156`*^9, 
  3.815820191732749*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158200091128645`*^9, 3.815820009659403*^9}, 3.8158201266266136`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158200116891165`*^9, 3.8158200121867847`*^9}, 3.8158201266385574`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810187966623*^9}, {
   3.815820014508116*^9, 3.8158200151563816`*^9}, 3.815820126650551*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414A", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414A", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810185913125*^9}, {
   3.8158200174241033`*^9, 3.8158200180005283`*^9}, 3.8158201266664734`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158102023562*^9, 3.815810223244505*^9}, {3.81582002020265*^9, 
   3.8158200207033105`*^9}, 3.8158201266804733`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158200227129345`*^9, 
   3.8158200232345395`*^9}, 3.815820126694454*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
   3.8158200252238398`*^9, 3.8158200257503967`*^9}, 3.815820126707424*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
   3.815820028866631*^9, 3.815820029389234*^9}, 3.815820126717349*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158102023562*^9, 3.815810223244505*^9}, {3.815810261406502*^9, 
   3.815810278822443*^9}, {3.81582003138354*^9, 3.815820031937092*^9}, 
   3.815820126731356*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158102649129915`*^9, 
   3.8158102836780014`*^9}, {3.8158200341377716`*^9, 3.815820034667324*^9}, 
   3.815820126743326*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
   3.8158102684974656`*^9, 3.815810289222659*^9}, {3.815820036705963*^9, 
   3.815820037191662*^9}, 3.8158201267572317`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
   3.815810272121211*^9, 3.8158102944079022`*^9}, {3.8158200392374225`*^9, 
   3.815820039717166*^9}, 3.815820126766262*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_WS_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1415", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806993117638302*^9, 
  3.806993141589811*^9}, {3.8069931980730276`*^9, 3.806993226112578*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_QKE_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1414", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.806992959744997*^9, 
  3.806992974919295*^9}, {3.8069931981638427`*^9, 3.8069932333281217`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_QKE_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1415", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806992957541885*^9, 
  3.8069929805888987`*^9}, {3.8069931981818*^9, 3.806993236342014*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_WD_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.807256015906372*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_WS_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.8072560473304796`*^9}, {
  3.8072609297334137`*^9, 3.807260939874564*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "3"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_POT_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.8072560473304796`*^9}, {
  3.807256091383912*^9, 3.8072560957163305`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "4"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_QKE_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.8072560473304796`*^9}, {
  3.807256091383912*^9, 3.8072560957163305`*^9}, {3.8072575899690304`*^9, 
  3.8072576007613964`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "2"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_WD6_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.807256015906372*^9}, {
  3.807260957083415*^9, 3.807260964226344*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_WS6_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.8072560473304796`*^9}, {
  3.8072609297334137`*^9, 3.8072609679981947`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "3"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_POT6_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
  3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886029396210537`*^9, 
  3.7886029407999268`*^9}, {3.7886972399627733`*^9, 3.788697242320899*^9}, {
  3.7899874027466707`*^9, 3.7899874202034783`*^9}, {3.7899876277217207`*^9, 
  3.789987631012204*^9}, {3.7899878281880093`*^9, 3.7899879359978466`*^9}, {
  3.789988002699628*^9, 3.7899880110677576`*^9}, {3.789988497551344*^9, 
  3.7899885640479565`*^9}, {3.7899888826705875`*^9, 3.7899888911790257`*^9}, {
  3.8057749895798645`*^9, 3.8057750240857983`*^9}, {3.8072554154040756`*^9, 
  3.807255559963552*^9}, {3.8072556000233307`*^9, 3.807255600480114*^9}, {
  3.807255702688704*^9, 3.807255703954446*^9}, {3.8072558017598248`*^9, 
  3.8072558035029497`*^9}, {3.8072558668870287`*^9, 3.8072560473304796`*^9}, {
  3.807256091383912*^9, 3.8072560957163305`*^9}, {3.807260959833536*^9, 
  3.807260970682913*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"EWPfcp", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "4"}], "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/EWP_fcp_profile_QKE6_\>\"", "<>", 
        RowBox[{"ToString", "[", "j", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"2", ";;", "40"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6", ",", "6", ",", "6"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/Wb6I1N9qzeO+w9xW4DojuBkNxCdMP9lAIhec7/4
OIhmmDkTTHOd/3cpFkifc/G6DKJ3PQk/ednmjePTprbTIDpMovwpiP6V/ABM
67C0/QPRMe/+c18B0lHJYSIgWkg7SRREz1liGASi73Q0RoHoktLQJhA9ZVdq
M4h26Ns08UMUUH4f0zQQbfDuTd7h2DeO2Vf/NYBohf0MbSBaIpYfTN/lvDYJ
RF/q+gemawIs5oNoLYkCMN2VFLMcRHtNfrUXRDN55hwG0XpvvoFpH6b9dUeA
dEysRAOIXrNRRuUYkG71Oa0KogHcvqBn
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"FitchOct1415OP1", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/Theta_\>\"", "<>", 
        RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"XX", "+", "300"}], ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7906827990182896`*^9, 3.790682863025484*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"XX", "=", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"FitchOct1415OP1", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", "39"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<c:/testdata/Dir_\>\"", "<>", 
        RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<.dat\>\""}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"XX", ",", 
          RowBox[{"z", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}]}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7906827990182896`*^9, 3.790682863025484*^9}, {
  3.7906828973188715`*^9, 3.790682901472246*^9}, {3.7907624552714176`*^9, 
  3.790762455867608*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Relevant data are extracted from WRF outputs for the site FINO 1\
\>", "Subsection",
 CellChangeTimes->{{3.7886683763853903`*^9, 3.7886683805826197`*^9}, {
  3.8169237382980742`*^9, 3.816923758806182*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "SetDirectory", "[", "\"\<C:/Projects/ALLDATA/FINO1/201710to12\>\"", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886684726609793`*^9, 3.78866849846179*^9}, {
  3.7886689068880157`*^9, 3.7886689178951297`*^9}, {3.788670392745325*^9, 
  3.78867039610468*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fz", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<33\>\"", ",", "\"\<40\>\"", ",", "\"\<50\>\"", ",", "\"\<60\>\"", 
     ",", "\"\<70\>\"", ",", "\"\<80\>\"", ",", "\"\<90\>\"", ",", 
     "\"\<100\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886689240031376`*^9, 3.788668961946226*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wsFINO120171014", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}], 
        "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<14\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.8063055127385244`*^9, 3.8063055128551626`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<15\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.789820896766125*^9, 3.7898209000706606`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest20", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<20\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.789820896766125*^9, 3.7898209000706606`*^9}, {
  3.8066456128244715`*^9, 3.8066456171209607`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstestmean14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"wstest14", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.806305525064556*^9, 
  3.806305528242055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstestmean15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"wstest15", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7898208649049454`*^9, 
  3.7898208794363985`*^9}, {3.7898209401256666`*^9, 3.7898209403258343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirFINO120171014", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}], 
        "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886704786829033`*^9, 
  3.7886705019093876`*^9}, {3.7886705708813963`*^9, 3.7886705711503897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtest14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<14\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788672432826764*^9, 3.7886724489293213`*^9}, {
  3.8063055910653973`*^9, 3.8063055912220306`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtest15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<15\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788672432826764*^9, 3.7886724489293213`*^9}, {
  3.7898207458020115`*^9, 3.789820750774514*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtestmean14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"dirtest14", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "7"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7886724596305313`*^9, 
  3.7886724761911387`*^9}, {3.806305596486952*^9, 3.806305599564677*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtestmean15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"dirtest15", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "7"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7886724596305313`*^9, 
  3.7886724761911387`*^9}, {3.7898208018232*^9, 3.7898208049669085`*^9}}],

Cell["\<\
THE above are measurement data from FINO 1, the readers need to download \
themselves following the info given in the paper.\
\>", "Text",
 CellChangeTimes->{{3.816923789398501*^9, 3.816923842999169*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<J:/OFFSHOREWAKE/LLJ/\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "THIS", " ", "IS", " ", "WHERE", " ", "THE", " ", "WRF", " ", "OUTPUTS", 
    " ", "ARE", " ", "SAVED"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886731910454893`*^9, 3.788673205871048*^9}, {
   3.78981690447651*^9, 3.7898169056466246`*^9}, {3.8056258545861487`*^9, 
   3.8056258585256166`*^9}, {3.806303453951067*^9, 3.806303464150792*^9}, {
   3.8130476117203856`*^9, 3.8130476167195234`*^9}, 3.813574667493128*^9, {
   3.816923850636476*^9, 3.8169238632130833`*^9}}],

Cell[BoxData["\<\"J:\\\\OFFSHOREWAKE\\\\LLJ\"\>"], "Output",
 CellChangeTimes->{
  3.7886732064937143`*^9, 3.789817009485281*^9, {3.7899848965628223`*^9, 
   3.789984906280923*^9}, 3.7905052026134777`*^9, {3.805625831639166*^9, 
   3.805625859609992*^9}, {3.806303455839028*^9, 3.806303464815981*^9}, 
   3.806304625187787*^9, 3.8063072969851804`*^9, 3.8063755444635706`*^9, {
   3.806645188491701*^9, 3.8066452131854687`*^9}, 3.807591331743722*^9, 
   3.8076795362917614`*^9, 3.807679591674693*^9, 3.8130477161828146`*^9, 
   3.813565601058965*^9, 3.813565746990775*^9, 3.8135669131409492`*^9, 
   3.8135746786817217`*^9, 3.813574754029387*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitch", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_old_off_rep/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.789817660121784*^9}, {3.8130476407663307`*^9, 3.8130476734359446`*^9}, {
  3.8130477083720512`*^9, 3.813047708499732*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7891908672791452`*^9, 3.789190885619096*^9}, 
   3.7898170767521152`*^9, 3.7898176610086856`*^9, 3.790505206597246*^9, 
   3.790683499324317*^9, 3.8056351557398005`*^9, 3.8063034734180226`*^9, 
   3.8063045426625605`*^9, 3.806304626198086*^9, 3.806307299483523*^9, 
   3.8063755454489393`*^9, 3.806645215136201*^9, 3.807591334636181*^9, 
   3.807679593588579*^9, {3.813047666265327*^9, 3.813047673946203*^9}, {
   3.813047711779313*^9, 3.8130477169746847`*^9}, 3.8135656022994013`*^9, 
   3.813565748162016*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitchB", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_025_new_rep/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
   3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
   3.789817660121784*^9}, {3.8130476407663307`*^9, 3.8130476734359446`*^9}, {
   3.8130477083720512`*^9, 3.813047708499732*^9}, 3.8135805999108562`*^9, 
   3.813580646056393*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8135806528925066`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitchC", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_1_new_rep/wrfout_d03*\>\"", "]"}], ",",
     "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.813580660969962*^9, 3.8135806648987474`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.813580665681176*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesEWP", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_ewp_off_rep/wrfout_d03*\>\"", "]"}], ",", 
    "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.7898176741786184`*^9}, {3.8130477316515956`*^9, 3.8130477483640127`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7891908672791452`*^9, 3.789190885619096*^9}, 
   3.7898170767521152`*^9, {3.7898176610086856`*^9, 3.789817675616431*^9}, 
   3.790505208074725*^9, 3.7906835013567204`*^9, 3.805635157299634*^9, 
   3.806303475348824*^9, 3.806304543534191*^9, 3.806304725922346*^9, 
   3.806307302864456*^9, 3.8066452160028763`*^9, 3.8075913357052917`*^9, 
   3.80767959441836*^9, {3.8130477406587276`*^9, 3.8130477489043493`*^9}, 
   3.8135656047551217`*^9, 3.8135657495737286`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesnofarm", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{"FileNames", "[", "\"\<results_nofarm/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.7898176741786184`*^9}, {3.789877510877441*^9, 3.7898775172644625`*^9}, {
  3.8063034935601892`*^9, 3.8063035154865513`*^9}, {3.8130477621491776`*^9, 
  3.8130477678212843`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_nofarm\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.789877519415598*^9, 3.7905052105222373`*^9, 3.7906835014380608`*^9, 
   3.8056351594987717`*^9, {3.806303507624556*^9, 3.806303516465951*^9}, 
   3.8063073037680564`*^9, 3.806645216923405*^9, 3.8075913368346124`*^9, 
   3.8076795952072577`*^9, 3.813047768343852*^9, 3.813565606020895*^9, 
   3.8135657507117405`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"link", "=", 
  RowBox[{"Install", "[", "\"\<NetCDF.exe\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4761779532304077`*^9, 3.476177962073931*^9}, 
   3.4761780970548506`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["LinkObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{12., {0., 12.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              StyleBox[
               
               PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0,
                ImageSize->{{1, 300}, Automatic},
                ScrollPosition->{0., 0.},
                StripOnInput->True],
               LineBreakWithin->False],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              
              PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0,
               ImageSize->{{1, 500}, Automatic},
               StripOnInput->True],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link protocol: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"SharedMemory\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  LinkObject[
  "\"C:\\Program Files\\Wolfram \
Research\\Mathematica\\10.0\\AddOns\\Applications\\NetCDF.exe\"", 3228, 12],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVyl1Ik2EYgOEtLGeZKzxIAw+mBspozn6GziZ7bNRcOdcWUgyjRElh5USb
WEOl/8DmCBnZWGkqOQ1SNFL8KyEy+aQsqanLKEzd971atrKlI3veg5vr5Bbl
FesL+DweLxtLB6lDPeeDhDphJ/WndtA1veoD89alVC+qGM59xF/zQWP/QDe1
eHV2eQuqTuto/oj21Hcx1EJVcNSD1ptnJZPoi76IB1Oo3fXQOE0/efk41X0s
c96LrnRm6WfQqHuJ+nX0pn3XCnVwpj2PH/SB9LPCthF1mnjqUDRjKKKSmufu
lQrQC1na+9RNkTXWMPT6F9szap1dI0pEDcxxTxI6E1B9/fPPB8HsZoUqhIUq
f/loVQwLv0vnm+N2s8Crrrn1XsbCZZHEsaBjYSr/2kIwhwWdrXR89QQL590e
/WsjC0K/eORSKQt3tvVFvRpioUE0EUNNsDiT94s42G6pvUhVr+x1y1DL86zY
nDgOwgWCwOJhDuZ6a9uW0BsafhfVKOB6qOFKtT1SzYFraYM/Gu0Oe1K2E5Ws
CZPzMzlgxuSp1D1WxtJ/hINDLcMGYQqBH+canWLU/Ni0Lk4lsGOx4rQUraiO
V8rQwJXbm0+iTFGBkFpMQmKo++LbGqjy9qeSJDkBb4frpRaFg5JoPbogLRkw
oiNpV03aNAJvNZXvDAcIjEqduioFgU9KTZHfSODXB1lTei6Bsroo69lTBDKO
1n7/doaAozU2zFpIgO0NbXqDTpT8bWWKCIiWrZNUj/luyhj6H+vkTdA=
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.789818351333433*^9, 3.7898183549722424`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.789877545639567*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8066451326032777`*^9, 3.80664513356367*^9}, {3.806645172056812*^9, 
   3.806645172856648*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.806645138716958*^9, 
   3.8066451397053156`*^9}, {3.8066451761388483`*^9, 3.8066451768130445`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.806645141998147*^9, 3.8066451429775753`*^9}, {3.806645179067955*^9, 
  3.8066451795546494`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8056377663279004`*^9, 3.8056377795904465`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.8056377734140024`*^9, 
   3.8056377807403717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.789818351333433*^9, 3.7898183549722424`*^9}, {3.8056377754993815`*^9, 
   3.8056377831958537`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.805637776759043*^9, 
  3.805637784424523*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.789877545639567*^9}, {3.8056377780745773`*^9, 
   3.805637785736024*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8056377663279004`*^9, 3.8056377795904465`*^9}, {3.806645230306546*^9, 
   3.8066452400603323`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.8056377734140024`*^9, 
   3.8056377807403717`*^9}, {3.8066452336026883`*^9, 3.806645242850865*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.80664523654875*^9, 
  3.806645246777306*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.789878558197447*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.813580726514374*^9, 3.813580731414074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580737976027*^9, 3.8135807410321283`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.813580746764064*^9, 
  3.8135807497713056`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580759581566*^9, 3.8135807624320936`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.806645141998147*^9, 3.8066451429775753`*^9}, {3.806645179067955*^9, 
  3.8066451795546494`*^9}, {3.8135807657609744`*^9, 3.81358076859492*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580775309825*^9, 3.8135807788448105`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.813580810318684*^9, 
  3.813580812857642*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580815942842*^9, 3.813580818854536*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.805637776759043*^9, 
  3.805637784424523*^9}, {3.813580827989236*^9, 3.8135808318573675`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8135808358467045`*^9, 3.8135808399282026`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.80664523654875*^9, 
  3.806645246777306*^9}, {3.8135808495311775`*^9, 3.8135808524444523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580856002179*^9, 3.813580858800744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FINO1posLeft", "=", 
   RowBox[{"{", 
    RowBox[{"144", ",", "153"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8056354517247143`*^9, 3.805635456839049*^9}, {
  3.8056354978305044`*^9, 3.805635501729127*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100m", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitch", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitchB", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}, {
  3.813581011837861*^9, 3.813581014606733*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mC", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitchC", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}, {
  3.813581011837861*^9, 3.8135810250983844`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mLeft", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1posLeft", ",", 
       RowBox[{"fnamesFitch", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8056360230439577`*^9, 3.8056360277374144`*^9}, {
  3.8135664722032175`*^9, 3.8135664725573573`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wrftime", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"i", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"j", "-", "10"}], ")"}], "/", "60"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "12", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "10", ",", "60", ",", "10"}], "}"}]}], "]"}], "]"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789824834074008*^9, 3.7898249232383366`*^9}, {
  3.7905061354386854`*^9, 3.7905061383728113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"obstime", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"StringTake", "[", 
          RowBox[{"#", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"StringTake", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "5"}], "}"}]}], "]"}], "]"}], "/", "60"}]}], 
       "&"}], ",", 
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7898249377799234`*^9, 3.789825017220561*^9}, {
  3.790506205827893*^9, 3.7905062095297203`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightednofarm"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.8057013044948387`*^9}, {
  3.8057014745592546`*^9, 3.8057014769010324`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.408314298775097`"}], ",", "0.5589603126751949`", ",", 
   "1.408314298775097`"}], "}"}]], "Output",
 CellChangeTimes->{{3.805701283742272*^9, 3.805701304983504*^9}, 
   3.8057014773348856`*^9, 3.806375600379199*^9, 3.8063847536965003`*^9, 
   3.8135667773736258`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightedEWP"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.805701317486081*^9}, {
  3.805701446459361*^9, 3.8057014706457167`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.19593413794988715`"}], ",", "0.5243896710071149`", ",", 
   "0.45331286453310266`"}], "}"}]], "Output",
 CellChangeTimes->{{3.805701283742272*^9, 3.805701318212141*^9}, 
   3.8057014812104745`*^9, 3.8063756017157016`*^9, 3.8063847545771513`*^9, 
   3.813566778992525*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightedFitch"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.805701330139263*^9}, 
   3.805701485953803*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3035236554197806`", ",", "0.45834060883237787`", ",", 
   "0.4384417408794124`"}], "}"}]], "Output",
 CellChangeTimes->{3.8057013306269584`*^9, 3.80570148665022*^9, 
  3.806375602811886*^9, 3.806384755216728*^9, 3.8135667799912224`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EWP14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWP15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8057023857040367`*^9, 3.805702508515811*^9}, {
  3.8057026696489244`*^9, 3.805702672790571*^9}, {3.813581464557933*^9, 
  3.8135814666373806`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EWP20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066455240449734`*^9, 3.806645561301324*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fitch14B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8135814808821316`*^9, 3.8135814979696255`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fitch14C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8135814808821316`*^9, 3.813581527272245*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.8066449660131216`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.80664498619221*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.80664498619221*^9}, {
   3.8066458659893665`*^9, 3.8066458717350583`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.8066449994528246`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449994528246`*^9}, {3.8135843930574245`*^9, 3.813584423607455*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}, {3.8135844176699247`*^9, 
   3.8135844285699463`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}, {3.8135844319859447`*^9, 
   3.8135844379121304`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449994528246`*^9}, {3.8135843930574245`*^9, 3.813584423607455*^9}, {
   3.813584460974019*^9, 3.8135844690772047`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}, {3.8135844176699247`*^9, 
   3.8135844285699463`*^9}, {3.8135844633270316`*^9, 3.8135844715715213`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}, {3.8135844319859447`*^9, 
   3.813584473871108*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450238546543`*^9, 3.8066450354886084`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450418456416`*^9, 3.8066450600948954`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450418456416`*^9, 
   3.8066450600948954`*^9}, {3.8066459080978384`*^9, 3.8066459134605527`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.806646704775715*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.806646722359767*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.8066467317566257`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.8057003773509007`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.805700404227002*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}, {3.805700404236977*^9, 
  3.805700404244955*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}, {3.8057004042559223`*^9, 
  3.8057004042639008`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}, {3.8057004042738733`*^9, 
  3.8057004042818527`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.805700404227002*^9}, {3.8057004577923517`*^9, 3.8057004577983007`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}, {3.805700404236977*^9, 
  3.805700404244955*^9}, {3.8057004578082743`*^9, 3.8057004578142586`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}, {3.8057004042559223`*^9, 
  3.8057004042639008`*^9}, {3.8057004578242297`*^9, 3.805700457831213*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}, {3.8057004042738733`*^9, 
  3.8057004042818527`*^9}, {3.805700457840187*^9, 3.805700457847169*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_OBS_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"wstest14", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}], "]"}]}], "]"}],
      "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_OBS_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"wstest15", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}], "]"}]}], "]"}],
      "]"}]}], "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8057003261936455`*^9, 3.8057003664160995`*^9}, {
  3.806376325883372*^9, 3.8063763259781218`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/ws_100m_Fitch_Fino1.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"wrftime", ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"tsFINO1Fitch100m", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}]}], 
        "}"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7905052884333143`*^9, 3.7905053879891605`*^9}, {
  3.79050626212634*^9, 3.7905062683697505`*^9}, {3.8135813262205944`*^9, 
  3.81358133089495*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Examples of plots: figures from the paper are prepared with the same data \
using MATLAB SCRIPTS, which is also included.\
\>", "Section",
 CellChangeTimes->{{3.816923181781724*^9, 3.8169231876966333`*^9}, {
  3.816923550665338*^9, 3.816923586911745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "[", "xlond03ToPlot", "]"}], ",", 
        RowBox[{"Flatten", "[", "xlatd03ToPlot", "]"}], ",", 
        RowBox[{"0.5", " ", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"fitcharea1415A", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"6.5", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "7.5"}], "&&", 
       RowBox[{"53.8", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "54.2"}]}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"XX", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6.53", ",", "7.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"53.85", ",", "54.18"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "10"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Longitude\>\"", ",", "\"\<Latitude\>\""}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Fitch 15:30 adv=0\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7891926883740296`*^9, 3.789192706512515*^9}, {
   3.789192838814603*^9, 3.789192881190255*^9}, {3.789192914515173*^9, 
   3.789192919379161*^9}, {3.7891929640189376`*^9, 3.789192964653288*^9}, {
   3.7891930303412685`*^9, 3.789193031172056*^9}, {3.789193178310893*^9, 
   3.7891931784495354`*^9}, {3.7891932145888805`*^9, 
   3.7891932151992598`*^9}, {3.789193317341813*^9, 3.7891933322888093`*^9}, {
   3.78919355994938*^9, 3.7891935604540243`*^9}, {3.789194581399146*^9, 
   3.7891945817820883`*^9}, {3.7891946864630933`*^9, 3.789194707541705*^9}, {
   3.789805829627242*^9, 3.7898058388326035`*^9}, {3.789805921812013*^9, 
   3.7898059235530205`*^9}, {3.7898059776089993`*^9, 3.78980603383108*^9}, 
   3.789806128712236*^9, {3.789806246139863*^9, 3.7898062465253983`*^9}, 
   3.789807046544841*^9, {3.789807388090448*^9, 3.7898073901950593`*^9}, {
   3.789813443348075*^9, 3.7898136168392515`*^9}, {3.78981375265234*^9, 
   3.7898137527682047`*^9}, {3.7898137853549557`*^9, 3.789813862301978*^9}, {
   3.789813904310199*^9, 3.7898139049429293`*^9}, {3.7898140682941294`*^9, 
   3.789814068848768*^9}, 3.7898142130008583`*^9, 3.789814569482603*^9, {
   3.7898149184411564`*^9, 3.7898149190964503`*^9}, {3.789815054050105*^9, 
   3.789815054197209*^9}, {3.789815246727021*^9, 3.7898152494776464`*^9}, {
   3.7905018642897882`*^9, 3.790501864489352*^9}, {3.7905019270047636`*^9, 
   3.7905019422972574`*^9}, {3.790502045641757*^9, 3.790502054276376*^9}, {
   3.7905022463956175`*^9, 3.790502246768867*^9}, {3.790502440570092*^9, 
   3.7905024545356026`*^9}, {3.790502548278941*^9, 3.790502548675728*^9}, 
   3.8135750935631456`*^9, {3.8135865780487156`*^9, 3.813586579498519*^9}, {
   3.813586636014121*^9, 3.8135866375458393`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJw13Hk8VF0YB/DJnjYhcWcwImlRpMWao7JEiRBKDFFaFEm21LQh2SKypCaV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      "], {{{
         EdgeForm[], 
         RGBColor[0.148, 0.33, 0.54], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNmHl4ldURxr/v3uRKkE1BNlFMIIYdrBuiLAZBgkAgKNLiwhYghAQiiHVB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            "]], 
           PolygonBox[CompressedData["
1:eJwlkrtKA1EQhmdzsgexMnhtU1hoFAIiBPURtDCWoqAIKSKJMXbiFbUSojFo
sBGiaMDGh1BErURtLSxSCMb4Bn7DFD/77cyc2Zn/bHwxn85FRCSBoqjByxPP
Z/QNh6HIfCCyjfrhd2I3YjVfcIpD4+QmUBFOOJEfck00BJe8yCR1U+gYHib2
S66FkvAJsQK5VXQKHxLrpFcXKsMt4i9iPePOvqHf0pnqcDNis2qN1h7QY43n
DNqHH5j5ntoG+oQL3nJptALPhrZbDWVh5622jXwMvuObvbz3oUd4l9h0xGau
wDlvvTS2B7czUyqwM3p2k9gguQTagkec7f6HRuGa9iCXR5fePFPvOjg/58wz
9U5rynDGWU49VC/fdE+xO/mAz7x5WURVb1Ku6L3Bt5zpCWxGvfBr3rsDi2mu
6sx7jV04m0lnO0JX3nbQXfROd+C6t97q+TmcpOdYYP/EQtR21F31TrNwxpu3
A2gZLofmvd5RHV73llPPNrx5rt5rzxj9Xokvie2su/8DUftUkg==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.30435631349963893`, 0.4106683529870936, 0.6401547550034072], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNl1lsV1UQxv+99F4fTEBFFAFxiQtGE0VUQJaKvrg8mBIBZS0FlwiiBtpa
Si1lcQEqFoQugLQgReMCbi2LuLQi+qQVMGwucUlMTEwUQQSMfl/mR+Dhy3fu
nDlzZubMWe5lxY+PnJHkcrkZeblcF/FT+igTxghbJTsgbBG2CQfzQuZ2g7Bd
qE1zuT3iF8XN4g6hXVis76/Fi8TPCp1qPyNeIW4TWoWlaXCj+CVhr9rLxdOw
NS4N3ZX48DO2T83xidAkDJKvA4ULhc3CJmGp8I6wTHhXmCJMFRYk4Yf92SK+
n7G2sY2YDmHbc/wk1BOzY9+Y0ideQtuyZcxXK/yVF7HvFvYRq+PolN4x8a40
crmNub5Pgz8XH82LfO4lXsf6C3ZsYz/wupyA95Off1mjQ/h6kP596BxHbt06
oQe+HskLPl/fh/F7D3LHYVknNtoYXyFf/xD/Dv8pnKfx36Xh7840ZB7bXfJW
9CqQd9LXTpw/wR6bSf8kvjuG1iyX+0Ky98VvCkvUfktcIl4prIBbaTehY92F
4g2s+2p9PypeI14nbheahVXCB8J2sE1odP0LDXy7f7WwQ3hFWC/MF7YIbUKd
cGMSORiQxLwPutY8n/Cy8CE25iBbK1TZX8a3EUczsrmeK4taXp9FXb9Aba/N
wvYqcU0S8U4XHkOnhtpfTv3XUp9v48tH+FNPnI7jDdnaKH5dvEvcksT3Z+Tw
1HcLcX3FXttMfjeQmw3E30KeOpLI93r6P+V73hkyj9nJ+nkd38f39/C/nTEd
+O7cfSx8AjcRzw5yuxObn5HPdnTt/+dJxNdKvtvwqeMMf3Yi24UNx9JGHboe
m6ldnz+FafCjnFtuVwmV0rtb+hVZ7DXvL+8zn1M9kzhzbhZuou8C4ZYkdM/V
mLPEXbLos0539M9HxzYuEgbTd5g9fG4Se821+Cf7z23PO5B5jKP4Mk1zXC0u
Fw8TLlX7CnEf4RKPE18s7isMZ16P+1vj+ySxV0/1W78giT1s/6+G/e29bR3r
+qyy7/+Ie4n7CXeifx7xeB9Vae57xE9ncd6dZE6fT0c5oy4klr8543phtyc+
+sz9h/mOcW4e5zw7gh3n4wjcgxzajxuxtY8xXof78O04tnqzLl670cTbj1jG
IB9I3Cc5p2cqntv1/VgWsoPIDxCj7T7CWnhNSoU71C7Jwjf71R/bF2C/B9/2
5TbW4lLmHZZE3oYkkR/7/L33gu78Hzxel/+vaheIW3Ih3yVcp+9u8uVa8e4k
+jrF1+i7q+T3ir9JYmzSJe7qOu6Is7UfZoq7prEWg6n5L/NVa5J/IZ6VF2P8
LvB8tuM5fpOt6712zHNDXnyb+wsjhXkaXyhelB/zFCK3jsd0o92NMZukVype
lx/yQmwWouexa9RXYn/EW4Uytd/LDx9LiM2o5y51fwPfX3OPeh8+hbyMtuNt
pNb2Uqvd0pA7H93Z4wNYp6Gs0THq1vm7lf3u9TvBPugNelGPZfhSip8ltO3/
LL6np+HLhDTeIPVnxFB3hn4b69JADB6zne/GvNPvBr8XZmLf+r5ffD77nJ5F
n3N7ZRrnYir+Lz/al6v9NPoeN4o8uIarkzjzfX5PECYmoTuC+nZtVwhjhXHC
JM6eoiTuw2lJ3Il++3mvef88n8W9/Bxns3X8JpjD/vI+u599OxAuY18bpfg4
inPAvjZmcW+9ytgHhHJhE3fzZvFs5Pa1Jjl9Vw9C7nEl2BxF/KNpe8+OJ8bR
7PExwOP8Zt+YxX1ZL56bxVm6KIt3g98L68Qv8v459Q66K4kcFJOfKYzx2MVZ
vJedK9/lU+l3jnz3tyD3+6GOHPkNMB+9KbSLyfE9xOxv3/uTk7hLJrGuI/Ch
mBgcS10W6zwC/WVZ5Kw2i5wNJp8TsVOFXhH1MRd5EbVURP8I5nHbsfYjF2l+
nBOHfY5lvJ+4f6aRK6+B328V1MJoYq/ju4x5m/DHNV2ZRN3eylraxmxsrIJn
E0s59TCb3JaxvpPJWzU1UUq9zCOW+cw3iflfQbaAGinHznrGzCeO8fhXjXwd
uXOuCpjDc63ErvWaiWUsa1DAvMOx57NrAnF5jtXEPZT+BVncXTOosYX4aTuX
MH8ta71U/A5v3y1Z5G4s84/H/jjmq0Q2ke9hzNmHdjUxFJGPBnLSl7mHM24o
+l6DRnR7Ix/CWlaiuwYfKsn/Wvqdl4vwcyL2hgO3L0Zehf4QdH2OF3P3+Q7c
jg+ukwncxb6TF2ZxVjwjHp+e/p/em8T9uZv8r2bsq2n8Sy4TX8W94/vnhTTO
7xr38w/uf/EC3gO+26dnsUceFnfkx13wobiGs9RnquN13fo8O5HG/9zJNP6d
GojhxyTeFXuQlSN/LY17ZUUa6+E+1341e89vwG+xadvnZPGefCiL/bWG/Jt3
ELPf+k3U6sesSxN9H5CTJ7J4Rz2ZxXyedyt9jay/6971Xwes53+l/wH0Rzt8

            "]], 
           PolygonBox[CompressedData["
1:eJwtlUlsTlEUx9973/euhAS1sRHzLOhnCokNNoaFEAvjQmOKTqiaZ9EK/UpL
jaEldKDRlpoikVC0dhSJhWFhDIlpgwTx++fcxS/f/5137r3nnXvO+fpk5c/O
i4IgKIQk1LogqMBwFS6gV8Mo9GhYiz4E5egyqEa3xkHwKwyCn/AAXYhtCu8m
QwH6BjSgH8FN9F983uLreO7K8zaYgZ4OW9FrCaIAaqEOzjs7qwmaWVvKc05k
a3aiE9AB/Y49X8UWo2KdA3vQEyEDnYJ89Fk4gC6FM+hu0BP9l/X/WH+S5yKe
l0IavRJbFe/uQAl6CDENho7QCbrj0yuyPbTXbtgFh5VHOKqcRZazI+g8Z7Eo
p6t0lrNYC+E4uhHSPr4m9BXZIov5HPo0ZKNLoErfArmR5US5ueTsnfZocLan
9tadnkC38w2/Q7uzx+g6bM2RxViD7g+9I/umHuiHfONGfDdAC7oZ1qPXQQP6
K35f4Bt8h02smcbvYMWELoYlkdXEFvQ81syFTEhBP+jrc6rcZsFiGA8T4HbS
ztaZN9Fr2GNSZDGuQC9zVkuDINvZHeouX8Br9HyoQF+DhegFcAa9HQagO0NB
aD7y/QLfQ6sZ1c7ZpH1rIZxSrLGtVU3MQuckOBeKoBjGwVhv07tyfFpCOzMb
3RZbbLegDr0P2nUXUIz+zLmffE6/+pwqt33Yqy/sdVabyqlyu4eYZrM2BTH6
A/b3fg/tNYI1wyETUvAW2xvvI992aKXv2+A1+hc+I/VtsMvXuGq9EXuTR7oV
2uAQMT/D9ymUxXanmf4Os/wdjvc9rd5Os6ZEedFa6IYtw9eEaqMe28WEDaMw
aWfoLPnId7mz2lLPZ6Cvc+aP0O7sWmx7au9jcByuqobxbdP8cHZHRT6GtPeR
byVUQQ1U+xjqva3S2/ROMQW+ZlW7EbaPgeVQuSzTd4Z2J7qbFbxf7u9Ad3Ew
tlw9gVL0Kc2YyHpava0ZqlmqnLbENgM0CzRDL6PvYXseWg+rl9Ox7aUa2o8+
EVuty0e+i2QLrYcHxjbTNdvV8+r9P9jehDaTNZvvxjbrZHuJ3uist6bCDmc5
VC5roB59P7bZqxqvRZf4/tc3HdQMTFrvKCfKzRhyMNr3iHqlIrZeUIw56Fxn
/x3qcfV6yteu1mjtjdh6RXeuu9/vLDadqbPz8cnzOVfun0ZW29XwDJ2bsF7p
AosS9h+g/GqGlqNnYuscWg9kofclrRc0Izpx3mZn/1XT/KwblrC9tGao6sZZ
bvQfUon+D7vd+YA=
            "]], 
           
           PolygonBox[{{802, 801, 810, 270, 809}, {1193, 1192, 1285, 383, 
            1279}, {1011, 305, 877, 878, 879}, {736, 200, 738, 739, 740}, {
            1647, 561, 1668, 1666, 1667}, {1685, 1684, 1702, 657, 1701}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.4386215859193078, 0.45785423147323917`, 0.5612256491720363], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtVE1IlFEU/Wa+7z3IIqJdS40Jgmgls2pRoM5ukKgIiRZBOmONktFCMhAL
ZvzNmtwUZSCBZvmX09hGosIg7c9F0WIIwk0g/QhCRELncM/ict7Pffede+59
r/pM+9G2eBAEeVgIq7gg+BYLghfA81jYjXES+MAHwS+MR4BD2JvDeBh4EfMa
BLgEnIVNYTwD7ANOwh7CGmApWAvsEfbGgfPAk4pzAjiN+WOsT3nza9a5DKyg
s/3wm4X/oLM9+tTDOnCmGpgDprE3Ss7Az8BPsBLspbPxErAG+awj1984kxb/
WuA89m/CijHjyzv2wZpw5hbWdgJ3OPNpBJZhHzBeAF7QOe5lxIe8ssBe5ZGH
3wz2+4CD3vjfAW7HvIPrkWnWT51gf2HfWRfwXZGeXN8v/szjlfK87UynjO5L
aUzdJlSHN8IJ+YxLW87vebv3rjcf3rUsLhyznkMx4z8Ne6rcqUGD8j0gDYvS
nFpw/kRYUj0OqZd+OItLLtRpVbkwJ4d5AhbBOjF/jvUx4Bf156Yz3gWdz6sf
WjQuKL9ub1p0And5i7tFvaF1GnHWQsu3Vzl2a537Vd7uPwtcx7wN69nI7ijo
njFxWwR+FH/m8VW1W42bcRzHXbmYxbkOe6t6su+H1SsD3t4GuZe89Shr/RN4
XzVireqlT4PqklPMG870LrLfQ8slB86j3vhOAiuR1fAKfFr1xrtC86P/ZeBp
zA9ifBy4CNuG8Ubc9KIPY/N+pzeSlT5pYFl5rkX2H7xTjh3qDb6VOf0V/DOS
erMZYLt6gz0ypJzYcwPyaXXGg3wOh5Z/QhyuRRZ7C3hVcRgvqRxrgXv0dhKh
cSEnvu0m+O1FjGPe+JLbe9gzb7ig/4l7rBvfJGtaBcxjr4494U076sM+alR8
clrWO1rR+RXVfkQ8ybcizTdC051jri3p73rt7A0VxXlG+vBPzIo/80hFpn9Z
vb2st18XmaZHEOeU/jT+bZuqHXu8R7z/4Oy8M278+7f0Jv856xXq2RNav7Jv
+4HnvNWhGdglTajNf1TB4Uc=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlUlsjlEUhr/+/3fvggZhwYIFVcKCEBsSEolhIaFERAWLCmmNNc+JCIpq
0UFinhZVWkVb06JEJfw2ZUMsxBBCQkQMicT4vDln8eR/c+797nTOef+BJatm
rcwkSbIBUmiOSdJEoBLOoF/z+wrewjs4GW1sP5xA94He8DckyT+4ie5i7DJc
Q3cQu5uXJG/gObqQ2GDoDwOiram138MHKGJODXNboRg9nUOtRK+AqanN0dyP
8AmOs8YSfivgNHoLc4qYuxp2oT+zxhd0F2xFjyM2FtbB+tRiGnsM19G/IM3Y
eV+g97Hm5IztUYWeEGyuvmlHTyA23u+ku5USO51nd96Mbid2gW8b4Xo0pB/B
DfS9YHtpfoPez9dvgT3o0ZxxFJTAIqgj1sbYU+hEX4n21s3Qgt4e7FutobMu
ITaEsQC90HOIXWPsKsyWzqLhIeTgLJyBBrgAG/lmEt8WQBn6Z9bedwR8RC+O
9l6FsBR9hDPWw2GogSvQAufgPLxiz5fwEHLwNrXcVsMk9FBiQ6An9ILbxG5B
G7TDfeiEDrgDB/XGfFsH89ErOMNAzjII1qI3w9SMvcGyaN90+Jpa+zF0QQ4e
6SyssRwWwMJge7b5HXSXhT6mM+qs33mDb7AKymEwcwpgGAxPrcZV632hHzwI
lrtn8AS9hzm7IUBM7U30No1wEfoQ6w3FMC+1mMbq4UiwHCqXB2Gax+r9DrpL
jedCe2ivi9AI/9TsjFdypjLeplQ9Ha2n1duKHUIfC3ZWvbHe+mvWcq8aUK9t
8v5QjahWmhlvgjzGMr6H9hrEb0GwN9HbdIf81HKsXHd5LvbDGl9/J3qk9oNR
MBr2QgVUQXXW3rSve5C8aHa0WlX+p+su6hGv90r0Bh/XebdFO2Oe50y5a3c/
kGe0BttDe9VCHfxJzVvkUfl+J91tJswKlgPlQp71g7k9gtWm7tQ9WA+XuAfJ
iw55P8rvDgfzpHWeI+Uq572pGlAtXI7W6/JoeXWV519rVAfr2QbPgXJxKZo3
yoOaonmMvEYedQD9O5g3qIflfdFrUTWt2v7h/qTxbnw/MVivymNeMO8Yc466
Z8g79B/w13tcvX6KOSfdE+QNRcyZASWwyN+01tfQWnvdb1RT8t58rxV5lLxq
fbTcKofKZbn3XimUZa2Hc+4R8gr9h7T6+8wN1kPF7qnyVtW8al8esSOa5+pu
qpkKdK1/L8+V947x/eUxU6J52jm/o+5a5mdRzap25YmFfh/1yn9j//lE
            "]], 
           
           PolygonBox[{{1580, 545, 1640, 1597, 1598}, {805, 236, 809, 847, 
            848}, {748, 747, 751, 236, 793}, {824, 823, 831, 265, 958}, {727, 
            726, 770, 233, 762}, {898, 274, 876, 903, 904}, {1362, 1361, 1386,
             415, 1358}, {818, 817, 820, 274, 874}, {778, 233, 735, 736, 
            737}, {832, 265, 831, 726, 727}, {867, 866, 1003, 302, 862}}]}]}, {
         EdgeForm[], 
         RGBColor[0.5728868583389767, 0.5050401099593848, 0.4822965433406655], 
         GraphicsGroupBox[{
           
           PolygonBox[{{815, 273, 873}, {1342, 430, 1405}, {786, 234, 785}, {
            818, 273, 815}, {1656, 548, 1642}, {1156, 335, 1146}, {741, 234, 
            737}, {1146, 335, 1010}, {1641, 548, 1655}, {1655, 548, 1656}, {
            737, 234, 778}, {1404, 430, 1341}, {1461, 430, 1342}, {1459, 430, 
            1461}, {1642, 548, 1637}, {1368, 401, 1369}, {1286, 401, 1357}, {
            1290, 401, 1286}, {779, 234, 786}, {874, 273, 818}, {884, 273, 
            887}, {1369, 401, 1360}}], 
           PolygonBox[CompressedData["
1:eJwt1EtIVkEYxvGTn35CKSS6yKAgUpMuG7sbVEZlkKiZFigoqIsMtFoUVAZd
wHJjkKlQYJQuUjHMyMLAr0UutI1tsgKlQKFAN5UukrL/w3kWPxjOmTNz5r3M
hupzJQ1xQRBUIx5XEoLgMrrQjUYeXsV13EARCpGPY3gdCYJXmGE8i72M92AE
MZxAMWpQGwnX1NojiOE0TqEUZTgQDYL9yEQWLrHmRfSiD+t5tg5rkI55fn4O
6ay9FovMWcAc5vGDd989R3Pn/a4OZ30GnUVn0FkW+YcFrGTtVTjEOA9TzJnG
ScYlKEQRHvLNAzzGE59RZ61EFe6iBffRhjq+OeMYK9YNqEclqhQL5pRhCtN4
gUGMYRz/+Ie/SGJusnLEuAudeIRa1CAX+9CBdtxDK34Rg584yFp5GOLZSwzg
Od5jHO8wilvMuYk7aMY2YrLVOVKuZpV7fMQkMvkmA5uxBV/4x8+OqWJbwTfl
KEVZNKwR1Yr+Sf+mHCqXmciKhHM0txBF2M0auxxDxfIbvmIM41qfPcuRg+1I
RBS/WWshEs7R3F70JYQxynWNqdYmfZZ6xg0+g86ShGSkIdV7VHiPHMdcsc9y
7apGVasp7LEaE7z7EB/WiGrlKXrwDP2I413EcyacA+Ui5l5RDBXLVueyCbex
kz124Cjyo+GzJp850TVe555V777VmhjGG5+x3j2uXm92rltcu6OuhZi/LXOv
HkcB0tgzFcuMg2gYY8X6PC7gCN8cjg97SL20QvOwERkJYU2rtlMd2wKvrR5W
L1e5NzYhOyGs0QHXfLdzotwMuld0B814T+2d79ioZlW7n6ixSfzBEjpYs909
qF7s810T+F+r3MvqSfXmkr+NMI6PhDVZ6BwoF32uLa2ptdVj6jXtqb2zXNvF
vhuLfJeoplXbPa6NfteGaiLOPZXpnA27Z4fc853ucfV6m+8a3Um6mzIca91Z
urvSfXcqZ8pdtmOrGk1xDpfdU+qta6zR6DtAd8F/eaPDrQ==
            "]], 
           
           PolygonBox[{{887, 273, 874, 892, 893}, {1293, 1292, 1360, 401, 
            1290}, {881, 880, 873, 273, 884}, {1632, 548, 1641, 1626, 1627}, {
            1357, 401, 1368, 1366, 1367}, {1153, 1152, 1138, 335, 1155}, {
            1155, 335, 1156, 1277, 1278}, {1246, 1245, 1405, 430, 1404}, {785,
             234, 741, 744, 745}, {1547, 1546, 1637, 548, 1632}, {1004, 335, 
            1138, 996, 997}, {772, 771, 778, 234, 779}, {990, 989, 1010, 335, 
            1004}}]}]}, {
         EdgeForm[], 
         RGBColor[0.7071521307586457, 0.5522259884455304, 0.4033674375092946], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkD9LglEUxk/63kVoaC2EUlenPkBQ1KQEhrzO4iKEugkSUbQW+QX0C9gn
qa3NQV00eAkXB8fo93DPcPg993DPc/6ctfuNXs7MSkSe+EvMBgdmL3BOPKKL
weyHWKC/4Cn5lvJJfCv/AZvEGJ3CLaa/+GXwMERPeaf+pw7XXivvk3z8X4YP
vN/IL5M4h2qf4TVxj97AEX+m6C489lr1nLnnJ1z5/wu4T2LfGvknYoIewqrr
Diz4nJr3LsTdKyHWqFb7FX33V3jjM5zDK/eRn+bW/Jch+iqvnju/p+566/7q
8+6euuu3a+Uyv+ER+/0DOCE4Ww==
            "]], 
           PolygonBox[CompressedData["
1:eJwt1EtIVUEcx/Gj9xwLtCDTRS2KFmlhtbGCykiLMFc+oNvCC95CNxVKUt0W
2iYhC8Kgh4K9SF1kkaTRgwRtYYts3wuSglxlmzIXtej7Y36LDwxz5szMf+b/
nw3HOpra86MoSiPG7lQU7cIUptGGVrQgi/2owQd++oiRJIqGMYVpbCuIoq3Y
h2qcYexp5HAOVSyyB2eRi8Mcmusv/uWHOTTXJ3zGGP88RoqxMbagAiuw0tSe
YMxTnKB9HPVowFr2sAYlKEUHc7ajBVlc5p9L6MPVVFhDa21EGW7SdwODuIUB
/un3HJprlr63KGFsKc7T7sYF9CDRnChEUSrEqFhjf8v6bNM4gjl8wQ8spMIZ
6Cz+YCkJffr2HfO6D/qu5EXRSRxk/Z3EuAO1OIQhxtzHA4ymwh6112ZkcJQx
WTQj4zPSWUXIKwg5oFz4xZ5/4x7/3EU/BuKwRq3vXHe/mf1swioU4zpjruEi
erEdlWhFm7U6J6o8RmOXYXkc7qjFc2ruBtaod4yKtQiFjkGxZBxbpddaT986
54ByoU57xgtieol3tGcxgzdeU2sv8u0POmi3owvdcTgTnc1X9vItCWfQ7xgV
a7Vzvwzl2JuEu9EdddEeYcywz1Bn+RMLzlnl7iRe4Rme4zWm3TfpnK53DHUe
o7FPMB6HHB30nQ8555R7xViNcpShEU3W6BpXrS851wp9tp30nXINq5bLHZvO
VGebY+xtYruDXtqVSWir70AScjrtnJ5zjU64ZlQ7aeY47DvV3c47t9/rjfEd
LHoPna7RPtekarPMtVrhtyHjXNacmjvnt+YhHpnaeewtPwlvUs41q9od91nq
jkacEzO+A91Fj2tbb4beDtWEaqPGb+Ooa01v1phjUCzKIeXSf7xQpfM=
            "]], 
           
           PolygonBox[{{1282, 1281, 1316, 382, 1266}, {1452, 477, 1451, 1431, 
            1432}, {1287, 1286, 1357, 400, 1274}, {1149, 1148, 1153, 368, 
            1271}, {1274, 400, 1270, 1261, 1262}, {953, 952, 1253, 364, 
            1247}, {1271, 368, 1290, 1286, 1287}, {1416, 414, 1402, 1444, 
            1445}, {1298, 1297, 1233, 344, 1234}, {1336, 1335, 1385, 414, 
            1350}, {1309, 382, 1359, 1335, 1336}, {803, 235, 794, 806, 807}, {
            787, 786, 785, 235, 795}, {1506, 1505, 1482, 477, 1508}, {1164, 
            344, 1233, 1227, 1228}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.8414174031783144, 0.5994118669316759, 0.32443833167792385`], 
         GraphicsGroupBox[{
           
           PolygonBox[{{1028, 311, 943}, {1161, 339, 1033}, {943, 311, 938}, {
            1172, 339, 1176}, {1032, 339, 1160}, {1160, 339, 1172}}], 
           PolygonBox[CompressedData["
1:eJwt1EtIlFEYxvGvcWZqoQXeFppWFGmStsiyK1lGpSs1MBcTONJIYORQpNMi
NTCoTLJNGhgUpSvddMEMA8dFLpw2uWk0UNJ0lUK3ESvo//I9ix/Icb5z3ts5
2+qbqi97HMe5CC/SkxwnDdnYjMM4hDFE4YcPyUjBgM9x+jGGKPJZy0M1zuI6
ImhFG67iCq6hGTuwXd/Yt/8I5q/HPcPOCqIO51CrM5MVY7pizNYetlcMk8gg
mUzs8TtOEUpxHPnIwxZsxVF+cwQtiHjdmC32EBqwj7VihNCAOdZm8Q3LFhd7
1KASVShj7QTi5DAtceVkudUqF9vD9vrF2k+P+419W88eQQRwHnOcOYtjKMUQ
BuGh1kmY4u+PuI9udOEeYviAP1jDMla8bg1KVQOrxQ/WviOOabzDKIbxBi/x
Av0YQB52YjcKkYscndmlGrYoRou1nDPOqAfWiwnW3iOKca+bY0A1tFq+pgav
1MOYZs5mz2pktVri70V8shrjFjpwF53qWUgzY7PzAN14iB48Rh+e4TneYiTJ
rbHV+hIaUYkq9TykGbFZSSHGZPXIenWHHtzWHbC7sKzZsBgt1jDfNOEGWr3u
jNis7EeJ363xsGpstQ6zRxPqEEQELTrDzlrCIiYR87k9jqmmE+qR9eoJnlrs
/OYC2nETB3EAp3BaM2SzZDNgsxDU2btQoDPsrEEM4TNmkMAq5vEFC/hqe5HT
Or+7Nq+1BcVssach1efO7JRqbLUuRwVO8r8yFKIIj9CrmoSVQ7tqElEOlste
FPvcO213OwvZyGUtRzlb7hU6a0S9j+rtmlFuq8rNemy9HlLuvYplWnfF9rS9
m/WWRfTWdWoWuzV7bXr7OjSrm/h2o9edcZv1BH7rTbS3sVB3y35jvy3RrNgd
srsU1+zbTIX1xtlbF7C7hFUksJ7YNvjctYDeMHvLCtTbVPWiWLWzmlvte3RX
+nRXbA/ba01vSatmOaGzxnWXR/V2FKl3NnM2e5nEnKGZ8KgnWVqz/63obWrU
3fsP6QHPvw==
            "]], 
           
           PolygonBox[{{1022, 311, 1056, 1053, 1054}, {1168, 1167, 1056, 311, 
            1057}, {1033, 339, 1032, 1014, 1015}, {1057, 311, 1028, 1062, 
            1063}, {1185, 1184, 1176, 339, 1161}, {932, 931, 938, 311, 
            1022}}]}]}, {
         EdgeForm[], 
         RGBColor[0.912089884280828, 0.65022471070207, 0.32747864127056686`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkDFLgmEQxy/f5w0cmoqWXITAqE3sK7S1VAq56eCoSRDh3iAuNcWLQ7i4
1eISUoh+ABcJGlwicpeGpsTfcTfc+/s/79099/wvW22c1VMickBESj5bGyL7
8CkWGaGHcMb5FD2FJVgkCsRnECnDBNa89xzOOLfQ2/T+cc6j08FyWqNzKq61
r03uAt0LNkNnFdGpTZEVehe+cNcbugsT18/wkOiiK7Dtb76FH8QXegn7/l/z
Ta+vwu/Y7tc5S6//he/BfE7gwj2q10Ew76/wKDaPO3DuvWOYI3eJzgZ7t96/
BzuR7ewuspzW3AfzrN778Np3pTu7ca3/Holj9IOz5Pu/8j3oPhJ/5wnMBKv7
p/7HParXNey5Pyg=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlE1sjFEUhr/xfV/pokOiVJqa6spfGJEZ/0SrQiuRdKIMSScxYuz87EwX
ip00GtbCqrpjIxUpIrVh0bHBwnTT2WhXKvGTTkp53pyzeJIz5zv33HvP+97p
KF7JXV4WBMFJiOB4HATHIANZaCG5FgagAKtgJYyHQfAcxohPJYKgH54RJxuC
oAmKcAE+kKvAO3gPjbAzYWvuEEfsEcIP4p9wCA7CdSjDar4NUvsAthBvpucm
2AAdsMgZMr5/K/U7yKWhE7rgfGxrX8FV4m3UnCM+CxuJJ8i9Ia7BZ+ICawbg
DOThXmS1OsNH4k/+Wz2+Kmb/PMxADe5DNmFnGvacvn2DedhDz93QA70wTI/T
CVvTRlznDAuxzVCzfBHZ3VTzmvgo37phO6Rj66neszAH7dSk4C6MQI4efb6n
9l7nekmDOvWN9FgBi+T/wD9yS6H1UK9dkIUSXIJpzFKFv7AEFWqnQvNIi9eU
XENp+ZZvk/CL2t+O4iPkuuEpNU8i84C8kPfZ68w5n1GPaypt17CmGdpgPeRY
2we9cCIyz2Z8RppVjdwMHIZO2Edur3tcXi+4t7N+V3l63O+ku9XJLUQ2I81K
HpVXq5pFZB4vumfknUeseQij8BgOwH6fgWYxR49ZmIIKDNHjhu+hvUrkLsIt
uB2bptL2C1RhEMowBDeh6P6WP7cSLyfXAE2QDE1TaTsP3yM706hrLK2b/X3J
0/J2q/tNHpFXpJG0kubSvuxvU5pJu7R7UWfW2bv87emN6q0m/SzSTNpN++xS
1Lbr7LG9Td3hWmyekrd0B91FNSnXTNq9JDcRmqbSdjK2t6s3PBabB+QF1ah2
xN+C/oP0X/QfrKSZIw==
            "]], 
           PolygonBox[CompressedData["
1:eJwtzj8LQWEUx/GDyyZ3R1FWi3gLFhncImzM8mcRBhdl8gJMeAW8AqUsDEwm
shjERllI5PvkDp9+p3NO53mCxYpRtouIDif8DhEfQnDbRBJkByb6iNJ7kx/E
qIfkCGM8OHCidySfeCHoEgnAiy8zzfW/qW4XyCxyOGCPqiaSZLajXlOvsESG
3oCsWXO114aJO24oWTO1o1nvnfnDBVekrbnaS8HAlv4GU8yZzdS/eTtCXSeb
aCHObp5emPRAR4/dLhpYMJuQP5jrK8o=
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9335380108654396, 0.7038450271635991, 0.39396783368286287`], 
         GraphicsGroupBox[{
           
           PolygonBox[{{1349, 380, 1333}, {1268, 349, 1284}, {1224, 343, 
            1230}, {1276, 367, 1289}, {1151, 367, 1137}, {950, 313, 1040}, {
            1145, 349, 1086}, {1052, 343, 1163}, {1273, 367, 1151}, {1055, 
            310, 1023}, {1230, 343, 1166}, {1289, 367, 1273}, {1307, 380, 
            1258}, {1264, 367, 1276}, {1023, 310, 933}, {1163, 343, 1224}, {
            933, 310, 926}, {926, 310, 1021}, {973, 313, 950}, {1284, 349, 
            1198}, {1137, 367, 1264}, {1047, 313, 973}, {1040, 313, 1094}, {
            1198, 349, 1145}}], 
           PolygonBox[CompressedData["
1:eJwt071P01EUxvErfdGpLEpUhAqbSGJdwNeBAonSTm1QcShJNcKEkVEXhd1/
QBL9C2SnTDBTBosDsMCg7SSI0dQ3+D65z/AhN6f33nM45/76qs9Lcx0hhDyS
mOZPBUMYxnIqhI94hyU8QRVXMYi7iRDuYA3rOEfsLBqc3cIqsRr2WO9jht+e
YQGL6NIZ9KAX3ey5iPO4gF2K28F/HOMMe04jg078xZ9EPKOzb1i/dky/Lbn2
F5jHY2JTqgf7iViTahtBHq+IvfQduusDZ95jBTXkcM3/g/6XYfdqBrOuWbW3
OfvbOZTrGw4cazuHct3mjlu4h/vuyYJzKvc/9gydCuEhLnHv22RcK5Zl/TTN
TFDBdDrmUK4mWsrHHW1k+K0TddYbnqlmWyZWwg3cTMeZaXZf8BXj3DGWiDPQ
LHaJ7SDL2csosi4k44xXPUPNsoAivrPnEEf4kYo5lGsChXSMHblG1TpF7JFr
KnuP9uZwHQO4gj70YxR5xwa8J+fYqHtS8Z26+zM5tlyTalNPMu6hejnvt1L1
W08RS6LJupWKby7jN6u3O+hvQW9eb7/l3m+rZyjTm5J7pF71u3bdqbtrfluq
SbUV3Tu9Ub1V5Wx6ZnX3POs3o7fzi5n87Igz0qwa+IQ6Nl3DtmMNf6P6VnVG
Zze9d5LaHtika1btx/729M3p2zsBf+6HsA==
            "]], 
           
           PolygonBox[{{1353, 1352, 1333, 380, 1307}, {1191, 349, 1268, 1243, 
            1244}, {1178, 1177, 1094, 313, 1070}, {1128, 1127, 1086, 349, 
            1191}, {1258, 380, 1240, 1177, 1178}, {1255, 1254, 1240, 380, 
            1304}, {1070, 313, 1047, 1118, 1119}, {1304, 380, 1349, 1327, 
            1328}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9549861374500513, 0.7574653436251282, 0.46045702609515893`], 
         GraphicsGroupBox[{
           
           PolygonBox[{{1051, 307, 1020}, {1636, 515, 1551}, {1324, 412, 
            1379}, {1631, 515, 1636}, {1049, 307, 1051}, {1020, 307, 897}, {
            1551, 515, 1530}, {891, 307, 1018}, {1530, 515, 1524}, {897, 307, 
            891}, {1516, 514, 1544}, {1406, 412, 1397}, {1180, 348, 1265}, {
            1244, 348, 1191}, {1128, 348, 1079}, {1191, 348, 1128}, {1018, 
            307, 1049}, {1619, 514, 1625}}], 
           PolygonBox[CompressedData["
1:eJwtkz0vg1EYhk/a922YdPEVgrJpomrzOSiSarsgBAPxA0j4CfwKHwm/gF1N
zGrQGsqiA62lRMLGdec8w5WcPu/zce77PE3s7C3tRpxzYxDACz+e4U/BqHPr
MecinKOwxbk3dK4HGiR/wBHnQziHC5gjJwPDkIQSsXu4hCt4p+YNujh3W0zf
TuEMOpnZAX3QD1PEJiELi5oLdeup3kPMGIQQYrBAzXzUa5CWGudXaMKnelPT
DmXuUAl8jWrr1vuGnKJq+FYL/MysaZb2FWLLkIcCxMltszvr7memZR8OQq9B
WvJQgDFmpc0jeVWwXpqp2XdwCz/c/Tfi71g2z+RdwXptwCacEDuGEUgFvka1
8kBeNKAOVXkCa+SsmgZp2bRe8kheJe3t5Km8TVnvLdiGCWLjkIN8zHvatBma
VYZHKMEDfId+d7RDX6G/Q9VylDsD06ZZ2rUT2o1RSEMCBmwHtAut5LSY53Gb
oVnSJG1Fcq6hAk+2k+cW0ze9qd52FjKB15CzN9HbaKcb5qm81X9A/wXN1Ox/
5xtlVw==
            "]], 
           
           PolygonBox[{{1265, 348, 1244, 1312, 1313}, {1495, 1494, 1522, 514, 
            1516}, {1544, 514, 1619, 1593, 1594}, {1329, 1328, 1383, 412, 
            1343}, {1120, 1119, 1079, 348, 1180}, {1397, 412, 1383, 1411, 
            1412}, {1343, 412, 1324, 1301, 1302}, {1395, 1394, 1379, 412, 
            1406}}]}]}, {
         EdgeForm[], 
         RGBColor[0.9764342640346629, 0.8110856600866574, 0.5269462185074552], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtULsNwlAMdHAShGgYAIqIjo9YAFEjPg1CoqBBDAATMAlMQUdBxwR8OqQU
6ZICMgHcyS6sO/n57vycbPeLXUVEWihFPSKRNBD5AuNY5AfeBs5DkRn4Epih
puBXCAbga/AjMIHmAF6CD52z1wlMS83F/c/Aic9wtvD+E1j13A/4yf03oWXT
ZxVaHvtFaG/k3KUHrKP6qKb7M+el9vYG3tR2GgFztdlSLTv1HfPIduANGmqe
NbW7cIb7lq7NgGP3v6vdi9pubP/kPO/6BwTPL1U=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0T0zQ1EQxvG9OSeG0btizITRGQrRRSEzXuIlV2F0UfkAFCEdmvgWmOET
RE9JSyUp0GgEKXR0/ju7xW9mc292z57nTu4dbO/nRGQKEaW8yBwWUUETR2jh
DE94RBs3uMMtOujiEhdo4BA7QWQ2ERnGBvXQgMggylhAh0Of8YEeMp7VUMI8
+sz4zluP9l5TX/mZevYPPcfMruM8Wo/2LmMF68HOnsEa9Sk9J36npt+h7Tvr
7l/RZunMcX6/Ec6rBkRvgi1kqGM3WCYt30l3G0PBM9Qse363gr97CbaLZvJJ
fY8a9TQeqEeRoogJVLEabAfdpeLfZgSpZsC7zcRmZNEyLXuGmmXq/9WMNes/
ZvzmbGbVzyj6nfRuXf+Wmnnfv2HDM9PslqLtqme+U/8DAJBCjg==
            "]], 
           
           PolygonBox[{{978, 300, 981, 976, 977}, {977, 976, 1111, 332, 
            965}, {860, 859, 995, 301, 852}, {1519, 511, 1514, 1487, 1488}, {
            842, 267, 784, 791, 792}, {769, 768, 777, 267, 841}, {1605, 1604, 
            1579, 511, 1543}, {966, 298, 964, 760, 761}}]}]}, {
         EdgeForm[], 
         RGBColor[1., 0.95, 0.75], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkL+OgVEQxefbz11Z0ZOtPrXOlhqN+JNQbJQqD0AjGoXKayi8gQego0ZD
JVqFqHV+J3eKyTkz98ycmVsZTf7HX2aWESlR/zZLKPyAb7CamB14yJMbeRMc
kBepD8Guc9USogC/ofsNZnP4I2dWct4A+67P0vim+gWsuUZ9T+IOv4ILYguf
gmXvlWfHveSp/bTnPo3eqrfgbddI2/D58rm4r/aa+vxViPdovnbckN/gxxBv
1u1/YM//R/909T23IXprhxO4JN/BZyH2a84rxDdpzuDaNdJm7qv7PsvqKvA=

            "]], 
           
           PolygonBox[{{1491, 478, 445, 1458}, {1465, 446, 480, 1492}, {1520, 
            512, 478, 1491}, {1492, 480, 513, 1515}, {1458, 445, 446, 1465}, {
            978, 299, 266, 840}, {839, 266, 299, 761}, {1545, 513, 480, 
            1517}, {1398, 446, 445, 1407}, {1515, 513, 512, 1520}, {1587, 512,
             513, 1613}, {1519, 478, 512, 1543}, {1469, 480, 446, 1442}, {
            1438, 445, 478, 1457}}]}]}}, {{}, 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[{800, 792, 842, 852, 860, 846, 800}], 
           LineBox[{841, 840, 978, 977, 965, 966, 761, 839, 734, 769, 841}], 
           LineBox[{1257, 1239, 1303, 1344, 1330, 1306, 1257}], 
           
           LineBox[{1407, 1396, 1438, 1457, 1488, 1519, 1543, 1605, 1587, 
            1613, 1595, 1545, 1517, 1496, 1469, 1442, 1413, 1398, 1407}], 
           LineBox[{1458, 1465, 1492, 1515, 1520, 1491, 1458}]}, "1.2`"], 
         Annotation[#, 1.2, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{830, 964, 760, 838, 733, 768, 777, 784, 791, 799, 845, 
            859, 995, 1009, 1002, 988, 981, 976, 1111, 1108, 1101, 957, 1251, 
            1091}], 
           
           LineBox[{1120, 1071, 1179, 1259, 1308, 1354, 1340, 1313, 1265, 
            1180, 1120}], 
           LineBox[{1256, 1238, 1302, 1343, 1329, 1305, 1256}], 
           
           LineBox[{1406, 1395, 1437, 1456, 1487, 1514, 1542, 1571, 1579, 
            1604, 1586, 1612, 1594, 1544, 1516, 1495, 1468, 1441, 1412, 1397, 
            1406}]}, "1.08`"], Annotation[#, 1.08, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{829, 963, 759, 837, 732, 767, 776, 783, 790, 798, 844, 
            858, 994, 1008, 1001, 987, 980, 975, 1110, 1107, 1100, 956, 1250, 
            1090}], 
           LineBox[{897, 891, 1018, 1049, 1051, 1020, 897}], 
           
           LineBox[{1119, 1070, 1178, 1258, 1307, 1353, 1339, 1312, 1244, 
            1191, 1128, 1079, 1119}], 
           
           LineBox[{1255, 1237, 1301, 1324, 1379, 1394, 1436, 1455, 1486, 
            1513, 1541, 1570, 1578, 1603, 1585, 1611, 1593, 1619, 1625, 1631, 
            1636, 1551, 1530, 1524, 1522, 1494, 1467, 1440, 1411, 1383, 1328, 
            1304, 1255}]}, "0.96`"], Annotation[#, 0.96, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{828, 962, 758, 836, 731, 766, 775, 782, 789, 797, 843, 
            857, 993, 1007, 1000, 986, 979, 974, 1109, 1106, 1099, 955, 1249, 
            1089}], 
           LineBox[{896, 890, 1017, 1048, 1050, 1019, 896}], 
           
           LineBox[{933, 926, 1021, 1052, 1163, 1224, 1230, 1166, 1055, 1023, 
            933}], 
           
           LineBox[{973, 950, 1040, 1094, 1177, 1240, 1254, 1236, 1300, 1323, 
            1378, 1393, 1435, 1454, 1485, 1512, 1540, 1569, 1577, 1602, 1584, 
            1610, 1592, 1618, 1624, 1630, 1635, 1550, 1529, 1523, 1521, 1493, 
            1466, 1439, 1410, 1382, 1327, 1349, 1333, 1352, 1338, 1311, 1243, 
            1268, 1284, 1198, 1145, 1086, 1127, 1078, 1118, 1047, 973}], 
           LineBox[{1151, 1137, 1264, 1276, 1289, 1273, 1151}]}, "0.84`"], 
         Annotation[#, 0.84, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{827, 961, 757, 835, 730, 765, 774, 781, 788, 796, 804, 
            808, 851, 870, 865, 856, 992, 1006, 999, 985, 1136, 1150, 1272, 
            1288, 1275, 1263, 1132, 1105, 1098, 954, 1248, 1088}], 
           
           LineBox[{886, 883, 1015, 1033, 1161, 1185, 1190, 1203, 1208, 1213, 
            1218, 1223, 1229, 1165, 1054, 1022, 932, 925, 919, 913, 907, 901, 
            895, 889, 886}], 
           
           LineBox[{972, 949, 1039, 1069, 1063, 1057, 1168, 1235, 1299, 1322, 
            1377, 1392, 1433, 1453, 1484, 1511, 1509, 1507, 1538, 1558, 1563, 
            1568, 1576, 1601, 1583, 1609, 1591, 1617, 1623, 1629, 1634, 1549, 
            1528, 1500, 1473, 1446, 1417, 1400, 1409, 1381, 1326, 1348, 1332, 
            1351, 1337, 1310, 1242, 1267, 1283, 1197, 1144, 1085, 1126, 1077, 
            1117, 1046, 972}]}, "0.72`"], Annotation[#, 0.72, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{1087, 1247, 953, 1097, 1104, 1131, 1262, 1274, 1287, 1271,
             1149, 1135, 984, 998, 1005, 991, 855, 864, 869, 850, 807, 803, 
            795, 787, 780, 773, 764, 729, 834, 756, 960, 826}], 
           LineBox[CompressedData["
1:eJwl0CFLAwAQBtCbm2KQBWFFGLqiCNOiDINBGIhRhJkWVLQ6GMiWhsEwhqBB
ZMEgyIoIggxWDFosM9nEJuIPMGjdk4XHHQcHH19ur7J1mIiIEkfJiCq/jKci
mlzQ5poOD/R45JkXXjklywxnvDE5GjHPDhXa3NHnmy8+SYxFZJhimjnWWGSD
AptsU2aXCf78fvBEhyY1jtlngSJLrLNClnfZfhj5z2PWWOWAZcpk6OuhS9qe
Z5YU92633HDFJee0OKFBPTnscwAMUSpA
            "]]}, "0.6`"], Annotation[#, 0.6, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{1341, 1404, 1246, 1346, 1093, 1253, 952, 1096, 1103, 1130,
             1261, 1270, 1356, 1365, 1367, 1357, 1286, 1290, 1293, 1278, 1155,
             1153, 1148, 1134, 983, 997, 1004, 990, 854, 863, 868, 849, 806, 
            794, 749, 745, 785, 786, 779, 772, 763, 728, 833, 755, 959, 825}], 
           
           LineBox[{884, 881, 1013, 1031, 1159, 1171, 1175, 1183, 1188, 1201, 
            1206, 1211, 1216, 1221, 1227, 1233, 1297, 1320, 1375, 1390, 1431, 
            1451, 1482, 1505, 1536, 1556, 1561, 1566, 1574, 1599, 1581, 1607, 
            1589, 1615, 1621, 1627, 1632, 1547, 1526, 1498, 1471, 1444, 1402, 
            1385, 1335, 1359, 1363, 1316, 1281, 1195, 1142, 1083, 1124, 1075, 
            1115, 1044, 970, 947, 1037, 1067, 1061, 1027, 942, 937, 930, 923, 
            917, 911, 905, 899, 893, 887, 884}]}, "0.48`"], 
         Annotation[#, 0.48, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{1459, 1461, 1342, 1405, 1245, 1345, 1092, 1252, 951, 1095,
             1102, 1129, 1260, 1269, 1355, 1364, 1366, 1368, 1369, 1360, 1292,
             1277, 1156, 1146, 1010, 989, 853, 862, 867, 848, 805, 793, 748, 
            744, 741, 737, 778, 771, 762, 727, 832, 754, 958, 824}], 
           LineBox[CompressedData["
1:eJwl0D1LAgAQBuAz0yEaBBeXhtAIQhAkGhocGw3EycGhCFLIWqICp4Zocohw
aAjCJYJAAhcHW1xscm3rR9RcjzQ8cNzw3sf6wWmtk4iIfcrJiBItzvgmvRxx
wx19HhkwZMSYd6Z8MCeTitikyQl9XpjxxS/ZdESONTaoUGSPbarUadDigkva
HLHCj5xPJgy44pgdqtTIE4v59jpnl0PKNMgyc+cbq+otCizxqvfMEw/c0+OW
a7q0k/9/+wNBOyY5
            "]], 
           LineBox[{996, 982, 1133, 1147, 1152, 1138, 996}]}, "0.36`"], 
         Annotation[#, 0.36, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{1460, 1701, 1685, 1667, 1647, 1596, 1518, 1403, 1462, 
            1463, 1464, 1414, 1415, 1418, 1419, 1421, 1422, 1424, 1425, 1427, 
            1428, 1475, 1478, 1479, 1489, 1490, 1476, 1434, 1423, 1372, 1370, 
            1294, 1291, 1162, 1154, 1016, 1003, 866, 847, 809, 802, 753, 751, 
            747, 743, 740, 736, 735, 722, 770, 726, 831, 823}], 
           LineBox[CompressedData["
1:eJwNz7tKAmAYBuBfypaGwqWlpQNCSyBE0NBF1NbQ4hBimtAJgoaWsINCEQ5R
lrSIZJlhB5eGWmzqCqKLaOz4DA+8fPDC+w0lc7NLkRBCmoeeEO65o0WdS845
ocguO+TZZJ01VsiyTIppRhlkgBi/0RA+6FCjRIZ54vTx1h3CKy880aZFgwvK
lDhkmyifXSHkSDFOggkmyZCnyBHHVKhSJ6I/whi9NN06xOQ5EiSZYpUafwzb
OkOaAlWeeeeLb37o9/cCi2ywxR77FDjglDJnVLjimgY3NLnlkTb/eGM7gw==

            "]]}, "0.24`"], Annotation[#, 0.24, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{721, 723, 725, 724, 738, 739, 742, 746, 750, 752, 801, 
            810, 811, 812, 861, 877, 878, 871, 813, 816, 819, 821, 875, 902, 
            908, 914, 920, 927, 934, 939, 1024, 1058, 1064, 1034, 944, 967, 
            1041, 1112, 1072, 1121, 1080, 1139, 1192, 1285, 1317, 1371, 1387, 
            1426, 1448, 1477, 1502, 1539, 1553, 1639, 1644, 1658, 1659, 1661, 
            1662, 1663, 1665, 1678, 1679, 1681, 1682, 1697, 1698, 1699, 1700, 
            1715}], 
           
           LineBox[{1648, 1646, 1668, 1666, 1684, 1702, 1683, 1686, 1687, 
            1688, 1703, 1705, 1706, 1704, 1690, 1689, 1670, 1669, 1652, 1649, 
            1648}]}, "0.12`"], 
         Annotation[#, 0.12, "Tooltip"]& ], {}, {}}}], {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxN3Hk8lc3/P3DJLiLlOM5xDlHKkkhSocmSchJKJcoWkSWhUihSaJE1ScgW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          "]]}, {}}}, {}}}, {
    PlotLabel -> FormBox["\"Fitch 15:30 adv=0\"", TraditionalForm], 
     DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Frame -> True, FrameLabel -> {{
        FormBox["\"Latitude\"", TraditionalForm], None}, {
        FormBox["\"Longitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{6.53, 7.4}, {53.85, 54.18}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.30435631349963893`, 
              0.4106683529870936, 0.6401547550034072}}, {{0.4386215859193078, 
              0.45785423147323917`, 0.5612256491720363}}, {{
              0.5728868583389768, 0.5050401099593848, 
              0.48229654334066546`}}, {{0.7071521307586457, 
              0.5522259884455304, 0.4033674375092946}}, {{0.8414174031783144, 
              0.5994118669316759, 0.32443833167792385`}}, {{0.912089884280828,
               0.6502247107020701, 0.3274786412705669}}, {{0.9335380108654396,
               0.7038450271635992, 0.3939678336828629}}, {{0.9549861374500513,
               0.7574653436251282, 0.46045702609515893`}}, {{
              0.9764342640346629, 0.8110856600866574, 0.5269462185074552}}, {{
              1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -92.04545454545455}, {
                    Rational[
                    15, 2], -92.04545454545455}}, {{-7.5, \
-92.04545454545455}, {7.5, -92.04545454545455}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -71.5909090909091}, {
                    Rational[
                    15, 2], -71.5909090909091}}, {{-7.5, -71.5909090909091}, {
                  7.5, -71.5909090909091}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -51.13636363636363}, {
                    Rational[
                    15, 2], -51.13636363636363}}, {{-7.5, \
-51.13636363636363}, {7.5, -51.13636363636363}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -30.681818181818173`}, {
                    Rational[
                    15, 2], -30.681818181818173`}}, {{-7.5, \
-30.681818181818173`}, {7.5, -30.681818181818173`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -10.22727272727272}, {
                    Rational[
                    15, 2], -10.22727272727272}}, {{-7.5, \
-10.22727272727272}, {7.5, -10.22727272727272}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 10.227272727272748`}, {
                    Rational[15, 2], 10.227272727272748`}}, {{-7.5, 
                  10.227272727272748`}, {7.5, 10.227272727272748`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 30.6818181818182}, {
                    Rational[15, 2], 30.6818181818182}}, {{-7.5, 
                  30.6818181818182}, {7.5, 30.6818181818182}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 51.13636363636364}, {
                    Rational[15, 2], 51.13636363636364}}, {{-7.5, 
                  51.13636363636364}, {7.5, 51.13636363636364}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 71.59090909090911}, {
                    Rational[15, 2], 71.59090909090911}}, {{-7.5, 
                  71.59090909090911}, {7.5, 71.59090909090911}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 92.04545454545452}, {
                    Rational[15, 2], 92.04545454545452}}, {{-7.5, 
                  92.04545454545452}, {7.5, 92.04545454545452}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               LineBox[{{7.5, -112.5}, {7.5, 112.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.5, -71.59090909090908}, 
                    Offset[{4., 0}, {7.5, -71.59090909090908}]}, {{
                    7.5, -30.68181818181817}, 
                    Offset[{4., 0}, {7.5, -30.68181818181817}]}, {{7.5, 
                    10.227272727272739`}, 
                    Offset[{4., 0}, {7.5, 10.227272727272739`}]}, {{7.5, 
                    51.13636363636366}, 
                    Offset[{4., 0}, {7.5, 51.13636363636366}]}, {{7.5, 
                    92.04545454545452}, 
                    Offset[{4., 0}, {7.5, 92.04545454545452}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.24\"", 0.24, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -71.59090909090908}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.48\"", 0.48, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -30.68181818181817}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.72\"", 0.72, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 10.227272727272739`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.96\"", 0.96, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 51.13636363636366}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.20\"", 1.2, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 92.04545454545452}], {-1, 0.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.012996595352888107`", ",", "1.4117201566696167`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.12`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.24`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.36`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.48`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.6`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.72`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.84`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.96`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.08`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.2`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.7905020555038705`*^9, 3.7905021686832733`*^9, 3.7905022473911242`*^9, {
   3.7905024427929745`*^9, 3.7905024552412033`*^9}, 3.790502549296754*^9, 
   3.8135751048771615`*^9, 3.8135865805142317`*^9, 3.8135866383060794`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "[", "xlond03ToPlot", "]"}], ",", 
        RowBox[{"Flatten", "[", "xlatd03ToPlot", "]"}], ",", 
        RowBox[{"0.5", " ", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"fitcharea1415B", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"6.5", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "7.5"}], "&&", 
       RowBox[{"53.8", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "54.2"}]}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"XX", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6.53", ",", "7.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"53.85", ",", "54.18"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "10"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Longitude\>\"", ",", "\"\<Latitude\>\""}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Fitch 15:30 adv=0.25\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7891926883740296`*^9, 3.789192706512515*^9}, {
   3.789192838814603*^9, 3.789192881190255*^9}, {3.789192914515173*^9, 
   3.789192919379161*^9}, {3.7891929640189376`*^9, 3.789192964653288*^9}, {
   3.7891930303412685`*^9, 3.789193031172056*^9}, {3.789193178310893*^9, 
   3.7891931784495354`*^9}, {3.7891932145888805`*^9, 
   3.7891932151992598`*^9}, {3.789193317341813*^9, 3.7891933322888093`*^9}, {
   3.78919355994938*^9, 3.7891935604540243`*^9}, {3.789194581399146*^9, 
   3.7891945817820883`*^9}, {3.7891946864630933`*^9, 3.789194707541705*^9}, {
   3.789805829627242*^9, 3.7898058388326035`*^9}, {3.789805921812013*^9, 
   3.7898059235530205`*^9}, {3.7898059776089993`*^9, 3.78980603383108*^9}, 
   3.789806128712236*^9, {3.789806246139863*^9, 3.7898062465253983`*^9}, 
   3.789807046544841*^9, {3.789807388090448*^9, 3.7898073901950593`*^9}, {
   3.789813443348075*^9, 3.7898136168392515`*^9}, {3.78981375265234*^9, 
   3.7898137527682047`*^9}, {3.7898137853549557`*^9, 3.789813862301978*^9}, {
   3.789813904310199*^9, 3.7898139049429293`*^9}, {3.7898140682941294`*^9, 
   3.789814068848768*^9}, 3.7898142130008583`*^9, 3.789814569482603*^9, {
   3.7898149184411564`*^9, 3.7898149190964503`*^9}, {3.789815054050105*^9, 
   3.789815054197209*^9}, {3.789815246727021*^9, 3.7898152494776464`*^9}, {
   3.7905018642897882`*^9, 3.790501864489352*^9}, {3.7905019270047636`*^9, 
   3.7905019422972574`*^9}, {3.790502045641757*^9, 3.790502054276376*^9}, {
   3.7905022463956175`*^9, 3.790502246768867*^9}, {3.790502440570092*^9, 
   3.7905024545356026`*^9}, {3.790502548278941*^9, 3.790502548675728*^9}, {
   3.8135750935631456`*^9, 3.813575119584363*^9}, {3.813586585221041*^9, 
   3.8135865893547983`*^9}, {3.8135866281877427`*^9, 3.8135866314595985`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJw1m3lcjF0Ux0e2sla2emaGkSSELJEiF1EqCZWITGXJEgktsow9e/ZoMfak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      "], {{{
         EdgeForm[], 
         RGBColor[0.148, 0.33, 0.54], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNl1twz0cUx/f/y5966o2qSyJ1S3npVErjWpGil4dqU0FUQ1BKOxWCuMel
UxpeSokgkbi8lL65hhASptPBTK+EBJGQvmmf2hGq59vzycTDd3b37Nmz53fO
d8/ur/fMBZlfRCGEFbEQEqwtN6wxFBqGGDobuhieNQwyPGNIZfwceN7wmqGr
Ic3wguFFQzfDMNZL9rrhaWy8ahjKGun+FPncz5HvORi7b5tf8wxvxdzecGyq
7W4YQf8j5O+a3gDDQENPG48yjERHutNoJfvYkG7INYw25CAfha2h+PaS2cow
jDF8bkFKtHaRtRXxEC5Z/7e4+/epYTy+qu1vuG3fk2E2blmbEvPv0bz8fAdf
JXuZcZLp9sKfuTYeh62vbL/R1v6Q4LJ+yEcQhx7B53sZ0vFVbXLMfTxkuBxz
vZ58p76pt+FNw/eGLYYrfOssbHQndt3IY1dymUZ/KLGaSn8k8e0BJ1LhyCA4
k4p8Iv0CwzJDieFD9FLJ/WB01WbRHwKPJiPvjGww7STsFdC/Y6g2nDOcUR4M
VeC0YbfhlGEX4yxsTUK/1HDWsBcbsrWHuSpazd+m1XyjITM4x/U9V4j94Zhz
fxBzynlHONALLo6mTTaMgYuJhjeC5145/jHB9SQTXwZi4ynDdNZobgCc0j7S
n4E8m/wpX1OIp8bXjKPvWXs1ck6msHY+HJWt6zY3wXTqIufwZ8jrbfy+yW9E
bm9IaD/3aezRyfTuWduCH4n4rzjeJP6J+C+OipdjDZ9wllI4OzpPs4hPB3zU
XF/0+3A++nNG+nGONB8x7gv3wxP6CazJJEfiY1/mYzGvAzpP/+Jbb+Zy8Fmx
z6FdG/wsaKw6k8F6rVkYPIaKV17wmGv8OPi89D6w/iJ0UvArjm/5wedXBT93
qn1Lg5+pLPxWf0nwM5PFeCJzqeRDuZ8MJpGzAvTbzo5i0ojucnQzsbMYeRqc
mkK7An5n4ucwfJwKsuFeNuOVhtXoTCNebXVasuFPyNfQV1wLkS0kVtuI5zeG
BfQnMN/FzswDa/tYeynBa+Nla5NiXs9bbW48tV01XnVUZ03zM8ipOJtMfsZQ
a5OpszpfucF1xc2Z8PNL+m2yDeiNpe6KP3PgbRtHxzFejz3pqx6kB68TOkM6
63fJh/Kimqda0hxcPhP9MaxPRyafH/EdDxnrG/OI01Zylk9Mp+PDOsbSESfl
80bO5hx8nsu9Ia7Pjjmv88jFWPSkvxSOFcBJjZfQSrYzuN5sYvSn1ZQjJvvL
2roE36Nr3Ncshovb8Vnjb/E1H5vF2Bd2oJMPP9XPYB/tVx28jpcF573qxW1r
6w2Vwe8KxVtcXwH/CuGl6vx9an0F8rXB+S3dbPp7GO/Glvo6y+L6avqlof1c
yLbuH8VXb4yvY86rDeRUudnHXjoDR8ij4nAUmermPNbLrxz055C3TTG3s/aJ
nK/H9no4tAGb+cR7Ff6V4aP6Opvy7SD6Rew5Dz7vx6bulM3ID7CH9HWfaE53
SlPwO/d8cL23mdN9Jz3dP1PxYyXfuRWO3ou8DrRYeydyDjZFDvWbI7+HLga/
l6Sbx3rlUXd125toPvuJc+Je97jPK896V/0a+fn8JfK7U7xvjDxPm4hvz7jz
KynuMVT8jtGKk8fhZzHjXXCthPF2uHoSHZ2RE8wVg6XIS+BqW19tATaXw7tS
4lbGWJysIo6ljPcwJ34uY30JreSn4WUZuT/DmlLk1cydRVZG/pVr5byc/O6F
P+X016G3D1TAy07kXrVvEVzcxrz0aoLnVPXxQvA6WMv4lbjXq9y4c/MAfNOe
hdioxY72FmeLOGt6R3Vk343UMeW1nHXiZxFc3gyfL2BH679D/yL7HuRbZE++
ybbeMHrL7CLWy/FB3NEbZjJy3cuqSTHq0hb2FEf1RtB9HYe7h5kTt+oM14L/
q+h/4Hdrb9j4OpzS3NXgnGxFX3N/Ry5/EHkN1N2hdXo36c2m97TeThF734IH
8q0xtL+LY8zdxvYJ7OvNo/tUbyrZF+cbgttugGMd+KYm9n7I2uP4fQx7dcjU
L+a75EMC/mlciY373Cm6W3awpm3tSew/wH4dsTnKXvInBZ9q4VkN++jNFIcv
kivHipXedY+J2y3icTy014DD8E35Ogq3NVdFjG/iez3+P8Av5SoXbs+Kuz/7
4d85+C1+KnbN+F4d3M9G/L7LXA3teeab+JZLcPgQKIJbOiu1rBOnVfcv4mvg
e2uwV8E3Kw99OQvy8QDcUnz/iXz/jpyFAM/1RmrGn/PEQNwQZ0rgTCUxUTz+
f8PF3efdca8Riqny3RD3O7pjBz+bh/i2O8SrCX61woEW7pE/onZe6ru2cMaU
L+XjUWh/Tz1kXAmXduLvKfisb2/h+1tZl0QtqEVehG/yUW+1R3zvY9oG9qhn
/B+3rxaA
            "]], 
           PolygonBox[CompressedData["
1:eJwtkbsuRFEUhtfZ51CqNIK4PIB4A45C6fYIBpWYRDwDWlqVQqPmJcSQyGDG
GLeIUE1oTCQS359f8SXf2Wfttdf+99hydWkjRcQIFLCVRwxnEVOwjY+yuIrv
wAT+RfEpdbfwjd/AJL4IbfwRZvASHvBxevzgQ+yfxd9Z2+N7Hz7w3p6IDv8u
4Ij+Z7nPnoZzvEXNArXzcIe3qKll3tPGD+BYtXBY+Mzy/z51/Ar6wjNqVs2o
WdXzHu8m36UBv8nINXM/51/zXQnf6UleOItdWMM3c99NmSm7Wu7ZS7hUltSs
ZM5QWT7TY45eVXjBm8l301ojeY/2VqCJDxR29RjEP6k5Cb+B3uI1uZcyfUvO
VNmqpqP3KZyNMlN2mlmzK7N1/A8EdUpp
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.32192160553822113`, 0.4168414588153493, 0.6298288325270521], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNlklsVXUUxt+79xURS0FAoRITpEAVmRLjSnQhtcwUJzTRGCYpQwumsneh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            "]], 
           PolygonBox[CompressedData["
1:eJwtlEtsTVEUhs/Z5xyjkqutIiJREiZaA0OPkZBGShCvaMS9lTBo2gRzAypE
RKk3ExNqIBK9gpAwMGh6SSgt9Yj3I40+RFAmfL+/gz/3O2uvvfZaa699qwst
q5tDFEV1KEUNSRRNjaNoAdoNX0cL4UXoNlyGBvEbQhPg9Wgya1PQJvgjwbay
1ooG4DpsFaxVouXwWlQVe886+CyHluBLqAnekDiWclAuTYnPnoaWwn/xGYDL
iJ1kxOB7D9970UZ4O7ZdrO1EjfAq9kyKfeYa+DH2anKbgZ7A71EzXI/ewYfY
s4Pfo+gg3EvMwdg5nk9dk2q7iL7C5xL3Sj0qwh+wtUWOqdjHiHGC3+OoHd6P
VsAt6ADcmLr2DpRPXYNquYC2wfWJe6caVsIzE/fiN/Er4R/E6YZL6Cfcj2rg
WvQcfhtc21z0FC4nZj52z+bA09E+uFU9hu+Q0038bqBb8KzMva5Bs+GGzKwa
NsOFzL1Wz/Lw5cy1taErmWtSbTqjNnUP1Avd0WH4ATUUYud0X7OXOhf1oAou
4tOObxE9hEvYumLPQA/ch4Zi35Huahw+uWDbK747M9/l/xjwaXQy+E5OZT5D
ZymHfs7/hr2PXvWikbEeqBfacw3uwmcLvotVE3wvMcvWC/fgN4+949Ej+EXw
Xcj2MvgOdBe6o2dwBXtG4HL2z4eXJGa9mWXw6+BZ1cy+Cc5JuXWiYfV97Hy9
Eb2Vu2PvRTbl9hmfq5Fn8hP8JXivbFo7knrW1NMz8B9so5F78Ct4pjRbevOB
eLnEb38YTYS7E9+d6ldvRoNnUzEUazD4rXToPwPOpfbVHs2ibFrTDH/XfCaO
rZ6oN/8AWZmdLA==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.4640271289941491, 0.4667826970905955, 0.5462907612302766], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJw1lUtsV1UQxi/3/o+GdlMwSmLcGKLGgiaGYNRIfC00aX0UpbSKGssCF6Vo
RGktkaQ1wUdabCSxDyqGUkyjFhSN2hdIgT/VhBJbUBe600BFNz5WRv19mY/F
l2/O3HPmzMyZmXtt05a1LXmWZVOgAJUsVoAKcBbF04uy7DjcVMqy/cg74Xnr
L0Pem7JsO3s74b3om9H/Am/h2yzyCPwH32ew/TtcCx4Em0GN75JuKfs62F8F
T4AfkefgemzdhrwO3mO9vo+wvgO5H+5jfVJ+wjWLwodqMAq6wEHwVIp7N8Cb
2DeMrhF+oRTft8IbbLMBfgLcjry+CNuKXWfes/6dIvxudhwnsXsAHoPnwSnk
OfgmcAvyjfB1oBp5PXwGPggOgdNgFMxaN+v1d+ybgc/B94N65Pvg1eBR5Jtt
59K571PY+gE+AQ/LrzxiU4yr4BdZPwbW5WHvJcuHbGOX7+72+px9OAvX5RHL
WtuVfcXcAz4BH4MG0AjaFCfY5nv2e7/8OkAtnALlLPboTCv4gDvehUfgjY7x
WXhrCpt18AXiOA/KYJb1V+i/hn9yvanuJl0ng66Lss/MW6/va3i/KuS74CuL
qJfHi7Cv2tf+dtdeDzzOHb3oj8BXsa5Avwze4ZpR7agf1BeVcM76IvH9zZnn
nH/V2hLfWwWfxtZR9UYKP4ftq3Jzwfm5gn1L0C2Fz1unb2+neMvdcH8pzvWU
4uyC91zPt5XsWZ5Cpx78FSx2f8jeCvujfCT7fDlcpJgF/5WiT+RbPbzK/siv
J1PU/qvwQynesRbeAdqRX4FvcF+rv5dbfkR9muLtH0iRX+V5dxH9Ouoebiyi
n4fgN9n3PPu74G9L8U7flGI2KedHi3hvva/mxJxlvbkGm+IunEO9nXLwOrY0
/F5L0Z+q7Wr43hQ9sSZFHisu5SqPnKz0DKu1XOs5JnnB9f2z+idFP33k2dPi
ubczxdx4P0V9KOd/ueda3IObve4yut2Xb3CmAx5KsafZ90+6d9RD/+Tx3v/a
XrftfZGiBz+HPwWHkQ/DY3Af6JfdPOx3epapv7+Ex/19II+33WN5l+tQ9TgK
9iFPp+gh5aTaWJyHrtP/i44Ud03ncabbcSm+wTximfI92j/oPDQ7lgH783Ie
NT/jun8mxXxq8qyo9L06P2l7y9y/V8M9KWJ9C/6zFH7myBf9jgs+M+E7h71f
5z5M4VPZsWjGHc8jV2P2b8LnJ/19yLnd5zxrfbd76p4i/pGK5Tf4M88czR6d
PWH7dZ6HD/vNjzhXU75n0DErFs2xY75Pub4zxfy/1f8ivVGN7U7bnwH7Pe78
Ko42o9E6zSH1hHKkXtF/RHVQzuPfoLppdV31uma2Oxfaq3/CNn9v8x291rUa
kjUj9B9SDasvGry/1e+kGK9RnlLY7UvhX7vjOOM6V723+T6d/R/fozG3
            "]], 
           PolygonBox[CompressedData["
1:eJwtlFtoj2Ecx9////0/F5uz4kJuJNQa5RgiGtoYO9vmzCjUciiHQtSoETNK
MW0mO1ntwGY2subUDoa1oVy5lOOVuRDh8+33XHx6P+/zPr/n8Ht+zzulYH/W
vmgQBLsgBn95+cLzKwRhEFyBhZEgWAQ38UZogHKogDoXBIXElEADPgQ9eC10
46vosxKSIQV+0/45sDn+4M/oc4vnU3ipWGdjNUE//o9FjVAM8w/hV0Nby2Ko
x/NDc7VtwuMhDkbCKI98NIyBLsa8xnhl8Bivhxt4BdyWw9Go9WnD1xCzGlJh
LYSh5eYbOPwX/eKYOx4m8j6VmMSorTnEf0atr2KG8RX0SfI5UW42QkLExtBY
KT5XmlNztzDGZdoPwnk8i7ZMyIYcvyatbR2kwXgYx1hjYRye5/OlM8wNLafK
7Wt47yxGsemQAS9oe6LcqA/e58y7oBdfFvqxYTneAe3wCDrhOWfUzbdPMBiz
GMUqx514G33u+RjFvtMcGhve4t959pGrXuUMb6WtlWcL3MUnhZZr1ZBqqUr7
j1gOJ+B76JNNew7sxeexhhK+FUJlaGessz4BlfgcvjfxrRkO4PUwELE2fcuF
GrwacvArxBwm9ohqxNketdc43ofxKtqKolbTTfgDZ3ehBjqc3ZlynwPloj9m
td0D1/GT9DlO32NaI37Hn/9dqON7Au+z8UzYprmc7UUxp/AyZ2tTDauWZ/l8
ZEGis5pX7T+EQfyNs9zrzuruKufKfa1qXPVKWy7P9ZDk7I7qrqpGBvB02IDn
Q5qzM9JZac2q3QvOalfv2ovugO6CzvgH3u4sN9VwH3+lPeOl0Kzc+fPRmXzA
G51900/rHJ5BW5E/nwK8wNleteedeB4k4KmwBT/rLHYdbHWWE/VXTmcq1zE7
C5357pjlONPfP+1lu39XzA58s7OxdOen45Od1YLmnObsTqX7O6u7e8bZWvTP
LHZWU1q79jADX+CsdrX++fglOB21mrrorCZUG8r5IWc1rv6qyVJ8bsxqWTWv
2ldOlVuNUYMX+/l0R8t0N/z5aE/a28fQ7oru1Ab9X5ydbZ5yiKc4c9VEMr7U
WW1oDUvw//o60KY=
            "]], 
           
           PolygonBox[{{1037, 1036, 1040, 386, 1059}, {957, 956, 960, 351, 
            980}, {852, 851, 853, 312, 891}, {775, 236, 770, 777, 778}, {1035,
             351, 981, 1036, 1037}, {783, 782, 784, 272, 811}, {922, 314, 895,
             940, 941}, {833, 273, 819, 834, 835}}]}]}, {
         EdgeForm[], 
         RGBColor[0.606132652450077, 0.5167239353658417, 0.4627526899335011], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNVm1olmUYffc8zw2BiKhTc+pGRURqBdu7ra1tryaR6TBZgTT3bmt9UJM+
oPqTcx+2WrX18aeiiGbM3KYr/FPOmUFlZbrMTYPAKChISqGVuiFt1TmdI/jj
cK7787qv6zr3/TxXNT1W82iUSqV+AWLgQk4qtRAdC4Afk1RqAu1d4CagD/ZG
8CKMTcKeAhrd35lo7aTX0z4PnADGbZ8DLmLeEoxPJerLjdR/HPgL+DNHvjl2
wX1jXtuANSPgZ8A/J/J/ADwJ5GHNBPgPYDHsM4nWct18tJvR/hj2w+Bp8Clg
BvgbY7PAeQg+P1LfP8CySPPY/gI4DfwKHPP604nmcfwHIAmp1L/gs+gvxtp0
pNjyY+2/DHw80R6/gd/xeZ4H92LsZdhp2Mthz4FdFmuMc3j2VWgXws6AZ4B6
+kT/1UAH7PXgNegvgr06Vh4Z/zycod913Iszzo00xv5in5H5LsZYEbgkaB1z
xjmsZYnnMGcjjvfNRHnpSjSW65rNdz1z7Yf+JuyPY/SxFKiIpIPz1gd1cgN8
F6JvZZBfaolauzIST7ld6nOxRpXeL9/tGdeO7SrgWux1PecE+TlnPe21X9qF
ifQ3mGj9Kce4FnlMg2+LFU/aMUxbM9TO417LPeizAMhE0kaBzzHbNZoFvoj2
Cti1sWKd55zMtc2+ezD2CPUGviKSZqi/arSLwetixTztWG+JpP//85lo7lgi
PRb4LJ1e2wVeYk1Smx2OcTs467pU+twZ5zDjuFYB9R6vcns1cK/PwLV15qWe
1wb0Aq3Gtkh+XoC/EvjtBt8epLG14IqgPFcGxVPhvduBBqDR9g7vnXF/lVFp
HWzG+jvoD1xjm31ZYB3sTeBycC1QZo2Rb+Z+QZpdHtQutf7Gfe94/7gH96S2
mm2zr9zn3QysD1pbDW713WwH3xWUt5vAL6Fdiv5XYuWz0THxLIu9X71jZf56
g3I44Di22H+Z340K8E6gmu82+I1Eet6fyGeT61XiO1TqvDXYT4fPcKmmdY7l
bfh7DvwWeIH374t1H9LW8FCie7wV/DrmPYu+14LeB/rje9OO9n08c5CPRuto
Yax7wfvxZFBdWoJ81zoPT/gNbOF7GRTLq0F64LnfBT5FewD8SVDOGqyXFu/Z
Cu5xfVnnDo/zHAdd32HwexjrRN9H4F2OnTnIWsN1l2k9az8Z71PvdpvH6l07
vp0H/LY0u3bdHs9au+Wue57zX2770jtIPT6V6P0qBY8Gxf05uCtoz84gbbHe
14EPB93Br8HfA+/DPgoeBO8GjgCH3P4sqG8P5wAv2mbfN6xxpPXHgu7gkaC9
2PcVeNTzh8zdl60h9wAnXaPvfPYdrsGAtT3IPFsPjeDf/R6eifWN5LeyCHyN
31W+rw8lyu0D4JOuI+s5x/diNnir79rdsUC7JtYZ9zjWjX6XNsTSMfX8dKL8
tfmsK7wn926xJrfF+r5SVz3O4VHn9n7/t/D/ZV+i79qH4A1+X+4Efwn0wx4P
uhu8Iw8G6aTbZxvz234IPBSUy37wiP8r+H8x7n1OBPlnXKOu3ahrcGvQXVwT
tPcW1+Wsvxk/gYd9f/cHfY/5Xbox6H+L3+Fh8Ae+P31B38Ax/3PkBH23FgXd
H96jfUH6pbb5trX5bm8HH7Q+DzumIcf8rfVBje8MysFu8H/Msk0b
            "]], 
           PolygonBox[CompressedData["
1:eJwtlUlsTlEUx9/3vntpWFmYJSIqgrBQbUlIDBG0jaEWYmhCDTHEFEQiUS0f
jaLRptUaqqSmomJhrJKYQ2KeQywsCBYqMYQIfv+cu/g1v77vvHvPPffe83oV
Ls9fFkdRtBIclPLnZiKKGqAQL/JRNIOAmbABL05GUQa/DYESvBQy8SzYil8h
5hixR6EFP8WzJqiD/ZAGbaEdtIc9xGwhdjPswqfAsNjmXI0fJ6ZRcbAXKqEC
qqAa1sPghOVUhI8K+enZSLwB8vClMB13kAQPbSDFHEuYKwcK8GpvuaSgEp8H
hfgomIrfhQP4QXiAV8DcEH8Y3+itVrNgk7caqBZa4xH8SfhfNXqK34YmfDuc
xG9qzXgj3MDPextbOV3AT0ARXg+X8YshX43f7I0tof638Oveci2BUxobymKb
Q3PlU4PssH+T8aPeclFNSvHxkIVnQy7e4G2sOVCGX/OWq9ZzFc/zFjsUJnqr
gWqxXjl7e0fvqqblyhUWx5bTIfxZOD8a87nG9vau1qy1V4Z6qObF+g0mxDaG
xrrjrTbao/v4grA/mk97uS1pa9Wad+Dvk3Y2yqEe70FMP2LTIMbPcAe+89sT
OIm3wBv8EuzDP4f3dcYO4eucxT6GtXL4m7B39G4rdGPsrvAF7+vtbI2EAfgk
b7XTHdBd+ElM99je+YF34llP/B/jOe0/z17jf+C+szE0lmIUmwUZ+BAYjo+B
zNj2dJzWCh3wwTDQW87K/TSswVfBI/whrMBTznqDekQtvhy+4q3wFm90Fqtn
+u0C/MR/wHn8FXPci+3Mv8R/86xHbGv8hX+CLrG98w7/CO8Tth8Jb3si/8Cz
b85yUC6Kacb7e8tFa9La5jvbq2aYh4/wVgvVYLQPZwy/Cy+87aniW6AOX+TM
9Wwh3jnMrzOSrrvFnh+AGqiF1c5qp5qpdoO81VZ7kKn+kLTeqZ6ZwnOJKQn9
djb+1Nne6szo7EwM51XxefhnZ2dHNVKtckL/1Zjj8QREocep12WHfHS+M531
zKqQs3KfHPZTOfR2FlMe+uUnfv/HPH9jGzMR1lgTerJ689iwHvXcMfjO0C91
59QbM8J4ykG1SQ/3S3c2X/3B2d7oDNfgR0K/HgAF+AdnZ1tnRGdlmrderTH6
ePum6NtyFs6Fnu7DNyYtfDP2hG+QvkVnnZ1F3Wnd7RvOzpLO0G58RtLmVg4d
8f+voOg2
            "]], 
           
           PolygonBox[{{1031, 1030, 1035, 385, 1058}, {1214, 1213, 1181, 444, 
            1182}, {792, 791, 794, 267, 795}, {864, 299, 790, 791, 792}, {779,
             778, 781, 271, 810}, {950, 949, 952, 350, 978}, {797, 267, 764, 
            766, 767}, {830, 829, 831, 306, 883}, {828, 271, 811, 829, 830}, {
            1247, 511, 1236, 1213, 1214}, {911, 311, 891, 913, 914}, {1028, 
            350, 980, 1030, 1031}}]}]}, {
         EdgeForm[], 
         RGBColor[0.748238175906005, 0.566665173641088, 0.3792146186367255], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxFlE2IjWEUx9933ud1lY+dGRvyMZjuWFDEAllIykYzbCZT0qg7C0bpIhrd
ixkUKcUd1IQkSWJizEhTPmZh4/vrzoIiYSSzEOZa8DudvyxOv/Oe5zznOec8
532mb2xr2FIVRVEOSZC9IYpexFFUhEUM69ALcG3s+nZkJt/j4Wx4No2iAwQ4
A7fyPR/7LrhHe9rhNtmXwWP4teB/HI5ie41UkCesrYcj8Dxrrfh0wlqkDr0G
LmBtIj6L4G2dOwAXkutRs8N3yC/0YZiPPQfL+U+V5zyFvXORCejz4InY/UrI
I/Z8gJ+C7zN7I3JTPemDw4mfZWdORQroK+C34PWMwG7kDfoAHKecx8Ka4Oet
FO3MPrEL6UcWq5av+PcizejdiddjdX2BWcW02Nf5fo5+A1aQ3+gf4RX18zQc
ld3WI/qVoReTYCz9M/Yx6kmAAfs07NWwkbVT2LPwjuq6GDzfknr7I/gd/gxe
s/m8hc80Pw/gZMXMpL4vr72v5G+xq+VTn/qs2MwsSZQ7UkZmqOcZ+F39qcBO
vl+id1ie7D9InLuao0NIDrmX+H0+Tny2bK0dLmdPD/al8H7q/oPp/3tqgjuQ
azbbcHfq8TpSz2ko9hwPB5/nHstRc27zflW5WY55xbF4peB3vk8c0jzUqw9z
4BHFtNhdlh/6/uD15VTbLdltfUT3/h628H0SfRNcQ6xV+Dalfta/ucvpflth
r+bf/oOd6on1JiufOnhZ82ZztwE5h74aztJZtcHrKOuMp7ojm+WM7i7AWG+I
/Zdt6tVm2KyYBdVd1t1brZa/3VlR/rZvUPd1CT7U2f3wgt4Heyca9IbYW/IX
d4OpPg==
            "]], 
           PolygonBox[CompressedData["
1:eJwtlEtsjFEUx7/p3A8Rj5WUENIGmYVEJRIW7CwkNtLHpoyWTKk2YSEV6YOq
Nu2gKhXTF5KZtCQlQhO0JJ5di8QjWBJBKmEhKBu/f85Z/JL/nHvvmXPP+d+v
ZN/h8kNFURRVQYB5yShalIiihTAH3Q5V6Eo4ji5L2pr2bEQvg6WwHFbAb5L8
Ze0fzKLPEjsDvXAOnsZR1MMfZmEafY3YVUjDHqgmtp21emhBtxKrINcGOILO
wUXIQwH2Qq3XoFq6oBO6ocdrUm0rYRWchz7ohwswBqNeg2oZgkEYh+sQ/L4L
IIFuTlotqumZ15z2GlTLY+48y9ofeIQ+RazDa1JtL4h9Ym0a7gerUbVm4TT8
8PPq4S/0FLxHT8EA+gG88fwf0AXvZzfk0SXEBlk7CovRW2ECfRu2BKtJZ5Xj
FjoFw+ghWBPsjM5q5i+pp42cB4tsJrtiQzoF5egDsB8yUAcznl93+I6uJFYB
66HM92Q8prVGaPAcyrWNM+2cLUA62IzzPhPNZpLYa69fvegM1kvtr1W/g/VK
PahBV0MOPQkn0HfgVcJy3EOf9HyKtQXbo73voD9YTGvq4TH0ZWq8BMMwEtvM
su5xeX1HsFp0h1L0FfkDvRtuav7u5yaYz/o3fs+4B8fck/3ucXlde7RXdyhW
bzy/7pxTfUl7m8rZ6m+s1z0ur494rTkYgNXBZq3+yCsPY/OOPPQEvYlYn/ul
Sd6Btz5PebvL/aeedaCLY/PCXEjE5jGdVY7N6M/BvgXy8HN0s6+rny3orN4A
NEAjfPH3oXwR+ZbEpvUfpbHdWXfXnrvBckz4/G6gx2P7tsizo+ivwc5rv95e
jb8P9SCDXpu0t603vg5d5/3Rm6jXfWP7Fqk/emvyhLyhnvQGqynl72Mn+mPS
Zq2Z/0T/B66ctO8=
            "]], 
           PolygonBox[CompressedData["
1:eJwtzr0OwVAYxvEXFYuI0aKIQWLBJMRVEBuLWLTxcQnFgMmExFdMIlyJkcXG
TnsDEuLfOMMvz0nf5z09iUa33PGKSBh+fH0iH2iaiOUR0UkHNh648+1GZiln
kEKcCyJkQJ01/7/v7p25q8pOnxxgiBh0RBFkliR37IzY3ZNrbNBGk28WacDE
m26dnat6p/veg3rXlhxjggXdOWbqjj55onvECjX6F9LBlPOTfMFGEQWUkGPW
I/MIcU6rmdsx+Y+BFpbMKuQPoZAqrw==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.8903436993619329, 0.6166064119163343, 0.29567654733995], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkk9I02EYx39rvzp06aLEwMsisMO6dEqwSx1GUpIz/2yemswdgkVhrClW
GgMVjaE4EZF0EAgeFGfbqRXsFEQUHRZq0qFoB+3cJejz8H4PD5/v73mf53mf
5/m94eSDWOaU53ldWBCL+p5XDnjedXgWG0V/5mARi6ML8O5pzklKwWO+M/hP
4AW+2/G3wvPKtRp/FLMN7yjGYsexKDoBH2Mp9CN4RfUvwXfkN8h9D9f4HsG/
DhvUGsD/De5jg+gD2MSG0D/gsmquwpxys/A3ZwlijmAdi6HH4Gv1aTP1qQfr
pczdP/F/hDnF1+ALrB/9AaawCHrYlkjOGXKbxB9qb9/hBv40/hLs4KyA/y/+
p+g6egn+811uCzG96FX892ELtoS+4btd2E524aRmtFlr6u0TvK3dxmGbegvB
HnLeoLvhFLaHzvvuX9q8aXhZ90bgM6yKTsAZ7C16EyZV0+a2epWA6+mq5upU
v1WdTehdTcJzWBYd9t1Obbe/4Jb+3UrQ7ch2lYc7mtfewoL6sb5C6uEerGiH
Rfg16OrbPX2axWaa1ZuZhk/Uj/WV13+0/xlWbxctXvM+hC/1xubgLe3tJpxX
P9ZXUT08hyW9sWLQ7cJ2cg1+0Yw26yvVt3v+A85Tctg=
            "]], 
           PolygonBox[CompressedData["
1:eJwtk01IlFEUhm/d+6XbwMg2mljaLzigKLU0k6CiBrKayCAoF+WoYES1Kpio
sBDCICSoNrWMrHHVoly1sSBQ6W+TkZuRhIIoKp+XcxbPzPvdc++55+82nBzI
F1eGELogwWp+zq8IoQdmYgjN0ATbYDt0Yh/DVoY8ej1r9dAIG6CLtV1wHHph
K2yBTbAZfrLnB/yGP1CThbCKAJqhIbM12f7Bf5iGPHcNQ8b53X6/vtei57F/
cZ/yPQpHsR2BW+hP/l2Ab+gP0Wxa+4iuQBE9Ch34W+L7u/uU78fwCHrhBIz4
+cNwI1pOym0jNEE91HkNVIu77Dnm9z9EX4t2VvUtoT9Hs2nPAvp1NJt68A79
FB+zXu8R9CA1GoB+KGbWE/WmBXLeg0bvmXo3xpkpzs7DBLoEz9DP4Sp6J3t2
wCAMRetp2e0H0W2stUI7dMAdj1f1u43+msy3evgXXSCmbu/nAfT+ZL50595k
Ocj/JNzUrLHnNHtPwTn0EGsvsI3DIfR9t/fBA/Rl1ibc3xX0QrK7FcObZDnp
PtXsSbI12VSDMnqP5y8f3eg51RdewqtkNVVtz8BZ/SeLRTFdR1/MLBbFdAGd
gxaohXXwK9osaaYWvWbtXmPVupo9VVDB12KyM7W+JtuM918zMhvtTaiWquk+
9JzPj2bwvWbb662YFFvOZ0E9a/M3pLdU57OpOyues3IveT7ycQk9nlkvlN89
dCFZr/Tm9Pb0Bof9uwa9xuNTDwL6bTS73uwUehkAzIf2
            "]], 
           
           PolygonBox[{{1320, 578, 1364, 1328, 1329}, {1068, 411, 1107, 1066, 
            1067}, {867, 300, 796, 799, 800}, {992, 347, 977, 1008, 1009}, {
            943, 366, 933, 935, 936}, {1218, 1217, 1192, 445, 1183}, {1394, 
            613, 1409, 1391, 1392}, {1062, 1061, 1060, 375, 1041}, {1388, 
            1387, 1383, 578, 1365}, {1089, 1088, 1085, 400, 1081}, {863, 862, 
            865, 300, 866}, {1118, 1117, 1152, 451, 1150}, {881, 880, 890, 
            338, 889}, {1090, 435, 1144, 1088, 1089}}]}]}, {
         EdgeForm[], 
         RGBColor[0.9211580228143548, 0.6728950570358869, 0.3555898707244997], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkjtLQ0EQhSfuXdBSEgtFCLcJioLaqCFg0KBgkcKAr0YhrRoJNjGK/gYh
djZ2dr7+ga1gqcEH2NkJ1hb6DTPF8J3dPXt29u5N6/u1Ro+ITFOBGk5ETjMi
c/ACtqkjKsP4DArMUQfoCCcSWx+A1ShSICyFz4S1mO9nfpBxyvxUtDX15KKt
qacA7/BX0TfwxfdqRvSzntCv1CG6C+vu3w5Wqq90ndwl8tvwMdjeQEbWz83D
XaqCbsA9v+c6XHXdhMfUA7oD5/3uC4n1qr2NwhWqg64l5lP/reZ4vp5zwviS
+S24Qz+T6FawXrXna/jDmuD/TMyn/kXYdH8JjiV293Glz+v6vZ97Dr+CvcUH
HPJv3hdtv/png/eKrsCi30vv9+099OLPuqcMS+7R98/7v/FHTtHvOBP9XdEj
sOs5mqc+9f/CZX+XjWhvo3oTvgf7x97gmmdq9j/XF0P5
            "]], 
           PolygonBox[CompressedData["
1:eJwtkssrRGEYxr/jnFOs2VjNnHIZYUSxtJHLyFBKUlZuS9fcxZ4tO4V/hS1r
cldMY0OjiAX5Pb3f4nfm6T3v977P98xJJuaGZ8uccxmI4JjHEezCHryEzj3D
J3xBBuqhGbL6pWcjcO4QRtDdcILegRQ6DwOQg36Y4swkpCGBldi5ZViEJWii
Zz2wmZqd9btaoQ1qocZ7kJcDek4D27mNvoBz+YYCnOm9v5PuNhqZ101oQa+x
c9V7kJeCP/sLfzDu76MdW5F5lNd5WIAGzQjMc2NkHuW1HTrgA0o+Q2WZ4kwd
gfdADv1E7dH3qLczsuy0U7sfqN1DEV5hiNqgz1TZjsU2SzPz6Bl6pn3Gyrqc
muNdAtWxZZ72GSrLUHdi1z5Uorsi06pVoStiO6sZpcg8FL1neb8J7b/S/a/R
P/ANb/AOd6FlrZ5b9FVovcrsMrRvQt9GL/TBP/IqUF8=
            "]], 
           PolygonBox[CompressedData["
1:eJwtzzsvg2EUB/BD9Qu4LGLpIkYhbjFINFGLCgkxN2ERpTFoY7Dr1MToO7jt
JIwuswmbjYkQqfi98Qy/9//knPNc3kJle7naGRHd5JnwKSqsyBFGs2JXRKsj
Ykp+5SK+c//1rD9EwXy/fNEP60d5zQ2fZj/44cAZA2p97Fu/qj3xzJr9c/Y2
5B51rtQveWDX/K2sM2zdSL1spmZ2h2p6+6p8V3/jhAXz53LevSVm0/9MyxmO
rJdkmUWaHFLjWG9L/tKm19mD7uiRZ9l/6l/IO+4Zd88Yk+mdm/I0vaEi19ng
D4JpLp8=
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9438585856667394, 0.7296464641668485, 0.42596161556689216`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkb1KQ0EQhVfvXjCtQRCxSWEZ/ClSKESLKBIQ0UIsrMTCHzQYIUQIvoBg
oS8QfABBOxtFgoKID2AVIShY2SlBEb9hTjH5zp6dzMydza1Xlvd6QwhjREJ8
81PpCeEaZmIIp+g++Cm/C6+kzdsmRtE1+EE00G34wn/a6Hs4l4YwS5MSfOCu
iv8Lt4g8ehfOcFcip5j62fxNuC//AN5yXsKvw3nNVoZT0ub9ECn5/VYHfYN/
DAuacwI+cu6gO3BEvXKJh+kN+Kc673CYOML/Svzb7BsH8A6JO/RZ9DB9AYeU
PwnPNcMJfFbfy+i1LOcNZlPvZT0XrBb+ImwQTfQaHI/edxBmo+8wgXXtdhUW
lGO5Nfl2v6Id2i67ersQva7VL8Id7cf21NTbtaLPbfNX4ZP2b+/QUs5r9Flt
5mn4D5hSSK8=
            "]], 
           PolygonBox[CompressedData["
1:eJwtkL9KgmEUh0+95xtsaGkz6c9Wi59QkDlYgw0FDbYUuDnYEBgYSEF4A23W
BUgXELk2BA4FIV1DlOCujTX4HM47PB/Pd87753fe9frlSXNeRFZAocSnMyfS
gxq+loiswiEcwRO1Ab0RfOAL1DIwwadQxHdgC7ZtD7Uua+/hGC9R241rbO1m
ENmAPKSwqL7W9mTwsnoWy5RTP9POzsJyJBszWJYrqDDQAbTxO/a8svfLZsJH
6tkT+n94P/7bTA/4Xry/BUv4GZxCCgW4JmOVXgoXeDu4W+0F/4FvmMJv8Dfs
xfNv1O8YxPe9xcfqWSzDJ15JPLvNsI//B89imext+vw/QwPOg99ZjXnf8Tf1
WW3mRzyo92zNkP4M9zs5Bw==
            "]], 
           
           PolygonBox[{{1048, 380, 1001, 993, 994}, {1072, 1071, 1045, 380, 
            1078}, {1342, 580, 1366, 1337, 1338}, {871, 870, 868, 301, 873}, {
            815, 814, 818, 303, 874}, {1266, 1265, 1248, 479, 1241}, {1032, 
            402, 1083, 1025, 1026}, {953, 367, 946, 944, 945}, {1011, 1010, 
            997, 382, 1050}, {1138, 446, 1133, 1111, 1112}, {1298, 517, 1299, 
            1311, 1312}, {872, 301, 805, 808, 809}, {1026, 1025, 1024, 367, 
            1015}, {1354, 1353, 1368, 581, 1350}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9665591485191241, 0.7863978712978101, 0.49633336040928455`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkD9qwkEQhSfO/iBCCMRKEhQjpLBRC5HgASxSWFgJdjYmKeIfsLDwDl5A
0wcsLO2C4EVyBQubFH7DTPH43u7OvJ3d59Gk/5UTkQpSdJ9EZjci/yzy4W0v
h6b4W/jJWR3fgJVM5IWAAuyGf4NPqIpvwV9qt+gbNenfwAFcJt8bwlWcbyPX
8muwHfXWV4rMu8xzzb/CP/X+YvK7bQab6zFyz5xPInOhnmv+Xf1uu7cDH6K3
DH+Sz72DJ/V/OMKL+j/Yf6yjxmrPMYPN8oF6+LH6O23+efK17e/VZf6g/h57
SwavFu8m4w==
            "]], 
           PolygonBox[CompressedData["
1:eJwt0DFOAlEQxvGBXROQA2jsPAINBSQiCbQWHMEDLNIssfAKQEINJNJrQSU2
asISuIHb6gmwoMCC/5c3xW/z5e1k3ry5vu91k6KZXSBGnc+8YPaEK/JnZPZA
vsOS/MrZC7bYoRSH/32Uyc0zsxvU0UAHbdyihYyaNZ6x8B7q9YNfVKg5x578
55S/keMyDrPNUCVP8FEIMz96T/UeYoQEU69P/Q7ddcQ/3nnTChk2GCD1M/3L
/W7NrNnVQ71055j8FYW3awfaVcvfqh1oF1Wv1ww18lsUdqn6A/kExnI2xg==

            "]], 
           
           PolygonBox[{{967, 966, 1020, 369, 965}, {1285, 546, 1307, 1290, 
            1291}, {947, 334, 873, 877, 878}, {1197, 448, 1171, 1198, 1199}, {
            885, 302, 874, 886, 887}, {1276, 1275, 1298, 549, 1297}, {1310, 
            549, 1350, 1348, 1349}, {878, 877, 872, 302, 879}, {1339, 1338, 
            1336, 546, 1309}, {1167, 1166, 1138, 413, 1134}}]}]}, {
         EdgeForm[], 
         RGBColor[0.9892597113715087, 0.8431492784287719, 0.5667051052516769], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkDEOAWEQhWftbiUhWgmJcIstRKEmjuAAuxWOwR22FsWWCiFhxRFEgbiB
VuGb7Csm38zbNzP/bG+ezdKambWJkGjGZn2EBjwiTAKzE/xFZhH6B56pp+gl
fFA/PYd1egI8MexoTgJTzSngmHqA3oVXet7oL5gSB/I13ChfwpV2LcKqdt29
O/Vu4V4e94403/cU2ut3lPK4N9ebLzCTx99400yf/Y2qW/ymVlzd7v/gLt2/
J7pxCP8HsSjR
            "]], 
           
           PolygonBox[{{1269, 513, 480, 1244}, {1272, 516, 548, 1296}, {885, 
            336, 335, 879}, {1343, 547, 548, 1345}, {1310, 548, 516, 1297}, {
            1167, 447, 480, 1187}, {962, 335, 336, 965}, {1223, 480, 447, 
            1188}, {1296, 548, 547, 1295}, {1252, 516, 482, 1226}, {1222, 480,
             513, 1242}, {1249, 482, 516, 1272}}], 
           
           PolygonBox[{{1293, 1292, 1285, 513, 1269}, {1294, 547, 1309, 1292, 
            1293}, {1195, 1194, 1197, 482, 1224}, {1188, 447, 1168, 1194, 
            1195}}]}]}, {
         EdgeForm[], 
         RGBColor[1., 0.9499999999999998, 0.7499999999999998], 
         GraphicsGroupBox[{
           
           PolygonBox[{{514, 481, 515}, {1244, 514, 1269}, {1296, 515, 
            1272}, {1295, 515, 1296}, {1195, 481, 1188}, {1272, 515, 1249}, {
            1188, 481, 1223}, {1269, 514, 1293}, {1293, 514, 1294}, {1224, 
            481, 1195}}], 
           
           PolygonBox[{{1249, 515, 481, 1224}, {1294, 514, 515, 1295}, {1223, 
            481, 514, 1244}}]}]}}, {{}, 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{1195, 1188, 1223, 1244, 1269, 1293, 1294, 1295, 1296, 
            1272, 1249, 1224, 1195}]}, "0.77`"], 
         Annotation[#, 0.77, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[{887, 885, 879, 878, 947, 961, 962, 965, 967, 955, 887}], 
           
           LineBox[{1142, 1134, 1167, 1187, 1222, 1242, 1267, 1291, 1285, 
            1292, 1309, 1339, 1343, 1345, 1349, 1310, 1297, 1276, 1252, 1226, 
            1199, 1197, 1194, 1168, 1142}]}, "0.693`"], 
         Annotation[#, 0.693, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{815, 809, 872, 877, 873, 871, 945, 953, 1015, 1026, 1032, 
            1033, 1038, 1020, 966, 954, 886, 874, 815}], 
           
           LineBox[{1011, 994, 1048, 1073, 1078, 1072, 1112, 1138, 1166, 1186,
             1221, 1241, 1266, 1290, 1307, 1332, 1336, 1338, 1342, 1344, 1348,
             1350, 1354, 1312, 1298, 1275, 1251, 1225, 1198, 1171, 1145, 1115,
             1082, 1050, 1011}]}, "0.616`"], 
         Annotation[#, 0.616, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{814, 808, 805, 801, 868, 870, 944, 946, 1007, 1017, 1024, 
            1025, 1083, 1096, 1098, 1101, 1103, 1087, 1043, 1027, 971, 959, 
            888, 875, 822, 818, 814}], 
           
           LineBox[{1001, 991, 1045, 1071, 1111, 1133, 1163, 1184, 1219, 1248,
             1265, 1289, 1306, 1331, 1335, 1337, 1366, 1393, 1395, 1398, 1400,
             1368, 1353, 1311, 1299, 1278, 1254, 1229, 1201, 1172, 1148, 1116,
             1086, 1052, 1014, 997, 1010, 993, 1001}]}, "0.539`"], 
         Annotation[#, 0.539, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{813, 807, 804, 800, 867, 869, 866, 863, 936, 943, 1006, 
            1016, 1081, 1089, 1090, 1095, 1097, 1100, 1102, 1105, 1106, 1091, 
            1044, 1029, 974, 958, 889, 881, 827, 824, 821, 817, 813}], 
           
           LineBox[{982, 983, 984, 986, 987, 988, 989, 999, 990, 1000, 992, 
            1009, 996, 1013, 1019, 1023, 1055, 1093, 1118, 1150, 1173, 1203, 
            1228, 1253, 1277, 1300, 1313, 1357, 1369, 1402, 1401, 1399, 1397, 
            1394, 1392, 1390, 1388, 1365, 1330, 1320, 1329, 1305, 1288, 1262, 
            1240, 1218, 1183, 1162, 1137, 1109, 1069, 1068, 1067, 1065, 1062, 
            1041, 982}]}, "0.46199999999999997`"], 
         Annotation[#, 0.46199999999999997`, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{796, 793, 865, 862, 935, 933, 1004, 1005, 1080, 1084, 
            1085, 1088, 1144, 1149, 1153, 1154, 1157, 1158, 1200, 1215, 1216, 
            1202, 1164, 1165, 1170, 1151, 1114, 1094, 1047, 1034, 976, 963, 
            890, 880, 826, 823, 820, 816, 812, 806, 803, 799, 796}], 
           
           LineBox[{901, 899, 969, 979, 1039, 1057, 1060, 1061, 1064, 1066, 
            1107, 1131, 1161, 1192, 1217, 1239, 1261, 1287, 1304, 1328, 1364, 
            1381, 1383, 1387, 1389, 1391, 1409, 1431, 1435, 1437, 1440, 1441, 
            1442, 1413, 1403, 1370, 1360, 1314, 1301, 1280, 1256, 1231, 1206, 
            1174, 1152, 1117, 1092, 1054, 1022, 1018, 1012, 995, 1008, 977, 
            939, 921, 930, 918, 915, 912, 910, 908, 906, 904, 901}]}, 
          "0.385`"], Annotation[#, 0.385, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwl0TsrBXAYBvD/4biUHSWKlGIwSUq+gI1RIiEMDJJy67jkkqROHU5IKRkk
kzspYpV8AWWRQzERJX4y/HrG9+l5i9v6GnojIYRhIukh/KSFUCiLKCCfVprZ
YpNnUlRFQ6hmgEGGGGaHPfY55IhTHkjxzCtvvPPBJ188csMxy0zSQjsddNFN
D7Osc849L0QzQsilgjIqaaSdTnqIESfBEiusscUZ51xwyRXXbLPJNKM00UAp
eUR4cv+WE5JM0Uo9JWT99ePbdnccsM4uq2yTZIMEcRZZYJ45ZphignFijDHK
CP3UUUsN5eSQTSbR9P8//wLdpUNt
            "]]}, "0.308`"], Annotation[#, 0.308, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwNzrFKAgAYhdE/zYJEmiqIFpGmtnKVighCJEwCKWjxATSorTVwDgJRCIMg
EWwUWtqChqagQRfHnqAlCukMh8u33WytUanPRMQRj7MRExr02eScCy7ZIk83
GfHFCQ8sccpPImLZrrDKr/5jSugkKeZZIMMiGxTYZodd9tjngCIlDilT4Zgr
brjlnhZ9Ojxxx5BnXvhkzv80GXKUqdGkzSsffJNIRayxTpUzrmnSY8Ab74wY
8w+DAyZx
            "]], 
           
           LineBox[{1191, 1456, 1420, 1375, 1322, 1321, 1325, 1324, 1326, 
            1333, 1334, 1340, 1341, 1346, 1347, 1351, 1352, 1355, 1356, 1358, 
            1359, 1361, 1396, 1404, 1406, 1407, 1410, 1411, 1439, 1448, 1449, 
            1451, 1469, 1480, 1481, 1486, 1482, 1487, 1484, 1475, 1454, 1443, 
            1418, 1422, 1424, 1425, 1445, 1462, 1463, 1464, 1465, 1466, 1478, 
            1490, 1491, 1492, 1493, 1494, 1495}], 
           LineBox[{1181, 1180, 1212, 1235, 1236, 1213, 1181}]}, 
          "0.23099999999999998`"], 
         Annotation[#, 0.23099999999999998`, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{741, 746, 748, 747, 749, 750, 755, 756, 757, 758, 770, 
            777, 780, 782, 784, 785, 786, 787, 819, 834, 836, 839, 841, 843, 
            845, 847, 849, 851, 853, 854, 855, 859, 856, 860, 895, 940, 924, 
            948, 951, 956, 960, 964, 981, 1036, 1040, 1042, 1063, 1108, 1110, 
            1113, 1127, 1169, 1178, 1227, 1234, 1279, 1283, 1315, 1318, 1372, 
            1374, 1416, 1417, 1453, 1455, 1485}], 
           LineBox[{1488, 1460, 1459, 1457, 1458, 1419, 1421, 1376, 1377, 
            1378, 1379, 1384, 1385, 1423, 1427, 1428, 1432, 1433, 1438, 1461, 
            1467, 1471, 1472, 1489}]}, "0.154`"], 
         Annotation[#, 0.154, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{721, 722, 726, 733, 732, 731, 730, 729, 728, 727, 737, 
            738, 739, 740, 742, 743, 744, 745, 751, 752, 753, 754, 759, 762, 
            760, 765, 788, 802, 838, 876, 882, 884, 902, 968, 970, 972, 973, 
            975, 985, 1046, 1049, 1051, 1053, 1056, 1070, 1121, 1123, 1126, 
            1132, 1179, 1185, 1237, 1238, 1243, 1245, 1286, 1189}], 
           LineBox[{723, 724, 734, 735, 736, 725}]}, "0.077`"], 
         Annotation[#, 0.077, "Tooltip"]& ], {}, {}}}], {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxN3Hk8lc3/P3DJLiLlOM5xDlHKkkhSocmSchJKJcoWkSWhUihSaJE1ScgW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          "]]}, {}}}, {}}}, {
    PlotLabel -> FormBox["\"Fitch 15:30 adv=0.25\"", TraditionalForm], 
     DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Frame -> True, FrameLabel -> {{
        FormBox["\"Latitude\"", TraditionalForm], None}, {
        FormBox["\"Longitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{6.53, 7.4}, {53.85, 54.18}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.32192160553822113`, 
              0.4168414588153493, 0.6298288325270521}}, {{0.4640271289941491, 
              0.4667826970905955, 0.5462907612302766}}, {{0.6061326524500771, 
              0.5167239353658417, 0.46275268993350105`}}, {{0.748238175906005,
               0.566665173641088, 0.3792146186367255}}, {{0.8903436993619329, 
              0.6166064119163343, 0.29567654733995}}, {{0.9211580228143548, 
              0.672895057035887, 0.35558987072449977`}}, {{0.9438585856667394,
               0.7296464641668486, 0.4259616155668922}}, {{0.9665591485191241,
               0.7863978712978101, 0.49633336040928455`}}, {{
              0.9892597113715087, 0.8431492784287719, 0.5667051052516769}}, {{
              1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -92.04545454545455}, {
                    Rational[
                    15, 2], -92.04545454545455}}, {{-7.5, \
-92.04545454545455}, {7.5, -92.04545454545455}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -71.5909090909091}, {
                    Rational[
                    15, 2], -71.5909090909091}}, {{-7.5, -71.5909090909091}, {
                  7.5, -71.5909090909091}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -51.13636363636363}, {
                    Rational[
                    15, 2], -51.13636363636363}}, {{-7.5, \
-51.13636363636363}, {7.5, -51.13636363636363}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -30.681818181818187`}, {
                    Rational[
                    15, 2], -30.681818181818187`}}, {{-7.5, \
-30.681818181818187`}, {7.5, -30.681818181818187`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -10.227272727272734`}, {
                    Rational[
                    15, 2], -10.227272727272734`}}, {{-7.5, \
-10.227272727272734`}, {7.5, -10.227272727272734`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 10.22727272727272}, {
                    Rational[15, 2], 10.22727272727272}}, {{-7.5, 
                  10.22727272727272}, {7.5, 10.22727272727272}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 30.6818181818182}, {
                    Rational[15, 2], 30.6818181818182}}, {{-7.5, 
                  30.6818181818182}, {7.5, 30.6818181818182}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 51.13636363636364}, {
                    Rational[15, 2], 51.13636363636364}}, {{-7.5, 
                  51.13636363636364}, {7.5, 51.13636363636364}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 71.59090909090911}, {
                    Rational[15, 2], 71.59090909090911}}, {{-7.5, 
                  71.59090909090911}, {7.5, 71.59090909090911}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 92.04545454545455}, {
                    Rational[15, 2], 92.04545454545455}}, {{-7.5, 
                  92.04545454545455}, {7.5, 92.04545454545455}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               LineBox[{{7.5, -112.5}, {7.5, 112.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.5, -71.5909090909091}, 
                    Offset[{4., 0}, {7.5, -71.5909090909091}]}, {{
                    7.5, -30.681818181818176`}, 
                    Offset[{4., 0}, {7.5, -30.681818181818176`}]}, {{7.5, 
                    10.227272727272714`}, 
                    Offset[{4., 0}, {7.5, 10.227272727272714`}]}, {{7.5, 
                    51.13636363636364}, 
                    Offset[{4., 0}, {7.5, 51.13636363636364}]}, {{7.5, 
                    92.04545454545453}, 
                    Offset[{4., 0}, {7.5, 92.04545454545453}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.154\"", 0.154, AutoDelete -> True],
                     NumberForm[#, {
                    DirectedInfinity[1], 3}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -71.5909090909091}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.308\"", 0.308, AutoDelete -> True],
                     NumberForm[#, {
                    DirectedInfinity[1], 3}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -30.681818181818176`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox[
                    "\"0.462\"", 0.46199999999999997`, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 3}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 10.227272727272714`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.616\"", 0.616, AutoDelete -> True],
                     NumberForm[#, {
                    DirectedInfinity[1], 3}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 51.13636363636364}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.770\"", 0.77, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 3}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 92.04545454545453}], {-1, 0.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.004733977373689413`", ",", "0.8527305722236633`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.077`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.154`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.23099999999999998`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.308`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.385`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.46199999999999997`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.539`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.616`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.693`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.77`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.813575120404335*^9, 3.813586590292442*^9, 
  3.8135866327147617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "[", "xlond03ToPlot", "]"}], ",", 
        RowBox[{"Flatten", "[", "xlatd03ToPlot", "]"}], ",", 
        RowBox[{"0.5", " ", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"fitcharea1415C", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"6.5", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "7.5"}], "&&", 
       RowBox[{"53.8", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "54.2"}]}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"XX", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6.53", ",", "7.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"53.85", ",", "54.18"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "10"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Longitude\>\"", ",", "\"\<Latitude\>\""}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Fitch 15:30 adv=1\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7891926883740296`*^9, 3.789192706512515*^9}, {
   3.789192838814603*^9, 3.789192881190255*^9}, {3.789192914515173*^9, 
   3.789192919379161*^9}, {3.7891929640189376`*^9, 3.789192964653288*^9}, {
   3.7891930303412685`*^9, 3.789193031172056*^9}, {3.789193178310893*^9, 
   3.7891931784495354`*^9}, {3.7891932145888805`*^9, 
   3.7891932151992598`*^9}, {3.789193317341813*^9, 3.7891933322888093`*^9}, {
   3.78919355994938*^9, 3.7891935604540243`*^9}, {3.789194581399146*^9, 
   3.7891945817820883`*^9}, {3.7891946864630933`*^9, 3.789194707541705*^9}, {
   3.789805829627242*^9, 3.7898058388326035`*^9}, {3.789805921812013*^9, 
   3.7898059235530205`*^9}, {3.7898059776089993`*^9, 3.78980603383108*^9}, 
   3.789806128712236*^9, {3.789806246139863*^9, 3.7898062465253983`*^9}, 
   3.789807046544841*^9, {3.789807388090448*^9, 3.7898073901950593`*^9}, {
   3.789813443348075*^9, 3.7898136168392515`*^9}, {3.78981375265234*^9, 
   3.7898137527682047`*^9}, {3.7898137853549557`*^9, 3.789813862301978*^9}, {
   3.789813904310199*^9, 3.7898139049429293`*^9}, {3.7898140682941294`*^9, 
   3.789814068848768*^9}, 3.7898142130008583`*^9, 3.789814569482603*^9, {
   3.7898149184411564`*^9, 3.7898149190964503`*^9}, {3.789815054050105*^9, 
   3.789815054197209*^9}, {3.789815246727021*^9, 3.7898152494776464`*^9}, {
   3.7905018642897882`*^9, 3.790501864489352*^9}, {3.7905019270047636`*^9, 
   3.7905019422972574`*^9}, {3.790502045641757*^9, 3.790502054276376*^9}, {
   3.7905022463956175`*^9, 3.790502246768867*^9}, {3.790502440570092*^9, 
   3.7905024545356026`*^9}, {3.790502548278941*^9, 3.790502548675728*^9}, {
   3.8135750935631456`*^9, 3.81357513955066*^9}, {3.813586602226976*^9, 
   3.813586622961609*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJw1nHlcjF0Ux4cWJVSi8jwTQ0r2QlrlipI2pbQomhIqqSSULNMikSiiEA2J
bBXSJpoQSVJRWhlCSaVkKVre87z3zvuPz/dzzj13Ob977n2m53mneviv2TSS
xWIFSrJYzL/Mf9zRFGL+Od9qzvzLypr5P/OvEWat+p9ZOYTNvDA/Ipx0CPu/
JNx2BdvrCes+xfE/EeZ9/p/Rd8KV4vT///4lzJn+P/PE2zAHLP+f+eMICzz+
Z64yYanw/1k4lbDTRWyfTThdgOMtItz3HtuXEDYbxv2bEk6azGb+5VgTblvy
P3MdCOuu/5/RBsLRe/9n1mbCdedw+22EOfexf5BoPg3YP1Q0n34cP4yw3CQV
5l/BIcJc3f9ZGEs4y/F/5p0kzNr9P3POELY5/T+jC4T597A9VTT/N5jTRfP/
iePdJJwnjfPZ8ZWsL9YDt5+wkxlmiXayvlv+Z548YRbWA0uFsA3WA1eDML/k
fxYsJNz9CbMRYYT1wFtFOEkV59eOcJsxztcGwrpYDywvwtFhuP12wkI+br+H
sCbWA4okzMN6EB4lXDeE258irIH1IDxPOBjrgXWFcKUrtt8izMF64N4jHID1
ICgkXFqA+TFhZawHXpnIH+uBVUVYoPx/frhvCcthPXCbCXthPXBaCOftwvpp
E/ljPQg6CXOxHoQ/RP5YD/w/hKWwHlgDovZYDxzDDtJeA+vDjHDeSpzvtYSl
sB4EXJF/FPb3FfmnYf9gkT/WAydC5I/1gI4RzhLD+T0j8sd6QKkif6wH7i2R
vzu254r8sR5YxSJ/rAdemWg8RZhfi/xJfWgS+WM9cD6L/FVwfjsJy2E9oF+E
vbAeuIMi/1Ccb/FO4o/1gMYQ9sJ6QAqEBfU4/xRhZawHHodwANaDQF3kr4N5
jsgf64G/QOSP9cDRJVx6Cu/3JYQ5pD4YEw4m9WEl4cpeHM+CMFcK7/eYLjK/
GTifSYTlsB7QZcJemzFnERYcxP6FhJWxHrjPCAc8wXqpJlzagvXUTFgD6wG1
EeZN+58FPwjXLcP5HiSsifUglPxO6gMP51uOsDAF2ycR1sV6EE4jnPQOx5tD
uHsQ62MRYTOsB4EhYb4hzp8JYRbWg8CSsBPWA9eecNZZbHchLIX1IPQg7IX1
wPcmLOjD50sAYWVSH3YRDsB64O4lXOmA8xlOWAPrgX+IMA/rQXhUtB7ZmONF
60Hqw2nRemA9cM4RzhuF89nYTfKP9SBoJRxgirmXcOkmzMOENbAeeDI9ZDyX
/2ehImHhY1wfphHWxXrgzCWcNBLnS4dw91SsD2PCNlgPXEvC6VzMDoSlsB6E
boS5WA9cb8KCh/j+EUiYg/WAQgkHYz0IIwjXsXF+j4rGi/XASyAc54LtyaLx
7sF6uSwaL9YD9wbhrHzc/o5ovKQ+5BP2wnrgFxEuVcL5KxGNF+uBVS5aX6wH
fpVofXfi+8JbwgjrgdtEmI/1wP1AuO819v9C2AnrQdAuGh/WA29WLxmfOs6X
DuFSE7zflxPWwHrgrCYcHYnzv45wWyqOt5mwGdYDfzvh9I9YT3sJS2E98A6J
+sd6EMaL+kd4PyeL+sd6EKSJ+j+A850p6v8Cbp8n6h/rgfVI1H8z5hei/rEe
+K9F/WM9sJpE/Rvg/ftJ1D/WA6tD1D/WA7+XcPcZzH8J22A9CEf8JPqow/VD
irAcqQ+yhAOwHrgTCVcuxvWfJqyL9cCdSjgJ60GoTrgvAe/3OYSdsB5YWoQF
WA9CbcIcUh/0CXMlcT5DfhF/NZz/KMIaWA+CE4SjPbH/BcJtETj/1wnbpJLn
EcJZj7B+ignLYT1wygkHj8D5rSVcx8H79wNhhPXA+0aY74b5F2EprAfOMGEv
rAe+1G+yng9wfHnCmlgPPIpw0gBur0q4j8b7eTZhLtYDbyFhwTrMBoQ1SH1Y
Tjga64FrTrg7D/vbEnbCeuA6Ec77g/WzgTAH64G1iTAP64G1lXDbWryfAwjb
kPqwi3AW1gM/lLAy1oOAJ4qH9cA7SFj4A8c/ImovgfP5/A9pj/XAqSXMW4Hv
Cx8Jt23E/l2EzbAeOH8JZ13Cdok+Eg/rQSBHmPcB1wuacBsL13d1wjZYD0JN
wnlLcT71RfGwHoQrRPH24/xbi+Kdx/vfSRQP64HjLorXhO0+hDlYD4JAwtFY
D8I9hLv18f6NIOyE9SA8QlgQgvN5grAG1gPrLOE4rAfORcJ9b7E9nTAX64Gb
QbhUEecvm7Am1gO/gDAf64ErICyF9cB6SjgA6wG9IFx3F3MlYUTqwxvC6VgP
vHpRPKwH1qS/JN50nE81wnXLcT61CCOsB8ESwlnhuJ6sIqx8iTyPEOYVYz1x
CXcLMW8l7IT1wNpFWDAF64NHWAPrgXeEcNIGnP8EwiysB3RBNH6sB95V0fgL
sX+WaPxYD7x80fj/4faPROMn9aGMcDTWg6BaNH5nnP8G0fixHjgfCZcm4fZf
CWuS+tBNmI/1gP4QlsJ6YA0RDsZ6QOL/yP7VxjyasA3WA0uOcF4QOV8Ia2A9
CCnCSVgPLA5hFqkP0wkHYD0INQg7ieN8eg2Q+aji8yCIsC7WAyeMMN8D5zOW
sBzWgzCJMO8i1tNlwm0CXA8yCTthPfALRP0N4/5LRP1hPQheifozwvu7QdQf
1gPrk6i/fdi/k3B3Mvb/Q5iL9YBYg6S/RszShHWxHoTyhNMpnF+KsDKpD9MI
R2M9oFmE+4JxvdAi7IX1wNIjXJeL2yPCZqQ+rCSc9Rvry4owh9QHO8JxWA8C
Z8IsrAe+G+EArAfOJsLCkzjfPoRtsB64/oQF1dg/iLAm1gM3WDQeMbzfc4fI
eLAeuE8Ixxnj/FUSZmE9CJsIB4Th/LcRFvLJ8whhG6wHNEy49D3W1+hhkg+s
B9ZEwumTcX2YQlgZ64E/k3D0eswLCbOwHtASwgFYDzxTwsL7WC+rCdtgPfCd
CJf+xf25i8aD9SDwFo1HD/N2whxSH0IIxwWT3xdF48F6EEQTDsZ64B8n3FaL
+TRhLtYD6zzhyok4n6mEEdYD9xrhPHtcLzIJawSR84UwH+uBU0BYjtSHIsI8
rAfBY8J9PTheqWj8WA9o1AgLPP5pON8KhNuW4fxxCHPdsf8cwpU8nE9dwmZY
D7zlhAVFWB/WhDWxHgTOhNOHsL8nYWWsB4Ef4bgleL+HEJbCeuBEiMa7l/ze
SLj7HLafJuyF9cBNISxswPZ0wjZYD6zbhEsn4f2cTxhhPXCLCec5YX5OWIPU
h0rC/ERcP+pE88F64L4XzQfrgfVFNB+sB0GHaD5YD5xe0XwWYe4XzQfrQTgk
ms8Ocr6MxOxE6oM04co7uJ6MI2yG9cBVICzAehAoidqPxPvfQYy0n4rrw0bC
ZlgPAn/CAi7mUMK6WA/cQ4SzUrA+ThLWwHpAFwjz32F9XSOsjPXAyiYcp4Lz
95CwFNaDoJQwzxXv/2rCfaHk90bCAVgPgs+E2wqwXroIe2E9CP4QFvbjesES
J+sxiTwPEq7UxfmWI2yG9SBUJly6G+ebQxhhPQhnEM7LwfHmEdYk9UGbcNYv
rB9DwhpYD3xjwnysB74ZYWWsB5414SSsB6EdYTmsB+RMOBrrAW0gLIX1wNpI
mIf1wNtCOH0EzucVCcwcrAfWXcJ8hPNXRFgZ64H7gnDSAVxPagnLYT3wPxKO
e4j100lYCutB0Ec4ehD7i0liZmE9CMcS5hni80CZcJ8L3t/TCAdjPQhmE+4+
i/21CQdgPfCMRPZ6rJ+VhL2wHjg2hNuUyfOgyI71wOMSFjpi9iLMxXpgBYjs
p7F9N2EnrAe0n3BdDeaDIjvWgzCGcOUEnL8ThG1IfUgS2e1wPi+I7DvI+UK4
9ATe7+mEzbAeBLdE9iqsrzsiOzkvckXrj/Ug/DWKrC8H53ukFFn/pTh/4wgH
u2GmRPb9uN6ri+wXsJ4WiOwPsJ6WiOzNuF6YiewD2N9OZGfj/bpeZDfAvEVk
x3rgbxfZ9+B8h4rsWA/CSJE9H3OsyI71IDwtsvdhPaWI7FgPnHSRXQdzlsiO
9cDJE9l34fwXiexYD6xnIvs9zBWEeVgPrBrCLKwHbqPIjvUg/CCyYz0IWkV2
rAdep8iO9cDtJRyN9cDtIyyF9cAbFNmxHtBIaWIn54UkYRsWzr/JaKK/KVgf
toRtsB7QBsJ1GzD7EHbCemDtEtnP4/0eRpiL9SA8SljYhPWUSNgL64F/iXAb
jc/zWyI71gM3l3D3OszFhAOwHoRlhPvOYPsbwsFYD4JmwixSH74Q5mE9sL4T
lsJ64P0hHI31IBgmLIf1wB8lQ+rfLvL7ImFlrAeuImE+1oNAhTAH64E3nXD6
T9x+NmENUh+0CGctxPnUIayL9YCWEM4LxPoxJoywHlhmhAW3sd2SsBnWg9CW
cGU3jucg6h/nn3txDOnfCOfrFmFNnH9hPuG8fTh/JYQRzj+ninBpIdZLE2Eb
nH/USrjyH9bPD8JOOP/cAcJCffL3qrFEDzj/AjnC3SHYnyIcjPMvVCXMwvlH
cwlH1+F8LyYsh/PPNyKcpESe/whzcP55qwmnO2C7I2HNXeT3RMJ5p7B9M2GE
88/dRrj0DT4PdhC2+Ul+7yJcp4DzwyPMxfnnHCLctgbv36OEAwLJeUK4Lx7X
/0TCPJx/QTJhKXI+XCQch/PPuiLyn4zz2z2O+OP8o0HCcesxS8sSve8jz4OE
+cn4fOAQ1sT5F8wmnNeI4y8mjHD+BcsIV1L4vLYk7ITzz3MgLHTG+eYSDggh
vycS7kvC/jsI8/JwfvcSlsP5FxwknPQH6+MYYQ7Ov+A04azFmC8Q1sX5F1wh
XLqT/H5I2AbnX3BPNN5snN9Cwl44/4LHovH24vZlovHi/PMrRePF+RfWisa7
hvw9irAGzj/ro2i8OP+oVbS+OP+oQzTeSqynHtH64vzzf4nWXwXnD8kT/S3B
+bIk3O2K2Ylw8F7y/EdYCuefE0A46T62hxLm4Pzzoghn/cX+8YQRzr/gHOFK
Pbyf0wg74fwLMwm3BWP/fNF4cP45j0XjwflH5aLxvMX2GtF4cP5Z70TjUcT5
+CIaD84/r0s0nrXY/lu0PjvJ74Wi9UnAdonxJJ84/7wxhOVw/rkKhPk4/8JJ
hDVx/jkcwoIFOH/qhG3WkL8/ERZux/nTIhyA8y9cTLgvC7MB4Wicfz4irEz2
vwlhDZx/4XEFsl8N8XmQTNgM55+bTrguFOcvm3DAOXweFBFm4fwLywjHNZC/
bxDm4PwLhISzJuH9/Y0wwvnn/xL154R5mLBXMPm9cAKZbyLWw3jC0bmYacIc
nH/BdMJZv3G8uYQRzr9Qm3CdNs6vEWEvnH+Wqai/IPL7IOE4nH+Bvag/nH/k
KurvNY7vQdgM55/vLepvPM6Xv6g/nH/WLsKsNeTvTaL+cP5RGGENnH9uFOE8
nH9eDGEbnH8UR1j4HZ8PCYR5bJzf9xOJXnH+hd8Ip7vget9HWDeUPN8pkv1x
FudXlrBXAY5HEe6rx/5qhOP6sV2TMGcS+XsT4TxdvF9NCNvg/HNWExbuxvXA
iXAwzj/Hg7Aczj9/K+H0WqyXIMK6OP+sfaLxT8T786Bo/Dj//FjCLLL/T4nG
j/PPOU9Yg+z/y4QFd7EebhB2wvnn3iHc/YP8XkWYh/OPiggr4/zzSwhn2ZK/
LxE2w/lnVYnWIw7Xh1rReuD8cxpF64HzL3wvWg+cf+4nwnU0zu98ZbKfDfB5
b0CYhfPPXUmYvwfb7Qhr4vwLNhCuzMf68SbshfOPdori4fwLDhBOUsb7/4go
ni75+xLhUkfMFwhzcf656YT7TmM93CYcl4P1cF8UD+ef9UQU7xeOVy6Kh/PP
qRHFW4Tz1SyKZ4/tn0XxcP6FHaJ4J7H9pygezj/3nyheNbaPnETmi/PPlyKs
ifPPkSVcqoXzPZEwF+dfQBFm4fxzOaJ4OP9CNVE8nH/BLMKVr7Ce5hP2wvnn
LAK2+70gYZM5hX7azjnMvN980qq//eUWCun/OrTm4FdzdI+SFnd7TaHxo2N/
tIF94IuZz1xrGoX/pvrk28yR7r6yDrfPFFodnMHaARzWG5bB6aSQsupAaiTw
NNOWl4niNGrX+flGCDyvyT9YdTyNytt48UPA97WXjm5TpZGrsV3NH+DVzpS6
pRaNeO9iWyWg/1h+Uojdchq9UuReOwL2A28frI9ZRSPNiBPfDwJbdWwuCvGn
EJ0UsGFCuzlyyU9V3RZFIfEKn9HM+5r3Ema1ZkdTSHt7SvA24I93pdpmplHo
gdQ/zYNd5ig5zVz+5E0KTbjvKlsGvOnltcr5Tyg0sHnYpOG7Odo/ZerUjc0U
it08/V9Btzk6uOLIU5MWCq2ssY79CZzQzK0yaqeQ/1+76Pk95qjIcqjVP5tC
H36f7bX+YY4eSgW/yXxMoWQq7GQz2NdGOTcavaCQ01Lky7zPtC1088/5EC94
zoe51sA9K1+3ecJ6aml4X3UEvmmty5HKoFDiy8lKPr3mSLvzmNWpW5CvuxW9
qj/N0ViD5qmPZCm0atxGm+N95mivsf9vTdivozbu3bj8jzn6+u3aATlPCk3c
11PkBOyXOJcnE0ihaSuUBq7+NkdcxU3F329QSNbjzbj8X+ZIaVB+XlIEhdZ/
TEurAvvau/f7HifAeknql/wENkoNqO6+RCGVoW1NEyHetpzqgNVFFBozssmo
AXj8fqXotEcU8v7X8e4rxNvpHRIwHbitfNZaIdjrZ2Z7BT2l0IgLlc9HQ7wT
N7Y2//xAoVNzRp9m3vdoDlmoYtJFIft3u/YWAFcdCVlsNIJGDopWs58Ay9k+
ePt0FKz3vxPt1n/N0SrZ087TYf4SenHH3gOHv/RrDFOk0NldsQsC/pmjgpiV
69/D/UYz+0gta8AcGXtUrKidTqE74XphD2C9lsrI+t7WoJA5SnzGBr7aVX1t
SJNCut+XPiwCHld9utVCj0LqF9qyPfrN0a5769TOLAO9WMXfkID+vEacMvFd
QSEZmYx7M8B/yG//dyPgI/NK7Z8Bn2rackYeWHrNx97N0H62ue3yT8spFL1z
4IQktLfJSKg94Qzr7bIsuB3W56r5rqsCUwol7PbdOQ7ac87XvOm0oJDhNbex
QcBnvy8aSdtS6FPDmjTm/QEF44T5Zg4UOjrGdMlSiB+b0Ou6E/K/yEiv5jKw
ZOuaI5e4FGryn7NtNPQ3S+m55KuNFJpe1bnRFNrfbz+0MhPYb37M5Bxgi4em
0ceB82I16tWgfVO8xHN/4JEdJSdPAftueiJtA2xpvtGamb/B7p2zA70o1OE0
0mcltN95z++Yjh+Fst8+354HnNm7pWdgB4VCHeJDZkL7r1ru9o9CKLS8xins
LLBqwLrcQwcoNNqec1iGyec57axloD8DE/rWeGj/ukf8ylTga1UjrBl9rzd7
c24EsNKGti4ZaN96ITX+QziFDrZXHI8GDvwVeKgYuHfXPU1mfMfSJXP+PqOQ
nFzBcyZed1eLvepBCu2fbxU0mcnXLyujuGMUGsxWe18LPHYwd8ZgIoX26g+t
Og7xaPFp8j4XKfSvqDZ7JcT7oits5IP+ba/d34rAf4Wk2eog4K4Sdmkn8KXX
mY9WAsd83Df9HLRnXVRaTAPPHH7HM4P2p/qe3zsA953vyTVJ88A/v39R+MRr
FLq0I58fDuzpsOpAK9yfJx048fwHtP/VMj6pvphCgY0hZ8SAEw/HRCcAnwz2
c5KDeOn3FqXYwf45/vRLbxW0b33nfznyF9SXuNsnL4H/iqpLX3ezaBS/aegj
E09zg9z2AXjeujVz0FMV2uubF6iv4tDomMGrEVbQHiUdXV81hUayMuYyeoxe
hoN5D6bSaGLKmnxLsG/60qCbA8/nU08NViwE+7yz48SuLqWR95D/cR6Tn7O3
NA2Ab5z5nWoA9tNFi5yeQf0WarV9Ogz2nGynvzHraeQRsECHeb/kxRvnEDE3
GhUt2vckldkvl/UWJG+gUWpEhV4Y2A2fH2mQ3USjvyrSI/LBHpZ048im/TTa
4FbRXsrk70JHWmcUjeh1a9b8AA7MmJP+jHn/5FGq7x9Gf2WlJoXXaRShtlbe
FuZvMGvo1pQHNDLIeW21Gtg5LPSDehWNlA7KT/0InOWal/tNHOprQdydHVAv
9C08236OplB7wctp7cAlenKThuQoJCwYfZI7COeVRuGqUUoUqi1YKfYWuEHR
a48c1JvygsgdVkOQT4kJNyapUuhxQXHLY+DqQxf8tzbRiM2O2dQC/V391x+5
AeqR5e5QqY0w3/cuOhUawEl1HmzmfRHlwiClXmj/Wc9csxm4a9fEBG3o3/vF
90AV8B96cyH3rRqFLhqzxy0DXucRP2bmLApd7qvJPwWc+z3Cfc88Cl3NOL6p
HVhh366cFwsodN1zlfxSiBcw2ltGRYdCtyixByeByxNduH5w/7tdWejVBjxT
zfpe0VLYz1G7JiyB+a+WV/vuBvWy+d906RkQTy+8RylkEYVcqjWLZwOr9j5A
JxCF6tMNQzSBb033RA+h3tUaL/oWBxyi/+DnWeCbWtVuChDfxEbx2m7gME7A
m1PA4zf7r7cHdpQdt0oZ+pNK2pmqbE2hoaq669rQPsJi23Z1eB6VrTgkzeir
5uq+e/ErKVSoF1a2B3ineZ/ULUsKmSyVbX8HPLEz0LUU6mXFivPSyyF+zvHO
zBaol47ms2deBXZY4CU2DPVSuDrfTAb6G6n/QtUB6oGPfm2mFbSforSJMxvq
XcGH1Hbm/adJ7gt6WMBGPzua1aG9wo3h4loPCj2SXFz1CFhu+sKZX6Eebq3r
jL3J6N80uME5CNZv2vK9R8HO9n4QUwb1btA3yccX+tOed/ih3D0Kjb1b8MIF
/CtOLT62IZVCnfz+IOb9LcfRgTm89xQS27K3yAfY4kO5GbeUQhGZHVc9gBM7
Y24kQL1r5ol5ZwBX+1naOQG3+y87EAv9je0e848G/rPhwCmmv4gqDSvlFApt
kbXw3QnslHprRSXUt4+bv6j6gv+BoKrf4cCBDpP+MO8Pxd7bsUcT7kes4fuB
zPtM1yedsTKA+qPmpBy1FVi84frK65404s9w2Hsa+l/IWtnYKqSQ3uP3Xcx6
vfzaedoTeP2GssuHId7a+69Sgj5RyPRKWWcms57C2qXDwzA/vf17PjJ6Uz87
L16GRstl+x7YAN9Wv0zJQ716/lHosBXa71Gp8bX9RiMnTurtB9D+2X5Fzxio
V0dbpqluAv9VYZlNVsA+NrcyA8Bfg/VUKVKDRnc6lfVmg73wk+bNJwtoZH6k
VroXePXzc0hiCY0+qic0MO8/+WZs3D0S6lfxT91nc8Eu7HCteGNEo/FVl7x+
Aq+d7aB2FXjjrTGj74P/Fr+kWSErafTeRGzDHLBfHsi2T7Sl0UzrkWY9TPsj
VfvvudBoh8OIBTngv2JX7RR/qG+F2i/Wm4K9mhseuQL45Bn+pWFgrsW8r5OA
fQZ3tuaB/8yF11UNvWjk7zBfjVmP72cCK8wCafRklt85BbDfYxmErN1LI+Xh
m/JvgfM3sTf174PzpaS4pBDWp1Krxr8auLJC+yVzH2odjN1zA/j222tvpoP/
0HPTg5HAJ4UqTXXAt3aWJ/YeoFFYyqIZT6C9BCvOZlcMnA9iSrmp0H79ETvp
fnjeSt7SbxoB/tdW9aSsh3prztrrNwD+DfwgpQXAh+crppWAv0zfn2OSwM82
ZDUeA//fY7fXR6fSyNe78ZMK2NWG9W7/vU2jNB0jj8Vg1xNm294rpNFmdu05
F7DrNT/OjgC+kjFlsQ3YR/PMFL89o1HZh2f8Q0z9Cl/Y8Ogt5N/930ImH3v4
k3bYttPodYGvQRnzPt2/H//m/6VRW+61D4PMfCt35z0apNHQgIEXUw93i3eM
PTmOjcRkzitrMv2X58p84bDR9jkLS/Wh/cO/Jkv+wvPgBuPUmUVgVxq7d3oM
3D8jno7xExuG+rU6/bTJeKifLR8HaoAD499IsaD+17LyY9JZFkhg7+ByE+p3
z2jBwlpm/rGXTjDvb4WPyHd5BOeBd+IJDxUJClXdCs1g3veTSZKdPG8shV6u
2NHC6P1W0tF6o4kUet7oo+zP1N8z0qdWQ/wngR5WgUy8qhSLcXCejG5ROJcB
433uMVe/tpFGCp4RSo/BbpowYcm1f3DeOL441QLzdeu9uzkQuCv4Ww+jz+A1
dnEGwIKzMtbM+3gjxtyt0ITzxHfaz8g4aD+eb7jadg6FHHZxVrPBrrro6avt
CymEyiwnpQNrl662OaFPoVmTQ1oWwnxMXesr78D9WCEw7VYRcEizedFaiHfr
xsAept7Ur5kjozUX7tN7c44EM+tdOtZxjDaFUiwDzoYCn1ny/VKrITw/qsy6
vh94jtqEqZXGFJr6YGFtF/RX7uDu5QT1/kV1XW442IuKl74fRbORd+eJ21Ng
Pv21IxQrKTaabraGa8rsz+TZj/z02Wj1drtRTmB/v4Z9YSZwnrgYxbzfmPFi
0FMJnn9fRKl2joL4No1PjcNOwv0rarZdCtg5C6gbvZFQz/9G9JwBFjvevfTh
CjZKOKdjmATxPBe6iJc+hPuqjvX7DLAHunlE+GRRyC6dX3oN+ECM98ixcP/z
mdR7m3n/ctP42tdlzmxkHnlBkcnXenGkEx4K9/kRGb5BsF4dqbMDq8IotEcq
dS4PxnP5bGSVRiXU0/WWv7Oh/fm9lcjOl41G95zNYc7jAxIlYsvgeVHyYI1V
IfA+q3eR7BA2cs0ZfMLsl+DV6U/nw3w4Z1I6WiHeu6mXZn+B+cR/1uJWgl1i
1+B0P3geN5eMO/SC0VeLJ2+fLo1GmmpOYurBBf2djiZ3KbT9evJUFozP0sh2
eAbMZ4eHo8NtsLt3JRTeElAo7cGbzScg/ra+kdqfamE+OmVpruDP/lY07mwE
1JeD1fHfwT/uanS5A+z3K+q/ZZj92Lzj6wJrqP8+Ubkv8sF/n5GPboI0jSxW
6XpHQjzJB0dG7WPDfr22gP4F9uJVRQ8eTKaR4iPFsU+Bl5y/Vqoygo3upC/y
VQD/A4JkmUyo9wYBN4yjgeOD5KPX69Do0xy7XVfAP7ixXLgS6vcnv66NzsDP
BAuUBavYyCKtZbY6+HfG8h89sKCRkfbITfXAnkO24eZQv2cN3ZCUgv09Snff
5nq4v/5tehBZBXaHxRPQCeBKzadSo8A+TGlafz3JRqG1i/7pgP3lcbnrvt40
Wrfg3ysB8OzmzJEGwTRq+PjumBD6r3iinmMJ9Te2zvhRA9hbtxRljQdu3G/w
4QvYf88Zc/haLI12v/NOnAF8vH67fE0y7Gd0NXYH+B89UzD7PLBSqk7FTrBH
pf7epnKFRnWWGpbXwJ7euOP2zHwaRY65qEzD+DYG39O0hXqa5fU1cwXY3wiW
u7CBu1qX1epCexPp6oOt92k0Z8vZgTng/3eSV29/EYynzU/VFPwt9gaJvS6n
Ubdw3u6l4H/+HU/hZj2NJOq7ynTB/0pHbI3qRxodMpRyZvInK200/xrUY5ZC
hNVM8N+t1hU9r5dGwV8Hl1UAN6WXP9cYyUb7lqyalwT+MTm7xp+Shv2RvLqa
ma/+E47LCHk2Uvq3dhfz/mtbVVnqNmU2+uTsSq2E/hzONZiOUGGjC96Ox5j3
dw96hhQ5q7HRApvYf23A2XOVde/MZaNnix97HYH2Lb9zskYvZiMXlf6a2Uw+
xfI6F8F9P1vyYp8Q9HjYKeLvJkkK7rn6H1aNsEBDxlnK32h4Hl9059X3kRao
qX70fGPwZ187Ovsec94cnfk2Heqt7faGikvQX5Bxz8QDwLTR9YQA6M+/L89+
LfCX0XvWGUF/buuaVTKnQf27GlllC+dDmJH8kSlwHpy7oDtcAv5ukh/aTaH/
x9d0y/KAZ8vvtgyF84BCbRn3gf/QYzMyJ8B+rE08+RD4sXqq7CcYX6nvyuBi
Rh9aetuVId4UsT+uzPvBSRvrV86GejtRq2tVKXCs9aTpy+C+f/jhP51y4HA9
Z5Yj1OshC2l15v3h9IaLl9hwHuhpT9rEzKfE0WXDMJyfwUm3fhmC/eObCdRH
4Nx/y6LeAu8Y93LURai3dFVZtxH4j3WaviIaeO5MreJi4KsXQ3n+wEvDEuNX
gP+yb9WFDsA29YPuz4AbF83qXwLsoeW5wBzWZ42+v7E01Pt0D2XJG7A+cT+P
PjMD7vbwcX8B9pcZ1y2jgXU3FhZ+Y84X6ycJo9bC+Xjs+GZ98HfuoDSOr6DQ
5HO3H/wB+6cvz0tTd1PI0yBc+Al4/mlPSXGo/9crelJjYHzGC5frftVjo55C
fcNJYF9bOdWnAlj3RsQbpl54bWMl3wXef6bcdxH0f0vHJuocPB9ERIQv7gS7
zeJ1Ti7L2ejB9RMTaiDehGze4eer2chgoaI+k888jxuW8e4U6jhSLbULxjeU
7jj+NbDn5kXfwyHeb4uovJ5dFOKXRtYy9sxbuRN4PhT6NyLLOALsf8pfbJaC
+ltS6uX5F+JVlZRPPAf386xyf/GfwJnvX04+AOdJe5r8Q1fo//qcNzGuwMf8
1zlOBfuVkIY+PeAFeqndn4G/5RkodNVRKDRCWMzUq5z2vyEyJRR6VXLtIwu4
2KDz83Q3NormeV04DfEkdsdfHg5io0dP/8UZgv2F+uhINTifym40N/4Dzpfd
tEQnCfh7SlUajH/WoVGmD4/A84vLq20XwO7o5+leGcxGQeUTFitA/5xXdZJn
gAc+j5O2Bnup/+SUKTScB2GHtScDS0o5NpknsFFTafCCZcDLtuePqeVT6Lzt
s70UcPujJZnNtykUEtlxein0150mJXcc1kMrWJoeAfaVR4xZbgtppHZx5FR1
4MXOn7I2JrHRcSoh0hbmk9qy8LUU8Miz6w47gH1s2mqrTgca6SssitICVnK7
abvyHBs51L5YFwD+AUMbDTKaKBQ00e+NBtSDa+uMxz6B9bJ8Wnadef98qlAv
/V4uG2XLqxcw83Mf9om6G0ej9Y//yixn8nunZ9+DCqjWPu1m/WCXZw/r/62F
++SMrabM+GwK1yyOEGcj67vX/mwEvkxlJyfA+WYsMWXYD/jR/a4FZ1XZ8Nxq
oerLzH+ZjUWwPRt9UHy2MxjYRX3HnkfLoL4FTXu2Azii5fXxb/A8gxQHPrcD
H3toYpFjTyPTjevcP8B6sRoOPR/awkaL6naY72Py8+qYjts+Nuo8VsNj9Fh+
ttVfGc6zW/eFs3RgvsZXE3pDgCfKesYEMfm+Iy6v5wHxDLtfHgO+FL3keG0y
G0k+O11xGPj2i9qZ9fA8Ms1af8EX4Ngf27M5B2l0I/or3Qg8cDm081cL+KeI
mZxh9Dc75IL4CxoNKxhI7oTxHTrgoVTfQiOPjoNdg2Bvat89eLGTRv82Fvrd
B7uWQ2yLzx8anWr80RUM4zvVvur6D6hXa5dq/9jN3Mfzm08USrJRl4/+TTPw
/3Voe2gUnB9Rp5dungT+Wwa3pM+YxUbT+i2zzoM9aH1qyUaot94uH+WuiFkg
z22t2QugPmtGbq4bBfV+iz23pQnqvUzNmmHmffuG/etK0uUoNG6isGAMsNU1
+6tBbArJrd22Sx74SZhJpTLU+5vtchP2QvxnhWpnH0G9PL+4eiCUWY/UoMw4
4DUT/BUDwW535PGTDcCjfshoekH7vpgFK6xnUShx7JNOReCLHyT3m8P9+m21
s4YKcMJp/twwqNfiLEW7ZBif4rrd1U+BPyvMrjgL9gtLpAO0HCmUQ2faMXqN
dd1irwj1dbV7SjQN/ZWpvvz5dRIb2S6veyMB9vj0+EXHoL4FefbuFQe7DG9x
Nhd46He/PTPfmWtGL0pdT6GrQS61RrA+5U+v5jfAfdn+1najV2B/2qfWX8al
0DeJrnl2YNeem6U1FurbBMtwtw0wvsvu+j6rgQ1PKMZ5g79GmknW52gK1dU6
/9QHtnUZJ3S9TiEr2XRqJfAe/f37xkO9WrXxxP6nsF4Higs1m5zYSFrhcNA/
GJ/8R68b1E447+JeS2dA/PAFXaftNlHomcubSOZ7g8zj78UDeBTqXzR62y2w
N7v5HCkCllTdI83opTu/mgqC/VyzgH7hBDzROfbsrscUmtF6fowNcIr1E0lH
qE/1vAjvEujvmFrgfE4CPK8VPNC6DfEebH3aMAXuz5H5bRlMvB2jkvPkoT75
W8zLVwT7+Kp9x5wNaJTBW7qJsbfotk3JTmSjmXMeIFfgmNkBjskFcL/IKwo3
gfXqW/3Ju/oqhQSjxubUgj3dRHdWVBGcB+PbX82HeLpb0z5d3kqjz7EL0g+B
vVzippc+1BuTyy9MZYBXrbDzNGqmkB9bbu4xiDeq8HNJHMynuO2X5hmwT1i2
Ss6jlEY8/Zx/l4Ar218Nz2qm0cX0nBLme4rw3nMx6XAfW5dFTckELpi8t9j0
NxstVHooMIX56wmnWueK04grGRTeAPaF0eIZn1Vgv90ZvLIKxqczZC79a7QK
0siY1sHo7fbjwA9lmlBfi9w1ioB3yjTrH5moghzvp8Qx67GLL42k4H6ecyRc
VRPaq38Na18M9Uola2L6ALDsYQ3LGOCfeV0JseDvamZfc9aOjfSb5imUAmf5
im0ygecvfuKyuU+AffMX7zPcwUZzNA/eZfS4u+LxnzUb2WhZUXbrC+AbPlIK
s9bC8/CYmW3LYX3iqJ89FXD/p1SfOcaDPfCk2PUEVxq9+KaZFgz28eeLU18D
H8kyq9gM48nWlDow7RAb3T5yxeMNsx8QN/ZSChvdvWIqx6yHWu3Zd54h8DwS
YeBwHdr/zdhm2Qb3fYnWTev3QXuHfEXxEVAPjw5SOXfAXpv12UgH+M1JJ3Ye
Y0/PDtkGzJ51OvwBxHvteM564CkbnXHYm/eRqW8mCkGxZ2h04Lj93GJo7yqt
KG55lEbvTj34VwTtVV8qJ4w+QKMlyeplD8H/u9zHqcHn4PmnceNMAfhH/PFZ
cxs4VOnV61zwV3rXG94OfN9Ofz+T70MDu2TSpqognb+rA38B1w78OuiaDfc7
j8ntzPciaRc1whUu0CjvXUsyk8+U5zPODBXA85nqssAosNMl12Ms4HlBvfFU
8zSIP+/biCfXoZ57HBWzbACezk6N/9IEz1O+89Yz+eFX7v/2pJtGxcN5hjbQ
/nezjvOqGWz0zmKe2kPwXxXvsfrESHgedx5jmycBejH9/GIt3G9Nt3s/PD/K
AlHp4rNdp8L+vXf9YZu4BerZpvAHSVBo0KDmpSPEYx/5pnwT/P0XTGnhMvVo
6eGGcQYUOv3xgNU24NunHAPUoV66TtnSwnxf4mjjOD3cjEJPK5/YDwLH3zee
Ms6XQjM1pnYeAPZbKe3Ogvscb2V10ibg3Hlhp52M2ej38sPUdhiv6+2t89dD
/TtzvOn+WxjP6qrga5VQn05v1rmmBONfLK22+0AW1Lete0aegfb1oZ/1j0D9
KRx3ZEs6sM/NRfoL4H71d+qPJY3Alumblt4D/WoGvFl1HuK3O8ZUFzLfY+w2
KrKGeMnLN3yhoZ6Nm/xr2XfwL+2IXB96DuqTjF5SMtinuO2cFxBFoW0xFuIj
YDzd5/fphMD+bQjYSeWA/xzNV9vFYtlIccSzmx7AvtaBFdNSmL93vpl4Htob
x51eGw+s+W6Kpzi0r4kq2jLnPty/Ak+dvgH2klFn9NPTKKQ0b/+RUWDfq2Bh
GnmNjfrf6V/ShHg73dTVrz+k0Cxv+aFD4G8R/za+sppC2nlb36kAB9vaTcjh
02jsmdCVreDPu1LxbC3ch5ZO7SuzBO7WX5427SGNduxoLWXm98b1sfvU5zR6
9Knnww/gvP3LJ3Pe0EjOYeDvL+CA28+vTIb5+XV2Os+E8ZQVF/sc+wD6i9N7
0g/208nHQw1+0Ehm9uLgIeBv1yYGu01jo/NtLyfIgD/9QidYwgKe1/eMDpsI
fHrJ2yndumw048asNuZ7oVCN0N7oNTAe/XVFPjD+n+sbL8yCelNP55lOATvv
1CmTnvVsZB8vp0cBC+zSe8oWqaA/o9JoGejv5L931YWw3oteXTinBvZ9A3Lx
ilBfpN8fnMGs9zHtmtL5ATRKjJLPsQH+vUUzaUIWG1mUF1jOBX/pefIB/FAa
HecbdgSAPefOHXnDYzQy2Tyy1Aj4gtazbW8/Qj5/W6/SBf8Lx/tTVGF/OxQ/
yDRl/Kc9E5y4R6O7V20NhcDZhvMH8y1UUMXXSd2W4H/quMuKPbCfE+Zf+SAj
CecHfedkAfBR/99VFWBPejFiSg48/zu8Tm2yAPb6wL4zvpJG5R9uhkYz+X25
0aX5PdTrVwd3uYOdqji0OakD1stGW9wJ7O0VN7bb9dOot/JTvDXE9zFXv7lB
iY2WWMlk6AOrLrlQrA/5cM5Is8lm9BSQYFgxmkJHY4sUc6Tg/Dm5n9/IodBY
8dZbzPcwN7l/yn9CfehcHfmZ+b5pi8ID7akNNIrRiXpkDxyTfNLdG/qT2T3T
dhX4T3FOTz4Bz78f6g3SrwBP77/46NpsCk3f7jsuF/wNGyVHdSpD//JBVUvA
fm90/xcFZwodYrfcZOrNh4c/NeLcKPQpqXpHMbD856cPmhxgf/6x6bUH/4M9
0TdaVrLRlzkb2xdCvL+D5mfaQT/nPXZ+GM/sn75I6V+ObHQ01eN1N9jFusp7
ZwVSKHNpecAciBdddbdnNuxv/qfr2zYD87nnG9v92MhM20r6JfhXL3ipOwb0
tfLnldwgiPfFyd+0/CQ8/zxyiXUHf9vHLy9fukAhKuiV4lHg545l50eOpFFU
ZchECRhfzey6SduPslGry6LgDIi3ozzWalouBXU19WMu+NexzXUnwX4tvTos
vA8sXKtc8M4EzpOoAk2a+X5oERWuepeNMqxMTyDgG0kSK5++pdB6/UijevBf
0jakkQz3jzE5Z3PvAofcHJzB/QHxWgKeRzLzy2xt9R6E8Tb0Lj4A7ZP3S816
CufFdpMtQub7rcrB9o1qT2jEurfUcBmw2L6X5yPLaRQ3XTlpObDOQObbFtjv
UxK6e02Aj8e1eVzsYKMx/qlxn5j9Y/ez5xzcZ3S+rdtkBvbnifyBhi80spU+
+MccWKLJchQF543vjMzDVsCI0y/vDPqIMqmnme/Dth8dmW43Au5rN8eFMva5
syclf9ZgI62Fnw64An8z/u7IfE941/DvXub7MXYMu6oO8l/VobSE+V6sp2dG
fhrk/33DZzdP4GdOCy8GQv47Su+GM9+XuW60fvnEl40MdaJCtgGXT+7ROwDr
O6u96tdT4DutHwzdDrORl8pvsyDgWTqLptXcYaOLZVoH9gHHa0rUjLRXQZ9D
fDcPQP6vVOrkzOlmo72hWc+PgL1imbRNVB6NLpse7GC+lzIrqm38mw/7dZLX
8wPA+8s+/XDYooIuKtR4XWTWv0i6ki6k0e99CjUbgFdM4UeefEoj//P7182E
fHXsX6wnU0Wj1sKv73uB43LGJRyG9V1wfY5kLPh7N4zdcBbW98O50K2GYDce
GqNx4zvUp9iyym/M+TxtzI/7fXDeH5i0+Bz0b3Jn/rSUEbDf+KXNTyBfTzzm
GWWy4H5OV9Yy3yvFVA46qE6iUHLrx75KRQt0brri8LNxFHKfEK12Sh70Fjzv
qi88f6kvm7vGeYwFynBVzmbiZeq1n3oM8Xr3vnc8VU8j68Z8Q0mI9/rPzYbV
ChRqc6PVB2E8xS49O03gecg+6BhfCez2Vnu/GK2h0ID3ZlaQNKzv1S1WiyFf
w2e2SGwB/ythv3aLA1v4tRr7gf8z2k39JvCN67Gpm2D+x051/Wtk9rO7mxOj
57UXdZL5wJufiNNV0P6Z65rvc3azkUNco98J4PaqoqfM92KU5PlTjyCe4bws
rwumNHKqjhqxFVg9ILFDJYeNcqMuGXwC/97079VfU2gUssLQLwrs7t9dDFSh
Hq+g1nUw37f5BRqtcHsE9bw0zTQOOPQXx+pcGTxv7+7hnwCODhZzeFsN+0dt
yb8E4OKoxFcdUB+78qVXJQKX95ct3fiRRhVCi41ngN/6DmXWf6VR5qhj+5h8
fXyvxbHpgXzOq0w8D9y5ZlPcU8hnwNrxd5jv5+6k2ruN+cVG5ZUHFkcDl63Z
JrlMD54n4o0jYkdDfXG7+P003NdvTHihmgv2Q2zpUzawPyYsLJTIBj5XH6A/
2gD0a3urlfne7uv6tb+OwPOS8oKa3BnQvuD9u6h/sD6W+R8uLoH8hKvpL7nq
z0a+yw4/fwD+3x713zR3h3gfBL4FwA/EBve4hLHRr2va/cXAN+p/q8bDejcu
Pi3BfJ83K2Fx8u48Nvp4ZSiW+T7vup1dq8oOFSQRETtNEfjArehuLXjeMXOf
msJ8nxdTpvfxdTKN/tarnLkDLBez6oImrP+NlLQZzPpyz8p49kO9KlvOr/OA
8WVeeznz0SsafW09e3ghjB89OMobFaqCejx+pP0Ef6O5GoKVjTTKv5fWlg/c
aHR9YdwnGt16XeC/Ddrvtplzta6TRpd6Xv3mQPsJHhnU1D80Oi37eR/zPVvt
ohWd92C/nPd6V9UF7R9WK7DHg95btrLYzHr/pWp3/YT8FE+smn0b7AEvxG3U
rOG+aftkKU/GAlXduEiPWUuh69rHD24Gf9lUV5+1y6GeL7hrFAP9yw0djd4M
+hWnN+ymgd0cDi+fD1zy6eOrteB/1lRsTMsZCqXVle0/Dvuv5sjr3nrm+6db
oX4+4O9fkPv7AvAfV01WAfgHlPeFbj1PoY7tkW0zwJ/70UZpXjrs11Npv81h
PKXsjsSpC2G9HEyuZIP/eDvnCxqQL5OiGFYW8K9C2yjbBxSqG/DWKmH0lDr9
cCQ8D+e95iblAM+R6ihrAX/vSweVXsF8d142ingO92lXiZuTf4L9xdpPCfwP
FNr5+bkxw7ImawY3PAQ9/Li3xR/GazxPkCh7h0b8N4kxjWAPPK7+ZdkAhb72
xzcthvG9smpa5Af3SZPodXeNgLsaqt2lIP9Kwftbme8JB88NGr6H/Id+OfhO
CDxmvYZyDuT/vX1sTQvwI+uShjGw3z76nr/GfG/opv1ouSfcR+um6NxsY9rT
RTfvt8H+q67MaGfWd2ThRAU4n54c9LndAaz7NW8/8/tWga54dhfwgayoZ89p
GkU0ddAzYTx+hz6lL55Go26xpwkzgMMVPntLikM+7q2jf4B/3qQxM5j/v5G5
+fzfUjDfIIUe1kR4ftGoLr4oAf4SuxcKPeE8Ou2unT0GWGhj1/dkA6ynbvFO
aeBVBWvPf4LzqOdwbbwC8Ey53zYhe9goK9dAUg546sCGi6/hflr1LIvPBn6R
EvL83lm4Pw94Bykx42NV6EdUQj2z+RuuChw6ZedCQ2kV9NTBjTMfOGzMlClO
x+A8m7XGbxDG+/6jV7ADnFdjdv+QiAC7Q/h8zXew3mc6zj3vA/tPvUG1RzWw
HpPe+bDGwnp8Kl5fUkcj7cMpO0aBvvac14vwEMJ+yNSYsBPaP+0K6+HEq6AH
OY5VK4GTt1i7J4+F5+nYqPVR4O/mFWKr8w/OM9sF3sz45LtD1As12Wjxhwat
N2C/NLLjSok6G9m80v6hALx581X5PaoUunfR9MMv4IXuq8ZmGlEo8HKs4m1g
saBt/hzYfzJvXlcw3zdKuD18YQTMqzrntxJ4lLmsxnrgXxUbx12F/qS1uZGh
wD7lszMkgQ2kj7Kvwn3Y2N9Q6w/4d4rX/3wEPNj8eZoncApL/eU74DzL4xOq
wP/tHtnzza4UWr1X4+K/cZC/oUz3RhjPt75fssx4kLFhk+ZSChk1nOlhvt88
qC3LO7WeQonzM779BP+0mPyqxTps5PdS7dpLsN/szd20Djjwx2E9MeCoCU1i
yklQP8YlGL0C1vxi0xEC+nEtCX1cDjwY/tT/3wo22t4YlTeSWa+MmelzdsP9
NT1x70WIv6y9L85uH4X+eWyo1QVOz9jTJYT70sy7s0yY9Txzx1ljEPS3YQx9
hhmfq9W/gX+gv8S0xAl8mF+DN4+/OIZCd3S6Gssh37zeKwPSp9go9eXc707A
Gx5/vVmwl40MjErSD4J/f9Kve7EX2ehAwMk7P4DblNTvH7oHz2NLbGzuAo/8
/atCtoaNzhVuWB3P6Et6be8c0NO2hGR5bYj3e5/x9sNQj2NmZZvpASe7tBh1
wPnXclvuhyFwV3XJmrMsNsq3vfcJAfeNvj3RXQ7O+4nbJ5oAH9vTb5swi41e
T9CZbAk88HrKNukJKihCQmsdM98R3j/bPnHZaB4qD3EG+ye9lRsVYD6HDxyo
3wTcervWbMJ+WP+y6GAusGszr7/oJuyvz9IbtwK3WDc/P10K45+T4Lod+K5x
ZXMu3H8ni2/WDAE+vpM7+YaaCmp5GOoVCXzis32h4QkVVFh3p9oD5vvs6Oj4
ENgvz/sfz9kH9sbV0cHmsF9uW+348QJYmTP7xn1ZNrLcsrp7lKwFWrzCxzts
GO7bvzf7VoBdV77kxYPrKmjE2GdXzgFzfFy65mnBevgvO7UI/Ps6MySY/bLg
nmTeVsh35faRKi5sNrr+90XDJfDf+2GR3onJFCqpPJWTBfamjmNTFaZQqKC0
rr4d1ueP4rzCMD0KjefcXjgC7ntaYT/q8mkKBddqiUeAv7zDu22UFOjpjnNb
CMznaoGrbxrUxw23xccz34vO2mhRUgnslvjGZRf435LRnzwAzN13OY0P/Qct
kLUNXEKhzw4qbmMgfveMfDQK9kvhoaQPw+DP55xd32sI90NZv9cDwOH//qpq
gX2/T/hGFsRfy7mtfGk5hbS6n7kz/o9abfrmwn58eMm8yRbsSue3p1oCu/T4
8AvAvnXNCeutwP1LYzxVgQWj7vYfBj597IYG8/3u5lt8/aLFbPRYW8HFGtq3
ZN8e3QS8YXYWygF/98JHDX3A/Rwr9cnA7x6/vj4R9meCYrtMFLSXvLqz3Nya
jab4HxgYC+1vaQ6YBMN+tFFKz7QBf/uC8KI0fTYKL6r0OAn+Iydu6bGH/Wd+
NfYN439x89eKYOCUN4sdGH+Ut/VmMnDvCOFb5nviSF6f2m+4b7lu/mhlBP6K
Bc7PpTaxUXXQyA9Mfq/2FvjS69hoVcS0oDNMfK3thz7vZCM3Y56LJPjLqE/r
Z8N9YJfh449lYDfzG7yhfYSNgtZLSwmZ9YlWPWkVykajXw8rFYOd6l5+Ydst
uH+MmV04F9qfsE6eaf2GjeacePqqGHio2XXzvJ8wvtLMPFdof8hkyk5JMTZ6
E/zZPh7sOymf45dAf15oc8ZZ4JQ/vbWlVmz0zm9+8mVg0wlXly1ZqIJqp3En
RzP1yO1eekYqG/Hl/YbywL6wZGfjaujvrVdhAfN9rrlWqVSouAqKymlOewm8
6GhXsZmpCloiZ6/fABy3q28o8LYKMkiP+D4B4rmcDTraN52NjG7PPXpRzgJt
arASxL9QQePzc2y7wf/uZ/FNnG4VZJ8r1sR873l4QmaWHUWhxXk+jtvA//W6
3dwQWQqFjS593wjroXJxqVwKPO+8dFXzYu5LYaZWX4dVKDRiyeTAFPCfmfbo
8W9FNjKd1BEfALxyqdUPDbjfVbiP+LYW9B2w0S/8C5wP+o60+R7ghFy++0bQ
U5fv/LiFwLcdzuxIBF664uAODrTXPlpTp2YL9Un5RHgy2Cfb2NjNWspGSqt3
KBiD3Vt4t3RgA+zfPKqFB/aJux+3uuyF/Sm91YP5vlbaU4XVuJaNmh1/v8gF
Vhrv4SUBepJwaIl9Cu3VBFcq5wPPs69cXQPr0ZpbuGe5Nxu9vB4xdiL4f5hZ
8sTSmY0EN7tHMt8ztzipTnsXDvMfSU35APakFUHvPp+jUBPnbs9P4OUDNdsj
QG/zRl5dvwhYTePVzDvAdxo6k2bJMfXVWy/nGBspKp/KiAX7m72abXn72CjE
Q2zMSrD//F51+nUqhUKa9taNgny0jAiS33mfQjfSlb3EgM1OHrotAfXZMbQz
4wC093V5+gkBL11SWjce2rM9l1W9yGSjMZ0pWnfA7p6zes0duP+4rIpTUQE7
dWjaspWPKRS9WU5aHuIZuHNlJRspJDAao9AD/rfk09YkZrORQp7Tk73ANwNm
dtc8B/05b5q8Gvh61rY2Gu6vMZHixX+BE8MObUr5C/fTs4qOzPfLJRMVTzQM
UegIO1fuI3Db2rK/WhSNajrM1zF29wfVoeHyKmhh68DwMPCGxDVaQyo0Opt2
Yesn4H99GVME8LxW31eu0gq8NXLX9q4lNCrN2lf0C/idWOFKM2caqVhuONoH
/MxT2DpzMxuppSy1Y8azblvng8/raZTt1yslBfOrV4wpKwum0dZlowqY74s1
vBpKgteooF9/Pkk0w3q8703ytwmj0UOng9tcwf7HYP7yZUnwvNelwxEAJ7y2
Ky2E8dbW7audAny2LqdtajqNZvldH+4B7nV0rSrKpVGCSdSrSQoWKHf6JheL
FzS6uX66CQI2m8AJWv+WRtONnEp+gf+HPeIr0SYV9HFOve98YPl770YOtMB9
3O/61ifAWxIfW7bA+eCApLI7mP3R+vrqw0oVdO9w615GH/Yme6eNmgzPR1pr
03aA/7Pxd5xLOlSQ8wnFIyuARz310tyhSKHnRVObN0P7u6NXdy0eS6Eo68eW
26AeuK3WvvlXjELGzZ6FO2D/quW+sqChvxPj/tQx349H22VFx8H+bXrKPnYU
4t3JqOSNgP24bfL6XluYz9LvMj9TzaHezmur2wX8peibYyjsrxNhw7/eAk/+
FsPZEwR6KxietWIC6OfAqgHme2Qv50pxM2CFIKN+C9gPO4xPd/hD/I/Xlo8T
A/1f3/P9fBxweVhEw+MEeJ7+/G3NRCa+xF1Hz6vQfsKDh1uAR6ysPW4M+rSf
5659CFhpZM801Zds9Nlx/MLPwGmryhqfvobzaGWAFPM9d8fPyN0JXfD8HXcg
Whb6l5VwPbG+l41m65rE14G9uX/HazUpFbSDahi8BNyzsuLJBjgfdjxt62a+
n06Z7aSRu10FDau/ve4G9v1TKh3O8kC/FaeyIsA+Z+nxcQpQPwPnNBuEwPgD
EpYYfYb1Nxp1oT4O/Le9MtsSAut/2Xj8nCyoHz6j7ePGMn+v3x+1/xXzPOP/
+Jo7zNfeo8DJdaIF2hgTs2DaFTaKzjDUvwJ8xT1qRP1dNhJzNrklrwjny/I7
P59XQX3xjB7DfK8bpnvm7Nc4FcTP9dQ6BHznd9GLZwkq6P54/YfM97YozjjK
HtbjzR3v8mfAihzprt9wnoRd8dnCfJ9b3L1/Y/EPOO+tvLf9UILzc+p1n5xR
Kkg2RfeWqTLcb2MiLy0fr4K+uqU07gOWHBIuy5+rglRc92Q8A7a5f25htZYK
OqHiWPEcOHHcuPjdNirI6cSkrdKTIJ7R6lIPW9hvoa5zJYH9r8U1zAxQQY6f
jX3lgJdfzqLEYH3nVj4TMnbZ5bzYMUdV0K3pEUavIF6UWo9WMczvnMIRq9cw
vhOCGR27ElVQ8NaADDvg/wAicA0g
      "], {{{
         EdgeForm[], 
         RGBColor[0.148, 0.33, 0.54], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNmHl01dURx+/v5eXFP8QAghVFSApIcCEoGlnEkACagEVAUGgwbCJLQEAW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            "]], 
           PolygonBox[CompressedData["
1:eJwlkjkvRFEUgM+7781Mww+wFRrBWAoREcvMEDEdUUk0gihI8APUOqVQikqB
xA8QjUKEkRj7LhjbFPa18Z2c4st8Ofe+c88yxX2jXSNORKIQwKwvkueJ5MMK
vgmFeBGk8EcuL3FvER7we2e+AHf4nG/fFsAqvuaba451PAGf3P2CJH7NN0P4
MNzgl5AUi13hPWGRMX47IYLX8M0LZ69Qi98SnxSrSWvrDYls8FYWBkOGei5n
MyHrQXuJQca3GrQW7Xkcj3Jn3rMc1fgp31VyXgEn+B6U4RFI4/tQLhbTsz/Y
FquxVPul5g5nPbTiDcTeOHuHRrzJN/+AZjzDEiY8q+EZT0IC74duvM633jVH
PX7obHdawwE+zZ0Bz3Is49/EtjhLwQ8eUEOVs5rCeMy3t3UncfyceInYDi7w
J2e71RxZPBWyWWqOND4VWG36pr694+x/pDnO8JbAZh2HNnyXWI7YTHW2unPd
ve5Qd/nrrFadoc7y2NnstccjvD2wXDoTnc0/iTFf7Q==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.31339984019106276`, 0.4138465892045269, 0.6348384326033369], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNl2lslVUQhm+/e++RtvjLNWqiCC6hFJCIGPa9lVISiSaof6DQFpTForiA
ItoFECgK1JYCla2tSFQWBZFFRKQbixE3VESjYltMIC6JW9R3nKcJP977nm3m
zJmZ78y5XfJmjZ8ZxWKxvimxWFxsnXHCLGGfsFbYL+wRVgvvCG8JbwqrhA+F
N4RtwovCDmG7sAb5vcIKxl9k7QnhdeE4fAI9J5j/QKgVjgib6R8WDgkbhfeF
DfTfE1Ziz07hXeFl4SBzxuuFGuYOCA3orkOv6duELeXYsAO7d9K38eXCa3LS
1fJVjfh79ZfKZ9+Jh6vfXeNbxGUaWyi8ImxPxGKlGq8UV2juSrWrxK9qbpGw
WGhDT3vksvnIb2Nv2zdb8nmSzRKflfxgtY/H3b8Wk2qhiji9LewSXhJ2C99q
3SCtzzQbmLMYHtFYg9Ca4jK2tpLxWuZulB1TBDVj5dJzhRorxDNCLNaitdPF
T5AbVcTnEPHZhG83EkfrFwuFkmkUF4jzgsdhkng+sbNYlZADm4lVLfGqYU1H
nJ8hvgfpW7sqGYudk50F4kzhtNpjxL2EJrUzkq63ltzqkfQz3yN+FnvNfvN3
iVCc4n3TvYC8Ws+addh0ALnnOOcmbLf8WkN85kb+Pe1jrAq/7cHvVcRuHuvW
ENvVyO+F1zD2JP0a7HhaeEh+bBY/GDz+j6F7duTfyQrW7mcPw1OMTZNMk3iq
eA75U4H8bvpV9B+nv4s1lk+raFfQftRyz/Qqd74RN4qbLM8Fu2zaLK/i7uNa
/Hy9+uc1nimWSKwruVevn7oU/5Y+0UQnjX0qTk3x765V/bS4606Ne+7WImP3
2k1CN3SZTsvr05GPfxR5f6QwQriOfLC8GI1sVsztN5sb0DESPacknyb+IvKx
UUIB69uR+VJz6eKvIt9jCrKmvxCZyN3yv52t7GOyZyLf/+vI9+3G+inYm8/Y
6Iv0dMPGEnxmfvhLExc09qf4JD40X05F1vY4KrTE/H66V/fFJMktTfh5RmHr
BO4iu5MKuccK8NNo9ja5PGJaqn4d9tqd2Ewe2H1k91KfhNtgefK88HPkNvyC
P7uy92Duz0Fx39Ns3ML+hdylP0lmq/ic+Edhifky8vxpxA/12GE2/BD53Wt3
+YWErzub8HvY1pWyRzMydr6p7NfImibmFrJ2JP7IBwXMNTPfgj8aiXE97Tpk
84nrNPbK4myF9POUl//IzgVJlylFh/ljKzFcxF4L2X8R7cX4eCvxKEPe9lrC
XC33nvlqqHx9lXiI+Na454/lUSbfac+4162l+PI4telo3M9Rxj49uYftPi7D
X/Wcv5Wzb+UMHTYu5rx/852Plc451CCrRS2c0WRSEn4PJBL+7Vus21L8e7Pv
7mNxl+D34Q3Ba4PViInidnF65OvbqIcNtNMi73cXZwg5ka+3OnKOeRvvmDc9
PYQB1LP+wW1pR99k/JAjPiOM15pT4mNJ1/Fv0uNq8V2NbbZPZ/ZtZO8c9Jhf
6xlrBA3E7s7gNaGfuG/we/52cWbw2tFDfGlwG8yWseLpnPGk1U6LJ+MZnCsT
NnuqyY214tzI19nciODvx2HiZeicIQwO3r4v+PqZjN8VvG4OFw8KXtMHijN4
W3QXFwnH1H5YnBP8HTEmuI5y9OQGfzeMFd8SvEbdHHxuOvbNUv+o7S2uxs/F
Sfe1tat5A5g9G6mL5jfz4zzaVjPNf1aDzb77Oefk4O8DexvYGazeV7N2LvJW
u22N7bGBdfZusVypYZ/51FCrn3Oopfa+tfo9iffSxOBvDLOzmLlHWPtC5G9G
i4HV/fHMmS7Lf6vblwRf90Bwv+Tiw3Li0iG/nH4b30gauZ5KuzLp7SPicto2
lk7OpIFUvqN08rgzOdSDb2Y2Nq7Elo5cW4ZN9ja3/w9Fkb9hKjmLxfhu5Ivw
2Sp0VTFvMdqMn0ouOucyZMcjP4H8sTwqYsz2GsidM0CcHlymU/DvJIO8yiL2
Q8R9gsf6NnGSN4m9TXpxf/YWZwfPgaHiEPw/V0IcR+8d4mt5h10j/jXye/03
8WfmT7U/Fzfytj9s/ykSXm9PJfz/htX9CnG/hN/J/cWjqOnDxecjr0kXLK/5
X5Md9zvU7lL7T9M7eO72Ev8R+Z3/u/jy4L6+LPjb196T68i9beRNNjqHcT+M
I5cyaefiX4u5/c/6DyAB4zo=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlMdPVVEQhw/n3XvCE3VjjbqQhZqAiCBVabagYEwkLrBE4WEvYO8d3Cga
JSEhxhhL0Kix8AdYVkiTRE1UNFgTBBHBstEY9ZvMXfze++6cMnNm5pzYSEVR
uTXGrEAe6uCnMsqYetQHd6Fr8HHUANd6ylWoBh7vjNnFBjvRWDgfW4SxUjQX
Tsd2kLEDKBVuCxmTw1g2aoKHYdvB2HY0FJ6M9sJ7UDy8EtXDVagYTvZ0reyR
DofZ4zNxN6OvzIniu8eozYfzWHMU+xGUD2djG8naESgLno7tkNUYM+D72O6h
y+hKSM8oZ5UzFXuaE8lNIxrnGzOLNces+pgHL0Gb4FNoKfyS/zCxDJLcwq+s
cgx6DV/HRxx7hdEfvkvYsxduRolwO0rAPhhdgBc4zUUlKoQbsYXhOPQYLnA6
JjHNh5PQfngfmgpfwt/F4Ixy1lynuTmMsuG72O4Ec2RuNLZFjG1Fc+Asp3Ml
ZzPgN5JXzjIBdcKJTn1JDRPgFKe1lxiS4eXoLNyAMok3BR/TUCpKQ5XY/nL2
TlQGV3vaS9KTN+ACX8dkTgQuRd1RmoPT8Hn2GMX3aHQLfmo1NtA8gdPwX2i1
RjnwTFQBL0TOaY4l11KDOjiZhUlBjBLrB8ZOstd69D7IieRGziRnK0FXrfas
9K70tPR2ERoCL/a1dyRmiT03iFd6MgdeENJe6Gb/Ptb887W2EnOI9QP8tzDW
ir7D3UE81agHnsic3VbvZCxcLncObkWb4Q5fY5GaxvC9BjXBj9Bq6V2nc1vQ
RjiDeNJRptwVtA1bu/Sa9AQc5/Suis9JTmOW2OUOStKf8x1t9A68gMc4fSvk
zg93WvPUwIf48pzWQnr+ma93UO7iA/QQbXHqW85UAXfxf8JoDj7By7CdsVrT
2fAU1vQzNoAS4Y9WcyXzpZY1IX0LJP+18DurtZWefgv/trpW9vgFlzm927fR
KniD01w1yzrpp5D2ntQ0D+7FftNojBLrD6u1a0M/4brgPZL55+B4X+++vLkD
ntZEaiM9FXHqU3xLDaQW36zuJT6+WH0D5S2UHumH1zmNTWq8Fv4Phum73w==

            "]], 
           
           PolygonBox[{{926, 280, 892, 943, 944}, {759, 758, 760, 239, 799}, {
            826, 825, 827, 277, 885}, {1082, 318, 998, 1087, 1088}, {757, 204,
             753, 758, 759}, {816, 240, 808, 817, 818}, {1088, 1087, 1090, 
            353, 1109}, {960, 959, 964, 317, 993}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.44802477161903465`, 0.46115886542521983`, 0.5556978978341778], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNlllsVWUUhW/vvf8RMSpQWksFLIkDoEIZOlBaaHyRFoyCLdjK1NapLYJD
RMQgsQlSWvSRdyOJgFUTE02o44P4pIkxMYbBB0LiBC2OMbEl+i32evBhZf1n
n/1Pe6+9z5nXvWvDznwul/sGFMCiLJfrxbACXgk3gErQDLaD1eAyuIjvOPxs
yuXK4Pfgpcx5mPFy+E7wEOO74DWgi/E9soEDjLdpfbCVcWMW624Dq8CfYIz1
/4DPlORyk2ACNBc5A9wAf89hVzIuY7wCv1k+62fYG7G/UYjzN4LN4Gb2aIer
4PVe5yB83v6ap72bwBz5e67WuJE53XDK4ixnwZWS2E/vdecbePcgXCqfFPE6
l8KnMx9n3MC7V+D1cIVt9aAPtIBW2zpsF+rATflYexlos5/8F4Aj7HEN/GmK
eNd5Xg2oBRuVD8/T/H72PgHvgFeBfvnB3zF/ieINt/F8UHvCwyliO5AiLpO+
u/acAuaDvbwrh59PsWe5z/Eo89+EH4M3+Tyyl3lc4xjPdtzHratrycUp9vhc
eQR58rQD7oGfZq238XsGnms9Km+N7P0OPqPFiMMm7zU/hYbWpDjvD4x/BK+l
4C54i8+hM8zm+Sj2sWLcbYrjfNRnGQBfpbB9kWI9+SgevzHnI54vw98Ww/8X
eCRF7C/AH6TIx/vw9daMtKP9tMfpYsRFeWs32pzDdrPea235K07jzPkQvlQM
LXa6Fi7wfBL7DPYatW71fLEYzz/DL6fQ4ksp1lJMdKd9KXT3IvwC+ZiObS98
3jqRXiZcm8pfO8//MN5j1jvV0HVZ+J/G/mWKmE6kuF+t81RvzStv1SliWJEi
NzpPW4o62+xa22/NH3EeWqzDCs9VHna7L6k/dbiuFJc660R66cLvVcYfOx6K
4bmSqFvV79dwIYt6+zdFz1Lv2u76GATH8lHTepbW1/KuB16XxdraS9o9UQzt
HFaeieNaxlMZd+J3WPc3j4BhQ7Upm3qcet0V5lUVo1/dVox4SLfS77wsYnq7
e+oW67k+i3EDXJPFnDr7NLl27s2itzfDM7PQWyXclEVPXg3fnUUcF7vu1AvU
B+5wbS+Eq7OI8RK4xT2z1f3mEBgCxx03Pff5nrJLK/rOSDt9vrvenbIe1Qum
FaI/lMGV4BLjqkLoTzqc417S6PV6vceQuddaWcqcGfhXw++6NlWjDTzPxF4P
j2Gbyngd41sL8T1aAN8Cxhn/7XUPeV2d9S3bnsxivBO+rxDrtMG1oJTxcnhh
iju1uK/OdS76eTcN++5CfJA1V2d5wNq7H17selwEd7vHqtf+5HpX3f+ej/j8
am0esz7b/e3Tt1S9UvqcLMb3+aoG8pGv477boGMyDD+exTpPZNF/1Ycf0f9C
Fv59to1Yt7qP9LPVemlyfspcI9P9PT3zv2/qWdfgVd35TBuz0Ex7Fn1tlrVy
0v6a3+G+oz7UnWKN1hTn05l6suhn+iaUOx6Dvmer9dbnd+pL6h2lzpFypXwr
73/BA87jAbjFOVKen3OspKNP/H/yeiFyqZzuKYQuhh0jnX3U913mmJT5nOrJ
9WbdV/1rn3W7H96VxRpP+T+t0pofsg6Vwwn3Ztn/AzFYFGE=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlVlsjlkYx9/vfb9zbJMMtQ0mppLJULRolRaDFKHqYmhrptYuE8vUfjFj
iDFjxhZVSWUWtV1ME1pqS0wyZiwXuCLcuCCuSCxTWwY3tOH3z3MufsnvO9t7
znOe83yDqlfPWRVHUbQO0rDYRdGDVBR1onEzXgYP+X0FhuM/Qgd+F6rxmc78
H8jGt0A/5n4EP+GTfRRV4lUwAz9L22g8D07ij/noOeb+DY/wGbTdwd/CPPw7
6MPY3vAtPoI1KvB5MBJ3UB3W/wAf5a1vPuTib5kzBC+GmN9joBafCQk+CRbH
tsfpeEsSRc3Qzu8OuO9sr6VwT3v3tvYCyMd7eusrg17evqFvLYccfBwsxBfB
eHyCN9c3P8eLvO1dZyjGh8KX+FcwDB/uzXXmbHyst29rzQL8BnuahA+ES3gm
beX4XBiE19HWP7Y72YVfdHa3isk1vIYxrXidYor/xx38SewvQ0/6Z9O2jb6t
8AXeA2rCfj/EzzEmP7Y7/Qt/5yy2WXDd2Z3ofJOhXX3hvrRGCX7TWZ/OoLNs
hL6x3fkG/DNvZ1FMBuMHuZsD0AonYB/8AY2wH3KgB3vvrnzEC6CXzgJj8K2J
udp24B4cdIVusD6xuVrje3xDWC8DNuGv2ccz3slTeBXbNzRebZ/go8P6Gp+L
b07M1bYFL+cMO5i3XTmD3ybeTeqDFnw7VIbfTfgaxhyP7Y7W4h2sMZ6+CZCp
u0rM1XYBX8WYY7HNWY1Pg6nKGeUhZCW2d+13GJ4JT8J5Pk2sTX06Uy0+Muxf
MRiBv4xtrOb8rzdFWyrEULGsCvlyRDmiXIadsZ15Lr4MjuLNeiP4eu74Tcpy
VLmqN6+3r7YKfJ+z3FbNUe1ZGM5SiI9zFiPFSjl7C38R297a4HlsOaJcOQSH
Q440hhxSLu2BemiAvfALa/6sdwFfw1VnudwZfneGXDWxHt8PjWGO5hY7ezuq
oaqlqpmqnbrjj/UWvdUKvdEB3r6hb5XALFjiLXaK0VL8OWf6N9TXZ/iTtLlq
Zht+HnbjKyDG2+FEytqq8AxntVU1dYizGq35WjMHTzOmJMxP4b8Rg1/Dm9Lb
6p1YLBXT/niht9qmO9XdVnirHaqpE/Eu0DnknHLvjLParRqhWlHprZYoR5Qr
K1RzY8vZlfgPzv47VAM24aXe3orGz8G/8ZY7mlOL57HnXBgLBWm7w4ZwBp2l
LuSH3lQ5ngPZYY7mTmFMUaj5LSFHlCun4DTUpC02ilETv98DsfDNZA==
            "]], 
           
           PolygonBox[{{1498, 561, 1547, 1544, 1545}, {765, 764, 844, 266, 
            841}, {945, 944, 929, 315, 989}, {1614, 1613, 1612, 611, 1587}, {
            907, 276, 885, 910, 911}, {1061, 316, 993, 1069, 1070}, {1615, 
            645, 1624, 1613, 1614}, {1080, 1079, 1082, 352, 1105}, {1504, 
            1503, 1497, 561, 1505}, {779, 778, 777, 235, 784}, {1506, 595, 
            1549, 1503, 1504}, {1034, 331, 1028, 834, 835}, {1356, 1355, 1326,
             444, 1328}, {852, 266, 768, 769, 770}, {1472, 542, 1433, 1434, 
            1435}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.5826497030470066, 0.5084711416459129, 0.47655736306501856`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtlElIlVEUx7833EeBTWrDIooiyDYtdKMtGla+NqU2UZtH0QSB7spmdNOi
dob5sojKaBEYBZVENNC2UCvLJwhWRiMVPHsvh6jf6fwXh9/57j333DPdb8mu
pobGeBRFjUgCCckoqolFUYGPrako2s/mNjg3RNFr1sthFptz6B3wFnar0C/B
Ddjtxn4jLLI2EPMzA9i1wC54n/Pl2NyGXUgl+lU4yd5NbP7CMfgCeYnMCe5n
dvA4LJ4aeBa7dtbbYB3fe1ivh4Os3UNyyGX2Oiw2eB3Jol9Lus048gZp4Mxe
zm5KuT/LqwfZqXim4Cf5+Qw7ybMaPfu/WG7zgPVn6Mvx8wh2832e9RuwAF+p
FrPYewpXwD72rqB/hGv5zqM3Bc/Z7H8hpUmv7Th3xYPXZA0clH+7pxrJoFfB
KtXf+jCBXS16DD2D/gGb9XACu1701RY7UobNHfOpvH7Cevk0322qcy8swdc6
7IPVnzMp9IewInjNSnWn9Whf3PO0fGuD99VqZTWLcz7N/iT6geDxWFzWt3bV
/7ty/AE3p9zfFlihfi2DI5qfd/Cr+vsN5sihEn0o4T3+rTm0/ti9FuOQbPrh
n+B5jVosyGL0vuBzaLOaV12sPnk4rFhnYrNSuVhOx1QTq82ofPbbPCT8TV2E
nfL/GCbUU+vtjuAzm4Yn1a+M9i0Oi2F+8HzmwSn5t56cDj7PZ+CR4DN3FD5X
jlaPJ7r3Alyq97Io5XM2prfWErxWrcFrarV9L382v0W9mXHVtE5z0pr0fMy/
1c/mt6AZzuk99uj923/gFNyufC3vYf1D7F/yVveOKJaielcW/L184ezB4L4P
wel6M9OC52+xNcNGzXY3vKt/jv17FuqNLIDHg/s/Idu8+n1YdWtO+KykNdMz
lFsJ/Ae+kLwH
            "]], 
           PolygonBox[CompressedData["
1:eJwtlElIllEUhj/9/vuXTf5aWlmEhTZYNOzKFgUNmmSDadAigzINClsEFQ1W
lg0YFCSWRUiDBAktgoZNtmhZUFRmA60iGgnK5lB6Xs5ZPPB+9zv33HvPee8d
v35rRX16FEW1kIBUiKLutCh6CkPRQ+IoGgwpyIKVySjayIRaqEDfJWYSOgmt
6A8kOcPcNviEziUmB7IgG7qCxWrOfXQaYyXoOpiCfs5YD7yEVzAenpOrB0ai
x/n6NTA2aTmUSzn+Kp495kMBFMIgYjJgESyGG8QMJ3YE3ESXwgty34bJ6DnE
bOJfKUz3OZq7FqqTtsc6P/9kdBFrTIGpMA0ayPGLXL/hALogabHa8wR0LjE5
kAdjYquJapMJKajy/NrDavTypJ1V81egV3k+xVSiY3KkQxIGQJXXS2dag35D
D06nWU/eo8sZWwozYRYsZM4CuAqdMJGYQpgOM9Q/yIE+/vXDRubUeA7lKvRa
qwZFvoeke0beafV+v2X9feiP5Lqo2kA3+l+wWquHD9APGWvl3y14jT5GjqPQ
DMfhnc+/B5nEdyTMazrfBXQnnHX/XUGXMWcJlMMyOOP10Bot6AbG9sI+2B9b
j9XrYnLPhR3wg9ifsEv3IdjdeAIZ6Nxg3nwGOcFyKFcjHHRPyBubYQuMCBar
O5Ylv7KHfK+5ar/FY7fDDr9zKfeMvLMbdvmeG9xDee55eb8xmPf+QHOwM+vs
lfIGnIQTcApa1CfWHJQwD8gLO4PNlYfkpSqfK4/Ja02MHXIPyAsxc9NhA9TA
7mC10h3YG6wGqkUTHIbRjI2Cr8R+S5gHZ/qY/h1JmDfWwUp0UbBeq+fD0UuC
eUlj+tePb/rSrcdl7lF5VTVVbbvgju9Re21MWG6tcQm9lRy9afYm1AfbY5N7
Tt5rh2L+z4Frsc054Pt5hK72/cjje4LdId0l7Ul7ux7srflOzDb0wGDeeQxx
ME83e0/Umxqv5WV0hyOtHqlXJV4Pram1P7v/5fkv6GHB7o76p7ezxXvdCqf1
3gR763QH9Db0Mjbbzxf4bvf3W//bErZn7V13YDv6fGyxmnMutjdab7XeWL21
P/2/apbN/HnBzqoaz0f/B94dt2A=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0DlKQ1EUBuDjkLSKkpBO3ICBpDAEEdyBuIEQsRO0Mw6tbkFx6LRU08cB
XEAwqUxhCnEBop0Ywe/hLb7333fuxLnz69trW+MRMUOOG59r3qmYuJJ9VoxH
8pUhpXzEhlpVFihSnoxYoEpjLGJVfk9E1I2HsuC/yB0dRrTN/cjLdN+bfGHA
iT3HnFKzbiC/rP3kg7OsJu/TOU35wCM1+xdZ4tncpmzZv8MuFbWuvFWfdW87
9Z31f8Gc2rk85Cj1nPXeS3NPcjmdnd3RSX3109l7cp8Dpr3NFLn8/zv+Wv8H
rJ4zng==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.7172746344749784, 0.5557834178666058, 0.3974168282958594], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkztoVUEQhjees0GDmhh81GkSFUHFQkFQUbiCWEgsrEwRsBBDUsQgPpAg
mE6rKxHUQmIbwXhNo0YUFB8Ec1XixVcV0CKI0UrFx/czfzF8M3t2Z2f/mdPR
O9DdvyildAgrsEpzSt+aUmqBk/AOVsX+5JR2s7GN9Rni79gCdppDW2C9iFjr
7exrEG/FH4U/OVvRJZx9VqZ0nfU52MCu6Axck+O+DvjJOV8VEWt9OTzrdd35
1vnn4TK+3cZvg++cswYPwuNYN7aHeBAOw3XNUU8TvJGj3nHYgj1iTxf8hXWy
/iKHyZ+Cs5yvsec1fIzdwn8If5ehy124H+vBPyVaT+k675q/wi/W8w08Styq
WuFsEfVu4uwHv1d6HMuRZxuc4ttF/Htwmm+b8U/Av86p3Buccz1sEK9gfQxu
dG2d8CN2Cf9lGf1W/vfs2e67VHuVb0P4l8vIseD+/rDO0vu+9XmeQ3PVr5pG
iP/BPtifYzYGcmgkrXbgj+EP45+DZ4jndC/chdXxd8LC79W7H9jvdY66Z27G
eZSvx3n2KkcZszEND/jt0qDI0bvF8LzrvArXejY0I12eh0qO2dEsSa/WHDP8
uQw9pIv0GrFW++A155QGo+57Fa7K8U+tzvEvqV/t8LBrPql54/wE/hP3R/+f
7r9Qhv+0jFoGrXWfe62ea/+kz6gXQ6573HN+Ey7JkX8pPOI6pUHNPZ1Qr3PM
+Ur4H0YZjL0=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlF9MzlEYx39v7zkJb1LolaIVtbmTOzfYkC0Ty5gbLowrVhcym6vIGJMx
uWAzQrHV8jdXNrIxtKbYwixXzG1hrNdWPt89z8Vn+77n95xzvs+f81bta2lq
zkuSZDcEKEknSTGUQhYusdiaSpIj0In+zNoOdB0MowtgFmSgEDbBRuiFPjjB
njZi98J29CpoQh+GDehdxOyENATYBo2+pm8zmJuGBvQWp8FjFDsD01DFWdVw
Fn0GzkGH56BcyqHCPWY8R+Varb1QA7VwLJhXeb4W7AyddQEuQlsw753QESxH
5SqP8pphbW6wGqgWv+EXRNby4TT6lHuU11Yo8noOoVP5SVLPObWQi0nyl7U/
8sreBZBDTykndDbYHu1VTcfS5lneu+AN+rg8Qzuc9BqnvWfq3dtod+nOKXRD
sF6rx2vQN+A6XIGrsJaYEb5NQo7fB2A/dHNWDyzFfwUshjJYTXwdlMESeEXs
Q/Y+gJfolay9cL9F6BnWRlN2xz/0TehyD/KSEHM/ZTGKXc4d1bAMKmEe35/w
7TKM8/0Wv4vJrQRuo++ydkd+oQcm8TzhPVKvKv0s5aBc+qPt/cl5zeh69/sN
9qAbYavnqFxVE9VmAg7y+3kwv+fhWbAaqVaakYzPhGZDPVavW6LdpfzWR+ux
ej3ts34P3Q+9mj2fCc2GZkKz8SXa3cr5E7ogWq1V89no9zAK4/A12pso9zeg
t/A0mFd5Vq0XwmP0ACyK1lP1thSy8C5YrfUfof+K+cQ8StmeYvTmaLVSzdTr
4WDf5WcomAd5GVRdo81ou78RvZXBYP7lR7XMRNurMwrReT4Pikmjv+s+z1G5
/gg2W3oTI97zbp8pzdbrYG9Z+X1EH/X3pDd5KG1rA57PGLqGnFf4zGn2+rwX
minNVmm0eM1gVl78fuU/h98fgp0l/6PoddF6rRyUy39PF6+0
            "]], 
           PolygonBox[CompressedData["
1:eJwtzz0vw1EUB+BD6SrpQHSraCNWg1gNJgzshkYHiTAZJCIsRiGpRIuvQGIn
4RtoJIqOtYoye3n+cYcnv5t77j333FJ1c2mjPyIKDPKai3jhgam+iI485og6
0/ae5MxAxLL1czqf3Yt8xJxmE3KcMq3UZ1fusc+jh2ad+5Zd3jihzi0VtRu5
zq+7NbnAYlZzv8wkQ2prsmh/lE8zndn7klUOrXNylRpjlKiwojYvR8w4TCH/
P9OPPvfccZ7ev5Dv6e9t+UGP7Wx+eztp9uwPTT0bnLKldiCv01xteckVf8/K
MZ8=
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.8518995659029501, 0.6030956940872988, 0.3182762935267003], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtks8rw3EYxz+273dW/gA5CLGTi4RyUMo4UFZLHJbLSkp+HDbkqIQmseSi
lJS5OLk4SLZpLLutbAdaQkmUUg4ueD19nsOn1/vzfJ7P83ye5/M0RefCsx5j
TC/Ly4q4xjxXGROHyxg60EW46hizgN6Dw5xV0NMwpLoH7rJcgi3BMn472PNw
nPs16AjMst9Gz8NT9q3oM/jLnT7u1vqMCXO2iD0E2zW+5Czj14VOwnP2Afzz
cEP95Z7DPoNugYdqT8Fqtcv5ur7tBl6yttBp+ELcTvQr/NT3fMBH7cMT7MZv
BD0IrzhrxOcI7qvOwjd95ztMsWbQE9IH7e2Aa+uXPsQcW7PkqoP3Xhtf8kw5
9q4fNnPWj0/AZ2uTWoKwhH8bugDrOQvi0wATWqPUmtYaM/BC/0j+qqB34zCh
ta957VslbxRWtK6ia2sTLTa//qkDS5pL/vzPY//0BHtM4+fgj/7XrWtnSGbp
AI5pHJmRFe2zzN2QzobES2o/N+G3a2v8cm0vpCfGZ3NIrjs4qTMjs/mg/ZS+
HmtMmbuc9v/asTXIG0bhP7x1YPo=
            "]], 
           PolygonBox[CompressedData["
1:eJwtk0tI1FEUh2/N//6FzBYpNPkgdEi3BdXSjaOLGBPCXbRxp/RYJIq5KYiE
wIr2RbQqKJJRVxExi0DtAdW4sZ35SCgldTB1Ud+PcxbfzJl77j2v35nmvusX
rx0MIbRDAuf56D0QwhDcxT6RhpDnQifksJ8m5huGZ9jTMAVFmIRRuAmP4Qnk
oQNuwW3oSeytYlxQwtRin4TdGEIX/MBXgjbsLHeOwb+MFVgDh6GT312wGa2+
DtjArsKXwg6+vzDPWRmWYQUm8L2Gl/AqsRpUi3pu9xpV6zjch9/E+AXrsAFz
0WqN8Bb7eGq5VUNTajWq1ha+c7CJ/Qe2oQJXOHtArqswgL3P2V7GelSvq9hn
8Z2DNezTnJ3yGWqWfYm9VYx3PmPNehbm4AY8dL9y5aPNUjO9hF1LzKPKB1k4
AjV+Jt+gz1/9PcL+TowF11haL8MSHMJXDeMZq1U138Ouw1ebWE/q7TP2J/gA
HxOb4brPRLNZhDP+fgn7K3e++Bu9rfjspGmV9zjrNagWaSytlVO5d6Ltk/So
RNvJomsu7Zu42yh9IAdt0Ar9MJAxzaRdAbphJNosNJPL0c4KvuPa9ZzHavVY
a9z56Tun3RtzPdXjHewZ3x/VqFoboB62iLXtO6ndfA4voAzffCaaTda1Uw/q
peT7JM3fJ6ZZ9P/Tm2gxt1xDafkfO+WCag==
            "]], 
           PolygonBox[CompressedData["
1:eJwt0D0vBFEUBuDLmthYq1LRUCk0iOhohEaxIkKh0wjxUZD4BySESNRKi0Sv
RoKEarEaWRpCrL8gnsnc4sl7cs7MvWeme35tarUxhNBOwk8uhKGGEF5knV8e
mkK454YDsyt5y6G6Kh954tMBH1Tocui1LNBCD5eeb5bHcX4kt9hmyT2LbNDn
uXV5Qa96QpaYZMQ903qv6hpvPMd3qmma95NnRa+s16ouMq4e4zyeeyLnKKjz
skhbLtsn3WuZmtlCkt2T3ldhUO9dDsf5gOygkzqjvu1PfvGdZHun+8/Eu2bl
mX1OKbOptyv32eMu/tsd+Q+SzzV5
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9138218046854508, 0.6545545117136271, 0.33284759452489754`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkb8rxHEYxz/u+3y7QZlsukE33KCUrJgsEiJ0TrfcQN1Ax+J75LpkoYg/
QFaDUspmYVCSgbuZG0y6rkRZlNfT8wzvXu/v8/k8Pz7Pt7+0PreWCiEMogjd
SAjVrhCO4TuBBfwbLPK9jJ+Ah2gLfwEP0Ab+CD6iGv4MTqEiPgvb5Ofxn3AT
9eDLcJ+zU/ye2D29H8Tqav1LOOL1EzgtNs8MfCV/Fj+AT6MC/ofYF1rCd+Ci
15mHu+gEvwNfvG8DPnn8GX6jW3xfbO/RvnU4LtZrCGZiu/OH7/Wd/Ea2I51t
TOz9uodtsRzNbXJ+hU/w12Iz6p7z3k9rjsJVr6n7bvicD/AeneNbYj20l+7j
zufXd5R9tzm44jsp6H5iy+2OTeo/iA97X31TyXMrkc2V+Gw5j2fhpP+jCvwH
7RpEOg==
            "]], 
           PolygonBox[CompressedData["
1:eJwtkjFPk2EQxx95nwYcoEMd7ACJiUx8BB2rTEbKAKWlDg7WqGjQYgQTiXGA
jUBHFxcoCwmhMZrohgM4OJjgB1BrpYHUYFASHPz9czf83lzuvXvu7n934eaD
0ftdIYRLEOE5n4dnQshDDnsaytjz8BL7WxLCV/gOTajiewT3YAo+pELYhlVY
gya+V57/EftpNFtvXsM+IeYvHMMfeIFvhX/L8Ax7F9+Oxyj2HzVP4Tz/stDA
3oI38BZaxPzwHtRL03ttwU8YJ2eWt5/AGPanaLVU8zP2Y5jxmTTbUDQtpMll
7I1ouXpjE7ugN6EMN7wH9TICeWh4vTl4jb0UzZ4Q2Cl6jHARBuEuvjvQA2ej
aSJtjuA3FPEVyS1BJVqOcnNwBYapeRXqsA7nICO9IJvYm3q7F/qi7Ui7WoBF
mCSmBH2Q9pnK7tO/Q2IOYB/aiocSVGEmZTVUqx8G4D2+d77DXe8x5zmTPpNm
68Av+AJ7vkPtcspvS5pIm7bX3vPYtPea8Vk7iWlbgMPEelJvK1CD21CB6zCS
spvWPepGt6PtRPnS+FY0Det+Yw2/Id3SPrSldbRa2rFu6zixXL1xlJjG0lo7
0W5OEtudYrqjzdxxTaVt3m9HN6XbWvTdVLz3ms8iTaXtf19NgRo=
            "]], 
           PolygonBox[CompressedData["
1:eJwtzz0OAWEQxvHBbnSiUFCQiCOoFRqJKJZdEolo9gAEIYhW4qPiBC5Bp5Hg
AKKi8FGh1SHx3+xb/PJMZuZdI27XzZpXRILQkdZESh6Ri0/khjtiiCKBADOb
tNgzYah9511DzVvkFjvk+aiBFNbMkuSA3Rn1hmyjgx6a9CbkCGM8ef/AC2Vm
GXpZVKhD5If+FxHqMARVZjnN/W3nhiMK9A7kmf4JS/TprcgrFtR+7tKg46e5
t77VvvOuiC69qfrflrrRuXWPObMh+QeBjCrO
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9353273847857658, 0.7083184619644145, 0.39951489283587394`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkb9LA0EQhVf3Ugj+aGySQghY21lZiaiIVoncIaSQCGkkFwMKirWFlYKt
YKv/gFpYKuI/YCUWiij2ioWC32NfMXxv383OzO3U271GORhCmCIisZyF0BoI
oQp/Y9JL6JNKCBmJO/DGWt4m30pyunCUWEEPwZwo0AW8Ja9O/juc4dzHn87S
Wf4jXIzprmos+O4n3hp6H30EZ1UX3YRX9o/hW0z+K5yj1gs6hxeufwbvrOV1
fFe1C/dSz9L/UoNtao2gJ2DXeiumHuqlWc49s2bP3bcPxzkPo8f0fvbn4TUx
yQz38NDvsAd/7D9UUj/1qsb0/5rtAz6Rd4r+g5fW8pp+k9Us7UDzb8Nv11Tt
L+c/Z2mv2ql2u+E5OzHNKt2KaTeabRceWGvenu+uw3+11EBW
            "]], 
           PolygonBox[CompressedData["
1:eJwt0j0vw1EUx/GrvX+JhFgsJCQSutTGyDswtI14VonBQ0Tl3wQDamBg0l1n
XgChEhshZp0lmkiEkAovwPfnnuHTnJ57eu8957Z3YT1XSDjnUvBo4WO0ybkC
Vokfks7d4wk1FBFbTmvXqCKLHN4wwW/H8Up8gXOrUe0Be+6jhD10kmujthUd
xHVyL4gi55rxTFxhbRtXxHe4tRrVjvlw1v+ZxEP8ZhDd6MFiMuytM9aIj8gd
YhkrUbiz7j6JKZyRO7Ua1e6y5w42sWV3LllOa1/UfOIdH4hR5yzPUMvEj+hL
hO83xBtRiFUzaz2q136kdC/2XMIc8pjBtOW0duzDLDSTSx96UC8ZZFEhd2Iz
0qyKiC2ntS4f3lZv3E48gDSGMeLDDDSLPObxy54/aODbNKxn9V6z/0ba9ipb
f+q5anfK2Jvobf4AiHJMxg==
            "]], 
           
           PolygonBox[{{1439, 545, 1476, 1446, 1447}, {1085, 1084, 1145, 369, 
            1083}, {1515, 1514, 1494, 545, 1477}, {1310, 1309, 1277, 412, 
            1269}, {1143, 1142, 1140, 366, 1134}, {1039, 332, 936, 947, 
            948}, {880, 269, 866, 881, 882}, {863, 862, 860, 268, 867}, {1144,
             369, 1157, 1155, 1156}, {1120, 348, 1099, 1137, 1138}, {1168, 
            379, 1126, 1114, 1115}, {1118, 1117, 1097, 348, 1135}, {1479, 548,
             1526, 1523, 1524}, {1318, 1317, 1349, 482, 1347}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9568329648860808, 0.762082412215202, 0.46618219114685044`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxTTMoPymNiYGCQAmJmIK5nYWAoYGRgaAHSX1gZGJSBkseBtDMQHwCKqwFp
JSjbEUjnAdXlA9nlQPo1SA6o/h2Q3gnkzweKPwDSRUCD9YHsAiD9EWomyOwN
UPULgfQVqJrjzBAMYoP0lUPNrwXS26F6NwNpdai4LJC2BeIAIFsHSB+Fmgly
yxwgvw5kDpC2hqoBqT3PDGGrANlsrBB3PmKBqAOpTwDSR6BskBk/WSD+Bfnb
BBo+miyQMAKxK4A0ALx0KD0=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0bEvQ1EUx/HLe8/aziQEKZFILPwfXAnRigqCJ9FXdsxM7WLVDZ0kSPs6
idgtZsQfIDFUYvP95Z7hk5zce8+55547vpX52qBzroQY7cS5W1yhhc3IuSq2
sWMU72IPj3hAjh6aFGmggnXcU2OSCyZwl4Qc5R6ihkvOnA5wH3LiG85c4xwX
SFnbxwaq+E5CLdX8IZ7Ck+UPWY5yUxxgAfMYxZhR3KfWLz7jkKsaf8QfeEcH
XXzZvnp8IT5BRlzHGXERhTjMQLNYhscaylGo0bGZaDYjGLacor1Jb8tQt5lV
7M16+ywWuWsOb9SbicPd6mHa3tC3ntV7y/5OM9QsPZZsBppFz/7KW69l61V/
rL9e5cwKjnBsM0ythrc17TXQxHMUelOPr1FY014XOf4BWFtLhA==
            "]], 
           
           PolygonBox[{{1060, 336, 1083, 1077, 1078}, {1136, 1135, 1120, 382, 
            1174}, {1465, 1464, 1479, 547, 1463}, {1345, 448, 1347, 1366, 
            1367}, {1053, 367, 1134, 1050, 1051}, {1441, 546, 1477, 1449, 
            1450}, {1078, 1077, 1144, 368, 1076}, {878, 877, 880, 303, 
            962}}]}]}, {
         EdgeForm[], 
         RGBColor[0.9783385449863958, 0.8158463624659895, 0.5328494894578268], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxFjzEOAVEQhmftcwmNSJRKcQ0JnUgkOhJs1FxAIrLNditKN2DRbMklOAaN
+CYziWLyTeb/3/zzGuNFb14RkRoVU+tIZE+tqAeDLrzDooqOMYVHSugP8IrW
wlPGpqlnCU/e67tvEMnxvIPt0p11+kmwnCHsBJs3YRLsjhH8BLvnBTOfq156
7g2eff8Tbv22Gey75wKnPt/AtmdpZuJ37qqmqUf/V3hW5vl59L9VmcKB79ec
H5ogJ5w=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0DkSAVEQxvEe3uQkEjuBJSfnCARklhqFhAtwCAegipCEshQpB+AIToHQ
v+u94Dc183VPz7zO9qeNSUhEYjBIcIkjgigOvsgea2ywIJt5Iktcjc20tsUO
KbKkm6Gzfsb2ruBR7/A89+yMMfdllFBAEb2wSBcBBmjyTgMVVPEgu+OJF6aY
uExrIwxdprU87+RQQ923MwPXo70ZsjQ+fPtrbI/2ttD27Q50F2d6L3gbexY9
w83Yf6q4GTrrhKPbme6u6M6mO9Hd/AFS+yfl
            "]], 
           
           PolygonBox[{{1451, 1450, 1440, 512, 1421}, {1423, 515, 1463, 1459, 
            1460}, {1368, 1367, 1394, 515, 1392}, {1055, 335, 1076, 1065, 
            1066}, {976, 975, 1060, 335, 970}, {1271, 1270, 1247, 413, 
            1278}, {950, 949, 954, 300, 955}, {1389, 512, 1386, 1362, 1363}, {
            956, 300, 858, 864, 865}, {1281, 414, 1273, 1314, 1315}}]}]}, {
         EdgeForm[], 
         RGBColor[1., 0.95, 0.75], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtUDsOAVEUvW/mvQXoZRCNTEJpAXoK02hJJBqfjYg9aKeSiIZQTKeaHXhW
QSXOzT3FzTn3d+6ns9hON4mIZLAU9nIiEeYQbHiRMXgTeEmNa0zzSWI1S8T7
8OfAXRB5g8+Aw2BaBfAcrP4A3AfrK4E9aE1Qk3vr0d4R8Af/Dv7xZsrbiG8x
YwC+Aj7Ja2BFrvmHM53IvXXnzNv8yFzOuS3eonvqjG6wfgc8cWfdvaZ+Rf3I
+pK3HIFX/kf/VPD2dbC/6H9uqelq/xdz/1/uLkM=
            "]], 
           
           PolygonBox[{{1423, 514, 481, 1392}, {872, 302, 301, 869}, {1442, 
            513, 514, 1457}, {1272, 447, 446, 1278}, {1054, 333, 334, 1064}, {
            1312, 446, 479, 1334}, {956, 301, 334, 961}, {1055, 334, 301, 
            969}, {1389, 479, 513, 1421}, {969, 301, 302, 970}, {1346, 481, 
            447, 1315}, {961, 334, 333, 955}}]}]}}, {{}, 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{879, 872, 869, 865, 956, 961, 955, 950, 1041, 1052, 1054, 
            1064, 1066, 1055, 969, 970, 976, 963, 879}], 
           
           LineBox[{1278, 1271, 1312, 1334, 1363, 1389, 1421, 1451, 1442, 
            1457, 1460, 1423, 1392, 1368, 1346, 1315, 1281, 1272, 1278}]}, 
          "1"], Annotation[#, 1, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{858, 851, 954, 949, 1040, 1051, 1053, 1063, 1065, 1076, 
            1078, 1060, 975, 962, 878, 871, 868, 864, 858}], 
           
           LineBox[{1129, 1116, 1169, 1208, 1247, 1270, 1311, 1333, 1362, 
            1386, 1418, 1448, 1440, 1450, 1441, 1456, 1459, 1463, 1465, 1425, 
            1394, 1367, 1345, 1314, 1273, 1248, 1209, 1174, 1136, 1119, 
            1129}]}, "0.9`"], Annotation[#, 0.9, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{857, 850, 953, 948, 1039, 1050, 1134, 1143, 1149, 1151, 
            1156, 1144, 1077, 1083, 1085, 1068, 980, 967, 882, 880, 877, 870, 
            867, 863, 857}], 
           
           LineBox[{1128, 1115, 1168, 1207, 1246, 1269, 1310, 1332, 1361, 
            1385, 1417, 1447, 1439, 1449, 1477, 1515, 1518, 1521, 1524, 1479, 
            1464, 1424, 1393, 1366, 1347, 1318, 1286, 1250, 1220, 1180, 1138, 
            1120, 1135, 1118, 1128}]}, "0.8`"], 
         Annotation[#, 0.8, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{788, 783, 860, 862, 856, 849, 952, 947, 936, 839, 1038, 
            1033, 1131, 1133, 1140, 1142, 1148, 1150, 1155, 1157, 1161, 1145, 
            1084, 1067, 979, 966, 881, 866, 798, 793, 788}], 
           
           LineBox[{997, 995, 1089, 1107, 1108, 1110, 1111, 1094, 1002, 1000, 
            997}], 
           
           LineBox[{1049, 1020, 1097, 1117, 1127, 1114, 1126, 1113, 1167, 
            1206, 1244, 1277, 1309, 1331, 1360, 1384, 1416, 1446, 1476, 1511, 
            1494, 1514, 1517, 1520, 1523, 1526, 1528, 1481, 1468, 1427, 1397, 
            1372, 1349, 1317, 1285, 1249, 1219, 1179, 1137, 1099, 1049}]}, 
          "0.7000000000000001`"], 
         Annotation[#, 0.7000000000000001, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{787, 782, 859, 861, 855, 848, 951, 946, 935, 838, 1037, 
            1032, 1130, 1132, 1139, 1141, 1218, 1228, 1230, 1234, 1236, 1223, 
            1160, 1162, 1166, 1153, 1092, 1073, 981, 965, 883, 874, 807, 803, 
            797, 792, 787}], 
           LineBox[{992, 991, 1086, 1102, 1103, 1106, 1163, 1193, 1197, 1200, 
            1203, 1205, 1243, 1268, 1307, 1341, 1359, 1383, 1415, 1445, 1475, 
            1510, 1493, 1513, 1516, 1519, 1522, 1525, 1527, 1480, 1467, 1426, 
            1396, 1371, 1348, 1316, 1284, 1287, 1291, 1253, 1226, 1182, 1147, 
            1101, 1059, 1024, 1048, 1019, 1044, 1016, 1031, 1013, 1010, 1007, 
            1005, 1003, 1001, 999, 996, 994, 992}]}, "0.6000000000000001`"], 
         Annotation[#, 0.6000000000000001, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{786, 781, 776, 772, 854, 847, 843, 767, 940, 837, 1036, 
            934, 1125, 1122, 1215, 1216, 1217, 1221, 1222, 1227, 1229, 1233, 
            1235, 1238, 1239, 1224, 1165, 1152, 1091, 1072, 982, 971, 884, 
            873, 806, 802, 796, 791, 786}], 
           
           LineBox[{900, 897, 978, 990, 988, 987, 1081, 1098, 1158, 1178, 
            1184, 1186, 1190, 1192, 1196, 1199, 1202, 1204, 1242, 1267, 1306, 
            1330, 1358, 1388, 1414, 1437, 1474, 1502, 1490, 1509, 1492, 1512, 
            1534, 1559, 1561, 1565, 1567, 1571, 1573, 1536, 1529, 1482, 1469, 
            1429, 1401, 1373, 1350, 1319, 1290, 1252, 1225, 1181, 1146, 1100, 
            1058, 1023, 1047, 1018, 1043, 1015, 1030, 1012, 1009, 1006, 1004, 
            983, 913, 909, 906, 903, 900}]}, "0.5`"], 
         Annotation[#, 0.5, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwV0M8rJGAcwOGXWSzGr4lBpEaITcltS1mHjVIk5eogTsTRgSQiag/KFGpr
09AexD9Aas/SmtuguSnXbZXaleGZw9Ont9637/u+iamF8fmCEMIWn4tCmOX/
hxD69VxfeCNYX+glEaY5joRQrl/1hFxhCMM6ygQRSohSQ5wmErTziW7mWOSa
W+5Is8QKq6yzyTbf2CHJHhn+8ESR+zxrTP/lZ2ouP1M76GGMNVLc8EiV93Ux
xCTLJLnkKv8nFBTbQydttNJCMw3EiVHNq/0PpMnyi+9sMMMIvTTy1/wMZ5zw
M/+3HPKDA/ZJsstvslQ6m6CeOHXUUkM1FUQp5SMRCvnCAAvMc8YpR6TIcE+Z
dwwySZ/1O5tgP44=
            "]]}, "0.4`"], Annotation[#, 0.4, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwV0ctLlFEYB+DTpzOgCV1kIFwVFJhCCLNIxZ0ICqVpWiSIVO4EWwTjODIO
iqEwAy0CIUTcuJJIFGwRhP4BQm0iCAVrNt1QWjsDPt/i4ceBw3vhvfHsxdDU
hRBCibuJELr4WBtChad8IuI5GzUh1MtuuUk1CqFP3meYiCQXuUyKJq5zk9u0
MkmGLDPkyFNggVcsU+Q1b1jhLaus8Z51tjmKe5mrGveSt7hDmnYGWYrn5yt/
aLRnC32MU2CFPQ44I0qqQwePecQIwzxkiEEeMEA/aVJc4RIJGqiod8gXPrPP
KotMcI82rvHffKec8I+//OYXZa7600wvozxhhCwliiwwzxx5ZskxTYaX7MS3
5gO7bPGOMj855gff+E6dPXoYo9P7HP6sRa4=
            "]]}, "0.30000000000000004`"], 
         Annotation[#, 0.30000000000000004`, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwVz8kqBXAUB+D/NWWIDSsUNpTZzXiNSZk3opAyz7PyCHayUCJJyYpSnkBW
dh7ASh7AkCEbxWfx9TudTqdzCqbWB9YiIYQdIgkhJNAeH8IFP3Eh9MlnGWSE
RFJJ4UX/lTfe+eCTL77JM1NGORVUEqWaWuqJsc0e+xxwxDEnXHHKNWfccM4t
T//73RuljhhtDLHLJQ88k5sYQimDTLLHIXfc80t8krtoYYRRpplhi002WGeN
VVZYZolFFphnjlmmmGSCcYbpp49eeuimnS7a6KSVZppoJEY9ddRQTZQqKqmg
jFJKKKaIQgrIJ4dsssgkg3Qe/f5AmjqZDsZo0PsDh783XA==
            "]], 
           
           LineBox[{1326, 1325, 1354, 1378, 1408, 1433, 1434, 1411, 1379, 
            1355, 1326}]}, "0.2`"], Annotation[#, 0.2, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{721, 722, 733, 734, 735, 736, 737, 738, 739, 740, 741, 
            746, 745, 744, 743, 742, 747, 748, 753, 758, 760, 761, 762, 763, 
            808, 817, 819, 821, 823, 825, 827, 828, 829, 830, 831, 832, 833, 
            840, 892, 943, 928, 957, 930, 959, 964, 968, 972, 974, 998, 1087, 
            1090, 1093, 1095, 1096, 1112, 1170, 1173, 1175, 1201, 1254, 1264, 
            1323, 1327, 1376, 1382, 1432, 1438, 1486, 1491, 1540, 1542, 1601, 
            1603, 1627, 1543}], 
           LineBox[{723, 725, 726, 727, 728, 729, 730, 731, 732, 724}]}, 
          "0.1`"], Annotation[#, 0.1, "Tooltip"]& ], {}, {}}}], {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxN3Hk8lc3/P3DJLiLlOM5xDlHKkkhSocmSchJKJcoWkSWhUihSaJE1ScgW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          "]]}, {}}}, {}}}, {
    PlotLabel -> FormBox["\"Fitch 15:30 adv=1\"", TraditionalForm], 
     DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Frame -> True, FrameLabel -> {{
        FormBox["\"Latitude\"", TraditionalForm], None}, {
        FormBox["\"Longitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{6.53, 7.4}, {53.85, 54.18}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.31339984019106276`, 
              0.4138465892045269, 0.6348384326033369}}, {{
              0.44802477161903465`, 0.46115886542521983`, 
              0.5556978978341778}}, {{0.5826497030470067, 0.5084711416459129, 
              0.4765573630650185}}, {{0.7172746344749784, 0.5557834178666058, 
              0.3974168282958594}}, {{0.8518995659029501, 0.6030956940872988, 
              0.3182762935267003}}, {{0.9138218046854508, 0.6545545117136272, 
              0.3328475945248976}}, {{0.9353273847857658, 0.7083184619644146, 
              0.399514892835874}}, {{0.9568329648860808, 0.762082412215202, 
              0.46618219114685044`}}, {{0.9783385449863958, 
              0.8158463624659895, 0.5328494894578268}}, {{1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -92.04545454545453}, {
                    Rational[
                    15, 2], -92.04545454545453}}, {{-7.5, \
-92.04545454545453}, {7.5, -92.04545454545453}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -71.59090909090908}, {
                    Rational[
                    15, 2], -71.59090909090908}}, {{-7.5, \
-71.59090909090908}, {7.5, -71.59090909090908}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -51.13636363636363}, {
                    Rational[
                    15, 2], -51.13636363636363}}, {{-7.5, \
-51.13636363636363}, {7.5, -51.13636363636363}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -30.681818181818173`}, {
                    Rational[
                    15, 2], -30.681818181818173`}}, {{-7.5, \
-30.681818181818173`}, {7.5, -30.681818181818173`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -10.227272727272705`}, {
                    Rational[
                    15, 2], -10.227272727272705`}}, {{-7.5, \
-10.227272727272705`}, {7.5, -10.227272727272705`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 10.227272727272748`}, {
                    Rational[15, 2], 10.227272727272748`}}, {{-7.5, 
                  10.227272727272748`}, {7.5, 10.227272727272748`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 30.681818181818187`}, {
                    Rational[15, 2], 30.681818181818187`}}, {{-7.5, 
                  30.681818181818187`}, {7.5, 30.681818181818187`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 51.136363636363654`}, {
                    Rational[15, 2], 51.136363636363654`}}, {{-7.5, 
                  51.136363636363654`}, {7.5, 51.136363636363654`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 71.59090909090912}, {
                    Rational[15, 2], 71.59090909090912}}, {{-7.5, 
                  71.59090909090912}, {7.5, 71.59090909090912}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 92.04545454545456}, {
                    Rational[15, 2], 92.04545454545456}}, {{-7.5, 
                  92.04545454545456}, {7.5, 92.04545454545456}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               LineBox[{{7.5, -112.5}, {7.5, 112.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.5, -71.5909090909091}, 
                    Offset[{4., 0}, {7.5, -71.5909090909091}]}, {{
                    7.5, -30.681818181818176`}, 
                    Offset[{4., 0}, {7.5, -30.681818181818176`}]}, {{7.5, 
                    10.227272727272746`}, 
                    Offset[{4., 0}, {7.5, 10.227272727272746`}]}, {{7.5, 
                    51.136363636363654`}, 
                    Offset[{4., 0}, {7.5, 51.136363636363654`}]}, {{7.5, 
                    92.04545454545456}, 
                    Offset[{4., 0}, {7.5, 92.04545454545456}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["0.2`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -71.5909090909091}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.4`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -30.681818181818176`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.6000000000000001`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 10.227272727272746`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.8`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 51.136363636363654`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["1", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 92.04545454545456}], {-1, 0.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.004484724253416061`", ",", "1.1669737100601196`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.1`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.2`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.30000000000000004`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.4`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.6000000000000001`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.7000000000000001`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.8`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.9`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8135751407009573`*^9, 3.8135866241629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchA", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Wind Speed Fitch, adv=0\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.790425082171939*^9}, {3.7904251545992684`*^9, 3.7904251558237486`*^9}, 
   3.790425220305675*^9, {3.7904253561856956`*^9, 3.7904253654911857`*^9}, 
   3.7904254259902124`*^9, {3.813577654614634*^9, 3.8135776617207584`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3Hdcjt//B/AUpSF7SyVFRlkZRR0qaVBoWKVSoqWhQVLd2XvzsWUlOzSU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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          
          PolygonBox[{{1204, 80, 1229}, {1230, 79, 1249}, {41, 3, 2}, {42, 3, 
           41}, {41, 1, 79}, {41, 2, 1}, {1171, 42, 1188}, {1188, 42, 1203}, {
           41, 79, 80}, {80, 42, 41}}], 
          
          PolygonBox[{{1229, 80, 79, 1230}, {1172, 3, 42, 1171}, {1203, 42, 
           80, 1204}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.40019489998691204`, 0.4443496453628125, 0.5838151386658409], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVTlPVFEUvm9890EiVsa4xo2tAGtDpYXaDIVCjFErcStMNGoB+AcQRwUE
NMQIFTFWyAyIgFuDnWJUGASGAZGowRpxQf2+nM9A8eW8e9+5Z/nOuefuqLpQ
cT7mnHsCrAKSgXMfgBRwGkgA14F64CFwDTglmZDs1jd1qoCrwAiwBIzKDm2c
AY57585CtkK+Bfrx/dTb2S75oN6NwPRoN6nzV6VD3a84Mwv5GbIACfyRv7/A
WGBrh/0ioBjIBy4C8Zjtf5BuLZYVQA1QDFtrsVcEWY31PaDdWY4n5fcx/jVA
3mHsQCO+27zFfF1xN2B9AvKgN64S4uAbbL0EhoA65cKcDnnjrYL2vPmqhHwT
OncFunOQt7zZOALZJLuHId8BA/h+D3kTsjew+BhHT2B7XD8KLNZn0Btkfbxx
Rw6XVJMb0md8887iZR3J3ZLyS0mPtvqAJuBTaHkthsbZvHIcka9Rb3lUOuN7
TnkNQx4S9xVCrfTSiu2Lt7q1AZeAQtW6QOty1TQHmMH+NHsscu4y1scis1ni
zA9MuVDrUq35fRt6a9D89yGnge/4Xp0DP1DIhZ3tkfliDLQb6fwuxovFC+zV
QebhzDY4yM+x+OKKd6f2+b9Q+4x7j+JkvIyvWlywZ9mb1C0VL+Rkb2S9vC6y
GLziuCe+27WuVGxx9TxjJy+ReMri28dsTT9FuhPjujMBUCNOyE2JYqDtP4qL
58g37eUKH7XXGpr/TsgZnH8AOwuR9RB7qUA8liu2fulQdxI6MeytAgawPo79
YchMYHshMBWYZA67wekB+NkHORFY7DHlU6xcCuWLebI3ywK75ydXzDPWfH9o
dZoSP+RpQD3FvFibDvVoJliOpV11Y/361Nu8u5xt2RXnB2XvcWDnsppV5JLz
KK25NabvJa2T2qMO42OczHlDZLkueLuLU7Kdku64fNL3R92lWc3OUdlPa05Q
d0Ln/vcCZ9SI5lS3uOJ8Xq8+ZD+Oaq9Ls2dSs2ZLZP31E742Rla7795yScje
uOpFv5si43PR231jP/32ZnNihV3KjCRtZvSfPExqJmXExebI6vjDWw3Ifb/s
ZKSb1b2Y1nxLir8xxZjWelw8DXibeXc1l55rLmyN7C788jbTOc/5BrDf2Guc
pW3S57zg/3r1YIf6h310QrzTRoM4ZbyLmrGrvc3fVLA833uk16E5QL1W3R3e
oWa9T0e96U5Iv0y+6LNFbwDf527ln1RvD6nvC3TXeOc6dcd7Ic9pBnIW5ukN
5VvaHNq8bQmtR9Li9HVod+VVaP2aVV0alev/d6VP/ZxWj7HXevRmpEKrAfUG
vc2VuGZLl/qW+v8Aa/Y3TA==
           "]], 
          PolygonBox[CompressedData["
1:eJwtkjtPVUEURvc5nDnXBKmMbyIRjRbE0sIGY6JUJAjEEKUCX4kkWFj4+ANa
gYgXQ2FsSIi1gFwEtbIDEjTaAj4qaxBF4/ryUax71szdM7Nn7znaf7trMI+I
01DAK346+bbABL63jDhJwAloxR/Ce/wdPMKvwB18HG6VRq6YAXwrRSS8gEOM
19nzPnu/gK/4Puay3Gfsx49VIpqYb4Pj+CLfu+GcpvAN9stzr9HaMeb4xCmo
Fs5RubbDOXwDXtZFbMIq/pv1Ze6cDjP+lZxbHRzUWsZ7sogz0JF8R921gfX3
8MnS3gtV3ZWYx8SOwBw+BkP4MMziz5JdMTW8Hj6Q609owLugn/+uKgbvgev4
DRjFP8MbfB1+4Ocrrs0FgV9i7lrmNU+Sa6ra6oxvhc/QWbrTbnyZuQfhHqgX
M9AdnnuNXySmL3NOnXgVbma+k+62mVwr9eAA9+9Ozl05jODThXuhPbX3cula
qQe10jVVbXXGML5GzPNwj5fw+op7pTfQjP/VnXbu/z25BnLNfcE/wVzmGr3F
/0Ald48bOW+BcS1zzMfkN92y89ZHC++p/XYR/0+1Tu7lLMzjl5N7oRo8TX5T
elt682dLxyhWZ6zg28l7KYcj/P8f+T5qeg==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.6212599428180356, 0.5220402354951563, 0.45385996971719317`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVklsVlUYfX/77v0ZWxZSZ6VUkbEtC9E4gFWgYCK0FVolFI0aw2BbTLAa
qSsx4kotnRgFiWioWxWkjC4oK4QSh53BDoCxsALaqvEczmnC4st59917v3u/
6Xy38LWGqvqcJEmymSTJBe7C4B3ITshlyCT8vALMB14C5gG7se4q5Eyi+cue
578C6LkGbAcehRyDnLKunyBvY7wxo/kOzx+HtEDqIXWQBn+3Qu6MSTId+wqi
9nGuzdLlM7ZbxwnIhJAkf+P8icCRVHfJC7rzoO9dAlkJqU5kU75t+NI27YfU
4bzd+Pc+sB7yHr5XA3uhcy/m/wRuBu5LtI/Y7W/On/a/Mz7zms+fnNF4PnS9
AJ2To+57R0bzP0DvCuD3wCbr432aYcN8rFkJ/CQqJu3AA0H2nwBuCPLRPuB5
2DQE6YHczNX4XK78P+r7hqDx/qD91HMSOBO6KyGzIEdwxivYd9BxWA6ZAenF
+AJ1G4chI5BayIeQLZDV/ua/UuwZBxlrvVWQ2dZVkaMzmXfMv0af/26O/B5w
Rh4wF1gOv9RB6iFroPcx61+K8UbI86nG83z+EowLU+2bmmrMtZWw80nYWwF8
JKt9j2c13+A19N239l0X1jVj/RHgb0G59jvwjyi/Xgduc/6+BSmyDurlmHs5
zzt/lCufNjmOjOc26FqA+RrgWMR7jPOUiGslxZCFWDcH6++Puit1LwY+F+XP
WuAiSDG+H4zKH+bOB5Dl0PsE9E8Lyqlu5+a4ROeVOjcHnYvdzl/m8WLoKoHO
wqj6vuq1p53TXNuKuUdh09fAi66Rs87lza63zc5n3ivPfDJgbiBHcHzFPMF/
Y2x3yW37m1y3TbZrrOdLvXalx+04ey7wQKpxtdcwXyY5P2gnc4C27GD9AF8P
8gnXzjXW+HvQ/mC9bo/S9U3UmaP3Ooz961hjwEOQteQq4I+Q9eSqIFvJryct
A7b9WBAPXgiqg1P2xQOO6T9BNq6wnRn8n4D/04A5kIn4ng5MIOPx/VAUj3D9
d8Au1/LPUbXEmpoZdYdLPq8FZzyDO7wM7Auq13+BZeYr8la1fV/jODLu5NCp
UXVeTr6Msmsr8LxrhzX0axBv9wN7gmriaFCtzrOuN4LqaA/9EFQ/u4NiUe1z
872esVxjfiZP51sH5z51zjP3yYVTUvFUufmDtT4UxVsTUUefYd1TWF8VVPes
085c8VOj+WiWuYn19mxG8V3nGPO71bFj3Ng/FthvZebPZebQTnPkQZ9xzjxz
wHl7CPg5dD0NnS8G1R3vxnGF71Lpe+3yWRvdF9vdP1vcQ9cG9c29QXNt7pt1
5qQW1wHrgf5aZi7mPUuD7KwFbnLejs413sbdFb5PmX3CPW8G3eOLIB9ssv1t
vhfzYIZ1cf/hVLE9B1wVpKsYuMK9bxbzxPfhvdjX2VenB8VqjX2607lMv1Sb
V2cDD0f1o7PAIucqc/Yl5/wc4EAqzhxK1ePJY+Sz86lyvj9VzLa4t7Wm4ue2
VDlX655U6d5VZZs32W+djvOtvhKFF6N61BL3qA5zxatBtnDvjhzFf7JjtdX1
9THwhnswe/L6qLWrot5A5KrxQfftdE7vd9//Kkgf9Rb4bdXq/Fju+zLGAxlx
C/miLyNuIe8c9/utz/XMeP4S9I/51Qv5zxxCLunPaB915WfVI6cB74mqqyH3
Verl2kVZ9fqFWfl1i2N8b9TbYTjIX+yzRe7/S92/U/Mb3w5cwxqnj6f4LVBo
Gb6NF3r8ZhpyjPhuog18t9zi06zWFmXl45Ouh4Ou306/k8ix5NqHbSNtHfb5
vMcGx4ixujuqfm7SlqzOHJ+Vz9hzmaN3RdXJDfu21z5vdN2TC5r97mAPKzDX
XPebrsM+vc/vhxH8vxIU17/sc/qb4x6/5ZhPx0dja+lz/Pp8B/qkwXlLPu0w
9xyzrn7nzf8sIYGB
           "]], 
          PolygonBox[CompressedData["
1:eJwtlUlsllUUhu//9b+3sS0NCwfAgaHIUKDIwpCopaUMTUgwUlEUSiViCNqW
QmIiWF0Zw1JorW0ZFEIANW6JFHAgLowraUHUHWi1giFxRVuKlOfN+y3e9rn3
O/fc4Qz/7Nc7mnZlIYR2VER/8+d9/p9AI/CWFMLbGKxHdfCWGMLKQgj16GO4
CT0HP4s2wFuxacJ2L2qB96GL8CHUCp/B50Z816CT8CXmXisJ4UM0CL+Ij9qC
fR6AG5l7irVL0Vq4jzVlrF2GeuFBtCn4zEPw2tIQ1vF/N2qEF7BmCmsrUEHr
0VT2Wo764WpUmdkmgz9lz3b23oV2wM3Jd3kHtcF/4fc4e3WiS/BWbBqwfRO1
wMvZs5H5WWguvJC5hwu+UzW8AP0XPKdvDfhcnPnNVsEvMbcitz8Iz0PPwA+i
+fB21Aq3oSPwq9GxqEPd8Db0VsE2h7SeM1QV/Sbz4c3JsVBMFdtybG5xnh/R
GDYPJcf6eVSffCfdTT774E3Re+mMXfKf/LblSiL4OHO7+bYHdcDnmGvmrZ9G
PfDnyW/fgr6Al+TnV05thn9BPcot9C18JZq70WX4ZLTvPvQd/DM+PijxHtrr
InP9fPse/Qb/g76BL6Bf4QreYBzbMTQH7mXNzcw5odxYnN9PZ3oFrsnzXTFu
hsewuYLtBBqHx5lblDmGjzKeiWrgJWh1csxr8/faqLNE36ULDcG3sRnE15fo
OjzK3ELWVqPpjO9E+5a/xxjfjfavepjFeCL6m+aeSH5Tva1q6jw8Fu1LZ5zB
+F/GIwXnfJHx7GRfWr8G/p/vD8BlaARezRu1F53Tyu1KNKfonHoSvq2cznzm
aaz/PfrttcfN6BxSLsnmkeSYKXaK0SnFDz/HgmtKtbUfm5HMPUO9Y1FeD4rJ
y8oNtDPPF/WiP7G5XOKYjCbXiGpFOV0B38HnT8E1NwGXlzr2evNr2Pfm+S2f
Z+HTyblaiT5Jllhn2gv35/WlNQPRNaPa0R2G4RvMDRecc8q9ucm1ofecZPx4
crwUU9X+eNG9VmfUWf9g7qsS30l3U09Ub9TcUHKOKFeU8wNwJ/ohcw6/p15X
6txUjBSrz6J7WYfuCB/O+4fucA6uKnWvUk2oNo5G9xb1wDeie55631HUnpxz
yhflyD2+H4v2rZpvje7p6u24Cj3w+ehc157aWzmlt9Ab6a3UQ9VL9ZvwNXw1
ulbVA9QLzhbd69XjB+B3k8+iO+vuk7k//UZUMX4h+rdIPfMj+D6WLNH5
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.8423249856491591, 0.5997308256275, 0.32390480076854544`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV1tQVlUUPv//n3P+svCCZvdpmFBAzZLLFJAvqaCBOVOERKhc7DaZFqAz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           "]], 
          PolygonBox[CompressedData["
1:eJwtlF1Mz1EYx3//f53znxmVC+9mUSqvSU3ZXEUiZiNphJC3C8rL2hg2NzYv
9+lFoVamuHDFwkQuuDCiTdyZ19jMZiMvm893z7n47P/5n99znnPO8zu/J31H
7boD8SiKdkEyzPdRlMpACng820XRhFgUfefZWPwYY/08a4X9+AzYiC+EmXgu
pMUtRwK/ypzDzD8C9XgXHIqFMbyMmEXE5kEmnuEtl/5H+HM2dRKthNt4t7Nc
zfAALw3rn4Bq7Y2xFp49hNf4e8ZuJkXREHzAa73FtkMd3qD98uwL/8/gv73F
qhh/8F8wyP8b8A5vgvH4UmjGSxJRdJDYMijEzzH2LW4x5/G7UIOfg3uqBxQm
2ZqN3tbU2qrpce3N294ew0n8rDdXTuXWnrS3GKSy3gd+OyKr0QD+EqrwzfAC
f0v8ddY6DQPezqCzaOwn7ry960/UKxl/4W2vqtlL7c3Zsz4YxtcwVkB8PuTg
q7253mEWnhSeK6dyP/O2djXc8fZO9G764RH+xpkPw1e8ytvdaoMD3uZobhFc
w7u91V417cGnwXpiy2EZvoccK8hVCovxRmqQQi0KoAvf5+zZSliC50Exvgy2
4enk2ECuCijR3XT2bDlsd5ZDuVTjXvwzdOFPYRjf6SxWc5rw6d72ppzLvZ1B
Z9Ed6MXnEzOF2MmwCU9xlusHpDpDrpg0fJ6z2ElQ6ezO6e5lQBa+I6xfAvn4
LmeumhTgc53NnQgVqpW3s+ob0rdcRI615KqHJfgnfk9FdkaddY6zueoJ5fhC
mBqzGqqWaeE8GluAbyHn0bi9o2JvPUS95An8IV8n5OGjoQHv43lT6A/38Yth
/zpTCz473DfdMd019Qz1ikpY5a0nqDeoB/Tg2aG/aE4cnxXiNRbztobWUk/q
dNbzUkL+ufgVxi5DLdQ5u5O6mzrTVvxWsvUmnUFnyQ31UA2q8LZw31T/3apH
uG+KUWxawr7lbBiHt4b7qzPX4NXh/mnOBfySs7urnHudfTP6dtRzR6lfJyyX
3mEOPpJstVaP+KhvgbF/3L2/kIlv81Y7vX/10iFn37rewSt8TMJi1QNHVL+E
3TXlUK66UJt26HDWc9R7dGcG8f/CvrWn
           "]], 
          
          PolygonBox[{{1390, 329, 1387, 1441, 1442}, {1444, 1443, 1445, 370, 
           1394}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9261006435272017, 0.6852516088180041, 0.3709119949343251], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV31Ml1UU/vH7ve/9TZcJiFMzS7fMQJD8BMrM9B9TMTHcShPQTUHbRE1E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           "]], 
          PolygonBox[CompressedData["
1:eJwtlWtolmUYx+/33XPfbzOptb3Sh04OrDTLZeo8JpJfnLplQZBlqYMwh6V5
WmBNM9YHUSkSQc2EMFo4FQ00qhmVGlS4PBJZTcgOZkagMzI1f3/+z4cf+73P
cz338bqu1TbPf/T5YgihFTLYnEK4pSKEh2A7vhwOEXAB1uD1MYT+hRBqoR9+
mWcnif0eqkohXEr2D+BXfBOD1jDuaOjAd/JNK9++CCvw88R0E/sK9OCr4G/m
+gra8F7Bu0NQyfijYRrjDBL4Vf4eYex/oYbxNhJ/c4XHWI3XwH/MdQnKeCM8
ybsZMBi/kDy21qC13MOYQxizDvrhM3nWRuxyaMB3MMfSgvfQho8l5jFil0ED
fpSY1Yz1DOzDt8H4Cq9pE/4m/MJYp2Ed3pUcq5hOeX6+d8BwvDnab4fZ+CKY
gk+F8fhu5l3M3hvha3wD1ONVsBF/J/O7u2AXfoU5epjrFJzR3pPPfhh8iL8A
HUXf+Qr8BLyhd/Cb3jPn5ILX8KDuMnkvXdCOL4leWyNMwLfDkoLP7CV8R3Ju
zYVP8XeT59aZ6GzuU47l9/MwXo6+W52Jck85pFyaBfvwZ5PnXg9L8T7cwa2Z
c6Y/PrDkXClCNT4JWjPn0Bj8M75pqfAejyevSWvTs534+8SVg3NYufwJPBV8
xh/jtYwxMfOcI/B6aMn8bCI+uORcUo6Mw4/xdyXfvgof4WdhW3AOX8GHRd/1
bTATv6nktavGVGvXQzV7HQUPKJeSa005d0xnqZwvOkax5xjjS8Y6B3/hffLv
z/K7Ev+WZ0fxTvgZfzm59rbCAnwsz8bAPHgO1kI7sU/DHuUiMdOJfQLuxqcm
u2psEP4jMQeIfRt+iF6D1lLm/Q28vx9G5vu5Dv+dvXYEn9HxzDWn2tMck/Ev
8vpTTnVGj6mxN8MB7Q+q8DN8PwCvhot4L9Thu6J7zxY4iA+NPmvFKHZ48tp0
hn3x2bCy6JpYiJ9iTZ8rF+AiPiTPV+2hhM9PPjv1jFn4ZWK6g/f0B/5P5rVp
jErm+5Pfr+HtcCIzcuWEcuObzHOpxnvwOdG9V/UwAj8d3dt0h734T3Cw4Dvv
wZui72okrMHL5FMpc49Tr7sz+p3OrBH/P7k3KKam5J6v3q//CW/pfpJ7gXqI
esk4aCi6x6rXnozOLd257r4rc61qj9/hLTybm+eUckt3PirPV+XmdJ1h0WMe
5v0j+Xudbx3+Xt5f1H8W4vuj7145odxoSu4durNmfG90bitnu6N7vt7rzu7F
p+X5p9/qPapJ1aZqXLXexBm8nrmmVduPJ/carXGOemV0r9OaFuM3Ruea7lx3
vzXv1+qZC1SLMc+9gu/qGqQS8Ow=
           "]], 
          
          PolygonBox[{{1337, 289, 1335, 1385, 1386}, {1389, 1388, 1390, 330, 
           1340}, {1450, 1449, 1451, 373, 1402}, {1401, 333, 1398, 1449, 
           1450}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9614145481328125, 0.773536370332031, 0.4803850992117185], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV2lwVkUWfeR73U8WUQsikZFgWPyh5ULAKElgRMSICyoqi6UjiY4ri6KO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           "]], 
          PolygonBox[CompressedData["
1:eJwtlXuQ1lMYx3/7vr9zfrtLG2qLGNqt/OMS1TZ2390alYku2wWREVNCxrjU
ikHYbasdt41GGaaStjLRtrsuuQzZZYakLQobo7aEQmTZZWhsPt95zh/feT/n
8nvec57zXApm3TX1zlQURStQjOa6KBqYFUUDUCn8PpMzmS9BW+EyH0X6YDm6
Fe5EL6WjqBXth29CNazVowp4MxrN2lmoHu7CxmFsNaME+9d4syWbN8MforvZ
+yxqk3329GftH85zCuPvnbHmTmN8GxrC3unoLXgb6y+yvga1w+uZOylte7S3
HFXz7Qw0CR6KiuESdDI8HV0ezqO7zkQbU/bNLPgOZ74pRBl4O/d5jrvMQ/vg
nuzJZ+9vrOfBFewZlGU+LYMvQcfZ+y/Khw/wTQt8BOUwfpVxBfw8aoe/Ro/B
jehXuJw9M7C1CG2BP2FuPGvj0DZ4Lv+5K2VnngdnwnuNRdN0/wQ/sG8pGgW/
x29NZG+st76KPaXszaAieKc331aiJXATuiJtb/QBPNmbL29Ag+EUNn9krQe2
+sCLmMtlfIj1p+Dezu6+B/WC7/O2pj1Pw9+F992N/oQ/c8aa64KXhffWm66D
p3j77xvRxd58JF+1oRPwSpSRr9EqeEO4j2xsgd/0djfNtcJz0LspO9Ni+Cu0
jLXb0ZdwMxqTtphugFu8rWlOa/PDfWSjGr42xLfG98LbucNa7lKHHlVsoOFZ
9qZPwlMVcynLodnwx85i+X70EbwjtthQzPwF3xLOq/+4R/d3FnvH0AF4Z/Df
K+ig4o89HfDv2sN4AroeLkKPw/tjy03FdCe8ylvudmF/JfyEs9jTeV93ZkO2
ylgvZv0Rb3sVg5Xyr7P/1hkOOXsjvZVybgg8MuTHueh0eL4z1twIuDb8n2zs
grNRXpbVkEL479hyp6dyjHEz49mR5cw3cLGzXFXOKfcUk4rNPJSGT3CGg9zv
HdQNn89cDmvZKB/+hbmtrP2QVsEi5pkfCY5AL8ObsTkZ+5PQAvhb9m8I+aLY
2uHsreXzDjhyFpvdqA/cw1uuqWaodixFx+FCvl8N93W2V/6Qr3RGnfVt9JPy
KbGz6g69EjujzqocPOqtJqs2d6Ic1qqdxZJq5BI4w9wCvp+GSuECNCq2GjEa
HobmwJdK8B/ebMlmNuPzEvv2InRBYjGh2FBMvQZPZK42NhuytS7UY+V7HVzP
fD+OfQZaHZvE8vGm2HqIeskXqErszNfl6AHVYmexq5gYD+c6iwXl1ER4mLfa
Lh/L1/uCP/RGHd5qnNaUc1cqfsN7TkFj4cXKyZB/8l0bZ6qPrGbuja0m6q3V
A9u99ST1pgLUG+6OrdZtQv8FH8lXijHF2sbYeqtqlGrVcG+5pBp8NbzXWy9U
DP4Mr2XPhMh6xKfwOYm9TT80FH4j5JtyphUuY+461qrQuMRqwrHw/uqVucyd
GdubF8EPBf/KB5fBjeH+8kcl3BTiR3Nae9DZW+ibMfAL3mJXPaIRPtVb75FP
SuAGZ7Zk/2H47MTOrphSbK2JrZcNQA3whYrB2O6guyz0FgvKkVq4KtjTeRaq
H4b+rxpbA3eFeNUd+/N9Hb+DIvNhk2Le21up53/O/r6J1Qb95+DEelJu6DfP
wEe85Z56wmG4Mbberx6sXqyaoNqgGtQCH43t7RUzip3/AcaQLso=
           "]], 
          
          PolygonBox[{{1400, 1399, 1401, 334, 1347}, {1346, 294, 1344, 1399, 
           1400}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9967284527384233, 0.861821131846058, 0.589858203489112], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmGlwltUVx9+87/PchxY6AnaUQti1iYgssthlagiyL19ACApSyhIS1rLK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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVuIVlUUx/f3nXP20UAsiHQcdbw8lEY63i1hdLQsR3uZcabAt/ESeRcM
BBFxNG/jDfHBp7xkPXQxL+mLgWZqOo5BD5LpKKiQYqlzMehBsN+f/3n48/2+
vddee++111pnaPOK+uXlEMJKlKJSHsK5JISz6J8YQifqgttQZK4uC6G6FMJL
KMKVjL3KwmZUAw9GPdhW8D+HP8emAds3UQt8G3/tiW16Mf8BYyOL+VlwL9QH
Ho9mw4OwqcFXPzQWvsj6Nay9hB7DGzKvlY/34V+w+5R77Ea34OPY1GE7HB2D
J6FWLlyD3oZPoreYa0AH4Zn4GFH4GwC3M/ZV4jN3wR1ofVKMwf0500P4AUrg
2aiFfeehOrgTH1PZqxt/3fBc1jTzfz5qhKdisyD1HXXX2kyPEMILfvrDz1AV
tjPRO9hvlQ/mG9FgzbFmGms/QbXw0+i3OoKuwpuK+GvNIHh9EW/d8T34R2xG
JY6BYrEbPWev62gX/Er03stQE7yWNW+w9nU0Ay7nvrtyRrkzMPdbKWeUOxOj
76qYK/bVuXNlO5oDZ/j4ibueUf7BU6L32ocWRtvIVjEaA68r3kdneBeeHP2W
irFi/SQ6N5STA7D/KNrXGbRaZ0FH4a1oAVxiTQd7l/FXAfew7n7wmXS2Mjod
bJPAJ1ALthvRSbhf5re6gV6D56B5JdvItg1/+5k7i57B3WgfvBRdgu+knvsL
5dh3pZ5bgi6qIDP7Po5e8L8jdazkQ77uMf9fyTnyMvdZFH3Xe2gjfCA69/Wm
X8C/Yf97yWt64L+ja30/eqTYRddCPbqgXMqca8qfLfCVIv+UU5vhTdj0xrYa
HYY/i95bY3vgU9h8U/KedzPXgGrhCOqC92IzBtuP0Wn4EGpMnJPKzR2ZYy0f
1zKfSWdTDzgBX2WsqaiHbap/xlYlrvnz8L+pY6ueMoz56ZlzVzWmWqss+ofu
MxA+h30r0wvRz3B75rNqD+1VQU71TV3zqn3VmGptHboV3XPUe5QzT+FRuXvB
BDRavSG6tpSDG+DtRXzlvypzz1TvVE2Pg4dn7oXKqVblW25fOoPOUlXcXz15
SOY30Fsopl/Cx7BbFZyDt+Hzqe+2CH0Lt2HTlDjmV6JroFz0B/XCztS5uBhd
gG9E54pi/Af8JPWceq56r74J+jaohobCf6bOXcX0Zuo9tfc09B18EM0qvj+/
wofQsOCxH+DvU9vWoqPwh7l73U6N5x7TXCU6AH8dnUvq0deUf9FvozvqrtpD
eykml+H66F6gntwA/w++a9y9
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNUjlOQ0EMneT/mQkHCBJZgNwAqFk6FBAV4gTQQw1JSYE4RZYbsAiSliwE
jhBo6Ek+cAHek1+Rwnq2x8uzPbXTi+PzvHOuDkkgL6lzT8AZcAeyDNmGvAXn
mgh4DGbTX4SseOTlnMsB7/F2gpgH4JnyGduSn++NxPQryB3sS+AA2JavpXzG
tIE9cAmoHyFT2F3434PlMHcULIe5tKvR+u4Bn5Hrc5Y/TK3WD3CiWTjTCHYf
/l/gDL5XyBjSSYxrW3pzwW6o32a0OY+iCfWNaBybymNtci9APHb0BfsvNV7c
8yfkWzMMg9lpzt4z2Bn8FdRc91Zjzdvu54ntvyid3H81ywcw8VYrD5zqprxt
gL2EOofAufx8P/DWtw6setvZtbd+7HsL3I12z3I0ftwv81PN5fUXWIe9yWui
nc6F5En+mXyZYqjvK59/qiae5BuixXEfW7ov77zqbbc33mp01GOQGrcMWFJN
1h7rfi3FtXXrUjRes2B/i/ebB9tlT/fjPqizLnt1F/p1VKvibS9lcedOCsK+
9H+zTW77
           "]], 
          PolygonBox[CompressedData["
1:eJwlkDlOQmEURu/jn3QBWjBFdiDUDq1aGlegvdaopYVhFRh2YGIcagFZgoKN
vYhxA54vtzjJeXd69/6d04vj85qZtSDCTzYbBbMZfODbxeyMxA7s4WNiQ3J9
uMcjsQ1yS77r+AOx6+Az5ngtmX0y91GzqVvBE/4MY7xRfLZmaNYy+6wpvMuj
96rnNfpO2m0FmfoFsRdyX9qffyVim8R2oYfvF3fd0MXf6L8KvuMMn8IlfgJD
/C67q0a1k+y3qka12km76Q2+8Yp/hspvDPgBxMpjdfwGMp6gid9CqTzWwhvJ
c+o5xJvFb9MNuuUv+m3r5Dvkj5L7Gmzhg+SumW38N/rb6k0m+D/dzDjY
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1265, 1222, 1266, 1244, 1284, 1285, 1267, 1313, 1286, 1354,
            1312, 1311, 1418, 1310, 1416, 1309, 1412, 1308, 1307, 1353, 1352, 
           1306, 1350, 1305, 1281, 1283, 1282, 1263, 1243, 1219, 1262, 1220, 
           1264, 1221, 1265}], 
          
          LineBox[{1715, 1696, 1735, 1734, 1732, 1714, 1733, 1773, 1753, 1774,
            1818, 1796, 1819, 1854, 1840, 1868, 1841, 1855, 1821, 1842, 1797, 
           1820, 1776, 1798, 1754, 1775, 1739, 1755, 1717, 1738, 1737, 1736, 
           1697, 1716, 1715}]}, "15"], Annotation[#, 15, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxc8uwgEcAPBvFG/QL0cvwEl0MCvMllvyAnHm4NJmZmWYi96g7sh4A+Uk
7uIRqPnzAnwOn31ma/uVvVREVOmkI27p0uaGa/pc0eOBd94Y80dkIrIkrJCj
SIk6qxyyxhHrHLNBgyannHDGE+cMuOCZF3745ZulqYgvF7xInm2qLLBFhV12
OKBBk0tatOlwxz19HnllyAefxHTEyClPkGWSHDMkzDPHMmU2+QdfcSzF
           "]], 
          
          LineBox[{1185, 1199, 1184, 1223, 1224, 1225, 1200, 1245, 1226, 1268,
            1246, 1287, 1269, 1314, 1288, 1355, 1315, 1419, 1356, 1458, 1459, 
           1460, 1420, 1485, 1461, 1505, 1486, 1523, 1506, 1552, 1524, 1594, 
           1553, 1622, 1595, 1637, 1623, 1652, 1638, 1667, 1653, 1680, 1668, 
           1698, 1699, 1700, 1682, 1718, 1702, 1741, 1719, 1756, 1740, 1777, 
           1757, 1800, 1778, 1822, 1799, 1843, 1823, 1857, 1844, 1869, 
           1856}]}, "14"], Annotation[#, 14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwN0DsuAwAYAOBf4jF4DdUDWNGIR4S0GqvF6wZqkyAlIkToBZxAu9OkLQeg
LLiAMmFDPG7Q8g3fBb7B3NbKZltErFFqjyhyzilnXFPnimee+KbBF01aJDoi
BpgiyTQzrJNmgwx5Ztkhyy5z7LFPmQMqHFLliBoFLrjkjnteeOWBN374pa8z
op9eJulhgm7GGWOZUZZIscgCOVbZJk+BY04oUqJClTo1brjlkQbvfNDkkxZ/
JLo8MUSSEVIMkyHNPP+pmjZT
           "]], 
          
          LineBox[{1187, 1201, 1186, 1227, 1202, 1247, 1228, 1270, 1248, 1289,
            1271, 1316, 1290, 1357, 1317, 1421, 1358, 1462, 1422, 1487, 1463, 
           1507, 1488, 1525, 1508, 1554, 1556, 1555, 1596, 1489, 1625, 1597, 
           1639, 1624, 1654, 1640, 1669, 1655, 1681, 1684, 1683, 1701, 1641, 
           1720, 1742, 1670, 1759, 1779, 1780, 1758, 1801, 1781, 1824, 1802, 
           1845, 1825, 1859, 1846, 1870, 1858}]}, "13"], 
        Annotation[#, 13, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwN0DsuAwAcwOG/hBaLtjcwCA3xFtET1GtxgdKkEYm0jYiNA+ACahNJSXsC
r8HjBK3FYySIE2DwDV9++6+/WFkpd0REiVpnxBF1LrnigjYtHvngky/+6OuK
SJFmjAwTTFJgijWKTFNihnVm2SDHJmVOqHLKFnW2OWOHcxrc0uSOe5544IVX
nvmmJxHRSzfjJBklwQjDLJNliUEWGWCBeQrkWaVClV322OeAQ2oc06DJNTe0
aPPGOz/8kkp6qGnNMESWOXLk+QdczTRK
           "]]}, "12"], Annotation[#, 12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwN0LsuA2AAhuG/tEy4ApE6VNUhRrNDu4uISNsIIhK0O27AFbREHSIaXAEh
wR1oJ1aEhAugDDzDk3f5pi++WJwuREIIRcrREEpUueSKGnXeeKfBD7+0x0JI
MkCKGQaZZYg5hplnhCyj5MhTZoE9ltinwjIHrHDIKkescUyRE065pcod9zzy
xAefRFtCiNFMiiaSREgQ6OXPtke7yZAmzhRdTNLJOBPkyFMgyzobbLLFNjuU
KLPLGedcc8END9So88wLX7zyTYO2Vl/TRwcJ+hkjTYZ/PpQ4UA==
           "]]}, "11"], Annotation[#, 11, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzDkuhGEAgOFPYilmlHYRWziCzpJQYyYiTKcSElpOQGf9fxG1OIFlxnCF
EWtrG8sFGGs8iidv97ZNzafmykII08TlIUTsss8Bh5xRpMA9DzxSIlERQjVJ
uulimBVGGCXFKmnWGGOdcTaYYJMMETFHbJFlmxw7HJPnnBMuuOSUK6554oYX
XnnmhyK/tFaG8K0t+qXN+qlN+qGNWtIGfdd6fdNaraOfGnoZoI8Mk8wwyyJL
LLNAzB4ROQpkuft/c0uiKoR2knTQSQ+DDPEHaSE9HA==
           "]]}, "10"], Annotation[#, 10, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1172, 1171, 1188, 1203, 1204, 1229, 1230, 1249}]}, "9"], 
        Annotation[#, 9, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"Wind Speed Fitch, adv=0\"", TraditionalForm], 
     PlotRange -> {{53.85099411010742, 54.37454605102539}, {
      3.7245514195993406`, 646.199220740953}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.40019489998691204`, 
              0.4443496453628125, 0.5838151386658409}, {0.6212599428180356, 
              0.5220402354951563, 0.45385996971719317`}, {0.8423249856491591, 
              0.5997308256275, 0.32390480076854544`}, {0.9261006435272017, 
              0.6852516088180041, 0.3709119949343251}, {0.9614145481328125, 
              0.7735363703320309, 0.48038509921171846`}, {0.9967284527384233, 
              0.861821131846058, 0.589858203489112}, {1., 0.95, 
              0.75}}}, {{-100, 
                Rational[-15, 2]}, {100, 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{-100, 
                  Rational[-15, 2]}, {-100, 
                  Rational[15, 2]}, {100, 
                  Rational[15, 2]}, {100, 
                  Rational[-15, 2]}}, {{-100, -7.5}, {-100, 7.5}, {
                 100, 7.5}, {100, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-75., 
                    Rational[-15, 2]}, {-75., 
                    Rational[15, 2]}}, {{-75., -7.5}, {-75., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-49.99999999999994, 
                    Rational[-15, 2]}, {-49.99999999999994, 
                    Rational[
                    15, 2]}}, {{-49.99999999999994, -7.5}, \
{-49.99999999999994, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-25., 
                    Rational[-15, 2]}, {-25., 
                    Rational[15, 2]}}, {{-25., -7.5}, {-25., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{0., 
                    Rational[-15, 2]}, {0., 
                    Rational[15, 2]}}, {{0., -7.5}, {0., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{25., 
                    Rational[-15, 2]}, {25., 
                    Rational[15, 2]}}, {{25., -7.5}, {25., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{50., 
                    Rational[-15, 2]}, {50., 
                    Rational[15, 2]}}, {{50., -7.5}, {50., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{75., 
                    Rational[-15, 2]}, {75., 
                    Rational[15, 2]}}, {{75., -7.5}, {75., 7.5}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{-100.00000000000001`, -7.500000000000001}, {
                100.00000000000001`, -7.500000000000001}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-75., -7.500000000000001}, 
                    
                    Offset[{
                    0, -4.}, {-75., -7.500000000000001}]}, \
{{-25.000000000000018`, -7.500000000000001}, 
                    
                    Offset[{
                    0, -4.}, {-25.000000000000018`, -7.500000000000001}]}, {{
                    25.000000000000018`, -7.500000000000001}, 
                    
                    Offset[{0, -4.}, {
                    25.000000000000018`, -7.500000000000001}]}, {{
                    75., -7.500000000000001}, 
                    Offset[{0, -4.}, {75., -7.500000000000001}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["9", TraditionalForm], 
                    Offset[{0., -7.}, {-75., -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["11", TraditionalForm], 
                    Offset[{
                    0., -7.}, {-25.000000000000018`, -7.500000000000001}], {
                    0., 1.}, Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["13", TraditionalForm], 
                    
                    Offset[{0., -7.}, {
                    25.000000000000018`, -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["15", TraditionalForm], 
                    Offset[{0., -7.}, {75., -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {200, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"8.221213918010235`", ",", "15.300578343780339`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"9.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"10.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"11.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"12.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"13.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"14.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"15.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7904243465056243`*^9, 3.790424372721182*^9}, 
   3.7904248201547146`*^9, 3.7904248876753135`*^9, 3.7904250139535465`*^9, {
   3.7904250597461376`*^9, 3.7904250829201508`*^9}, {3.790425156689357*^9, 
   3.790425162468549*^9}, 3.790425223615613*^9, 3.79042536657777*^9, 
   3.790425441409998*^9, 3.7904901766384296`*^9, 3.790490268593161*^9, 
   3.812877344925907*^9, 3.813577663068453*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchC", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Wind Speed Fitch, adv=1\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.790425082171939*^9}, {3.7904251545992684`*^9, 3.7904251558237486`*^9}, 
   3.790425220305675*^9, {3.7904253561856956`*^9, 3.7904253654911857`*^9}, 
   3.7904254259902124`*^9, {3.813577654614634*^9, 3.813577677353488*^9}, {
   3.8135777226798773`*^9, 3.8135777263394136`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3HdcT98fB/CUEQ1KqBShokJWKKOjFBpUUiqlpZA0CJktm+yyZ2VT9syW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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          
          PolygonBox[{{1550, 469, 1581}, {41, 2, 1}, {41, 3, 2}, {1530, 469, 
           1481}, {42, 3, 41}, {1171, 42, 1187}, {41, 1, 79}, {41, 79, 80}, {
           80, 42, 41}, {1210, 80, 1231}, {1531, 469, 1550}, {1187, 42, 
           1209}, {1481, 469, 1531}, {1232, 79, 1257}}], 
          
          PolygonBox[{{1172, 3, 42, 1171}, {1209, 42, 80, 1210}, {1231, 80, 
           79, 1232}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.4032744570025375, 0.44543191779641894`, 0.5820047920496265], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1VUlIlVEU/v/f99/XQPMoFREaLZIwKyKiIKI2rTIsQioszWpR2Kag9va0
bF5UaJNJQWD6fM5SmyCoaAKfPodyaNJ9bnra93G+Fud9957/3DN859z7Vh09
k3868DwvDsmA3MHmJeQVxGEfQnIgtViU+p5XDHwMOY51EfAhpBjrQ8AnkBNY
l4Z2LgJZC+nEYh/wM7AOH07C5hQwBjwKuQTJi3rebnzfCRzDty7oxkPbU18A
vAZdC+Q6pBFSCWmAtOP7XvhvA9bjzA3o3gPvooBZKKrVmV0F5AV9YF8IfRJ4
O2J11gInIa+xTgMf4XwJbI8AvwEd+IgGljfzf6Zar/q2v499EbBG5y77xlGx
8qSO/FX5di5f3DDvmxHj6hZ+upHMM+Q24ez8FZ2bkH4meDgQGm8HgWXqF/tG
f/nq1wN8OwabQuBsyDh0a4Dl0NWL8y+Idx76MeAFZz4qndXAWvYLy2VPznsh
cfHeI91XSBgYR5udrRcCB6GPBLYvVS2s/516xF7tCayGs4FxFpfdcXHIdZZs
aFunWepUz8+r5qR6+h2YLdvVkHvOZvmpM96r1LNl2M+APtOZ3aRv5+jznPzm
yDfj/YHdBPwvj1pOzLNJ+TXJLyUh/zm6O+zJZeXAXDh/SfHXrXlkP1rFYxvk
sDM+LgKrPesd53IA3zIC47REc0WOYvJToXmr0Dfm0ezbvalQzEpJo86elN01
3Svmwd5UK2aNZ2ePKU5M+b7QTNRL9za0889Du2+8d2+czWlM5zshw5AR1cp5
4d2aHphuWLFbxcOobNmnj6Gd/w38AWnH+ifwA6QD61/CIfnhOzEoX4zRLp/8
Ni2wmLzPQ/rOWphrkTgbkI8u5T0iznp0B0aUN3NjH9PqK2chBekTrwn5a5Iu
Ia6b5f+T3jq+eenQap4MbeY5w5zJpPhmnFzM30rM/oqo2dH+b2hvK+e0Q99o
sx64AT0I4GOes1o7xEWm5n8HMFd3YB3wY8Tm/0PE+tkiDpl3v/Je6qz27c5s
qzUnedj70M8FruejivUcZ5w1iJ8ucTeqXnQqJ96tXRHLm8I13332gfPOXm5x
NjOLgBud3YX5znhljf3qP/vKHm91tl7sLPak+hdXD9mnbc5slzirc1CzSV/0
z/hV6l9Cc/z/npXp3eVdbdaZAd2rRsWp0VtyTu8v73IBcJOzuhY443hAsZnf
lPIb1/8R/5e4J58p1cF+TUnXqzPZesfSip1S3u2a8SHNIHv0ny8i6+SZLM1b
Sn59xehRTPI0LD9t4umb8uYb/1Uc9YmLlGL1qfdp+fkHVs4q+g==
           "]], 
          PolygonBox[CompressedData["
1:eJwtk8tLVVEUh/c996x9ytBe9oACiWjkI7VEKgwc5KRRSoqIhaZZk4ImCTZv
UIMeI4NevuiG4FC0wiZBZfkg8C/oZTYu0MS+1a/Bx/323ms/1jrrHui+2nwl
CSEchxROxhA2M7EJGvCaLIQyFpqgFp/i9wxx5TCML8ND/Dos4I3sKUp0xl78
C3TkQyjAEr4n6uwMTuBbMq39hl+MFzmjmbP64RN+NtPdp6AVf0bMa/bOQAHf
n2mvv7Ea38lcyloejuIjzPMTKmAUP8xgIxfCIdar8U44jV+Dc3glHMTXiSnB
f6R6yyP4ib+zECZYuwmreCf04L0whK/AK/wzrOPvTbFd8Bg/b4q9CMN4H1zC
L8MY/se012u4j/vnGE8xnoav+HbmEtZyUIuXgiXKuQ7fEZW7xxzBd0FMFFOP
V0Xl7jl77rujvoXHHMO3RZ0doAbfGuVeM69dl+ntfTDiuZvccxjF26EbvwBP
TDX0Wi7BGuNxuIvfgw/4c7iT09wsXjDVwud8bT5Vb3nPTePfTLV4AfP4Lc4f
TNQTt/G3UJxXz03i302xL2EBXza5f6NF/KPpLV5jr3Wr6Vt5Dm2mnvHeaYGx
VD1f/v+/cj9VD3ov+p0PPFfm3rC2AiV+d6q93tPe295D3kv/YvAOU628h56a
auS18h7zXrsR1Zue4wD+F7ThckM=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.6330163903847938, 0.5261718943844323, 0.446948831211495], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVttT1VUUPufw2/tEKljYZSYzsJmkFEQSQfHaDZzJyzSCXbgkmc1UgA5q
Q+BT2EuXl5IIMYWk4IhNFyenqURwJk3LIrCpPwAOIPDYAGX2rfk+Jh7WfPuy
9rrttdfaaRXVT1VFQqHQv6AE0EFMWkDHQF1Y6AedBsXDodA8rCWBTmH+WwL3
Fweh0N/ANOB+7G0B1YC2RShre4R70+BJBW7F/ID2uyHzHGgQdD7M+ZBoboT6
erQXF9+cCPfinnZNAh8BZWFtI7AwoL4CUCfmcax3eNrcAIqBbjjqvQ48BXoF
473Ai/D/BOgHUBLmY8AbkDOE8XvguQp81zM2LaYzCv2QtxB4r6ddjwPHHe2e
AGZH6fcK4JuKmdlt9vTNiuNhrcW0buO9OLcZVC1/KkFVAWNssbZYXpVtPwPT
tWaxfVBo8a/zvJN64D7zFfQBqEnxt7g3SKfZsVXyD0iOyXgIlAof7of+lcAl
0mU650WZA4uAYegYhrybsOdh8du59Fl2TStf7MxZ8H0I/n5HH82/QlG1/Df/
KkGvgqpBVaAjYeZeoXi2yV7LuffFY2fMj6Pa26791zRv0fyw7sDuZ6Wnryme
dnUr/w55nnvHM35mR6NydVD5uks8hxTvZsVxOfKoGJQFygQVhbh2n+d72gws
g/8bICfTMQctF1tBdcI20HHlpu1n4cwDJhv4utaM7xPEIgPYDrwe8MxYwP1a
yWgXz0ndpd3RY8AXISsTMtd6yrokvXswX471DcAU2LgatCZMGTvk0/OweyPW
shz9M7vrQ+RbEOa5RPmdpf028ZTgzHqTB3watBbjpY5+zcTgFumx84ma27gC
fJvAnw18FrQO42XARvh0K/Y/BVbA7qWwf5XnWqJs2Am+fPAXO8qLSket4mn6
S3HmSZzN9NzPEM8O7dfJjiLd8RXIehkyY8A+xxwZceSvE9+vjvk7DNznmKef
A39SLeoCnnbM989UlyZ0H4s862IBMF/3dRdwoWdtfNSTr1U5ZPkyrvGM3WbD
L47vJA5sVwx3A0/qHnfpHuvl1zrlwHrgC6BlGOcBd4MyMF4DvFt1eJOnTrt3
s/u4Y85ctpgEjO+3wDbdeynwY+V/OTCG86OQ841nTTeZL0mm+TMmn1LC/+u4
qLUxrdu4OMqaWRTlOz+mtz+tvjYFKgWtApVo/Ib6RBkoV2t5mpeDVnjWvvnA
EcME2vqRbDbby1RHjf93T5mDnmtlkn/Fc/8PYLJsMFk/eur7DtgboY4LoFrH
uvOVY67bfe1R7lh9tLs8F/CuBgKetbrXozrXKzk2H9a8I+A7+D6gnzN+lygO
paqJ5fKnWf20UzabnCRgjWO9/cJR537VvlHpNB+uBcylcWC2Zz+4DZirXLpD
vWmmLyVJflz2mj6T06/8sTzq0FurdNzrFW/PrHMtqvVmV8jxbSQ79hur7wPA
g471/EvhEdX2HNWNBar5jbJvtXL+Ts/aajV1FDgRsKbdBD4RZf/eGWUfK1Rv
q3f084z1R89+eLtnLtpfYFJ5MCKfq3S3ZtM9euP/4Oxfnv+EOVGem1JOh9R/
rQ9bDHMSKGdS8vuUW5Zjlz17+BL928pU66zmnVAdfsaxx1ivSfbks7HxlShv
c6S7SzoG9MextWbdh8X/bc/5W5489g7tDxDTPXY6yt4im47qTu0Op/R/tDOm
u0Z8U5I1N0q+C3rnaYr5YpH9EazP9UuvnclX/bAeNaw/pvXjJt2z/Y3Oevp3
ydPXUtWFPz3fxhBwvmMNSgemqqdbb8/Ve8rTv65B7+qMcuBrR58K9GeN6z9h
9T1XeWA6e2Sb2XhNf0v7Y54Xv+21qvc9p7xu0t+lW/8T40vWXZnM/wBn13iO

           "]], 
          PolygonBox[CompressedData["
1:eJwtlUdPlUEUhod773w3UcReFnYTBRXFglhANBZC4sIYwYYFrFFRiInGsjNx
Y9nYG9YIsZdE7NGYGGts2H6AoFiWlqjg8+bM4s19Mt+ZM2dOmdurbPW0VTHn
3EqUQNcj5xpZaBN37gb8E52GN6O3cMukcy/jtqZvv9A5uA79hi94fKU4twI9
hTPQGDgXzYRHYDMA//3RfPgkh2ZyLm7dbrgr8CtuZ/zgezl7lgd/Z+AKb6wz
zsEjsRkYM59lcD3aEreYGuDRKDNmNgvhWd5iUUwz4MesjcR2PnoCP0TZcBq6
BvfHpkOw110mEF8BcfZEQ+FcbAbF7IxFcD9s2mP7lfukwUVoVIqt6Vs6+u7M
p3wXsKcVe1NRN7gQpcVsrTs8Fg2Gs1AX+Gy4v3LyBC4O+R2NquAF2EzFdh0q
hd9Hdjfl5AP8Cpt92O5HtfAk7lDIXSrQ5KTVXLXPQTcjq5FqJZ/yPRGbPgnb
o70DQj7z0Gw4C42Dx6MyeGlksesOS+DLrK3mWwVaD19Cq1JsbS18PvRPOapU
rtA9+BNy7P8YWS+WoHfwFW++KtEm+DZxZWFajO7AqUnrzT+oFXyQPfeI5QDa
Bl/0dpZiWANvjyx3h9EOuAY1xGyP9hbhozxhPaBeqOa3hbMza+BbaLqznj4F
54f6qUcWw5Miq3VL1FW9g6bAfVVjuHPoJ+3Jg9uhjDAvw+G2KD1ma8Pg1pHt
7YeGwD2IqXfCajQM7hT6Xz7HwB3DvGhtFNwhzKPWcuBP5GA3udiFnsMN3ngn
qofrvPXOXfW4N4lVozfq/dAv8pmtXoosNsU8FL7qrVbqQfXiTeJcT642oFdw
N2L+Hbc3IAs+FFkt7qsmui97HjqboTZwI3uOOPPxGu6etForB8pFM7/Hne1x
2P9L2Gw+QE0JmxnNjmb0CNzsrdc0gz0ji0mxqaaqrXpOvac3ohZ+5i036lm9
fQO9zcJYVAJ/QXfgvahR+UtYb25Cb+BlmhF0ClV7mznNnt6kR/Bfb73ykf1N
8JCkvT3KkXI119tZOvMY/BntSbEavvB2R91VOfoCL/I2m5rRk97eOL116vED
6j3W8sP3Bd5iVuzy+dJbDIpFd/oXYlbsy/UueauRaqX/kCp4a2SztgZt1HsS
/Cvm4/CckC+9IUfhzHAf2cyDvyUsV6rhd3FkvjQz8+DS8N7I/gT8Hy1EzHc=

           "]], 
          
          PolygonBox[{{1382, 321, 1445, 1383, 1384}, {1387, 1386, 1449, 362, 
           1448}, {1603, 523, 1563, 1561, 1562}, {1562, 1561, 1601, 560, 
           1602}}]}]}, {
        EdgeForm[], 
        RGBColor[0.8627583237670502, 0.6069118709724457, 0.3118928703733635], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVllsllUQ/fr//3f/B5GyCC5RFAEFN1JoEVoIkX2poAhSwAi0BUE2oaC0
gFRjgmjU+MpWQASUsJooi4CRUijLi6G01HelFlrwSQ1Qz+GcP/AwOXfuzJ07
d+7cmdu9eMmkxYkoivpmRVES2CtEUSdM9AD+FEfRMsz/BnwFNA7jNcDpoK4Y
Pw8cChqLcUUsPer/CGwFVWN8AzgENAbjD4DLgWWgDaC6WHgNuCJLso2gT+HI
ftB6UE/7Q7+aIeuYEH8SazaDrwduAv4KOgWakIIt0ERQPmSjade6lNOnStha
DRtfAV+F3vKU1u3A+c+BzoOeAV+YknwcaClovGmZZSPTko0A9rKM87Rx03Z6
ej1lvb3PROuV2f6zRsoi+FoLaMP4Fs+C8VXgQsyPgO8vx4oX43bJujfs9zeR
+MwZ/gZdAH1r/oJlN+xfcVKxZpzfRSyKEJP5wM/BHwQdAh0A1Zt/A/IK0GRQ
U5D8P8fyTdCUhPQavLYf+JyE7E4ClSdkYzbWvA6cZVxp+SrQ9oTsrffen4F+
t09Xg3juQX4fqM65chGyUmBjEH/Z63s73n1AJT4rbZQYuWaI+VKfsdznnGTf
yo1VHpO2Woe0zb6X2iZ9m+K51Y5Xhfl19ptx/zOI/wM423O8E47Xmc8HzfJc
gbHYc+vu49f7DNNxr7mg/qArQXoNwPbI0UaMb2HcGun9Mg86xOKzgY8F3ddw
YEtK+XQ9pfxh7uwEzQk621DgGucc300Pv9PXgubOeX6Hc4821hp3+n1lcr9H
WvczAPih11Cv2m/2L9DTQW9/QlBeP4K5R0FjwOdifmGQrQl+Z02QZWO+Q0L1
YaNrRJTS3tTNMlK/COfvAnmfWHFhfB723rTBvftY57lYdZD1cC0wCrLdwrUp
nS8rlh71e7teMs7kG6AzA+OTwFFY2x+2FwTVCtYJ1pK2pJC+joMsDzqLgIlY
d9ExlrzQOvWgSsy3AudDNhz75Lk+tPrNd44Vs76uh5sc33LX8EPA1T7XD8DF
oJEYL3FMGA/WjRWOJ9f/7Np9AjgPNAzjucD3XfMPAstchw8Al4JGYbwP+In7
wVHgx7H6whFgpfvIYcs3eL/zrlu8/7di+fMCcKBtLoslZ25Q55TvnLmwy77R
xz2upYti6TT5nquN7DN3kroPxjjh3pMEjgcNwF0sAT4VlGNtsXKXOTwaOMp9
gf3h7Vj+vBgr38vcb3b7jhbEuvOl7iufOp6Ma6HnuGaW7+4l4F7fy3ux8n25
e16977UhVj3Y7xo42DWC9aHQ/vMcpUG1aXDQ22TeMoem+a1y/ItzlTk7xzHM
jVXnDrgWz3QdHxD0fjNvvQp8Leb3AIuD6ulA9plIetSZ777zEbAkqP7mA5/w
uxgNfDyol4wM93rGTNefHbbFujXVvWZe0HgtcJBrZb4pU0c7JyXLd3xK3Af6
+fysn6zrZ92T2kWScT4n0hnIsw+ccQ/oYltdQZuxdzVrD3BLQuPTCckGe68C
3wv5h+wL504EyS8Az/sM54LsF1h/i+1zn1rWRswdC8rfJtesrf4/XEwpT1lD
ePe8zzz3iamOX5F59o8ZPluRYxHdVy/ZV2/7TzDZPY39oMj3mYndNNs6aF3+
Ca4kZavR/4PMHLHN47lBf4l3gtbdsXxPSj5/l1Je17nHs5/RXnZaNlgLuceD
aem0SytPL9uPu2t8hhyfv8i4xrG47bfPvetSmr8EfDKttd3S+pMxtozxFft/
d1+fn7Gs9z6ZM9yxXp19oC8d0opr97TkmdrfaHuU8S6zfXfNrlHsR93c+8YC
h7l3s4dz7/aRfLnpus0atDulM+9KKf/znXctCSHzK89rc72+nc9DfMB5UQP9
a6Dr9If/8aT4Fr+BVud6s/VI3I/6NV53xusGJe/JOtsfrmM+Uz4mrf9bUVr7
59iHvUFv6XjQG+Wetbbb4ne7zfxZ73n/WQt83mN+O0eD/Oxkf7527WIN+965
xxw8av0jQXt28Xs/kVIOHU9pz+v2o79zhrlz1nOt/kuedjwq/J+kv4f51mBn
e0r/zCrLtli/ylTj+VVexxr1pWvNF0Hvr9Jv8N+gP+c/QX/Kfe4NK223yvWp
2Xtsd8xqvUeN45jnHsf/2mnfK2X/A3t3wKw=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlFdszlEYh8//6/c/34XRqigSoxWJihHV1goxSlUjNrUitLVrbzFKJCRi
3ZBYFyS2hrrQCiXSmxpX1Lw3IrRxZYbnl/dcPPme73/es97znpNTvm7G2oRz
bhUk4ZN37nCac7XwGe+Vci6Xhr5QiL/jW2WaxbzHx/OtlLbeUIA/5HcB48yH
V/gDYrKIHQUN+ObYuYmRcyUwCv/BtxraDsJHPA2+0JbJonrjv7yt5S38xtO1
Bjxi7Az8K78XmWs3NONviFlM+3B4io+AmYw1CyrxtvRpTrM5f/I/J2VjaY/a
aw7fMogdApO9zam5NWd72jey5uLI9jAC7w+d8SyYj48nfjB958IqvF9sbZ1g
Lj4AukTWZyH+MmlrL4MGfAh9ptN3BpTj64iZENmcw/Bn3nKpM3iOb4stl5Ng
NJ4J3xmrK/874sO8jaUcVOAjveViNizF/zFnk7McfkvamensquE13pI0vwSt
+H36ZDJ3B2jCW5mjMbIzS/C/JxQydjpk4x+8na3O5C0exTbWM0jg/2KL/Uz/
iPbR3tY2B5bhHWKL1Z60t4Gx7U05XIRfVV06q7lHyiV9ticsh0vwW6HelL8N
+BNvtaE9aC+3Q/4Uswm/A6Uhnzvw2thcMVvxfd7OtgxWyKmJqcy7Bebhx/i2
i7YLcBxfE/JRACV4lTfPh2JvMYptghN4GWNsSNqdKsZrQr2pBm7ie73Nrfzs
wceE/3kwDj8Ljfh5OIq/pM9p7Q1e4A+SVmt5cEV3lm/jaCuClbHFKHYj3MXX
qKZD+xWdFbQ4qxmHDw3tWt9avDC2WH2rwhtgC34WXuHf4DF+Br7i60N9K/56
bN/UpjU3x1YTqg31cfgRb3vTGeusp6hGEnZndXev6f1IhBzgq8N6tMfLeB4M
gnKogFPkoL2zGrqGZ5Pzv9TGH8jHJ3o7K51ZD/y5zprYPlCHF3nLve58N91X
b2+HzrwUn+btLdMae+GXk5b7NnAS3xnqSzU3Fn8D5yK7Uy3KTXhPtIbu3nKo
XCrmId4jZWvVm9YuZW+w3mLtQXu5QZ+WhL3BN/F79Nkc2Zkcwpd7qyXVkGqp
IuRmMOTr7qTs7VeNl+DXvdWqxtTY9aFeNOYBPDe2t041koHXxVZLitmvvYb6
V370VqwO+dUe9XbWe3tbdIY6yz1hfbpT1fh/hY7AqA==
           "]], 
          
          PolygonBox[{{1461, 1460, 1462, 370, 1408}, {1331, 1330, 1382, 322, 
           1381}, {1407, 330, 1404, 1460, 1461}, {1327, 281, 1376, 1328, 
           1329}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9307508398002087, 0.6968770995005216, 0.38532760338064675`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV1lsVVUUvW3vORcJSAciUECFWFCmhiAW1MhQg4BFocVEoIDRAGUQEAxU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           "]], 
          PolygonBox[CompressedData["
1:eJwtlV9ol1UYx89+v/ec18BSmxWo/TF1VES7MOd2keUEm7pVOINSszCEXLaR
LheTqZsGBYWsLioMlQIrdXVR2Kxsq1FGqNVFmFtBF1pakosYlRr1+fJ9Lz7b
53f+ved9znOed/rqtqWtpRBCF2Swiz+N/J8FB/HXoQpvgn68Jg/hFv6XYQZ+
XwqhlgXqYAb+Ke2rGLsdhvG3YSVeA/vxexgzt+Q5N+IDMLUcQj0cVx9rVjPu
fliMj/D/4eA1tfZ4xlysCKEP/o4hXA4T8bPaM76f/lHW/gp248eZs5O+dvgZ
H2LM04zfDSfxRbmftQmW42eK8UNwCf8FPgtuu5D5HfQuE2AfPps1prLWFHgU
/562nuB3HsRPZo7FPvgD38ueTrO3l+HV5Db1fav4M78GrmOt62EyPrf4fS2s
w6ujn/Un4yvxuuixN8DV+FPQDnfAPJjOO5V4xgjxnYjfrTPLfIY6y3powRdA
c+4z0FksgEG8OnffNJiPl6P3+hdchb9CeyVeB334xcxnoZiNp/92mFbhGK2J
nqO5eie96xme8TzPWgMjeBnO0fc5lPAPWG9DcE4exdcX+aYcasKXwEPF70b8
MFxTdg704RuSc1Nz7sVbYSXeA9uS19BcrfEkPgsqS97DTPw59vgsfAyH4RA0
0dcIPXh/tC+BrdF3QM/TGlprgD13B+eEcqOZtslFfxV+nrY3g8ecwJcR497M
Z/IIPif67BXDtcov2IV3wInoO6i7qDOeg9/Emr9X+Bk3Jz+jsrifS3XXGDNG
fL6GI/weTo79PDiGn4JufDZ8h0/InTvvwyV+T8mdC1rjNvwCbe+VfYZnk3NO
udehewb/0tZP3yE4l7yG1tKcK3LfSd1NnfFp/CPmfFjEXLGvh/nQBZvhstx7
1x7HWOs36C37GXrWl4w5wPs/A6fw16J9FRzBf4Q9chjB74I7oRM2wTfJud8C
P+BHk2OjnPoEn8nzc/Y5TnmPXwk/ld2mvtHo3NUZndc7JN/1RdCp+hh9dqpB
O7QX1Sj6xuBdvCc5N9+Cl/D10Xdbd7wW317ku3JYudxW3H/dp1b8WOZarZju
yUx7Ub9U21Yk70U19Fa8QnOCc3A0cww6i5gr9lsY08X4zfBY8pl2FDFT7L5I
zhXVtIP4O8nvopqu2l6lGlbhGt2ML4s+C7Xt1Hkkx1pn+Cu+FrYw/0FowV9M
joVipFg9QIw3Zq5hDfgTtK0o4rFYuZu8V62htdbB8pLHNCTfGcV/IwxEfwP0
LVBODONVuc9W36Ba/PHkvWiNharX0bmjO5bx+0Dm2qdv1BDeVtQXnZFq06To
Wq0Yl6K/Sfo2vQG9+I5kV4y34oPRe9MeX8C3FfVFNacB/y/5LinnJuX+Bupb
qJz/B++OrkWasxD/HxxY9gY=
           "]], 
          
          PolygonBox[{{1415, 333, 1412, 1466, 1467}, {1340, 288, 1338, 1396, 
           1397}, {1406, 1405, 1407, 331, 1348}, {1469, 1468, 1470, 374, 
           1419}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9674508291583965, 0.7886270728959914, 0.4990975703910293], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNWGlwlFUW7XT39z5Z1FKJoAxoAHFfiIozEHW0DAngRkAgiLL4R0tIBItS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           "]], 
          PolygonBox[CompressedData["
1:eJwtlnuQV2MYx8/vt+e8J1sx2GhbZmzbVsbduNVWaiVUZLcmulDWP4whxVAY
ontIul9kJqWGWJXKDBqlm3EJpT90M3tJxr1sacvg8+17/vjsfs553/Oc933P
8z7vr7RmVPUj+SiKFkEMa/nTjv/FsBhfCh3wfrABfwdG4l3hXXxN7L5tFQPf
mETRgFwU3QHT8P2wFH8D5uEvZe13wu14F2jm2RNQhM9I3FalGHg3KMVP0l6B
FyTuuwsS/HveuQqfBHvxRliYzecQvjxE0cdM8CNYhn/AvTGR+6hvA2zKrk/E
jqnYihnjh7m3Gf8JWnH9KdeTI6/BFvyL7H2KWY8fhPvxGtiK74epeC0cxZvh
cOR3FhJveuK10pr011oxxu8Y6ylYg2+BsoIo6gvf4n9rfPTdDc3467G/jd7/
JX6Me6toexua8B9gGb4cFuBzoBofB7PUTszRxF4Av+FLiNGXWGWwDs+lUfQJ
bT9CEd4ZWnP/GqjAWxLjzJznVIafir1WZ3GvnOuBxOzKXCqgE74Z2hd4Tu/j
BxPnhsY4H69LPNaj0IL2tlz/o9hc34TvIH4PrrtrTfG1wWulmIq9K3itNKeD
+DmMsQ7/EM7GDxHjVvqPgqdo/xdm0zYLfsWb4Ct8BaT0bwj25+Av/O7gsR2B
gP8XHFsxFEtz1FzbwMX4IOiOd4Mn8CHQB78IWuLDoDTvMWlsJbxzJ7GaoBA/
wr0/ct5D+/DbuPcM8x6s76TxZfmgb65vvwRO5hzzUmKPoM8M+j4APfEzYGWB
37GD9iu4rqTtQRiI94Oh+HgYhm9PnEsToB5/DSZm72vEr089liuhS+p36F29
oDr1HDXXZvpfgnfUGGir5/3leIvUc9Wat8U3J977qgEva79l+ap7r+BtUuei
crBT6j2lvbUHAu0d4Tr63gOL8QNZ/VG+78VnZvEV81V8U1ZvtP9exAclflZz
3JF4j4zL1n8uvijxWgyHbYlrnmqfcnI1fgv3ymnrCCV468R7QWMaiI+F9jnX
tB74StZkfIG/ybHgGqK9PBrq8KcT576e6YnfDB1yfkc7jSXxu3TdB382a9cz
lXK4Nuc9WpV4D6lNfYrxNPHaaY+djz+fjV/tvfH1sceimvA53iq49ijHlGvH
E39b5WAhbWPgXr73CBiAV6bOrZk6N/BfgvfaQ/Az/lhw35FQhU+Hq2kbAnvw
bdpz+FWwGz8Q/Gxv2I8PhYfz3lNj8clQg98Hj+OPwsS8xzQa/xou5NkLYFNw
DioXVSPOVb5zr2WBx6Cx7It9tqjmq/YviH32FenMiF2DVItU87fHrvmq/ar5
B2KfWTq7dMadh79JzEJiNzCedarvWX4pH0/neuLc0jdbiNcGj/U4/Vfj64PX
QjG24t8Er4XmpLkNDq5Nf0ISvAZaiykwKbgGqRZpjZ7Ex8GcvNdwCt6ONSiJ
XRN64Tem3su6V5w6hmLVwlzV9tRngWpGf7wx+NudzungmqDaoD1/Q+qapv2u
eJenHqPGqhp5F/5Zdn4pn3TWdQ6upaqBcfAY9KxiXJY6Z5Q7OmOq8d+DzzKd
WRHtU4PPfs1xPj4cGvP+xhvUN/hb6DeCfiusgI1591HfacFnxTxoHYxcfRYq
l5VT+FswW7kGE/LOOeWevpm+nfq8p7M9+CxRTtdr7YPXUme+zv4XgmMpxgR8
Z+zfMvoNchL/H/8lO7w=
           "]], 
          
          PolygonBox[{{1414, 1413, 1415, 334, 1355}, {1354, 294, 1352, 1413, 
           1414}}]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.8832826192530702, 0.6249049110995065], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmHlwltUVxt9837uwaVHbElmrpQimIFatM+2UYEHUItayI6i1CkSJ4igI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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsjVEYhs+99//PaQkbQ6l5SFRLYsHGULUQocaaCWJoxBBEIqZEwoKa
iaE1hZAurIxdsCG0NS7UtKpOElbGW0Viel7fXbz3Pv853znfOd9w+i1bX7Iu
6ZxbjSJUz88V/veiN3AqOHch5Vwt+uSd6x87FxLO3WK+H/wEmwr4DvoBn0f9
4YnoJvwVmzT2T1EW6wPfr5358HAb+sFcHw5RwHyaNYeZq0KtcA7+c/j/jP98
OBub3KTtqb0noUGwQxPhfObHM78WbYGTwc7eiT0Gw/O9+ZKNbD+jbSm7YxP8
LbJYrEIP4d7sWcDeM3VG+Cdj75jrwPcAvr+wZnvK9tBeb1El/BQF/FVhvwH7
ctQEj2ZsBP8d0Sh4N/ZlnGUv2qT1kcVSPtrFdmadfSmaAvdiLIXvfDQNrmF8
H7YrUC2chU0a37nw0GA+5Vs5alY+8PGI+YsoZr4Leg/fRZ3hbuz521mOcuBG
NAdfs1E53Oxtre6suz+IzHepcgpXMpbN3DBUDc9DY7lbEQpwBWpJms1N+Fxk
taIYPYYTwc5yCjn4OTbF8EBUBx9Hr1h/BZ1UvDhTXcJqqJ23GCqWy9FmuI09
12Tq+1FkNaJa+ctfD7gWXeb7GUrrfrHVaiWqjs2HfClHJ+B76Df8C92AJ8S2
1x+UC5cxdpu5ZnQRboisl5Qj5WorY8eSZlMO17NmVqa+TsANscVaYyfF2OzH
thDNhV+iHSmrsbRiGyzXRWhIMJ/yrRhfghd46wX53ANXecvNXPQCvu8ttrqT
7lbjbU4+WuBGtDFlOWjw1hPqDfVoIzzH29mUYw9/9JY7rfkAX9fZsB2HbsDj
Y4uVaqw7nI3qndV0T7iQO5RiV4imw4diq/XBaApczNhO5haiyfAitA/ejxbD
JdgsxHYXqoGPZPpXe0xVrL3VhmKq2B6Ibe88NBnum8mH3ji9dQPR8ITteQpu
QjsS1hMV8OnYfKmGWmLrAfXCWHQ1shpSLWmN1o4MdvYRmbfge2RvqWq0LXMH
3eV/DILlVLldiUpgH+wtVA93DVazql31QCucF+xtUU8Pgo/FVlu6k+42LRNP
xWQ6fC2ysypHZyLrUfWq3li9tccz62V/FG719rbpjenG/kuCne0gmhHszdbb
rZxmxZZz5b4HOgsXBMut3vQxyl1ssdcbXgy3j+1tVcxnwNe99Zp6/hr8D00y
17I=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtUElWAlEQK+APshfdOOHO4Qi2N/DBY68LcK2H4QRcArmB7SF86gXEEbcm
L1mk63cNqaSG0/vJXTcizoEe0OKzAB6BmxpxmyKuERvEHeACaPx/hrgu6u3h
vcJ87kSUjvrYP0jKPaD2DAyz6sdZPaxvA1v4X6L+g/dTEtcGsU2a/SUf92FX
qcotzckZvr+5q8rDV1Ev3+/AGPwJe0dZeshPjiPrmWf1tfa+l8XdR/wsuskb
4qVvwttsrPMP8cM97OUcd3HPSZW/btU9qGngOzI/BV7skV5nrjHPPY1zM79Z
OzXXLuKV+blnbG3U+Go91HVozwdZd6df+qYOeub8yPfZd37tu/0DHKI90g==

           "]], 
          
          PolygonBox[{{1794, 1044, 1006, 1796}, {1427, 262, 261, 1311}, {1815,
            1046, 1085, 1853}, {1870, 1122, 1044, 1869}, {1271, 184, 262, 
           1313}, {1798, 1007, 1046, 1834}, {1310, 261, 260, 1360}, {1796, 
           1006, 967, 1775}, {1795, 967, 929, 1760}, {1778, 968, 1007, 
           1814}, {1267, 182, 183, 1247}, {1309, 260, 221, 1308}, {1885, 1124,
            1123, 1884}, {1835, 1085, 1124, 1872}, {1289, 221, 182, 1288}, {
           1269, 183, 184, 1225}, {1761, 929, 968, 1797}, {1884, 1123, 1122, 
           1871}}]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1870, 1869, 1833, 1794, 1796, 1775, 1795, 1760, 1776, 1777,
            1761, 1797, 1778, 1814, 1798, 1834, 1815, 1853, 1835, 1872, 1854, 
           1886, 1885, 1884, 1871}], 
          
          LineBox[{1224, 1247, 1267, 1268, 1288, 1289, 1308, 1309, 1359, 1360,
            1310, 1311, 1427, 1312, 1314, 1313, 1271, 1270, 1225, 1269, 
           1224}]}, "15"], Annotation[#, 15, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNzj0ugwEcwOF/E31f3YmvyVRnwCYitAxSH4lFHIDFxwl0EBGkLcHiAmh7
AhQzc73lAAxO4Bme/Nbf+NbO8nYuIja56Yto0+KaJlc8cM8bd7zyQkaHT7r8
keQjUoYYZoYRZhlljjHmWaBKiSPKHLPICUucckaNc+p0aZBxQY9LvujwTX/i
Rwuask7CKnnWWKHCPgfsUWWXQ+o0qHFLkxaPtHnimXc+yOjxwy+RRuQYYJAi
E0wxzSRlSmzwDyyUM2w=
           "]], 
          
          LineBox[{1183, 1204, 1181, 1226, 1205, 1248, 1249, 1250, 1227, 1272,
            1251, 1290, 1273, 1315, 1291, 1361, 1316, 1433, 1362, 1477, 1434, 
           1506, 1478, 1523, 1524, 1525, 1507, 1546, 1526, 1579, 1547, 1625, 
           1578, 1656, 1626, 1671, 1657, 1687, 1672, 1698, 1699, 1700, 1688, 
           1716, 1701, 1732, 1717, 1747, 1733, 1762, 1748, 1779, 1763, 1799, 
           1780, 1816, 1800, 1837, 1817, 1855, 1836, 1874, 1856, 1887, 
           1873}]}, "14"], Annotation[#, 14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNw8sqhAEYANBP/mHtulcMXgATSZJQkrGzZD9uKaUUQ5Kk2LDzAG57yVz2
2M6MeQFs5gFczqnTs7KWzTVFxKrXScSVd95atmTNolUrNkxSESmb7XLITjN2
O+qY246744S7TrrnlPtOm3fGI4998sRnTy14ZtFzS5atWLVuzYZJS8SAg/a7
ZNqsi2654KbzbrjuoTnzHnjphTc++Oi9L75a8M13P6z76Zc/fvvrn22tEe32
2mGfaUfMOOycsy77DyXRNac=
           "]], 
          
          LineBox[{1185, 1206, 1182, 1228, 1207, 1252, 1253, 1254, 1230, 1274,
            1255, 1292, 1275, 1317, 1293, 1363, 1318, 1435, 1364, 1479, 1436, 
           1508, 1480, 1527, 1529, 1528, 1548, 1437, 1580, 1627, 1509, 1658, 
           1673, 1549, 1689, 1702, 1628, 1718, 1734, 1674, 1749, 1764, 1703, 
           1781, 1801, 1735, 1819, 1802, 1838, 1818, 1857, 1839, 1875, 1858, 
           1888, 1876}]}, "13"], Annotation[#, 13, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzk0rA3AAwOH/vN68foJtnCWGlKTEQpITV1LGbCWlFBs5uOHk6Mw4KsTm
A3DdFl+A03bGwePw9Lv+oivZxUwkhJDloimEawpc8UKVEmUq1KgTaQ6hgU66
6KaPflYZYI1BUiRIM0yGLCNsM8oOY+wyzh4T7JPjjjz3HPHAMY+c8ESRMiUq
VKlR/39tCaGRHnqJs0CMeaLMMUuWGbZIkmaKTSbZIMUh6+Q4IM8pZ5xzSYEb
bnmmyCtvvPPBJ19880Nbawi/2q4dRImRIM4Q0yRZYpk/G4Y4fw==
           "]], 
          LineBox[{1186, 1208, 1229, 1184, 1256, 1276}]}, "12"], 
        Annotation[#, 12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxkkrBGAAgOFvynIhzmJm3OwJSVJkzdWFJMtgKNkSpfgJHJ1wHRHZIusd
N0vxB7gYZ07jOTy9b2livm8uEkJYZisrhBR73HHPK2+k+SFDyA6hgELKqKCc
ASoZpIohqhmmhlFqSVBHkmlSzLDHLAcscMgRixyzxAkrnLLKGWucc8Ezl7zw
yjdvpPkh5IQQIePjGqOXKD2U0EUxHRTRThtTJGllkhYmaGacJhI0MsIoY6yz
wSbb7LDLPldcc8MDtzzyxDsffPLFL3/k5YaQT5QY9cRpoJMuuunnH6eTO94=

           "]]}, "11"], Annotation[#, 11, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1173, 1188, 1189, 1190, 1212, 1234, 1211, 1233, 1235, 1258,
            1260, 1259, 1278, 1277, 1294, 1319, 1365}], 
          LineBox[CompressedData["
1:eJwNxUsqxAEcAOCfBRYWXuMVFi7AzDBJEyU3UEbSn0gpi3EAbsAJTHmTkbLk
CPK24QQYY88G+RZfX9/i6mSxJiISrmsjdtimwDQz7DLLHgn7zHPAAocsccQy
x6xQ5pQbzrjlnDvueeOdByo88sETVT755Y8fuusiuhinkzFG6SBPOyO0MUyK
HK0M0cIgzWRpIkMjA6TpJ2GOddbYYJMSJ5TZ4pIrLnjhlWe+aaiP+HKP0/SS
IcsEUxT4BwxqML0=
           "]]}, "10"], Annotation[#, 10, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1172, 1171, 1187, 1209, 1210, 1231, 1232, 1257}], 
          LineBox[{1530, 1481, 1531, 1550, 1581}]}, "9"], 
        Annotation[#, 9, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"Wind Speed Fitch, adv=1\"", TraditionalForm], 
     PlotRange -> {{53.85099411010742, 54.37454605102539}, {
      3.7245514195993406`, 646.199220740953}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.4032744570025375, 
              0.44543191779641894`, 0.5820047920496265}, {0.6330163903847938, 
              0.5261718943844323, 0.446948831211495}, {0.8627583237670502, 
              0.6069118709724457, 0.3118928703733635}, {0.9307508398002087, 
              0.6968770995005216, 0.38532760338064675`}, {0.9674508291583965, 
              0.7886270728959913, 0.4990975703910292}, {1., 
              0.8832826192530702, 0.6249049110995065}, {1., 0.95, 
              0.75}}}, {{-100, 
                Rational[-15, 2]}, {100, 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{-100, 
                  Rational[-15, 2]}, {-100, 
                  Rational[15, 2]}, {100, 
                  Rational[15, 2]}, {100, 
                  Rational[-15, 2]}}, {{-100, -7.5}, {-100, 7.5}, {
                 100, 7.5}, {100, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-75., 
                    Rational[-15, 2]}, {-75., 
                    Rational[15, 2]}}, {{-75., -7.5}, {-75., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-50., 
                    Rational[-15, 2]}, {-50., 
                    Rational[15, 2]}}, {{-50., -7.5}, {-50., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-24.999999999999943`, 
                    Rational[-15, 2]}, {-24.999999999999943`, 
                    Rational[
                    15, 2]}}, {{-24.999999999999943`, -7.5}, \
{-24.999999999999943`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{5.684341886080802*^-14, 
                    Rational[-15, 2]}, {5.684341886080802*^-14, 
                    Rational[15, 2]}}, {{5.684341886080802*^-14, -7.5}, {
                  5.684341886080802*^-14, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{25., 
                    Rational[-15, 2]}, {25., 
                    Rational[15, 2]}}, {{25., -7.5}, {25., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{50.00000000000006, 
                    Rational[-15, 2]}, {50.00000000000006, 
                    Rational[15, 2]}}, {{50.00000000000006, -7.5}, {
                  50.00000000000006, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{75., 
                    Rational[-15, 2]}, {75., 
                    Rational[15, 2]}}, {{75., -7.5}, {75., 7.5}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{-100., -7.500000000000001}, {
                99.99999999999997, -7.500000000000001}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-75., -7.500000000000001}, 
                    
                    Offset[{
                    0, -4.}, {-75., -7.500000000000001}]}, \
{{-24.999999999999975`, -7.500000000000001}, 
                    
                    Offset[{
                    0, -4.}, {-24.999999999999975`, -7.500000000000001}]}, {{
                    24.999999999999975`, -7.500000000000001}, 
                    
                    Offset[{0, -4.}, {
                    24.999999999999975`, -7.500000000000001}]}, {{
                    75., -7.500000000000001}, 
                    Offset[{0, -4.}, {75., -7.500000000000001}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["9", TraditionalForm], 
                    Offset[{0., -7.}, {-75., -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["11", TraditionalForm], 
                    
                    Offset[{
                    0., -7.}, {-24.999999999999975`, -7.500000000000001}], {
                    0., 1.}, Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["13", TraditionalForm], 
                    
                    Offset[{0., -7.}, {
                    24.999999999999975`, -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["15", TraditionalForm], 
                    Offset[{0., -7.}, {75., -7.500000000000001}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {200, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"8.256106676759565`", ",", "15.068097752833927`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"9.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"10.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"11.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"12.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"13.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"14.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"15.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.813577727381785*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7904243870755568`*^9, 3.790424394110364*^9}, {
  3.7904247639172792`*^9, 3.7904248144912033`*^9}, {3.790424880836952*^9, 
  3.790424886033677*^9}, {3.790425213239052*^9, 3.7904252333888545`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7904243870755568`*^9, 3.790424394110364*^9}, {
  3.7904247639172792`*^9, 3.7904248144912033`*^9}, {3.790424880836952*^9, 
  3.790424886033677*^9}, {3.790425095407351*^9, 3.7904251053746247`*^9}, {
  3.7904252772748156`*^9, 3.790425281464591*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"LredFitchA", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<TKE Fitch adv=0\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.79042511329219*^9}, {3.7904251451479115`*^9, 3.7904251489914513`*^9}, {
   3.7904252836393943`*^9, 3.790425289602617*^9}, {3.790425387663539*^9, 
   3.790425388026908*^9}, 3.790425430736617*^9, {3.8135778568502536`*^9, 
   3.8135778616118975`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3XdcT+/7B3AtSUUSUURUGmhQRHQ3lIZ2SXtPKZWKZGeVKLLKllF2NglJ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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmgfUltWRgN//K/C9EhU7EcUGKqIIYtmNIqAuxbLZIApKEbAgXbAlahKU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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVtsFkUYhmf/fxd2YkisxmiiVKvl0BaQQuSGSEUMUkU5aKGlIrZ4RGkF
y0mDSgXUoEQMlKMWq9JqQBSioDFKvNAbE0hMvNArLjDBRJMmKgGK+ry8e/Ek
z858M/PN7Oy3Ve2d8ztKIYQNkMK7MYQK5Gw5hH34VFhKwBaYhh+nL0tCqIOZ
WQizaJtO353QiN8T7TPgXvw+uAuvhEvDQ5gd3ac29T0Ki/GHoRrvJOYcc5+C
IfxP1huJ3wDrWe9DnlvIsxk+wg+mzv1l+AT/LXXs9bCa+H6owm+CDC8NC2ES
Xg8BT2Fy4rYyPkjMsMR71F4/Tj231tTaF4kZoK9bMfh/meeaCP/iF2jrTxyj
2H9oG554zq8Y/0exn3PMdww/Aqe0F/gM3xN99t/BbvyKPITRnM0YOISXoBof
BX34lcRMxhfpDPEWWIA3wbP4c9CML1QMvjLaFbMC/zT12t1wKHVOyk05HcXf
h4X4AujHh9jTyWJ/HbyfVTy34ougC+9hzr3k3gU7os9IZ6UYxTZmjtWZ6+z1
jvWuNedF/D3GXJX6DvbifXB16rb9ulvQQO53wF/EN/A8reS2QZ53EFdDrrrT
2/FdUIfXwr7UOSt3vaPl+K7os1bOO/E9xIwndpy+BXx3atcc7+B7YUJwTK9y
gqbgNvX1pT4rtR3AP0h9V3WGA/hJ9j+atUfpG8J/yOzVAv8VxuJjYAp+GG5O
fIdH4D9n7tMc9XhF7rsxFo7ix2i7JfGYa/DTUJN4zqn475m/3VqYgZ/IvLbG
jMTPQ574zn5Nvmcyx2qOBnwo811XzDe6H5xZW+p3pHd1lhxuJZeJMAcfzO31
0Iy/TsxsznolvIVvhll4FWyKvoPdRT06jG+M7rvA+Ffw7mj/CTbgL2kMvhle
jK5Rl2sVTMe3qQaVvabW3gKNZa/5Kr49OpcVsDV6Ds21CV7A10evpTW0Vg/7
v5G9V8JW/A3VvLLnfA1vgvnEzoNn8L9Tx+qb35i5BqoWqsbt5zx2pr6burM9
+IHc37a+8fv1/RTPqgED+MGiHqitHz+e+93rDswl/oui/mk91Zo3o/emHJXr
56lro2LO4N8yvqa4P/PoP1LcJ60xR7UEHih5T8tVO+DBkts65NF7nQtP47cx
fhw+Xu8Iryzmr4UT2ktur4Pv8bthQsl35jR+e+6xavsFfyz637AEavDHo/0R
xeDnc9+tSdCmsbnnVg4/4tcW56McvsSfiB7bpjH6N0XXEv3DZuJPRve1wxS8
HR4q+R9VqbHQWnLbdfi6Ij/1L8XXFv8z9bfha4rxGrNEdyP6rJSPzr45ulbr
TDvxJHovqunL6F9drKf6vhh/Pvpuas3La0f3KaYCX1U8tygHvDfzv0939hLv
uyu6T/+EVvyp6L3qH78Mfzu6duub0bfzP3lz35A=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.36303924273571764`, 0.4312917466483353, 0.6056574419700574], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmgmcz2Uex//m95sZv20tXUKkS7p2246hIjqVUkJFCZUUyZFxFxMpunQn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           "]], 
          PolygonBox[CompressedData["
1:eJwtlnlslEUYxr/dfrvbEVFBuVRQI5AoigGliIAYQRAEWg6leAH15Gq5BGm5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           "]], 
          
          PolygonBox[{{2375, 2374, 2376, 539, 2041}, {2314, 2313, 2320, 564, 
           2163}, {1904, 547, 2213, 2046, 2047}, {2364, 573, 2369, 2027, 
           2028}, {1352, 343, 1534, 1532, 1533}, {1247, 1246, 1245, 282, 
           1390}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.5333984657867705, 0.49116240011675644`, 0.5055101670774256], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkj0vg1EUx2+rvU9rsDCIWLr4DhKDRKQGg1BiIpogJd4iEgwMEobW22JR
+hGQWETExicwkSaaCgZCqy+Il9/JucPJ/3fPc+/J+Z/zROIzvdN+Y0wbUUOk
rDFbPmMi6IJnzA3sCxlzETCmH/4KcubbClxFZx3PoY/EITzCu3s4DQ/CefgA
HoLT8DZcD3dTqxU+pfYd+X04Rt4jUvA6uRJcgDvCxozBV3AWrfO0zx2rb+Tt
LfxDzQG4C/3jfAT/ogXuvMPt1KnARenf01pScxStJTbhJPfXrPbQiMadl5zV
WlJzyapn8S7zaPJrTel1kTonqB8NOpZcgriGX7j/6embaFjnKHUq6BSRgZ/R
ee4cS330w2r/RTiKtz74jLn1uBmG+D7u5vyAJtwunqzOWma+Z9Wz9DmJtrhd
yE7yrrccOux2kUXLVj2VyS9b7WcFnXD35Z14EC+d6GVA5y97yIQ0L15LnGPk
X3m7SiThBqsexEuB799udyXyG1Z30Yy+Ob9F9DygdSrwrutffFSD+n8Wrf4H
0r/4+Aep0G3E
           "]], 
          PolygonBox[CompressedData["
1:eJwtlmtM11UYx4/w/5/zB83KWlprgS+grRstm5iDLku3rNUqq2UvbEE3s8Cy
hmmjZUtfSIkvMloptnohvVDcaktdK+gC1iK7ONqk298SA4L8E9B0RZ/vnufF
B57fuTzPOc/t/OfXNd7ZUBRCaIMM9PKnB5ZnQ7gLVsC9WRvTXC1yDQzAj5pL
Ibw5I4Q3YCCGcEcuhNuhAONwDPIwBMNwAh2D0MTedVAJFdAF3XACHTvR1Q5P
IOej6d8BjyBPsXcSXmLtJrgBroc8HINPmOuGj6EL5rPnFfZuhW3IfzE2Bs2s
fR6Wcaab/Iw662OMrYJvWfMdPMT9PvfzPIj8FnO74D/mpuFfdO5l7gg8w3wz
353I+yDwPcV3M/I9cJp9E9Hku+EfvrdhsxWqSkK4Eq5DvhaOwgA8lUy3bEyz
90bWFJBPQiHZHXQX+VS+LUpmW2dYi7yU9RcU2Z4JvlvdHy9DKd/bo/lGY7P5
vg+bK+AUnIZF7K+Ga2AxXI6ty6AXDsEv2PwZGpAb4UvkLzKWM8qd8eRnhUnF
T3nl9/+Qdb9Hi61ivgp5RrKz677y7Wes+RRuZd9tMAajMAwj8ANz/RmLmWK3
CKqhX3OyH82WbE5kLaaKbR1yveeQckk5ody4MJpv5I+WaDFWrF9jTZv8DMc9
55R7o9F0L4e/sxZz+X8LbGTuWc8P3Wk9chlrLoIPYD/MY6zF47EZuQAn4Th6
BmEkWu4pBx9N5gP5QjmuXE/I0XNSuZlJZltnyCLPZew86IR9XiN5r+Fa96F8
uQSWwgK4Cg7DN94D1AsUA8Xia+iDlYzdD2fCbNgNHa5jiftIvjo32nl0xxfl
W3KqBS4hly6FbuQuqISLc+Zj+XortCo+7h/p0N0q2VNRYjqkSzqkSzWkWipH
LoNNyJu95wx5T1JvKocytynb58M8OAAH/Qw6Sw/0QoBp7BbzPwPvwNsQIcG7
0AGz4AzY4vmjM6dkPXLAc1K5Oe69UTWmWnuSNWuS2ZCtyWS1Mg5TyO8z9p6f
UWc9At97j1Cv+Cla71WPrEOuYuwK+Ar6chbDw16zqt3tjL0KC/DR1XAO8hy3
IVvqce1ej4PRck6516P6TNajuzyHlcu3wM3KQdamaD6QL/bA3pzliHJFPUG9
Yb/nvnJyrtdov+ecci+5bzvct6uT+UI9rN174lHv2cs8Zgc8portIe9NFf62
rEzWX+SfX6P1WPVa+UC+WOy9bQfyTo9xscdYsX4gmS+k47doPVG9sQ7q/Y57
3Ify5Ux0lcJa5Kfhcd0hZ2Oaq/e9RcjFUAs1MIKdP6EUGyXQBOtgFsyEDfAc
DMMQNEBjtDdUb6l6sHpxIWu9SD3pYMZ0NLkO6VJNqDZUQ6qlDcjrlVt6J0rM
hmydBWdHyyHl0kKozlmMo59RZ9Udddc5yiXYiPxCzmqw3HNMudbG2OuKW9be
P72Ja6L1OPW6Mb3N0dZord4cvT2KiWLzB2uGkvWY3d7z1Pt0Zp1dNmVbZ9BZ
dCfdTT6Wr1d7LKRDumrc93oD9Bb0eW8bY240WQ9WL9abprdNb4zeml7vDaqx
KvfJQq9J1eaprL03uuNHGeu5nd4j1SvzyWpJNfVwsh6nXqffNPpt8z/4mks9

           "]], 
          
          PolygonBox[{{2049, 469, 2209, 1904, 1905}, {2032, 497, 1780, 2030, 
           2031}, {1217, 1216, 1204, 313, 1360}, {1647, 1646, 1524, 339, 
           1520}, {1523, 339, 1351, 1518, 1519}, {1769, 415, 1772, 1770, 
           1771}, {2029, 2028, 2368, 497, 2032}, {1544, 313, 1654, 1354, 
           1355}, {1553, 1552, 1666, 395, 1663}, {1776, 1775, 1773, 455, 
           1898}}]}]}, {
        EdgeForm[], 
        RGBColor[0.7037576888378234, 0.5510330535851776, 0.4053628921847939], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkk9IVFEUxs/YzH1PA2kjtGgzmxDaiBAMA+pmCqSNDoIwgqHoprDBRTii
Cze6aTOW1ljqwoLauJlqE25kDKJFBP6paCUEKiUOujb8Hc9ZHL7fO+++c7/7
3ZceLuYfNYjIXeoKtZkUySZEaujjSGQPPg8iO9QS3E3vC/wC7oQfUCdwnd43
qgLn6CWpKjxH7xiuwx2NIn95noSP0J/US7hHZ/iaOpqlvwB/RLN804LBDNqf
Ehmm30x/jCrBh2iP7/sdTfm+uv8mz8/hDPzeZ7ZGdh49VyKy/XRf9Tiu77Qf
00uZzyJru6hFeAPt8xx20ZusfwZX1UPKctP80vSfwm/pL8fm/xWad/96jtfB
1txGT4N5uMwgWJ4H8LSfJaA3qHl4jffX4TK8ohkEm9mE5vy8NfSTe25n7TXq
AzyLdvvdfUXv4KMX/odO8e4/3IhPiS0HzaPgd/QLPaA+wyP0I80UfkLvTWzf
JmPLS3PTe571fa+iA1QN3o7se50zij4M5uEID/mEcclL52ivEuy8tzQbX3eG
7gebOcicezwPwTG9Jt+3DM+4zxhd9bvQf2rb/RTQd8HucR2d8Bw0j/vUFvwD
/ROMh3ROsLto0+z9LL81k2Ae1MsFgVB2DA==
           "]], 
          PolygonBox[CompressedData["
1:eJwtlm1MlWUYx58j5zz3wRfMhAVGi+MHjpuVljrJzdTmF/pQwrAlbmHAonzJ
trSgbLBo4lY2oRKw5ZZ9qGwuxWyL+hJkA2tmpVZLseAoWG5SttXW6++/6/rw
27me+/2+r+t/XSdTv7X6sSlRFL0OSfg9HUXXoBbWw580/gE7U1HUAdfBTHgH
DkImP4rKoIOxu6CFtmb4kTk/wbchij5NRNEgrMceoe88VMCdsplzDirhHriL
tuU+RmPHmDMKD0MTdDGmExay5+1wgDFvwH86PL8boA4+5/sL+B77O1gEi+E0
bd9AA3Yj3Aa3wjCcgK/hK29T36E4il7m7K/AMuyz7H0GVsBK+ACOQQnMgcus
PZG0N2jxN9PbTdL2a9LOsMj30F6DrLmXtbuhEjvBGv9gn4Xt3PcMbb3Y+6AW
+2P6P4IyyEA/a3wIN0AxvETbbpjP29ySb23qOwJ9sJA1OlmrC97Eng97Eta2
H3stY2rgOGf9DB7H3qo31FvCl6x9EpZCBfwNf0EDNMImxm5M2Rvrre/HXsba
D0GV3pkxQ7BAPoQfuOPxhMVIXbAxGlsP1dhJ7pAHmxm7Ba7QVqU+uIq9JLa7
yEdvY9fStg6G2HsY0rGtpzOs8Zir8JhQbChGFau6o+7aBq0p86F8OZ29p8E2
9t4OJ2LzVY/Wwz4Vmy0f1WBvhuaEnXFTbDGp2Ozhtxc6YU/KNCVt3cjac+A5
1m6HnGLeNSAtlMHN7uN+X6PH19BaSeb8m7CYibAHYQCyMA8mGDMOq+Bu16y0
GyCdMp/Kt/KZfJeFchhQbMKTwdbWHk9h/wxXsYtIGvvTFlNHPCcoN7xL20GY
AQVQyN1mwzPYO9K2Z3DNSrt3sN6rrq+jiu/YvqWJ1dhPB9OCzqCztEAzTIG8
YD6Rb7SH9iqU7ZqUNhXDiuV72eu+lL2x3lo5S7mrS3qAcsjGdkadVT6RbxRD
iiVpQtoo8Lu9B4eVr4LFg877iWLN851iepzvF+Ao9vswNdibDrhP5ds+zy+K
4Qz9O/nuS9icEExjSz3nKPfkYAx+kRZcQwtck9KmcoxyTavHcpq24D6Rb3az
/ouQgbnwrO4Ms+B6uAQX4VHYCGMwCk3wCKzjTA/AOezzseW8Es9Jyk1rguUq
6eE0/auD6UNvNBSbhqVlaUraavTcIY1L65XB5mrOScang72F3mQH9gXaRqAe
GmKL6VWuGWmnjbZWKIQimBpbLlEOCLHlROVG1ZAuz6FlrhlpRzVFtWUvdrdq
GnM6oBRuguehHYqhJLaap9pXzpxsvtUc1R7lIOWiPI/VJ2AbVDO2ymusau0p
5dSk1SzVriWssRh66duXtpqn2jeiuwerybWec5V7u1U/oIC+mcHOVOxn3uVn
LnWfy/dveb5Uvi9l/IPBarNiNucxkXFNSBu6k+6mmqLa0uBvP+qxcSw27Uqz
K2KrocOeQ5RLrnis6s66+wzGTPeYU+xdZP+c13jV+tfSlluUYyaC+UC+0Jvo
bZbDZML6lYsOuxaleWm/yH3f7r5SjVet1xvrrecFO680V459wOuhamAx39OC
aVUx14Y97vlOe/7G2IpgWtd9+/m+DC0Jy/lbtDf9s4P5RL5Z6f8V9B9H/3U2
0FbnMXzBNdXkmrvkGpzlMaxYvpayWqc9JlP2H6nSc0DOc3zWa6pqqzQpbdZw
hrXwP3tJSgo=
           "]], 
          PolygonBox[CompressedData["
1:eJwlzkFKAnEYhvHPyBmFLCE7QJu6QrRvWyQW6aYYaJFELWoxdQqXJrbzBNEN
pCtEERSBoa66QfQbXDw877z/D97ZzK6bV0sRUUcZnTRiXIr4TiJO5DbmHg51
ezzFDIn+SVfmHHeoViL+dCNOUcEAD9ipRmwYGspfbj9xjhf3Gb/bG8gffIoz
zPS/ui5P8INb3KCEV2/3/Oi2Jw953XcDq3Kmy3kFNRz4732MlyN2vR3LR25b
6WK32H/jLi6KfeS6S97GVrLYKLb6vFbsoCc/6+ryP8FqKY4=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.8741169118888763, 0.6109037070535988, 0.3052156172921622], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkc0rhHEQx2etfZ5nFUtWURw4ujnIgRxcqX2pVZQLiRAX7UbJ2cVBavN6
cHFwU95uSGpPLspetpSXOPAv8JlmDt++35lnfjPfmad7eiW/XCciAyAODiOR
NIl9eCcUuYqJdMBF8IJeh/fANboLngD36Ek4DS7RR4FIp9ecorc93wY/E9+i
s+hxf/sEN5KfQTfBVXCHLpAv46MVP31JkVpg9TrzA/yiv+BucIM+5/ux6x64
17XmUuACXabmJ2Y9dc9CQmSIuFIv0u77nlAzF1rdG7xIXEIvwV/UZ9Hf8Fho
uzzoLsSD6EzCYs2PwrnQdqmE5lU9H0RWp/WPzN1yby3wPDOKOldn+s319rt+
h1po/0a993OTTeI/ahrI5b1nLmFe1fMCvOG31RuPuH/dYxhk0O/wqs+Kw2eR
9YzgqYS9TfF2jW9VdBBaX+3/GdhOeiv1pL3Vf8nfa59kZPmMf8u5T71Zs++u
/2fdPaiX2cDqX6n5B01FVbw=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlWFMlVUYx99rvPd97zSt5DZRaV7c4jotpdIJtqSWH8S2lGRuQosEmptl
9SGbpQVLSz5EEz8YZrVJW2bLaaQWyhbCWl4rQA0QQ7SkzaZtNdtqy9Xvv+f5
8GOHc59z3nOe5//8T2bd85UbJwRBsBfyIBHyB9pgD1xKBsEY1EE9HITPoAyW
QC8xPTALMrA1DoItMCMVBDPhOHOdMA0KYIQ156EWnhbM1cJ3fPx7R+O1zFVD
FzEn4FFYBg3M1UM/MQPQzNwOKIS7YLLOmgiCB2ENcR/y/wewAErgR9acy7M9
tJf20F46g86ynZhtUADT4VnmNoS2RmtbmHsbimA2vMNdW2Aed70HjjJ3BJZC
OfzGmquwmT1egU3EvgT5xKahmfEOKGachRFiz+fZN/XtJvZohDTcCQuZewDO
wFlohZ3wN2v+gV3EtEIxZKGd3/Z5TVXb2X52xSj2OHTCfVEQ3A/VjNd6jVSr
+ay5F3JwOrSa1bompI0sc8WuAWmhhrtUw79wE25n7jY4AJ96DpSLy5z1Z3iY
mHIYhYuxaURa+Rw6oIpvrFbdYBC+Yc0Sr29VaHfUXd+FNmhirjG0nCv3e1zL
Oz1X5V4baarLNVzmNVPt+uAH6Y1cLINFyjnsh0+SpvFZrmlp+wnOXAk34K/Y
NFjoGpFWOvwuyoFyUcWe3Zz9JIy6JqXNdvjI76C7zIV5ScuRcvUCa18MLabd
z7TINVrgPaBeUIxipSFpqSa0XKknnmS8ku9/nbAzDBP/hc6oOjI/B04x/hYe
Yrw0sjvv955X75+EbljMb6WRnXGu95h6bQU5qIArMC5t88234A/O8idUELMc
cnAaVsFK6IcB73H1eo+8BYbYY9A1Iq1c1R04+8uwwXsi7T2r3pXnyHveIHZb
bD2p3mxlvEs648xTMbzrrL/MuAkaIYYUvArD/Dakb0TWk+pN9bh6fZi5IfUJ
1EAdrIML8BPUwlMeo1j1uHpdnihvfA9+Z+98zrCXcRn3KVW95I2h7am9z8I5
uJW1k1LmGfKON5nbDhNhElxhzeMJy8kjjENi8+A5YjfCa36f/+B11df1Jw08
xvhjcvYl468g43e44HfQXfoi06rWrGJcFFms1rR5zpS7LbAVuvjmCchAEbyv
viL2GEzj993qtYTN5fN/LzE9kIU58GvSarsJ1iftjhO9RqpVWt4JR+GYo/F0
vTnuIaOuQWnxlshqqRxsZjyFuclwCA5DOrKz6EzNuh+5y6TMk5s95pB/U98u
hcWuSWnzOlxzD5AX5OAULIAS94Qb7onyRnmsvLbDe089p967G4qVT2oYu2fL
u9Uz6h15mrxtYcq0Iw3vju0NOOMeLa8e8F6SZ8o7G4ipj00T0sage6k8Xl4/
4trTm6K3RW+I3hL1rHpXGpKWpEFp8Zmk1Uaaa/AeznkPq5fXuN/Ioyv9zcj5
G6G3otd7Wx4gLxh3r7jmuZzK3B3+5untUw+rl1UT1eaXyHpXPTTOuCAybamG
LYz3Je1/6XOm8hmb9lV/9XaJ16YP+mN7kw54zpX7wsjWao/WyGL6vOalrtGs
11i1riBmeWRvht6OIte+NC1tyyPllZ3+1spT5a3d7qU3/a1UjVSrMc5w0T1B
3jDDta2eUm9dYu2Ye06dv1F6q+TZ8u7/AQ+PQeA=
           "]], 
          
          PolygonBox[{{1371, 1370, 1225, 316, 1372}, {2195, 2194, 2353, 531, 
           2196}, {1917, 1916, 1798, 472, 1918}, {1809, 437, 1808, 1925, 
           1926}, {1831, 1830, 1714, 441, 1834}, {1551, 355, 1661, 1554, 
           1555}, {2058, 511, 2219, 2062, 2063}, {2004, 2003, 1882, 450, 
           1878}, {1636, 1635, 1763, 374, 1638}, {1867, 448, 1748, 1865, 
           1866}, {2017, 493, 1895, 2015, 2016}, {1504, 335, 1342, 1502, 
           1503}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9230792547827363, 0.6776981369568408, 0.36154568982648255`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkr0vREEUxWfxZvZpno9YtcpXaKzCJj4aCkKhXZv4eCsqGkpEIZEoFPwH
CqVINhGWlegUIgoSG2LV/BF+N/cWJ+fMnfNmztz7ela3FjebnHN50AwWMs5t
gx3wC9rZ7ADLQdef8HFW6+/o06zuD8XOdXrnUjwJPMveA3oOXvF6Zh1+AjX0
NPVzcIsehAvgHl2BB6zeCx/iL6Nz8KNXzyT170izNuCCaamte82ewkusx9FF
eJdvPtAx3EbmDJmP0Cf2lr5YvZJ/AlxRd9QTeA3fn9wVNJNk64fP7O3Sg8T8
rXCFu6t4RvDkwR36MmjGeetvajkb8I+d/wXvWU7JOxz0nAv42jJ3wfvmEe9U
0H7ewAfWf5lD2c6XfpSsD9KP0Ugz1CO9U2Yqbyia57nFuRevs5MZNiybZNyI
dBbdXnskd8l6xmZdC9pTyZkjZ9Xr28fkH4j0m1fOL3nN8EbtH2TaS+I=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlV9o1WUYx38b53d+Z1LWDmywNSee08VOaP6LYsvMCfNim4Kz1oU7QulW
F6UUaVBUzCw9u5jgvNmCFmwSamyEY1FzJ5DtQrdw/tmmJytJ7MKlF4lCwqTP
l+e5+MD7e97n977P+z7P93lXvLWvZW9xEASdEIO6RBDUwjxcg5vxINhfFAQf
wpuM62ETjEMeWmA7XILL8Df/3Ia7cA9OYTsJQzAsP2wzvof2mouCoJQAFli/
wHgztnr4A/6EVv55HeZgHtL4pKAX+uA1fHbAA3gIT2J7AjrhIKzin5XQD9/C
emxj7HUWxvjeAC/DKPwI62AtDMIJeAle9DPoLEehW3HAs9DFejmdAZLwK5f4
Cmtv1H2FQfAGtla4CDNQRYzPwDjkYZo1pvwOdZdb8WmGCZiMLKZRv/N6v+NL
fietfqdDfoYNHvOgx6zYJ2ECGqEJsqzZBldhFjLwc5HdyQjz+4hpr+6xJAiW
lliOlesG2AIfMXcAypgrhxb+3w7n4QJ0MNcOIXNx+Izxp1DFeBl8yfgQpBin
4TD/fOU5U+662CMH1bAcvsB2ndgCauQQ4xuR1co/sJvxcXx6oAYyyg+2biiD
ciiQg634boO60Gqg33OsXPd5LS2Dav2DrR3fPdDpNafa2wlt8oderynVVj//
fOM1qdpcxZmSxVbTRzlnD7ZjUAGVUBtZ7Y3DOeUHnwnIwHMJu+MGz5lyd5aY
x6ACKkPThLTRBM3wVNxiVc1lmS+GIuiDr2EEzkApJH2NCrdp7jvXg2pggPGw
xyfb84y/x+c0lMCS0Gqo0WtWtZv0teUj3yUJy5Vy9jn/92A7Bv+hi0cx06i0
2gZZWMPcapiCad9Dew3AYGg513pF8DT+B7F1wh3WWoiZz4CfWWefwzYL7Yw7
4D14NzSb5n6DQsxsmitL2Nra4wfGt5j7C95n7gPIQA1MwGRoNa3alkaklQte
+9KstDsSWW51hy9EVvOqfdW8av8T1vg4tD20Vx6fX/DNw6bI9tTeBY9VGpPW
pCFp6afIfLVHXWQ9RL0kBemEaVbalUal1UmPfQWkvCb6PCfKje5Qd6mYFFu1
a0E1q9rNeq4W4XHCel7aNSftrcO21nu6enuDx6czXYzbGzLvPV29fUp35v/o
3+Wu9W7vrWk/izQhbVS6dqRpabvZa19vjN6apPde9RD1kvuc5d+Y1Yhqpdx7
gXq0evWrnh/FeD5umst4TIot472k17WuHqVelWOuS70bW6X3KPWqXXF7G9Vj
snG7o0XvgR3+Bt71N0pvVY6YjoQWo2Kd9V6sN0JvxduhvR3qQe8wvo7tmvds
9e6U51I9Qb1hxt8W9WD14mnXUo3X7u+R9Ur1pOMJ06C0qBgUy1W44hqUFm+G
1iv15rdznv8BMmgFzg==
           "]], 
          
          PolygonBox[{{2010, 491, 1888, 2008, 2009}, {1922, 1921, 1801, 473, 
           1923}, {2070, 513, 2231, 2075, 2076}, {2186, 2185, 2344, 529, 
           2187}, {1493, 333, 1333, 1491, 1492}, {1628, 1627, 1754, 372, 
           1630}, {1559, 357, 1669, 1562, 1563}, {1382, 1381, 1233, 318, 
           1383}, {1835, 442, 1834, 1950, 1951}, {1989, 1988, 1867, 447, 
           1862}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9502931881774732, 0.745732970443683, 0.4459088833501669], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkLtOgkEQRofLv6wFgVBAgUSNxMJQ8AbwAFQ0WACFBdiohbE3XkKChaHi
beysSKi4RHgCfQrOMFNMzu7szDffzsXtY/chLSJXRIZop0RGxJjY5UT+4cb5
RxQp/ozGabTQ8+WJSMt7VeONnh18hafUpKkpwxeiwHlJfk5kOTfINRORDvUr
+JzY/PMg8u46qvfrPtRXPVqvany4Zg0PE+57akqwGsxPJZgP1cnDr2D6Z/Au
Md9j2MvZH9dwyNsT5z4c+FydP/C8vk9dX+don3rQXfS9ZgsX7vMajnzWJivy
7TvR3az872v4wz2j+4zm6bhTWPP8DA83weqX5IvR/qV7uk9s93v0D60rNNc=

           "]], 
          PolygonBox[CompressedData["
1:eJwt1EtIVUEcx/Hj4z4qUim4glJS2kJLBS2Kq5Ea6CJtoT0XtmihbsrIoqAo
KCLTIkPbqKCSlliiC6WS0tW9i9KoK0qPRUJh9KAWRUKB9f0zv8UH5sw5c86Z
+c/8NhxtrD4e73leAxIx6ve8ERRjJ+Z8nlcZ53lNqOV6S8DzNqMHvTjP/XP4
wOCPuM0zHchGDrrQiVzkIYMx69GODkzRN4lyVGAbfVsxglHcpW8A27ED+fTl
4R4GkY403EQbUhFCC1rxiDEPUYoyRBHBHlQii2cy0YkuxIKe9wphFGGevi/M
PYVFauV6LXNdgwcYRg6yEUEU6UjDGMYN48c0J5vbFCZRglJEEUE5KuxfGLMR
T/AU86zpLr5fgmNcT/DMY4RRhELmUKA1srWao+9znPvnWtp/Gf8H1xjbghv0
xTOXBKyzuXL9EtWoCbgaWi1P8mwTvtH+muhqbLX+RfsnLtG+jOeMeYYq7MUb
3vkaZdiNWwH3rURkcZ0TdG3ri9AOBd3/vON/m23+QXfP+iaDbg8Wq4ZWyxpU
I4ZZ7bFs7bEu7RHbK0O4j8N+t3dtDx+iXcU7K7GIT1jAe/XZvcwVrtbJuML1
i4Br25rGaM8w52nVPEc1j6hmVrtNtqd0BuwsrGbM2zg3v6taoyrV3GrfxzO9
qqHVskJ7YVJ7pUa1sTW2tU7l/0K4wL9dxBJ+oxZHsB/71LekGpRpjgt6xp5d
xj/8wHeNsbH1qIOfbwSQjCScoe+szkRYNbZaF6JAZyamdy7rHfVa40V9w75l
77R3N9I+IdZO0rfsG/Ytm6PNNYM1qWft6tBCO9Xv2nYmGnwuQ9qVAek6UyU6
IxM6I2GdwXFlyogyJF9nvlOZlKFM61EmWDbMaq8dwEFlVLkyJKoMsSyZxoz2
3JAydFSZl6sa9ymDSpV5ln0JzCEeXej2uXdMa4/bXh9W1qzEKmXCE2VMuvrs
Xj8GcMrnssLW7LT1M4c7ymzL7usBtxftfFkW2Bm2s2xn3M76oLLVxtjYDu61
+1yGWJaMK9ssAy0L25S9IWVvs95vez4l6P6pX3NMUAZZFlmGWJZ0a+72DfvW
f8cS0RY=
           "]], 
          
          PolygonBox[{{1486, 332, 1328, 1484, 1485}, {1623, 1622, 1751, 371, 
           1625}, {2175, 2174, 2333, 527, 2176}, {1395, 1394, 1243, 320, 
           1396}, {1931, 1930, 1810, 475, 1932}, {1568, 359, 1679, 1572, 
           1573}, {2092, 516, 2251, 2098, 2099}, {2002, 489, 1879, 2000, 
           2001}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9775071215722101, 0.8137678039305252, 0.5302720768738513], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFkT8vRFEQxefh3vcUKLcQCUGzBMluR7MkChKFLZZW5U9CLBISCYkSCYVK
SChUvoNCottNPJVkJQqFQukD+E1mEsXknDt3Zu6ccwdWthY320RkgmgnhjKR
j0TkMhV5Jb7hObgURerwZXAaXCXWiJ0gUgG/OkQuUuvtBT+ZkzJ4BixSM0++
4bid2KxT6lpgIf2/a4IlegK9o+At5w3yZd7ty6z+nPoRr7mBH8O74UeZ3WnN
GTgcbc9+sOpaVNOU7/YI34d3wXs62dU1rSe2y5zvWnG9qvsh2j4l90Hrta/u
c56ZWYZH+H1qZ80fkLuOVl8ED4P1/+DbYLC3XoL5q97UwHefMwkuRKt5CqZT
9RbYedf913/IXWMT3PO83lej6WhE86Xl3qt+9WGWeXfRdI+B465RvT8Jpu+X
Pa/cT/U1d//1r2q+8xv4B6YFQiY=
           "]], 
          PolygonBox[CompressedData["
1:eJwtk0tIlFEUx2863/0+6bExcGGRQW6kUiijaApmBlIqJyiSVgZtsoLKICho
EbTrAQXOahzQyDB6MC2ULMpZjUHlolZB7YJcBLVLKKjfn3MWPzj33HPPPc/N
py4cPd8SQjgAOZhLQ5iFftgFb2EdBsurQviA/CsL4Scch2HI2kJI4SLyGAxi
MwAL0IAO+MLbr3AX+V5qsnQbM7ORbQGK8CmGcIm7MTiG/BxdHXqhD56gewx1
3cEyPr57TIptP7p98ALmoYxuyG1k242PLVCFCdiLLpJfAh+Ru9BtgnGowDbY
CpMwBa/gpd5BHkr8UYQFaMA0ugf+Rm8Xoek1UW2GvXa/YQXeo3sHZTgCS6nV
WjW/nlmMVY9JsQ3yxwA0YTFaTJOek3IL9OIf707DaGY+yx6DYtnDm91eQ9Uy
77mo5+p9w3PRH/prLuEO2mF9Yj7lWz1X79egWw3T8BB28OYc8Z+FKeQ36F5D
J2yALnSj3BXgMuf7qdU/hTx+a6n1QrqdnE/CSGY5KbcabyZgHCqJ1UC1OAxD
0WJQLK2QcxvZ/mG4/zqSb6K7ldjMFbyn6u0P7orEVoIb3N9OTFY+dxJDsnLs
jfZHq8dU8xw7vWaq3TN46jVSrfp8lmfgkTPjM6PZWfHZGPHcm7w5yF+HoAd5
e7T/z0A12o72+45oV0qZ1VL1+5zZjtR9J7QbS4n50o6d4HwVm7UtNm/a9W85
641qcM173u45KJd53y3NvGa/J1os6mkFuaPNfMnnFc1ftF1WDmXk/2YeiTo=

           "]], 
          
          PolygonBox[{{1944, 1943, 2092, 517, 2091}, {2118, 519, 2272, 2125, 
           2126}, {2161, 2160, 2319, 525, 2162}, {1997, 488, 1875, 1995, 
           1996}, {1471, 330, 1315, 1469, 1470}, {1942, 477, 2084, 1943, 
           1944}, {1588, 363, 1702, 1592, 1593}, {1613, 1612, 1741, 369, 
           1615}, {1941, 1940, 1819, 477, 1942}, {1419, 1418, 1268, 323, 
           1420}}]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.8851073758942303, 0.6283263298016818], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkj0vRGEQhWfZe9932VKpoFCJSGSbTURjP67CShSUREWyH+j8BrYkCltQ
qDabiERo0FHwF1ChVCoUnslMMTln7jtz5szsTm51VttDIjJHDBPPQeQrJ3IQ
RcYSkQx+AzZSkV34CjhOvgS/BxfJ2/A7sAXWiRqx4PkV2PRvVWKWvAJ26V1j
RoHhP9H0OjmbUSJ/B3vB5rf9re9aZfCYtzf4BLhPfRGdvWj+VGNZaxKb2QPz
iXm4TMy3zntwzFz/KDFvh+A5uh/wGfDUZ524n7p7ylLre0ztTWvU1zc+In4a
4Hw0nYtgntTbU2oaLdcp+14l8Ja6UXp36NuOxqVgWqpZAwfB7rYezat6/svb
fk3XPQt2wylwOpo33WMDPkLvr97Kf+uXYKH8Ndgd9Z6RuRWfWwWvg/VuwjP4
p+4CFhPbZ5BYv+ro/6jr3vSu/0wvR0M=
           "]], 
          PolygonBox[CompressedData["
1:eJwtkT0vg1EYhs8rPe97itFoYDAZVNLUgkG1aiExMBITCa3Y/BAbEhISIk1K
4iMliqH/AhNGo8HguvOc4Uruc57nPB/3GV5vLNV7nHMjkIOTzLmPxLl3KAbu
M9O6O0Yfeucq6Crk0M/cdWAGyrDHmy9in/CaGdL9NNkldsW5BQUYV71Y/w1G
if9CL7l5WEbfp87ViW3DNPqJnvPoHVjgfMH7cziFMxjKrJZqHqBv4QZKMKEc
b7PPaSb0WuzXB3fEm95iNRjw9qYUZ9bsRXpuJebBkbedtXsbHmAKJmNP9V4J
tot6XHP+iecA3+hKMK27JvHHzLySZy+q420W7TyI3gw2q3KU+8enzcZ59ol3
mK+RmGdltMtbvvqv8raVmpfa4RLdjf+jP1tEd1PzVjVqqf1RIXosr0Peeqvm
RjAP1FszjKXmQTt6IC/+ARgVR0o=
           "]], 
          
          PolygonBox[{{1963, 480, 2108, 1964, 1965}, {1958, 1957, 1837, 480, 
           1963}, {1986, 486, 1864, 1984, 1985}, {1965, 1964, 2118, 520, 
           2116}}]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          
          PolygonBox[{{1976, 484, 2144}, {1853, 484, 1980}, {1958, 481, 
           1962}, {1985, 485, 1986}, {1847, 483, 1975}, {1963, 481, 1958}, {
           1841, 482, 1970}, {1986, 485, 1981}, {1966, 482, 2117}, {1965, 481,
            1963}, {1981, 485, 2153}, {2116, 481, 1965}, {1971, 483, 2135}, {
           1859, 485, 1985}}], 
          
          PolygonBox[{{2144, 484, 483, 1971}, {2153, 485, 484, 1976}, {1980, 
           484, 485, 1859}, {1975, 483, 484, 1853}, {1962, 481, 482, 1841}, {
           2135, 483, 482, 1966}, {1970, 482, 483, 1847}, {2117, 482, 481, 
           2116}}]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1962, 1841, 1970, 1847, 1975, 1853, 1980, 1859, 1985, 1986,
            1981, 2153, 1976, 2144, 1971, 2135, 1966, 2117, 2116, 1965, 1963, 
           1958, 1962}]}, "2.25`"], Annotation[#, 2.25, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1419, 1276, 1429, 1437, 1284, 1446, 1292, 1454, 1300, 1462,
            1308, 1470, 1471, 1614, 1615, 1613, 1735, 1608, 1728, 1603, 1721, 
           1598, 1713, 1708, 1593, 1588, 1438, 1583, 1421, 1420, 1419}], 
          
          LineBox[{1948, 1829, 1953, 1837, 1957, 1961, 1840, 1969, 1846, 1974,
            1852, 1979, 1858, 1984, 1864, 1991, 1871, 1996, 1997, 1992, 2169, 
           1987, 2162, 2161, 2312, 2152, 2304, 2143, 2296, 2134, 2288, 2280, 
           2126, 2118, 1964, 2108, 1954, 2100, 1949, 2091, 1944, 1942, 1941, 
           1824, 1948}]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1411, 1268, 1418, 1275, 1428, 1436, 1283, 1445, 1291, 1453,
            1299, 1461, 1307, 1469, 1315, 1478, 1322, 1485, 1486, 1624, 1625, 
           1623, 1747, 1619, 1741, 1612, 1734, 1607, 1727, 1602, 1720, 1597, 
           1712, 1707, 1592, 1702, 1587, 1697, 1582, 1691, 1578, 1685, 1573, 
           1568, 1397, 1396, 1395, 1252, 1404, 1260, 1411}], 
          
          LineBox[{1947, 1828, 1952, 1836, 1956, 1960, 1839, 1968, 1845, 1973,
            1851, 1978, 1857, 1983, 1863, 1990, 1870, 1995, 1875, 2001, 2002, 
           1998, 2176, 2175, 2327, 2168, 2319, 2160, 2311, 2151, 2303, 2142, 
           2295, 2133, 2287, 2279, 2125, 2272, 2115, 2265, 2107, 2258, 2099, 
           2092, 1943, 2084, 1937, 2077, 1933, 1932, 1931, 1815, 1936, 1819, 
           1940, 1823, 1947}]}, "1.75`"], Annotation[#, 1.75, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1410, 1267, 1417, 1274, 1427, 1435, 1282, 1444, 1290, 1452,
            1298, 1460, 1306, 1468, 1314, 1477, 1321, 1484, 1328, 1492, 1493, 
           1629, 1630, 1628, 1751, 1622, 1746, 1618, 1740, 1611, 1733, 1606, 
           1726, 1601, 1719, 1596, 1711, 1706, 1591, 1701, 1586, 1696, 1581, 
           1690, 1577, 1684, 1572, 1679, 1567, 1674, 1563, 1559, 1384, 1383, 
           1382, 1238, 1389, 1243, 1394, 1251, 1403, 1259, 1410}], 
          
          LineBox[{1946, 1827, 1951, 1835, 1955, 1959, 1838, 1967, 1844, 1972,
            1850, 1977, 1856, 1982, 1862, 1989, 1869, 1994, 1874, 2000, 1879, 
           2005, 1885, 2009, 2010, 2006, 2187, 2186, 2339, 2181, 2333, 2174, 
           2326, 2167, 2318, 2159, 2310, 2150, 2302, 2141, 2294, 2132, 2286, 
           2278, 2124, 2271, 2114, 2264, 2106, 2257, 2098, 2251, 2090, 2245, 
           2083, 2238, 2076, 2070, 1928, 2064, 1924, 1923, 1922, 1805, 1927, 
           1810, 1930, 1814, 1935, 1818, 1939, 1822, 1946}]}, "1.5`"], 
        Annotation[#, 1.5, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0CFIAwAQhtEbTMEkIggahLGyIIwFF7RYLBZRMG2GDbc0NqxrC4KWhZlm
MWxlDCyCRWxrY2GICysOo9Fm8w3D46v3X6rcOK8nIuKU1krETzLiVn+1ow8k
6LHGkA2e2eaVFCMyjMnyzj5zDvhkQWU1osoVC0rMKTDjgilnjDlhxDFvHPHC
IU8MyNMnxyN7dMlwT5o2u9yxww1btNhknUv3FSkwsb+kU63oh9aWe/Rav7Sp
38n/v/0BQo8qmQ==
           "]], 
          LineBox[CompressedData["
1:eJwl0CFLgwEQgOEzuDlRxLAganBFNzCIaUkMFreigisLQ7FubW2KIMKKA7VY
/A+CYBgrsqJFg6BhygxGo1Hw+TA8vOHCHbew19iuj0REhXw64jYVsapdLeq9
rumDbuiTbmqJPuVkxlYyY5cXqrxRY8A+Qz5553Is4oLlTERHl7StOT3ROW1p
Vps6qXUd1QP9pcoPO3zzRYkP1nmlyDMrPJKnn+yhxyx3yR5umGKcIzce0iLD
MROcMk2bLGfMcM48V+S4psBi+v+vf8PhK4c=
           "]]}, "1.25`"], Annotation[#, 1.25, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0DEoBAAYhuFfHd1CUsoNiltuUDIwMFCymNxdh7rFhUFOWA3qBsViYGIx
sEhZlEW2K+UyXGK4hURitBk9l+HpXb++/sWN/HpLRCxQaY34SUTs6q8e6DHB
KUku6OSKHm7oo0qGGoM8MkyDUV4Y54NJvvim3BaxxiqfrPDOEq+UaFDkmQJ1
stSYpsoUt0xwzRiXnDPCGUOcMMARGQ5Js08ve6TYoZsKXWzTTgfzdufJMccM
d/6a1Xst6oOWtK7L+qTl5h+6qW+61fwg8f/7H4q/MwM=
           "]], 
          LineBox[CompressedData["
1:eJwl0T8oxGEYwPFXp5/fRRhuEJbfwg0GlLpJBguTrgzcoC4xYfEn3KCkTAbL
lT+LxWARZZBFFhYGQukyoAxGo8HnuuHT992ep+dNigv5+boQwgydDSEcRyEk
eqZdmuXcu18vNafXOqi3Oqz3OqJPOqavOq4VndBJHinwwhRvFHlnlg+++GY/
DuGAPQbSIZS1T3e1R3e0W7c10U3t0JJmdEmbdE7rdVr/KPBLnh8+GaXCEM/k
eKCXO7LcVOdwRTsX1Tmc0swJMWnW7b/CMmsskmKViBIxGzSyRSstlN0ro4fa
pkdR7U/+ASPHMks=
           "]]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0j9I1GEYwPHn6s47+2OEQX8IyuUaIgoKOgKRhoYQosShGpK0PyTWERUc
FAgFOmSgixSIELTUUg0N0pQiGEEREQSplBZnmSg5NETU56Xhw/f58cLv4YW3
ob3ccikTEU8o1EQczUW8yEaMccQ8rq06oSf0lbbpG+3Qd9qpH7Ssn7Sic9qt
S9qjv7Rf7/LXfF/zPGQdT9nICNsYpchLdvGWvWkPJaZoZJaDVDnEDxZZTrsp
u9M837jIHBf4ynlmaGeaNj7Smo+Y1OP6WU/pFz2tVT2jZ5nmHDPpnE6WnFf1
py6mbxZorI34rsOFiAPmEvfM+3RQ9+iA7tQ7WtRe3a43dYte13q9qqu1S1dq
h/7mJMscY55ZDjNJE+/Zz2t2M8EORtMenrOZZ2kPj1nLI/I8IFtIDyXisrtk
9Jr+cdeMXmEFFXJk6XGW19u6Svu1Tge1Xoe0yAAN9LGVXjZxiw10s54brKGS
/pf+TXPu/9v9B4MMXSw=
           "]]}, "0.75`"], Annotation[#, 0.75, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzz1I1GEcwPHnMi+LcGiIXIqGa4hIUOgIjjiw0KFActGl4aZCOC8aAofA
oaagFrGGqHDRRRpu6IUwQ1ACI0RoSBBuMLquO7z3Tnr5/IcP39/z8Of/4zmd
mbqejYUQnnK1O4T8wRA+8JFrzqs6pms6rp/0hn7WjG7qLf2qWd3Ru/pd72lF
72tTH+kcf80vNM4CvbziOK85yQoJ1jnHFwaiPSTZJkWBNLtc5idlhnljT1Xf
aUvfa0eX9Y+OkIuHcJsYbVrsu29EZ61pI/qn1jWrRUrcPOTt/DJX2DXvaVnr
WtOmNrVFm0me94TwW4cPh3CFhnlIq5rWkqb0hz7z7UVzkifmQZ3Vfn2sZ/Wh
JvSBntIZ7dNpPaZ39IhO6gHNaIcJqoxSpMAI37jEFhfY4DxrnGEl2sNbTpCP
9rDEURaJM08X/7wjx0vzf4r4XzI=
           "]], 
          
          LineBox[{1654, 1354, 1542, 1545, 1655, 1547, 1659, 1552, 1666, 1792,
            1662, 1658, 1657, 1790, 1791, 1906}]}, "0.5`"], 
        Annotation[#, 0.5, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwV0Edsj2EAwOGv1aIRiR6EC4mkDiIkJHoRGiOltlq1qU0HXfauvXUPunSg
VdqgROiJi8RB4mAlPVSCVNIESY3y/A/P9/vGm+8dI5LTE9PCgiAId8mPCIIC
8iikiHKKuUYJ1ymlgjIqqaKOauqpoYEb3KSWW9zmDo0008Rd7tFCKw/p4gGd
3Oc9H/hITmQQfNKD+k1z9Yde1EL+htamkdQzkGYG85BhtBPDC0bzinG8IZZ3
TKSDODqZxhe6iKfNPN36WH/qE+3Rp/pHe/lH0NfZ0ocIErzL1CyyieQ3v+gh
g5R+QZBKGn9C3/R36J50Kvvbp86NCoI5zGYWCcwknul8N2aqdmucftUpOpmJ
bGcbsWxlPFsYy2ZGsYkYNjKcZIayjmjWMIio0P+sK0zXaw9JdDOfz3Qwg7dM
4jUTeMkYnjOSdobziCG0Ek0TA2ggkmrC6bWvWp1n7jqtpzE0r+cWXaBtulCf
aaIuYgeLSWEJqSwljWWkk8ROlrOLDFaQyUqyWEU2q8lhLbtD58AeNrCXfRxg
P4c4zEGOcJRjHCeXE5zkLKc4x2nOc4E8LpLPJS5zhitcpYBCiiimhFLKKOc6
16igikqqqeE/3+yP8w==
           "]]}, "0.25`"], Annotation[#, 0.25, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"TKE Fitch adv=0\"", TraditionalForm], 
     PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.36303924273571764`, 
              0.4312917466483353, 0.6056574419700574}, {0.5333984657867705, 
              0.49116240011675644`, 0.5055101670774256}, {0.7037576888378234, 
              0.5510330535851776, 0.4053628921847939}, {0.8741169118888763, 
              0.6109037070535988, 0.3052156172921622}, {0.9230792547827363, 
              0.6776981369568408, 0.36154568982648255`}, {0.9502931881774732, 
              0.745732970443683, 0.4459088833501669}, {0.9775071215722101, 
              0.8137678039305252, 0.5302720768738511}, {1., 
              0.8851073758942303, 0.6283263298016818}, {1., 0.95, 0.75}}}, {{
                Rational[-225, 2], 
                Rational[-15, 2]}, {
                Rational[225, 2], 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[-225, 2], 
                  Rational[-15, 2]}, {
                  Rational[-225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[-15, 2]}}, {{-112.5, -7.5}, {-112.5, 7.5}, {112.5, 
                7.5}, {112.5, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-90., 
                    Rational[-15, 2]}, {-90., 
                    Rational[15, 2]}}, {{-90., -7.5}, {-90., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-67.5, 
                    Rational[-15, 2]}, {-67.5, 
                    Rational[15, 2]}}, {{-67.5, -7.5}, {-67.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-44.999999999999986`, 
                    Rational[-15, 2]}, {-44.999999999999986`, 
                    Rational[
                    15, 2]}}, {{-44.999999999999986`, -7.5}, \
{-44.999999999999986`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-22.5, 
                    Rational[-15, 2]}, {-22.5, 
                    Rational[15, 2]}}, {{-22.5, -7.5}, {-22.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{0., 
                    Rational[-15, 2]}, {0., 
                    Rational[15, 2]}}, {{0., -7.5}, {0., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{22.500000000000014`, 
                    Rational[-15, 2]}, {22.500000000000014`, 
                    Rational[15, 2]}}, {{22.500000000000014`, -7.5}, {
                  22.500000000000014`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{45.000000000000014`, 
                    Rational[-15, 2]}, {45.000000000000014`, 
                    Rational[15, 2]}}, {{45.000000000000014`, -7.5}, {
                  45.000000000000014`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{67.50000000000001, 
                    Rational[-15, 2]}, {67.50000000000001, 
                    Rational[15, 2]}}, {{67.50000000000001, -7.5}, {
                  67.50000000000001, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{90.00000000000001, 
                    Rational[-15, 2]}, {90.00000000000001, 
                    Rational[15, 2]}}, {{90.00000000000001, -7.5}, {
                  90.00000000000001, 7.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               LineBox[{{-112.5, -7.5}, {112.5, -7.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-90., -7.5}, 
                    Offset[{0, -4.}, {-90., -7.5}]}, {{-45., -7.5}, 
                    Offset[{0, -4.}, {-45., -7.5}]}, {{0., -7.5}, 
                    Offset[{0, -4.}, {0., -7.5}]}, {{45.00000000000002, -7.5}, 
                    Offset[{0, -4.}, {45.00000000000002, -7.5}]}, {{
                    90., -7.5}, 
                    Offset[{0, -4.}, {90., -7.5}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.25\"", 0.25, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{0., -7.}, {-90., -7.5}], {0., 1.}, Automatic, {1, 
                    0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.75\"", 0.75, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{0., -7.}, {-45., -7.5}], {0., 1.}, Automatic, {1, 
                    0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.25\"", 1.25, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{0., -7.}, {0., -7.5}], {0., 1.}, Automatic, {1, 
                    0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.75\"", 1.75, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{0., -7.}, {45.00000000000002, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"2.25\"", 2.25, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{0., -7.}, {90., -7.5}], {0., 1.}, Automatic, {1, 
                    0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {225, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.014674274250864983`", ",", "2.3112919330596924`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.25`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.75`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.25`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.75`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"2.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"2.25`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.790425107279467*^9, 3.790425113862465*^9}, 
   3.7904251504106855`*^9, 3.7904252910671782`*^9, 3.7904253890447216`*^9, 
   3.790425447437894*^9, 3.790490284411289*^9, 3.8128773641194057`*^9, 
   3.8135778626122503`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"0.5", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"LredFitchB", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "-", 
       RowBox[{"0.5", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"LredFitchC", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}]}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<TKE Fitch adv=0.25\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.79042511329219*^9}, {3.7904251451479115`*^9, 3.7904251489914513`*^9}, {
   3.7904252836393943`*^9, 3.790425289602617*^9}, {3.790425387663539*^9, 
   3.790425388026908*^9}, 3.790425430736617*^9, {3.8135778568502536`*^9, 
   3.8135778750282574`*^9}, {3.813579009835369*^9, 3.81357904266621*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3HdYj98bB/CUhIrsWaIhVGZEw1GSSrRLQ6m0KEJFVkqRUfYsskchX2SW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     "], {{{
        EdgeForm[], 
        RGBColor[
        0.14800000000000013`, 0.33000000000000007`, 0.5400000000000001], 
        GraphicsGroupBox[{
          
          PolygonBox[{{1724, 479, 1666}, {1730, 481, 1732}, {1717, 477, 
           1660}, {1721, 478, 1663}, {1676, 483, 1740}, {1802, 480, 1729}, {
           1743, 483, 1739}, {1739, 483, 1814}, {1790, 477, 1720}, {1794, 478,
            1723}, {1727, 480, 1670}, {1798, 479, 1726}, {1672, 482, 1736}, {
           1720, 477, 1719}, {1719, 477, 1717}, {1740, 483, 1743}, {1806, 481,
            1734}, {1735, 482, 1807}}], 
          
          PolygonBox[{{1663, 478, 479, 1724}, {1734, 481, 480, 1802}, {1660, 
           477, 478, 1721}, {1807, 482, 481, 1806}, {1666, 479, 480, 1727}, {
           1729, 480, 479, 1798}, {1670, 480, 481, 1730}, {1723, 478, 477, 
           1790}, {1726, 479, 478, 1794}, {1732, 481, 482, 1672}, {1736, 482, 
           483, 1676}, {1814, 483, 482, 1735}}]}]}, {
        EdgeForm[], 
        RGBColor[0.3819264862690079, 0.43792943606898044`, 0.594554397848251], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1k91KlFEUhvfMtNdnmTlkaIiF0mUE0Wj+lQYpCAV1YGCTjSNIJIgHXULQ
bUQFnQhm4EFFB0EmBWUdJOoVCAWC+ize1cHieff+9l57/X190/MTzXJKaQyr
YC8spZ+llB7DQfgIa2A9rOfgOByFI9h8cBhrYtew2bjTj9Wxh9hA0L8tZ935
HWyGH/cxF2t/b6ik9xezvv2An7P2NuAKdhV9Gy5knf+W5WM47q+xrsF7cD0r
pvvwU1aszaxYByP2y+Q2A9vg+6y46/BpVs7b8HScaYX9RUplivcPPYUu0K3w
VOgP7J9Bt6Db4XfWu9z9Cq+zPsH+EXoIXUEfoG+iM7pS6OyOv1VWPo2o0UfO
nWSvkzP70a9Xpnp4bA8iB9ceby32vB8dhe7eLXTH776EdyLOKuzyHNDTsLvQ
+zPwQmjf246a7MGLpr7dghN8M84Uhfy6f5+pG6b4u+HzqMOmz5hpLjq9nqY5
OWeqqdf2Lxwx9ek8fGaqyRfP15TTWXjJNEe9pr7NRk834y2v/a+SfHqt3Yfn
6Plsxb5/PzT1ZRVa5LLusURf3kU96zHjb2MOfR5fm3w9gW/ivSXTuf//QW/E
OWmqndfwT/jwHrnvKyZdhcdN0GB6
           "]], 
          PolygonBox[CompressedData["
1:eJwtkltLlkEURuf78p0phZKKiqhA+hUSiFqaFQoaCAV5oWBa+gkidWMoBR6g
rvojYpTnSvOIigfwIg8XQf2DwAvBWg97XyxYM+/M3vudvctae5oK+RBCORTB
1xhCxkYUKYQSSL5uwnf5/ifHPuubrE9Yn8HzUM36GZzDz8JT/EIy194KZ0dh
BFZhDY6j3T0g5jheD914FzzC/0FR3nLUEqsVij3eJdWWrDbV3IAvR6tXOc8n
i6nY+/AXb4RCznLcwK94vYq5znoapmAABuEDvIcN2IT5aPmUozjZHd39Tbwt
vUWyWlTzQ3zG69dennV7srfTnav4HN9n4S28gx+wAIuwBG+g32tSbdvRcqkH
H/GWLIQqvBrm8RL22vFKmGV9PdpbvoQ6/S+8wDt1B/8Cnz2Hcj3J7K5izuE7
UIPXQi++l5nfh9f4L3iA98Bt7newvovfgzW8kJkrxibellmtOrOE/8wsVh30
45ej1dahf/AZWfUeqBdHmZ1VzkG8L1pv1eMxvNTnTf1pTvamettv8B0mfV7V
k1N/40WfyVE/o7NDMAyPo/2bZuaW7w15j9SrCTjMWUzFvhbtrfXGNfgrnz+d
+aT64HnOenQHvxjtX7VX4TM34DOh2fgP11dnng==
           "]], 
          
          PolygonBox[{{1658, 476, 1719, 1717, 1718}, {1741, 1740, 1743, 484, 
           1680}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.6536919882882357, 0.5334380789511372, 0.43479448611809784`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtktsqxFEUxvfQXv+ERyAyTV6AlJgbpUZyKCmX4kY5TG4cImLS8ADzCA6l
mHKmlLyAG+bSDTVKFLn1W6118fX7/suavb+9ltbJ+dG5mhBCJ6pFtzGEbCqE
egnhGN+DH3ROoV505j1j8AMN4D+jSX3VmUN5lE1CSHHJL2eeq6itwCbqDdSf
8PfoivoW7KYeqH/jr9EF9TV4hCr4RdhGTyM9aXjq+U6iSb1mL0fLOxKtT/tb
YJHf31B/hAfoBb8PO8TemIh9az0Ph71/F96hS/wGPPQePWNbs+ILsF3s3Rn4
lrI36t0l/36GD96/I/at9Qr8EZtVWew+vXcPLvvclsTmuuCzTTyzwC40ja+D
Vc+mGTOeZwIWfTe6t02f+ZDYuXp+n9jcdf5fcN3fm4NpsXvHYbPvbgYWomV6
j5Zb8/+JzVrfPZvYHjSn5lv1nfbrHv3MV9+V/l3/t/4BPT9SbQ==
           "]], 
          PolygonBox[CompressedData["
1:eJwt1N1LlEEUx/Fn050t1Ci1NDVL6qJ/oCtLS0vLTSuNwo1WcM3sIs3eFMpQ
KqKLIqm/ojezVzWMXlBQUNRS2iChAgOvuigoCup7mN/Fhz377M48M+ecmaLG
ttrWJUEQNCAV7S4IPoSCIIk7xJ/DQXCSuAoLxDU8q0YUe7Ad25CJLDxwfmzA
pH3Ea1GgMTZ2hjmmcQqn8RLDiKMBoxhBC46jmzEDzPccQ8S3cQvv8B6lKMEK
rEQ5ypCNVRhnjjG0og1XeTbEXIN4RXwWZ/AQ/ehy/l3PjObI1h5tr/nIwy7s
RmUkCCrwh/gv7mr/lsNFWw+/leEX8W/kYLXWWK532rvPoQP3cU9rsrXtZWwN
UpCKOtQigqURn/NM5cByUYT1qMMBrdHWmos1qllUe7C9VGCn1mRrizJnFf4R
B3yu47MQ+1GrNdpaH+MJDvGfg0hDOq4ovy+wj3gaU6qZ1e4NNXiNBJqww/lc
W87P23t4VkJciqfE1dga8s8ehX2NrdbF2OJ8Ta22E5iUCfXYjHqoRT0wrp6z
3pvFHHqsx/AFX7GMOY/yriZsJu7kWQeS+IguXMAnzOO7871uNbfapzm/dpsj
XTnPVY4t1875uW1P/WFfozrl2HIdQ3vIn7mN1tPkdIVybLnORQ4akUC29QCO
II7DiGmMja1V7Qp0FvN5lodmHMMMz9JZ/wLvm3O+x1LUA9YLN3h2HROYdL7n
IupJ680+7T+EH87ndFY561SNEzrTozrjcfWA9UKVzredxx7iEed7x3rorfNr
bNaebe+VOp825iLxIHMMoB6xsF+jrfUmeu38OD+3zXdZPWO9k4Hlztc0qZpa
bePKZUy5HOc/Y8qB5SKh3Gcp90nnc5fB/jfw/afzubCcFPP9W9jfnVFcI14M
+9hqvIn/XtL6bD/DukPsLrE7w+6OQGfR7phKnbE03QF2F5yI+HdbDQsjPgf1
ulPtbu1VLqZ0FufVu93q/f9MZrFr
           "]], 
          
          PolygonBox[{{1365, 319, 1468, 1464, 1465}, {1507, 1506, 1510, 330, 
           1413}, {1651, 473, 1710, 1708, 1709}, {1748, 1747, 1750, 486, 
           1687}, {1898, 524, 1821, 1818, 1819}, {1716, 1715, 1658, 438, 
           1657}, {1675, 443, 1673, 1737, 1738}, {1550, 1549, 1548, 357, 
           1592}, {1785, 1784, 1783, 513, 1855}, {1623, 368, 1571, 1568, 
           1569}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9040666917424064, 0.6301667293560159, 0.30260674440145974`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtk0trVEEQhXsSp+5OE4OIiIiIaIhxRISgDogoBkNmIkEEQQhEXIlJzEPx
gSDoSsZo4mQh4mMhYtRFfOzUH+BCcCP4dmcyIz4QxZX6FXUWh+903+7qruq6
K/oHewcaUkp9qBE9spQe51I6Br+gv/g6vIv+4b/Di/mUSvgfcBKV8T/hce31
GKuzlBYQeBiuQvPxQ7ANNeOPwlbUhB/NIt4IGkXdaFjjm34P+BH+5owe/B+4
jj0t7C3AGnNzuYjlaxc2xLc7rNvC+B486ffG74CVfJzxDa6xOKumtf2oiCro
oeeC2nXWKbg2i/gnYDd7J/lehjXVx+tUz0WOvm4W/zkX+fsdvSZNmvc5H1+1
GL+Fz9ET/Hl4Qd7nCrqD32UZ48vM98Ld8ufgDZ39QTWrqxbXLWr0Hl5CT/Ev
fB96hn8JD6FX+AE4hGbwh7XP7+v5XLPI4R3cqzgTcJ/iVC3eyc/+BM+qPj3w
ikUd3sDbqnUnHGT8AL9ZsWdVo6piTsFbupvfcReawC+FZ+S7LHrCe+MX7Mii
b71/71u844jFd+/VMbQpi/f6ynybRa/1ec315t7HM8Q6AI35nV47/BK43iJG
Ac6z6JlGeFprOi32FdVPreqx/bBo0VvNXmOLs8YsYnnMg3AbGscv8pood69B
Wf+Hr5tSvv5PVHRnv/t0Ps7tysfY8xjXP+A199qvzOItXhNzOari98B2i/j9
cFrvckTnlnT2BuXreW9Unnn1XU19X9I/7DXdrv9usUU/eV91wK2qdQv8D6vT
k/E=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlXtol2UUx9/f8n1eF6ZtOlSs1moqYooEZepihdLSdmtTNzWcbI5s0rY2
L1u1wSIFF5n3+kOsICoHi7a1QDEDAwUFpbz8RE2DAq8YMwwKb58v5/zxge/7
XM5znnN53rzaporGjCiKOmEYZCdRlAVVUA2X4ii6CF3wAXwPBakoqoM+9IIQ
RdvQW6ET/S57sjGYBVPRb8AytynbKYigCF6FRvacYW8avkL/CgfRP8km+i/O
+BM2wEb4BQ7BSqiHbcHWas8S9PvYHJ1hPjyjs1mzFA7Cz3ACjsNvcBLOwzno
gE54CBu12JoDe/kuik3rzj3oAeiH16EC8jljJGddZv5p9DHGjkITNMNd7N2B
uczNg//R/0Eh+qXE7qS7XYYr8B30QgmUesy7PAaKRQt7RmXYmRMT80G+DMKP
MBPbffjSD03oz+BTSMPZYDZL/A4DHgPFohXWuA3ZWgSL4V/23IY5nFWQWAwV
yxpYAWuZ+4GzBqA32FiN50i5eoQ9I6ASFiZ2hs46A2nIZGw4lEF5Yjno8Jq7
5D7Il32wH2LWDIPXoBjWJVZrj8IU2U9MK0aTE8tBk+dcuX8nWGwUo2/QDYy9
5Tk75jWl2joMRzwnys0m6Ia97LnH3vtwLZhP+7zGVGvt0OY1pdr6gzU3UlaT
0/HnZrC9sjGT79ZgsZNPPejn4TlIYDiMD9Zb6rH56Br2LPeeUm/d5owy5tbC
DOZzGXsCGmA1PAYT4E1YBeNhHNTBSljPnsGU5bAP3cjY224j1200uA3ZamPN
Jynb047+m/OL0SWwBZ3HmifdhmzNYs0LkAkPw1Bsa0thO/qf2LTusAudw54x
fkfd9YjnQjlSriZiIx+qoDpYD6mXVKOq1WKvjcjfmlrG1mC7Faa6D5keY8W6
PljstGaa4htsbQtMCdaz6l31rHp3lcdynMey2n3Jg6dgFIz0O+vucbC3Um/K
s+hlsNTvoLuUwnbmdsDj6I/gAHondKMrgs3pOzdYj5R5D8T+huot1Rujt6bb
a/U63IitZ9W7Q8zdgmux3U05u6l1Xs96f79GT4ZJ7qN8LfL62wLvBevhSu9Z
9W6O14Pm5wb7Z1R5z6v3097rbd4bE/x/oTsXBztTZ+sfcBU92/tTPdES7J+Q
9n5t1lkeH735i4Ot0dqP4UX0t75ed1Kvlnl8dWaX8hnMV/msWj7u/w/Z3Bzs
TejzeMjWBo+/bHyIvgBX1fvwOXqs21OMXkH/HmzuOnyBPg9XUrZnD/o0nPI3
WW+zcrzT81+OXuTf8kd3HQ2b3d+X0eeC/Wtkczc6K9jdtaYQfTHY2XpzvgzW
43XeU+qtB0KNAAs=
           "]], 
          
          PolygonBox[{{1597, 397, 1596, 1550, 1551}, {1544, 1543, 1542, 355, 
           1588}, {1354, 316, 1456, 1453, 1454}, {1628, 370, 1576, 1574, 
           1575}, {1752, 1751, 1753, 487, 1690}, {1516, 1515, 1518, 332, 
           1421}, {1570, 1569, 1620, 405, 1621}, {1904, 526, 1828, 1824, 
           1825}, {1686, 446, 1684, 1748, 1749}, {1778, 1777, 1776, 511, 
           1849}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9474797112342958, 0.7386992780857394, 0.4371871048263169], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtlOtrzmEYx3/P1u/3Q0nJlFKy0hxm5hD2MCFEUfZk2rIwUXNokxfPM2cv
DaXImMcODw9aXiBJ9gY7+QuUnFKmSGNvKNPwubq+L64+133dh+twX/c9c09T
qrEgCII0Uoh0JYKgExk0RkHQB9/B7Ugr+kX4HQ4jU9jYxPg8+jLYhfSjv498
rqjA135hPAZvwjS8gbRLTDcfn5gbgafjIOjQnJ1VhWxFMkg9a17YHHypGC2O
IvaU42svvM7cc2yvYRPjxdgPwRVwpWK6o3i+wVLmKrCdgPOQ5ejHYs/T8q2G
Z2Lf2wOPJrxGuYSfZXna2S2M7yMPLCfF+QZeYc9s5tfEXlfLbQB5xdwz2ArX
hkGQRN8Az+ocO69YMdTA5oT7TiEPFWczbAu9Pr9huer7E/0kc0nWPIbTkIXo
DXCf9Lux70urtu2MS7FXwWzodR+FGxnPxZ6IvY5Wz3tws9ULPYR/Qo/rL6xh
XIZ9MtyPLELvhtOlH4QzdE4jbIi8lgfgbfZXoE+F65ibw5ox7NdUK6tZSj1h
9dipu85GykH1tTtJ6l66OaseWyFrtnHmfGwT4b/Q/Zr/VYxLsFfaPUv/hb0s
9v76GLnPjPweV888sn7QXdidtOj+z1nPqp7j4ST2X8BWqXvs0Btbrd4YxX44
8r15OAu5ir4DVmivnZFTbWvtjTDuxf428vP61VdWP8s3qX5plq9anXlJ9bYe
tje0VO93AvyR8PdqfX1EfpPwFv4WYNutHu7S2UN6s59hndbssnuOvBZh5OsH
9Far1c/F8pVTDMPya3pWfbUl9vvsU24l1gewzvJQb6yPvaYWp8V7Su/8ifWe
YhtSb6TVH4PyYzl81T9g/0GP3vjT2OctHouxTf2/Cdbrn8nHnvOI/q0lkd/5
OHhZ/WM9lYs89w+R/3O9yqdTfVgd+/1k1BN59UAj/A/5LbdN
           "]], 
          PolygonBox[CompressedData["
1:eJw1lWmMzlcUxv9vee8tiS9SkiaShoSZGsYyghk+IJVSFFMdBOXFUPvQoRla
hKTWiqUMhjKW2BqaaAk+WFsSTUhoKrRGG5JKhsHUWtvv6Tn98Mv7vPd/l3Pv
fc65TUdPK5z6RpIki6EuHE4nySEogsGwLiTJ8VSSrIe16MlwAL0Y8tC7YpK0
Y4K2kEGPhDb+vxE6G7JgBnwG55jzLEyESYK29vTNg3fQi2j7Cv6G27AMlkI1
3IGnMIC1B0IFOsWYlozNgb7oSR7fr7AT3YK25lAC06EnvEvfbFiLnsccc6EK
bsAqWAn34QGMg2KPWbF/6vtVzE3QdVgj4+dRF/0DfQ5CIXwEL4Ktpxh70T8d
LdZWMAA9hO/rGFsOzdHPgsWmMe9Fm6PQ70R3MxyGwXE4Af18Ps2/Ad2ftg89
BsXSBz6A/XAAdkS7G93RdnS9aLG0hkHoN1l/KbEsg47Bzkxn1xSaRVtTa4+C
jH7pM1J7hJZwhrbTfmY6u95+P9pPue6AthK4ABfhGBz1PWlvC2EB3IRbijdt
55sP7Zj/G/6vgVr4B8rlUXgEj+FZ2rxRCP8qBsYUQ2vIDbam1r4El7VusLOX
v7PQ3aOdfxasQY+hbTTkQKtgOVHkMR9zD8vL5+EXaEOfTcw1C9qiN3j+nIBP
0EOZM9fPe4vnxAz3qLw6kT6V9K2BP9FV8DP6J6gMloPr3S9D0VdY8zcog9kw
jznu+fi/+P47nEafgm/R14PNdQa2oq8F+3YSNqk/c1zznFBuNPR45Zfh6H20
7XVPyVtXg43V/jYGO1OdbSnM9DM573euu78SrO9/NQX9R7BYFOMW9A24k7I9
a++jvJ4ohkr0WI9XZzwePcX9+j2UoGvhAeTTtwAaRDtrjR+i/OPbkpSN6YCu
H8zry+UxdEEwrbZpwXJaua0x7YPVFNWWF3AbXQN3oRNzd4ZOPp/mV2wP0+YF
1awn6I89HuXc5mh3rLvSnU1A96LP+37GOutc9648KC9+R1tBynJiD7rCz1N3
kHGP5nhOKjdnKy7Wytea6M1+XzpDneUX0b4VyJPo1Z4PqklF6H3RarPq3YRo
Hitzj8grGqOxb8kj6EfBckc51E21Bhqhu8J8eZMxNV5jVWs/p22WarLqBDRO
W65rjz3cQ6XucXk9z+9D+1dteJm2XC+D5+gV8LWvcc9r3n6viaqN6qO+yrFX
6LFeD1XT3462B+1FHsz1mBRbKcx0Sv1Ny3aPyWt33QsZr42qgaqFA72+qkZX
oI9EO4suMDfaG6e3Tm+c3jq9cdW+hxVe42q9xqnW7fH3UvEW/+85qFbeBHuz
7nuNVK2cGiw39Cbqbdzu/tV/veV686q85qr2HnQ/yDNl0WqwarHeZL3Nh6PF
rjv/Ej3C65HyWbVuW7Dc0Bodo9Ug+VsekBd2M8cu97i8/qP7R2vOQb8Grf8b
4w==
           "]], 
          
          PolygonBox[{{1527, 1526, 1528, 336, 1433}, {1350, 314, 1452, 1447, 
           1448}, {1853, 551, 1852, 1778, 1779}, {1578, 1577, 1628, 408, 
           1629}, {1826, 1825, 1902, 563, 1903}, {1639, 412, 1583, 1637, 
           1638}, {1773, 1772, 1771, 509, 1768}, {1912, 568, 1835, 1910, 
           1911}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9908927307261852, 0.8472318268154632, 0.5717674652511742], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNWWd4lUUWvjf3++73gQRCFaSlESCgJKSxugisSyQQCIhAQkgotlWBEDCA
ooIgK/tgeSyUgEgLCRBRH9eOlFXaKoRm74VQlCIEQUBh39fz5tn8OPc9M9+Z
mTNnzpw5MzdmXNEtEyMCgcBK/ISA6U4gMApUAJqIcj/QzaAJwkxQO1Bb0L2g
XD8QiIBsT+DdKLcBtQYVgwaA+oOK1A/7m6S6LMn0V90k1VH2HfT3ILACeBi0
HvwR4EUvEIiCkkGMNYM6g1aBVoDuBy3XGLX6srxD38lvV/kB1a3U+HEa+wXJ
ULYUNAU0WTplaQ6c4z9AT4GWQqfB1AH4BWgN+M3Ar0Dl4Lc4ZoN4jfMZymXA
TcBlGotjztA8OOeBoARQtviOKt8jm7eRXtnSbSf6mg9cB+wCu+yCfboC30f5
X6hf65hcttZjspC27wS5nZBPBL7k2Lw2ABurnt890DbwccDt6nMH8O9uINA0
GAjc5Jq9pmsupRpjMegy1qs72n4LXKC1eQ4UhTabgI2Au9FHGegM6EnZlXos
kN1r20zUmmZDjyr02R+YA7oIfhBwkXxoIe0EXz6P/s6B2oH/LWjl9uJZNw06
ZQCnA2eBeoJP8uwbZdlHEcqpwFjgNcCzqK8JGl8jnVuD/zVo31pLht8XSp8i
6VSkOS2C7VpxTo7ZaLLWYpGQbbjH2gdsn63T+u5yzIfi5a95mHMIdSOBN4Ic
8Pm++RB9aTXoDpQzUX8ncD3wcdR94JhPcB25ngF8i4QNw77tm2iNv7iOXpWQ
ewK427E9EKM9Rj5W5Szx/dQ+WnO4Wd+jJRMnORfj5WHcBsAesG8H2OxU2Hyz
g+aZLd9nOUlr9EPY5kGbvBqwGNRW+2M59MsBPgv8DvJbKQ+8F2P4qCukX6M8
GPWLgadB9aBDDfCweNadBB2DzM/A+7QPued+ccw/TwGz4btX05eAg0Et6V/A
vqDm4NsAZ/oWR58AZqHcgn4F3I5+B6H/54DT8W04ZB7zbQ7c34wxO/Ath34E
vBVtWqFtNPC8Z+vFdduovfEO6F3510bxC1XeJP7P747F5sWOyS1Q+81a502i
RWrzumP7+YJjMov1bYf8Z5tjfkx/fh74AXQbCp1fAF5CuQT1B4BXHIu1HwOn
QO+hwLnADzk3yK8A7gENB78GOBXfukFmPHA3ysNQvwr4X9At4J8H7gINAb+E
exN2acb9B1ytfsqALV2L95cdi0+MUzwnVqq82rHyioCdCYxfrJ8GOov29WHn
X4HrQXnocx9wLSgX/F7gBlA++APAhq7ZOBLYxDV7NQZ+gzEqwG91zJdK6vjT
QPk4x6Z9eA5U6OzbCHzLsW9rgG9K1zLH9FsmfXPET1N/7J9nxtuO9VcOfBH6
jYSe+4EvgUaBPwhsDv0OQ+YiZHLBXwMbxgDrgy6hvjPwLciNg/znwHLQCPBV
nn2PgXwsaKzqK4BzUC4AjQKNQ/s2wDjXzgmeF62Ar0FuDOQ/9WwM9pUIfBXl
0aj/BHg/1n4E9JoHfIixgj7nWx7AfKCaPgy52yD/JfAN0FjwnwGPOxYbfga+
gnIh6j8GvgwqAP8RsJPG5VyzFWMYe7bIz7l+PC8uBO3MKJW/DfRsfhmgdM2T
mCaemA96GJQLGqEy61NBe0DlQTv38lU3EpQHSgF1VzlFdQV1xmFdA8mcd2zf
nwOmYw5vg69RHGE8meZbrGTMnMlzGDKJaPc8cBmoC/sDPopvvSHzDXA26Ebw
X3lma9r8QeAclHuh/mvGnqD5DPUoBI2WLe7EWEuBd4VtTg2DJpsmPlV8I5XT
xdfaJVLzq1T87AeMklyG7JgEGs4yvg0DBsPWJlJ2oUyy5NguSmMUQK4UmBg2
nedK74fVZrjmkiF7J0PuMeYlrq1Bd60ly6xPCVs5We1zJcNyF8jEAecBu4Li
wT8OvBbUAfxTrulBfcYAZ8sPHgGtC1p5rcr58oUKlWfV+ca6rmi/BHgbcD3w
0aDtv0rx6zU32mq12o1UP7PkXzMlW6i5F6pMG70orJRuc6TfHPnjbH2bqzYV
6rdcWOvXsyWfL9kNsv8arUGZxjqobwmwUTRwhmv65UpupHwlRXaYrTnFKk8r
BiajTWfULQEmgTqBXwy8DpQA/hlgN1BH8AtcG/t00HK5mdKX4+2WfmXCmdLh
Lvn57WHTeYPmdJ3quQ9q51/bZrj6KVcd+1uldblV6zRHNh6mb1yvaMzpYtBi
0CXt2Yuu9bdafZaJPy3i/u2lPHd/0HJZ8gdU3qdx9opfr/J+8fv0jfatEr+u
Tnmt1vl8nf6o4yWtH/PiPbLfuTr9nVV9jeZzQHrVSPaM+tyndufU7lf1HxNh
Y1zQOAf0rUp9U5dKzeGA/Ill5pXZoATQE571M9+zPmlflqMV5xnvn1Vu1ge4
SLliFu8vysf6ApcqDxkCXKacZ5hn41ZKl+XKbfKANWEbvyf478O2vveEbc5c
q95a54OaH3UeIL3jxMdH2PdL8rkXNU/WxUuG7dI9a7MqbPbZW8dGVVqDKq0h
+UTdg2rvQzwfeV6mR1iewPLhsN1t/slz07NvJcAEUBr4KcJ8tekTYXeg3uJb
q0zinFn/mGd3rCPoe6DWh/PN1HpwLfZIz9rzslx7Z57aso9MyfYVkW8nuxXL
Lo9r3bn+DyivYH5xRnuGa7BSeeYY4Puetf0e+LDyn7eBDynHeBM4QznM68C7
lR9W8s4hnbYAN3mmUypws/hNilUjZa9kz2z0rmyYqvo09bNV9k6Tbb9UzvMF
cJtntnsGuIW2jLA7z/We2ZN+N1fnO8/59zyz8dPMr5Rr/Vvrnq61vkP57Trg
FcSaobDP767lRaXKjQpQbo36WNfifoHi13iU2wEnALcqnxwF3Cb5scBdygnv
BL6pe9NQ4EbdcUbwTQDUFvy9Li+KlsMzl78Oa1aBnLwh8BXH7kungX1Qrgcc
I+Rdj/eHbbqnHHXszWBvyNrXd0wuSdhN/Gu60+W49g6WAYpy7B7I+2A1sD/K
xXzXAXUQZoOyQJMc+866yapPEA4ExfL+LNlc6JEMGgG6T3eiEt/KrE/im4tk
2WeEb3VnPNOrEDQadDPf6dQv31rYL+/V8XV04beiOuN21xi9dS8ezbc7UFfa
1Df70B7JoA919z8BbARKc8w2R9H+CNcCfGfH3iL4DhgAdQQFQal8n+C7hGPv
E4mgLo61idT3hsI09U97HwtZH7TZINDtvq3dAN++cWzKpjiWo3KMUuVUzPUm
Qa4v2/s2TgPJ0lYTZK806cW3zkue3f35BkDZ7pI/jLrqkNVd5ZhdaBPOm98i
NY8UzeEqfWd7tjsUsrpGmifHdGUD2vpyyHzoCvAPrRnrotSGdu7lW5tR/v/1
6K71YZ4/Qn3d4pgPfRGyNaD9O4FytD77tDeLXXs/5TvqBcYNzZHzucq1e9NP
XC/X3jO/dOw9ke+KTfjm5Nob5ueo76Mc/Q3wd2nPxgPTXMtrAliLm3yzwzXy
X96paeu/+KZrK2DYtTvyt5w3yptR34Y6+qZfW2Av13L53q59PyS9I1x76/qU
tnXt3fVr8B74teC/B98U7WdCNgRMVUz7A+iovhmwtcbl+G01bjvg33RvbeFa
HGTby67tn/rapw0Vl64GJoM+Bt+S72ny1xi9oTaGLk2oj2v3lRtcG5s6UEcf
5XXQ+RBktockC/J9K3cAXsGaVSMWnWN+ovz2LLBUee9519Z8KmiwY23YNsG3
ewvvL+PDFhNitCca6C0uknc91+703zH3du2O/xXvMZoD34PX6r0l07X3NZ45
hzx7a5ygPv8KagFqDnpZb18DgD96dk4dB/aUDGWLfCvf5luZ7ZrRj117z/zE
MTvlKcYxpk5RjLjetTvfC8D5unMdA65w7U62Evi08v9fgM8p/z8D7OnaffRG
4JO6o50AHg1bXnUibP2y/+W8/+l+V015rcURz4j8MWAHfGsPmanAEvEfAZfq
Dn7BNV+hz7QAPqD7zmfAEzpr+AbJuJCgmNpJsZBrm6HYwLfF0fKpxooJ3RQX
ljj238RSxV36whC1KVQfjH+PgGarvzTFwzTFs/w6cSRCdSmKt9SlRPocdOxt
a7++Mz7lKRYmKUb1lW9kKv4NUczqr/f85ooT9RXjzjr2psG3jeG+2aKHb/GC
ceMG4DT1M1h9dVXffBPh20gP7lnH/mf5iHppb3KPDtJ/B0m+9dFFdkqRDGU7
a37s/1bfYnQ68HrpwBjGvIvvsfTpYb7F7wzf3kP5LroQWE/n+u+exfja3GG8
9uPqsMVixuTfPNOFMZ9nZkjxO1FtanOKwzqXeP609+1M6gs8GbJYvVNnCnMI
jpmjN0L6RGKdvhnnNiuW9kP7U8BrgdG+nbOZimFR8rEjOvd4nlU59h7Od/Ff
pD//o+ObKWPjUd6fZGf+V9NRflPrT500N8YhxqNY+TrnR9kktR3i2zfmL5zP
7yErx4n6a46nNPeT2jcD1U+1zmHa64rOXH6/rDOX5fpaI65VUO2o33uOvTfy
f8iW8o1U385jrlGBbzGLsetR3/Yi4y1jJd8feZ7yXJ2Ib+O414BP+bYHn/RN
d+aNxbJvlPbm7XpPWBa2ODjWsfY/OHZG/AgsVM7D3GeS7MM876jyMuYQxxz7
r2Sn9KOec3w7V8aoX+557nXGAcZd2o9jtpBNm6v+lGxbonyVb/n0R+a6U+TX
xSqfUzxkjGTfjBmMNaM1T86xicrU4zvHzuv/AKdrPw/RGrLv++Q7xBL5ANee
Pk65aWrHvTpV5cHaN/SxQuW6zHmrFWNPeXY34B2B/5ce19n0E3CPY/9HnnTs
rZk+UM81+9JXJ0q3Wr04h6aa01i9yy0NW/wokU536+7PN4Bxvtk3yzdbN9Va
8OxrprX+H92Dmfw=
           "]], 
          PolygonBox[CompressedData["
1:eJwtl3u4llMaxt+9v/fd62VESYyi2p2k6JyaTCUzhUtN5xMd1FwoRVdDpJA0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           "]], 
          PolygonBox[{{1446, 1445, 1302, 275, 1348}}]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmnn8llP6x5+e5757boydpDLKOkT2ol2LZfB6zSTGRItol34jaxtpUWkh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           "]], 
          PolygonBox[CompressedData["
1:eJwtl3f0lmMYx+/3Gb/nqVSSRIOyDlFEiRwlIdkjnWwnm4yDNu0lo2OWZBRl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           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1174, 1180, 1172, 1175}], 
          LineBox[CompressedData["
1:eJwNyzcvBmAYhtFXgkFvi+7Te+9GDBKDiMFisViUxGCxGgwSiUQi4tMGie5f
6P6HXoNF4gwn1zPcT2R8Zng6JoQwy1psCKtEOeaEI2445IoDLtjnnHseSIwL
4VGfuOSZa1645ZU37jjlnTM++KTd/5d26rf+kOROJoVU0kgngyx+bXo0k112
2GaLTbrpIiY+hA4N2qZ/tNJClA2aWaeJNRpZpYEV6lmmjiVqWaSGBaqpIoFK
KpinnDnKmGKSUiYoYZxixogwShEjFDJEAYPkM0Ae/eSSQza99LHHP9PnNgI=

           "]], 
          
          LineBox[{1183, 1171, 1178, 1179, 1186, 1184, 1185, 1187, 1207, 1188,
            1208, 1189, 1209, 1190, 1210, 1191, 1211, 1212, 1240, 1213, 1242, 
           1214, 1244, 1215, 1246, 1216, 1248, 1217, 1250, 1251, 1218, 1254, 
           1255, 1253, 1289, 1288, 1252, 1287, 1249, 1286, 1247, 1285, 1245, 
           1284, 1243, 1283, 1241, 1282, 1239, 1281, 1238, 1279, 1237, 1277, 
           1280, 1304, 1278, 1276, 1236, 1303}], 
          
          LineBox[{1275, 1234, 1235, 1233, 1232, 1205, 1273, 1231, 1301, 1274,
            1340, 1341, 1342, 1343, 1344, 1345, 1206, 1443, 1538}], 
          LineBox[CompressedData["
1:eJwNxskqBAAcwOG/y/AaHsH2Iq5uHoBnsI1tJkaSJEmRZEuaFGNn7LuxT8OI
krur7/D1+1U3tza2VEREEwOVESnS9NNHA9tssUmOenrpoZvvRESd1vLlk1rD
Bl10UqSDN9p5pY11XnhmjSeyPLLKAysUWOaeJe5Y5JYFbpjnmjmumOWSGS44
Z5ozpjhlkhMmOGacI8bIM8ohIxwwzD5D7JJhkD3e2aHEB5+U+eWHP6IqIsE/
U5lCIw==
           "]], 
          LineBox[{2025, 2023, 1934, 2038, 2047}], 
          
          LineBox[{2095, 2070, 2071, 2062, 2094, 2069, 2122, 2124, 2123, 
           2148}], 
          
          LineBox[{2160, 2125, 2149, 2150, 2161, 2152, 2128, 2127, 2126, 2096,
            2129, 2130, 2151, 2131, 2099, 2098, 2097, 2072, 2100, 2101, 2132, 
           2102, 2133, 2103, 2134, 2104, 2135, 2106, 2105, 2073, 2107, 2108, 
           2136, 2109, 2137, 2138, 2110, 2139, 2111, 2140, 2141, 2153, 2154, 
           2164, 2165, 2163, 2181, 2162, 2182}], 
          LineBox[{2176, 2191, 2190, 2175, 2189, 2174, 2188}], 
          
          LineBox[{2178, 2158, 2177, 2179, 2180, 2147, 2159, 2121, 2146, 2093,
            2120, 2066, 2092, 2091, 2090, 2088, 2065, 2089, 2087, 2145, 2086, 
           2085, 2056, 2083, 2055, 2084, 2082, 2081, 2119, 2118, 2080, 2117, 
           2079, 2116, 2078, 2077, 2064, 2076, 2063, 2075, 2074, 2115, 2114, 
           2144, 2113, 2143, 2112, 2142, 2155, 2156, 2166, 2167, 2183, 2168, 
           2184, 2169, 2170, 2157, 2171, 2172, 2185, 2173, 2186, 2187}], 
          LineBox[{1201, 1177, 1203, 1182, 1204, 1202, 1269, 1201}], 
          LineBox[{1219, 1192, 1221, 1222, 1220, 1256, 1219}], 
          
          LineBox[{2027, 2021, 2031, 2032, 2042, 2049, 2041, 2040, 2029, 2030,
            2027}], 
          
          LineBox[{2033, 2022, 2043, 2034, 2050, 2044, 2057, 2058, 2059, 2051,
            2067, 2068, 2052, 2061, 2060, 2053, 2015, 2046, 2045, 2024, 2037, 
           2036, 2035, 2033}]}, "0"], Annotation[#, 0, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1585, 1444, 1587, 1644, 1699}], 
          LineBox[CompressedData["
1:eJwNzzsrBXAAxuG/Ad/AziCZTJKiKCJJSFIGFDmIJLnlUgaDUkInSXILGSR0
wmIwGAwGg8HgWgwilFzCMzz9esc3uaGjoj0uhNBLZmIISwkhPPBElv2s2fqm
OZrLFHnMUECUYmYpZY5y5qligRoWqWOZFepZo5ENImzSRgcpdJJKF2l0k04P
vWzTxw4D7DFIjCH2OWCEDG78GNZbveeOCNe00MxffAg//PLNF3N8MssHUd6Z
5pVJXpjgiXEeGeOeUa4Y5pJ+LujmnDM6OaWVE5o4pp4jajmkmhiV7FLGFiVs
UsQ6heSTxCr//0FKMQ==
           "]], 
          
          LineBox[{1629, 1578, 1632, 1580, 1635, 1582, 1638, 1639, 1636, 1693,
            1633, 1691, 1630, 1689, 1629}]}, 
         RowBox[{"-", "0.2`"}]], Annotation[#, -0.2, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0k1I03EYwPHfqH9vIELgIQhiwRhjmhFSFAYdhCQiYugwFBaiIInbkBEo
4aFDhyAUoyEjeoFeUMSL0KGLhw4dOniISDRfDh2MhmHRCEHwIx0+fC8/Hh54
fvHeQiYfCyFUuBOF8JF+PnCbBbp5T5Z3ZJjnBnNcY4arvGWWaQ4cCuEg54ho
4QjnOcZF6rnMMJcocIEhirwizyCv+cEbflLdf3s4hK39WfpbW7WmV3RH23RX
2zXGdSJucpQO6ujiOD3kaKCPEwxwkkFOkSdOkQTDJCmR4i5pRmnkHk00c4YN
+6zzkjVesMpzvvGMFZ6yTIUlpvhCmSfcYpIs43Rymi4SdJOkhxQ50vTSRD/N
nOWve/2jRpk/PGabCX7xiCoP2eQB37nPOmOsMMJXSnxmkSKfov9/bA/zHk7H

           "]]}, 
         RowBox[{"-", "0.4`"}]], Annotation[#, -0.4, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1385, 1478, 1380, 1474, 1375, 1470, 1370, 1465, 1365, 1461,
            1361, 1458, 1357, 1453, 1456, 1457, 1542, 1543, 1589, 1545, 1592, 
           1550, 1596, 1553, 1599, 1555, 1601, 1557, 1603, 1559, 1606, 1561, 
           1609, 1563, 1612, 1614, 1565, 1618, 1567, 1620, 1569, 1623, 1572, 
           1626, 1574, 1576, 1514, 1518, 1515, 1417, 1511, 1413, 1507, 1409, 
           1502, 1405, 1498, 1400, 1494, 1395, 1490, 1486, 1391, 1482, 1385}], 
          
          LineBox[{1662, 1610, 1665, 1615, 1668, 1669, 1616, 1674, 1675, 1738,
            1678, 1742, 1681, 1745, 1684, 1748, 1687, 1751, 1753, 1827, 1828, 
           1824, 1901, 1822, 1898, 1819, 1895, 1816, 1891, 1812, 1886, 1883, 
           1809, 1879, 1804, 1875, 1800, 1871, 1796, 1867, 1792, 1863, 1788, 
           1859, 1785, 1855, 1781, 1851, 1777, 1776, 1707, 1770, 1705, 1704, 
           1703, 1649, 1706, 1651, 1709, 1653, 1713, 1655, 1716, 1657, 1656, 
           1604, 1659, 1607, 1662}]}, 
         RowBox[{"-", "0.6`"}]], Annotation[#, -0.6, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1477, 1384, 1481, 1390, 1485, 1489, 1394, 1493, 1399, 1497,
            1404, 1501, 1408, 1506, 1510, 1505, 1571, 1568, 1619, 1566, 1617, 
           1564, 1613, 1611, 1562, 1608, 1560, 1605, 1558, 1602, 1556, 1600, 
           1554, 1598, 1552, 1595, 1549, 1548, 1547, 1468, 1464, 1369, 1469, 
           1374, 1473, 1379, 1477}], 
          
          LineBox[{1667, 1725, 1664, 1722, 1661, 1718, 1658, 1715, 1654, 1712,
            1652, 1708, 1710, 1711, 1780, 1714, 1783, 1784, 1858, 1787, 1862, 
           1791, 1866, 1795, 1870, 1799, 1874, 1803, 1878, 1808, 1882, 1885, 
           1811, 1890, 1815, 1894, 1818, 1821, 1746, 1750, 1747, 1683, 1744, 
           1680, 1741, 1677, 1737, 1673, 1733, 1731, 1671, 1728, 1667}]}, 
         RowBox[{"-", "0.8`"}]], Annotation[#, -0.8, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1724, 1666, 1727, 1670, 1730, 1732, 1672, 1736, 1676, 1740,
            1743, 1739, 1814, 1735, 1807, 1806, 1734, 1802, 1729, 1798, 1726, 
           1794, 1723, 1790, 1720, 1719, 1717, 1660, 1721, 1663, 1724}]}, 
         RowBox[{"-", "1"}]], Annotation[#, -1, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"TKE Fitch adv=0.25\"", TraditionalForm], 
     PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.3819264862690079, 
              0.43792943606898044`, 0.594554397848251}, {0.6536919882882357, 
              0.5334380789511372, 0.43479448611809784`}, {0.9040666917424064, 
              0.6301667293560159, 0.30260674440145974`}, {0.9474797112342958, 
              0.7386992780857394, 0.4371871048263169}, {0.9908927307261852, 
              0.847231826815463, 0.5717674652511741}, {1., 0.95, 0.75}}}, {{
                Rational[-175, 2], 
                Rational[-15, 2]}, {
                Rational[175, 2], 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[-175, 2], 
                  Rational[-15, 2]}, {
                  Rational[-175, 2], 
                  Rational[15, 2]}, {
                  Rational[175, 2], 
                  Rational[15, 2]}, {
                  Rational[175, 2], 
                  Rational[-15, 2]}}, {{-87.5, -7.5}, {-87.5, 7.5}, {87.5, 
                7.5}, {87.5, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-62.5, 
                    Rational[-15, 2]}, {-62.5, 
                    Rational[15, 2]}}, {{-62.5, -7.5}, {-62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-37.5, 
                    Rational[-15, 2]}, {-37.5, 
                    Rational[15, 2]}}, {{-37.5, -7.5}, {-37.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-12.5, 
                    Rational[-15, 2]}, {-12.5, 
                    Rational[15, 2]}}, {{-12.5, -7.5}, {-12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{12.5, 
                    Rational[-15, 2]}, {12.5, 
                    Rational[15, 2]}}, {{12.5, -7.5}, {12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{37.49999999999999, 
                    Rational[-15, 2]}, {37.49999999999999, 
                    Rational[15, 2]}}, {{37.49999999999999, -7.5}, {
                  37.49999999999999, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{62.49999999999999, 
                    Rational[-15, 2]}, {62.49999999999999, 
                    Rational[15, 2]}}, {{62.49999999999999, -7.5}, {
                  62.49999999999999, 7.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               LineBox[{{-87.5, -7.5}, {87.5, -7.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-62.5, -7.5}, 
                    Offset[{0, -4.}, {-62.5, -7.5}]}, {{-37.5, -7.5}, 
                    
                    Offset[{
                    0, -4.}, {-37.5, -7.5}]}, {{-12.500000000000012`, -7.5}, 
                    Offset[{0, -4.}, {-12.500000000000012`, -7.5}]}, {{
                    12.499999999999988`, -7.5}, 
                    Offset[{0, -4.}, {12.499999999999988`, -7.5}]}, {{
                    37.499999999999986`, -7.5}, 
                    Offset[{0, -4.}, {37.499999999999986`, -7.5}]}, {{
                    62.499999999999986`, -7.5}, 
                    Offset[{0, -4.}, {62.499999999999986`, -7.5}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    RowBox[{"-", "1"}], TraditionalForm], 
                    Offset[{0., -7.}, {-62.5, -7.5}], {0., 1.}, Automatic, {1,
                     0}], 
                    InsetBox[
                    FormBox[
                    RowBox[{"-", "0.8`"}], TraditionalForm], 
                    Offset[{0., -7.}, {-37.5, -7.5}], {0., 1.}, Automatic, {1,
                     0}], 
                    InsetBox[
                    FormBox[
                    RowBox[{"-", "0.6`"}], TraditionalForm], 
                    Offset[{0., -7.}, {-12.500000000000012`, -7.5}], {0., 1.},
                     Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    RowBox[{"-", "0.4`"}], TraditionalForm], 
                    Offset[{0., -7.}, {12.499999999999988`, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    RowBox[{"-", "0.2`"}], TraditionalForm], 
                    Offset[{0., -7.}, {37.499999999999986`, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0", TraditionalForm], 
                    Offset[{0., -7.}, {62.499999999999986`, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {175, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "1.0945990085601807`"}], ",", 
                   "0.05712921917438507`"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "1.`"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "0.8`"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "0.6`"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "0.4`"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"-", "0.2`"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8135778759856853`*^9, {3.813579014470152*^9, 3.8135790433475814`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"LredFitchC", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<TKE Fitch adv=1\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.79042511329219*^9}, {3.7904251451479115`*^9, 3.7904251489914513`*^9}, {
   3.7904252836393943`*^9, 3.790425289602617*^9}, {3.790425387663539*^9, 
   3.790425388026908*^9}, 3.790425430736617*^9, {3.8135778568502536`*^9, 
   3.8135778750282574`*^9}, {3.8135779221147823`*^9, 3.813577926166712*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3Hdcj9/7B/CGCg2ULZRKZIRkJDqKttHe2ktEEcmWvbNKhMpe2XtnlKKS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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmgd0lUUWx7/33peXB5Ei0iShKqAgmoSmKz105OweVmkCKtICIZGiq+66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           "]], 
          PolygonBox[CompressedData["
1:eJwtlMlLVmEUxt/vu/d+91WbJyqNNBpMrWzGCq0sqFURlbYKWrVo+BPU5nmR
aQ4VjWojFbSICFErhwbtL6ggCIIgCM0ss9/hafHAc4b3nHPPcHP2HNx2IOmc
KwchKI2cK0s4Vwja4aO8c2dwOAs6Y+d6wF74OrAJno19Y+DcBjADPhY0YasA
Y+APCXqbuC3gEXwzbzKx9RO/OuVcDj77AsWwWB3krMS2C6Rhn+kVuxRkwdPA
Sd6fAulePuZbDjw8A93ppGp+Ra6n5Bwgdx94DB+JVVsl+AQP8T8CPwq+Izsv
WxX4jBwgH07K5xtywst2CHxBXo7cTm2NYBk86WWzN1+xl/A9edQWgGK4x34i
qW8YilWT1WY9sl5t5Rve4dsMzsPvoKvEVgHuwZ8QIz+hmGvhkVftx8AP4s1G
3h+op7Pgz3nz06kHA/DRXrM8B7rwj5GPJ1XTIHLKK5bpBmL12HptPR1GbiVn
TO4U6CXeg1CzrQJ34avwf0HuDrASnp7St9hMt8Ab8FmAbwG4DJ+CTy+xW8Bk
+BowIVQMi1UfyjcfXILXheJ5oBFeG4rj7qrhcUq7YDucgl9Bt90pp+Vusxkk
9A19oXJa7mYwHn4dXRm+O0FTqB21XbWZfIRP9PK1HR8HL7H+47cbFHvVYLXY
TdXAn0XqVWQxkKfhk4VDPw5TvXpmvbMZ34cvRFeD/QKYC5/jxW2mNttJXm+t
Z9a7llC7Yfd7A74IXW2gGPPg3bFu1W7uQ0o3bbdtPXgf6o29tW9uhi/lTQNv
60G+zQL/IWy/QJvVj/zbSdcRaodsl+yfYP+GbOx/nHxeYs/0/28XTIfnYh92
8um0XUD+66TrQl6CPOKk6zbZq5Y6kOfVQ+ul3cD6SDdnt2c1F8CL0CWwOfAa
3xVeu2g3WgRf7TUr2zHbtWuhZr0D3IIXorsYqIe58BF0g043NAzPiNQL07Va
/Ei5rOYe5MVetVqM+V43b7efBG8tZyRuNb5Bvhoqt+3oTfg/DqiooQ==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.37666679105101947`, 0.43608098088055, 0.5976463592543528], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmXnY1WMax8/7nt8555e0mBbJzEVaRQttlooxM9miektCpcVYxkVSvNqZ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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVlslkUUhr/+/f5/RnFjcQHcallaFVSIICpQNBqRsrWAuIBaL4wa9cIr
t3pDvDHeILgEVDC0uCAGtcrWzQKKtAUJIUSQugYUNVQqdYP6vLzfxZPvPWdm
zjdzZs5MSc3jVY/lkiR5AVKYUUiSVUVJMg+mo/fjPIr/POwD6F44DptgM5wf
k6SHAEOLk+QCdCVjuoscQ7Hq80kyEj0CxqL3MuZc9CC4Ffsj7IHoI/zjFuzl
MBx7GJSjl+atSwV6PXwKDfAJPBmSZA7/nwt7g31qq4ApsCLvfyvmaPQS/odM
ymEpei2+chxlcD36YtbwEGt5GC5ELwqOPQ/2oQdHr/UmGIJ+OXWsWfAK+jp8
h2n7GSag38s7tnIwXnOnTw99j8EhdFnea9Mav8DeADtp+xM2Ks+0V9M2B3Zi
N+et58Iu7Na8tfbrK+w9qXOrnO5Gz2bOlcx9OuxAn649oa0DFqOnFhxP/2hU
frBL6TsMvkO3MWYiehJ8gz2t4P9pTBP996U+G9rT2zW34H/NgHb0dhiCroDb
0NeSk9Zi50i5qsE3i7bZsBO9AGbm7OtEzw+OJV8H+sHgvlWwC/0fPJDzHLco
VvDcp0Fl8Jw1d53Jg+hefPdh3w+N6H+hJucYirU1W6/sE+geuDfnMRvQ3bAw
Z18D+irWsJm1NEIZ+pLos/MIXIQeBJ0514hqpY0cPVfkPZjJfArRsRXvGPHy
0Vr/OBpcg/Oy/W5hbDHtC2i7B36hPRet74ZD2EXR+i74UfkoeK974Fv0SXy1
tNXBWfQtiZ7rYihFJ9Fj79T+07cvWM+Hg6qv1Gf3D/gBfXZ0rHYYgD4zeq8n
w+f0H429qdg5Gom+BprQzXA5+uro3MlXjh4FG4s9ZgR6THTfFrgCfVr03mjP
/iH+2Og2nakr0TG6Tfv7F+2BNdcWOecRfXPe+ZSvgB2i+2oPjtP/Buz+rGs8
TEQfCc6vcr4G/Xuw1v6sCz5jp86aakxnnfiDoY3xW+BV1SC5qoLlqe8I3RXy
LUOX0PdS2IreBm9ANW1PwZvoftHnV2dSZ3NKdrd9qLsTxkXfNafmjD4DXz9o
xm7RhY7u43sCTuquxR4ArejPsjlqrvKpTXPQXLQGrUV91FcxFXt96rtJd9iv
6CeYU3XOd/AedBO+xuyN6M3moLn0ZXNpSH12uqEL/TbUouvgHfTHqdv05uzP
9kB7sRAmaX3RZ0s52cb/BmJ35Fxj/dFr6beasZ3wQeozqbOpPuegfwo+36qR
lejJ0bEXQUV0DagWXoLL0BOy90t3eDt9xmXviXw7sN+CZxOvYTX6xuy+15vS
gX04+F86Q6vRfwefN53RFvTXwW/LHfA8empwrerO7Cp4z05kOVVuDwT3VT2+
iP4+q0+taRm6K7hNviXolYx5JvEc61PXsNp1B+guGJO9t1rTl7S/C/WJc/g+
emj0W6c3UW/jo8F3r/Z8d/Ceae80Zk3qnCv3esPWodPoWlHN/Eb/4dG5VY2r
1l9LXRs686+jR2Xvvea0HXsFPJ14DXWpa0K1Id8q9P9sbxcx
           "]], 
          
          PolygonBox[{{1314, 291, 1223, 1312, 1313}, {1212, 1211, 1210, 245, 
           1265}, {1468, 339, 1346, 1463, 1464}, {1459, 1458, 1343, 297, 
           1341}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.5596996530388906, 0.5004056288635079, 0.49004876626467775`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtk8tLVVEUxrd69jkTFUQh03xcwSz/A62gBKHrC68pVpCUiDTKiRMnTZrc
mjWyafkHaGhXB3q5vgrKauREvRYYFqKoQWgp6W+x1mDxfefb67HX2uvE+oe6
nuQ65xJYHnYaOXcd4QSMe+ce5Ti3DM7y3Yh+E8zwPYbeHjq3ZD7i+zNwrgw+
DW5hF+EpsJmzBvgk/D9WCXdoM1gXfBbMoFfB80XDLsCzaP+oUU/dQeqWo9eg
J8ESLAZ/BoZeY0fANfz34etyt0B9ytDfBxobg9/m7DW8BdxFL4fPgD18T8BH
wU/Uu0zdRKQxElsDprE38FZ85rzmicOLsBfwO+Bb9E74GdhOfC152sBXnK2i
b4GH1LskvYMbgfa7Dn6NtN9+MIvfAfoifM7mfxSpn/hPgd+wUvg7MMPZNXz+
Rlpb7jABfuH7KvoD8DN2BX4XPCKmAp90oPeTe3ZG2p/MUGrfsDyTYIfNZId7
JdHGsefmKzEyi3tW6w8+C+StRismts/6kvcs8Ko/lbdGr0PfCzWXzF/mOMVZ
AsxFH/a6Mzlgoc35I3zT5pO12HGLX7Idll1esfzdYL75ffC6xzLPdKS5JKe8
YZPNcB586HWff9HHgNc92ZM9sRke4v/Y6zv+Ru8I9b9oA1ttntvwINQ9zwv1
nxEf8R21fesGb1m/Ka+7KzN9CfZ6fd/vgfY6ZrO+7/X/+oE+5PUdjwPdaXkH
D54DD1J8YQ==
           "]], 
          PolygonBox[CompressedData["
1:eJwtlEtIlVEQx797u9/3LdI2BZU9LXsualHQwzZFlGUPuxk9oKgIskW6yI0t
2mRZgUKgEnQDNUjByjQ1ixKz16IHZpqPLM3ULF8pSUUQ/YaZxQ/+58ycOXPm
zDmxR9PCqUHHcU5ACGp9x1nLRDxsQMe4jhMbcJx58ByHoOc4u9BJUI7tGRxB
XxA7+jL2EXQhJKAnQDigayqx72Z8CX0H9qBHYTF7LYH97JfPuBlbGYQ9jSmx
L0IU4xeuaokxifG4p2uXwiHWDzFeFNSYexg7+M/Gdw7UkX+1q7lITjXo7/gv
DOqaMP7djD9DD/TCZHzmBrQGT1nfx9yCoK7ZgX8zNEEGnIY87LkWQ2Jtg+us
/QGf0GXEuw1rIR6iPT2f1HCj5Obp2aUGV9BPfF0rNe2Q2vu6t+SwHd0HvVAI
Rb7GkFhrYCL+yZ7WWmJK7GRfzyoxXtoaWdsP3yALzkMHfIQ2ztwKW4mbCAmu
xpY9nqLjYD5kQw6csXpJvT30Fk97oQhqGUe5ahOfeuImemqTGtVhyzC73Fk6
eiksgTzIh5WwAgqgEMaIMRPfGXDM1Z4ps36U2i5nbhlE4BpU4T8N23T4gu6y
8VTpCew9IbXJ3F7G/YxjzP8A4zZq0grt8AFasL+HTdg2w2/0rIDmlCK96+rb
kf6Zgr7r6tuRHlxvZyiwHCXXWlsv5/8X0jPnWY3j7AwRq4nUJmD9LWvS0M2s
aYJGeBfSO5O7kxwl12L0Dauh1HIopLWTMx62npTeLIWbcNbev9xXNLrG/OV8
o+gk5na62iPSK/esXuIzKO/N6ilzX9Gr8V1lOUguD+3+JP9f6MqQ3oXUvxP9
lxqvs/+oDl0NVfATxuGPrzb5sx6hK6AcRmHM1zOU2p6ydwtz7yETzsEt8YFh
GIHHFk/2rEfv8/UvkTfzCp0D2dAJXfLeIVf+DfhiMTOtR6RXInDV3mif/REZ
loPkkgonoRHeQQochwZ4C+lwyv6YZvNptDmxlUAxDMCgrz0ovSg9IL0wbrW6
Dw/sjMNWowqr0ajVtNr2bLCcUq3H2+1PyLI/ocNqkGNn7rYzRqwmnVYTqc1B
X/9nqeFr+2P6LecSy3nA7kDu4qivf7mseYP+D1Mc5CI=
           "]], 
          
          PolygonBox[{{1863, 1862, 1756, 495, 1754}, {1456, 336, 1341, 1454, 
           1455}, {1763, 469, 1866, 1684, 1685}, {1765, 1764, 1872, 549, 
           1867}, {1986, 572, 1988, 1862, 1863}, {1235, 1234, 1203, 313, 
           1352}, {1978, 1977, 2039, 570, 1980}, {1541, 417, 1469, 1465, 
           1466}, {1422, 1421, 1314, 290, 1307}, {1245, 279, 1244, 1359, 
           1360}, {1466, 1465, 1468, 338, 1540}, {1894, 554, 1999, 1895, 
           1896}}]}]}, {
        EdgeForm[], 
        RGBColor[0.7427325150267617, 0.5647302768464658, 0.3824511732750027], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtk01IlVEQhs/n9Z7bQiKkP4IWtgr6/7EfbWndQDCsjIhWBqEb3ShqLVpF
Qam1MITMojYamWlRYG2UutIiwuR2MQlCKRCiIGglXXuGeRfD886c850zZ2a+
isbWky0lIYQzWAobiCGMJ/jwSCaEwyy+hmPpEDqIlxDfgr+P+D34BX8dOou+
jO1CX4EbsT3oXliFHUK/gpXYQfRz+IIzOzkzxRmb8fcSv2PEDqCfwq3YfvQj
uN2+Rw/Du3xT5NslOMI5J9BFOMPaNvY0wQn8LuJp9hzHptG3TROvQs+WhtCP
/xldbzlgPejz8DF76tDLcAH/H7ovuplehFnWqtEFzrmReN1uJv4mq9Vg4veb
f1/2QLFlnT+c9jwsnzxstneSfwqOqA4/YQHbib4EB1T/RaurznkCpzLei0k4
pFotwQ16V549farzN1iH30j8PZxT767CPLYD3QbfqlZWs1nl1gLblc9qOK6e
/obV6sWoejuod48q/gy+0VxNwFbdtQpeUO9WyHct1s3+T+x/qfn5A8uj1/hj
2r+3c/7CNdF78IF4afQaW/8fan5+wJze+w4ejd6jBJZFj9t6A3oMfQoWsBy6
N/o8WW4X4Tnltj763FvNrfY9mvmv8Kz+I/ufavB/oefQ5ejd7LkOs9Hr0x19
LqxOOfXJ+mXzWEh83opam9YM1WtuT4u2x/beUs6W+zXdNZ/xO+yuY7A24+d9
jz7rdtcm5Ws1tPf/B9uziOA=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlUlsjlEUhr+//v9+NggxxbAgJEKpqaZamGdFq0olhoZEF9RCQ0l0gaig
ZWGmpoUhSJSwY4MKEUEM1VRMNasgxBDD8+acxZO8ufd+557pnq9LYXHOsrQo
ipZCEpqEKFqViKJSSKLTYGXC1s6nouhbHEVD+WAIXEA3gXR0byhGP8PIU8jh
bC5MhSy+LYRs9IrYzuqbe+hbrG1mbwu04q4nfFsP01mfAa9ZewXZnJ0Gj9mr
hcnsTYEvsfkyGKrRLzj7B1sPYDd6ot8/DK6gyziTwdm+0ApdHpvuB+3RlbHp
/tAZfQIy0YO0hi7CxhLdiw9f4Uxse7o/E33R/VGOhqNjzgYohdWwMzbbA6Ar
+ic2fiTNpmyPZa0Ne434OwZ9FAammQ/p6GWe715wBz0f5sEvYv0NfbGRAQeg
Ck5BNramQRa63uNTzBt1F2utYR2sd6SbQXO4zJlLMApGQ53nSzmsRd/lzFZs
V0A77s+FswmraUt0GftrPQfKxb9gviuGIr5PYy0BxbAcFsMi+EhOGuE9599B
DmdzY/Opmdss8x5Rr6gn1BsbvL594CG6RD3nd+iuTtARymET3E9ab6hHxnuN
Sv2bEvdJvqlGqtVIbI7wnCg3vdjrqbrCLugO3aACKlWH2GqtGvZAN/X+l38l
6AKYA9+I8XuwHlevK2bFXum2Orrvx+EYDIRMOAKHveaq/V6+eUgsf2EfehIc
QtfABPS52HpVPToMPQvy4DN7X6ACDnK2SvlAz4LqhNV0T7AaqBYf0Y3QEOwu
vbnnwXKw03OgXPxNWe+pB0+ixwWzrZkyVufdX9nPQ1/nTI16D93Ckb7B2k3l
FH0tYT7K17bB+k/zIz8Y0vJ5tsek2OZ4rqv8bahmql2HYL0rGwXoR8FypTu2
BYtZvslH5TbTc3/Ycz8z2KzRvmKZy1oBvKRXGpLWY+X+xvTWXvl7Vk/sR2/3
+/Te6xRrbL2hHl6D/uT10ow5HVvOlfs8r91CbC6AN9z1Fq6mbNaqnzX7nvq8
0ZuvQK92++rB+5qX3p86syO2HlQvzvPZMhsb+Smb6ZrtH3zeaR4dj+1O3a2Y
Fftbn5eK8Qj6dsrqofy2DpYT5UY2ZVszVLN0kb/92mC5UE5UC80AzQLFqFjr
fF8z8jE6FexfpR5Xr+ufo3+P/iH6l/wHvi3bbg==
           "]], 
          
          PolygonBox[{{1356, 1355, 1239, 315, 1357}, {1536, 1535, 1456, 335, 
           1453}, {1787, 1786, 1894, 555, 1891}, {1481, 354, 1548, 1479, 
           1480}, {1483, 1482, 1553, 395, 1552}, {1859, 1858, 1985, 533, 
           1861}, {1979, 569, 1980, 1856, 1857}, {1769, 510, 1867, 1766, 
           1767}, {1449, 334, 1336, 1447, 1448}, {1537, 375, 1457, 1535, 
           1536}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9041158749224654, 0.6302896873061633, 0.3027592122596425], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkk9IVFEUxu/L3n1Lg6RFQTiQkBCUMO0aY5qxNlNRwUwlQswYCEmubNki
CIrE0XTR/BEqKkxwla5aBJVgJEgQ8jQYCAQTx1YubJP+DucsPr7v3nvuufd8
5ySKQ9fvH3DO5UALuOmd+xA4V4Cn4C/gK6iDz7Z+x9k83Ac/gIftvJP1BHwK
fgUciZtwDcTsV+EUeIH+Gzp3HD2G/oXORs61Ed8TKURn4BuR5tki9hJYIH7U
/la3/xxjXYZj8lwG59A5OM3dw9z9CHeDJvsrxG4Hui9vxLZehZe91vgEbgUl
9CJ5Rrx68FP+a/Fyb1reQ7+Hr4EUunHQube2/w/uD3RfclXMh7zX2uT9T1Kv
1XPRq0exxcrbcu8b/NL6cgt+DebQvV69EE/KXv2oWZ9uW8xReAPsoTfhLjCJ
TsId4Dn6N/n/WL+kb0mLOQPvcFZBX0AXrV/tXs8kZtCr3yWrs9v6+xBOe737
CL4LxtEn4Ds2PzJHs6HOkPPql/j2JtS17AfwIa8+fmf/mdee/4CfWr+kb7uc
VdFZ60/Tepy3HiyFOqc1m5sZW/+Hr0bqj/g0YJ6chM/af6TPBfP/CHzP5vy0
1zmWes+jr9jsyQwmrN5GqF5ITMpqkvel3+uheig9yXj9/2Ovsyt51pilffWS
ei4=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsjlEUhr9f+92/3bSJFq1oY05FBRUWtMS8I6aagxbREkNEFyppI0Rr
SGuIolGCjSZYtMJOYliImGcSCUHMEsQ8PW/OWTz53vvd6dxz3nt7lK2aurJD
FEVrIRXy4ijqBvWwFTpDJ9gEm+ELgz7DEvRSqIUaSEIaFIYo2p2Ioj3wnPYa
WA0/mPMT5tF/mr4GyEP3pa8PNECj5kN/aIJ98Iw5T2EaejpUw3pYB1UwijX2
sdZ++OIxKtYMyISPzP0Ai9BlkAIdPKY1HnPS16z2ORl+plqPqcFzotxUQkVs
OVAuEuxfxd4HYTz6KX27EpaDfsFyWO85VC4fxHb2RsgPFpNie81ab+BxbH07
oUewf+qby/95sIN/F+m7BBPRT2Ibqz370L5CezG6HDKD5Vy5r/DYs/jXEa6j
b8Bf5TJhZziBHhMslwfgO+3Lsa1VDJO8Jk1eM9XuUar1lcAU2oegxWuoWr6k
/wXMQs+GGbGNVYylfiadTWM0Vp6St1Qz1W6g+0nnWxZsDa0lT8gbVUnihwzI
TJon1nmNVesJwWqjnCl3ZxlzBoqhBNqhDYbDCDgH2VyILBiN/sycTzAHPRdO
wUkYCsPgG31fYQF6IfxG/4Jy9GLIgo5QB/XQib5suEVst2Pbc7jHpNg+0vcB
StEzYQNUQw3UQi/oCQehBfpBARyFY5ALOdAAjXCPtd65X+6i73v7vTyI7h3M
P/JcWTBPyBuKUbH+RDcnzCN/VCv+taPb4DC6q7d1p3W3C4LVSmsuQXcONlZj
5qAfBttbOR5HfAOgEI5DKywIdj+03kJ0HZxPWAxbgtHs/hyL7h4sds3R3Pn+
vmi/I+jNwcbK06PRG93fejNGolcEe6vkseXBaqLadEHnBKvxUPdIu3ssw2ui
2gyBIveEvDHO91OMyl2L16rAa9UEe72GqmUE/5hTwbfSPVLnNcz1f+pLgVT3
QI17St56y9yIXP5jv8nuQXlRHpQXBxPDIL+Tups6k852F30PjsIRH6Ox8ri8
Lk/L2/JwuccYuSflTd0J3Y3V6FWQBunuOXkvD/LhJmMuJKyG9aptMC/Kg/Li
MfduoXuh1b1Q5LlN97V1x6s8Bym+p/Y+FOzsysEr9Kik3V2tPxJ9jTNdje3N
09vXAg8SNkdz8z3WvV6bO/6+KuZtwe7MJX8/tqNf+35aoxn9H7NY6oE=
           "]], 
          
          PolygonBox[{{1532, 1531, 1449, 333, 1445}, {1444, 333, 1333, 1442, 
           1443}, {1533, 373, 1450, 1531, 1532}, {1853, 1852, 1979, 531, 
           1855}, {1772, 512, 1875, 1774, 1775}, {1364, 1363, 1246, 317, 
           1365}, {1484, 356, 1552, 1485, 1486}, {1494, 1493, 1565, 399, 
           1563}, {1693, 1692, 1622, 472, 1694}, {1625, 435, 1624, 1692, 
           1693}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9333543512783553, 0.7033858781958882, 0.3933984889629013], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1kksohFEUgO943Fkje8rCQslGo4nx2rHSoMkCIyLPIgsWijyKLYo8CmWh
pDRmKExZWEwij2Jp4V3YSZTvdI/F6fv+8997/3PO/bPDvTU9ScaYUiKZuLbG
vHqMuYElXmPSeRmA9YQHfyc/Tbyw5gqupRpTja/DT6IKX4AR3u3j3XBGz/w/
Oy3JnSv+os+17CnBg/CMaMUTcIw9x/gpnCTi+BTcIWJ4B+wnDvA++MueAfwb
bqj/6NlyZoDYsK6XD7hJRMg1wzCxh+fAOt0jdQV0DsWwU/vqgnna7wpsJNrw
C/jEu1vJw0Y9PwsW6KxkZsu6Zsm6+qROqT2gdcpZPq+bzyVrMqzLy2y28ais
kXnyPI/78Wd8Di/Cy3Ru49bVLfVH4aLWLHfVp3OLwUzrvnlOPo4f4kNwS2fS
It/X7+bCCb2LhHV9Si/SU4Xm5a6atHeZQVDneZ9iTEj7fMB91tU8CP1e9y/s
wi/W9JMvJ/+Iz+KF+CpxhzfAEeIIP7Huv5Q7fZP/VvOjsF3/k3zrZi11huCw
9ii9fuv8K/E/+9ttIw==
           "]], 
          PolygonBox[CompressedData["
1:eJwtlUlsjlEUhr+f/7ulm5ZKqaHUUCpmNTSiCDtWFhJB0QmtoVX5GxQtqURr
wcIUSWtokZJgQ0tiSCwsmqghKELakKCiEmqWeN7cs3iS9z/3fveec+5775+W
u2Xp5l5BEJRAFIa6IBgCz8MgaIcd6FuRIDgG29FviL2GMeh0+IEuY2wJfEfX
EDsAD6ANxkMGTICJMAOOMPcmlKGnOK8Vy0TnwCo4A2chKy4I+pHgR8Zno9+x
x1uYytg0SIFB8JTYM+iEjtDvqb1HQprzOSv3cehm1mqB9VaDaumwbx+hH1oN
qqUV7jL3DuxzvgfqxVHlg445r5W/ahsB19DXIRd9Hs5ZTaqtlT0KGMuGZZaz
clfP1fvRzn+rHAvQTxh7HPoaVWuejWuPC873XL1fDCfR94jdjvgz24meD/Pg
G2M9cN/5WjRnD3oT3LB+XEVPdl4rVow+DS/Q7fAeXW3fqycL0Q02HuGMGtHd
7PE59Htq7/GcWQY0QCMsIrYt4j3z0zwmr6USH25IvyT2KvSekXd05jr7DZaf
+nPZ+Tmam2ZnPZo9RkEd1EMiJEAF7II25hZG/BkkMb+K35XQB/pCMRTBNy5D
T9TnrNwnwiRbs85qUm0XoQmmQ6btob0qoQq2slYp/GatP7am1i4kts721N47
oQKeOO/1LjiIjhLrbWtoreGsmQrH4Dh8Ya1uyGUsD8ohZt/o20RIsBpV63H7
Vj1Sr0qhBPpCPBRAPgQQgZWwAn6Qy08oRhdBFEIoh5j1ONFqVu1JMABq4ACk
wGCo1RsByTAQ1hJbA39Z+x8cJnYIhskT8Ml5b8lj8mKF9SpmtR7m20PWE/Vm
P7Fqq1m1XyF2GWbCLMiRNyPeA6vRLfb+yO/X5Ge7T/Lnr9DXkGQ1qJblzt8F
5XMKvdfum+7EAnShvS+6o5ecP2Odtc5IZ5VpXlFOyq0+9HdXe05F77b3Vmtm
O9+zFKtRtY5lTrr1SL2aZN5sMi+mWu/U41rrcbL1RL3ZaPddNevt7SKnj7CS
sVXyPbGvzp+5zr4z6t8q9Ww541n23ukN7OL3THvPFfvA77n2PqoG1fLL/h90
5xv11jnv7f6caXac96y8qxy67I7orhTZXYyYF+U5eU8elBflGXlHnpF38s27
zXF+bf1nzEGfkOetZ+pdaN4tMe/Hm/dj5uX/1ITjRw==
           "]], 
          
          PolygonBox[{{1776, 513, 1879, 1779, 1780}, {1595, 407, 1597, 1518, 
           1519}, {1586, 1585, 1588, 405, 1511}, {1633, 438, 1632, 1702, 
           1703}, {1847, 1846, 1972, 529, 1849}, {1747, 490, 1675, 1745, 
           1746}, {1744, 1743, 1672, 449, 1670}, {1489, 358, 1557, 1491, 
           1492}, {1525, 1524, 1602, 371, 1527}, {1373, 1372, 1254, 319, 
           1374}, {1699, 1698, 1627, 474, 1700}, {1434, 331, 1324, 1432, 
           1433}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9625928276342453, 0.7764820690856131, 0.4840377656661602], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtkj0vRFEQhmc/7tySViIRlVaEWN3aUqlmZYlcmpUghB+g0NKgRBSSjR9g
4x8ISyI+fsCKSLawPgrimcwUb545c85575w3d3B+ZbqeF5ERVEDvichUTmQP
lmGGJtFQ9A8SXy+hCvpkvQq/YDfqsoo8wzzGL7BOfxk+wTP1Xg3OxTeq8Cju
ml8l/O3OcCrShtfq381i74d1Ef8GXEOX9MbUZfUGnA3/t6JICZ9ezk/AD/XZ
OnA8+hdwFPVQn8PXnNe2t6u+bsEs5usW3cv2zaMVZ+7gjvrMN7CEmtRbcCGy
63C3T/0t94nnYfMU0HFkV1XP2jI/TDxfy8cy3gzPKziT+l17k3mZ5y1cjxya
6vlaDpbHafifwAH1jB/p96vn+kBdS32Wb/Vzdt7makTmf3Ax9fpX/W02z3Zk
0I7s9mN++6f+AWO/UZg=
           "]], 
          PolygonBox[CompressedData["
1:eJwtlMtvzFEUx++M+d1Ja2EmqZSS1lvSxniGFgv8B6yFUDEdZWiJkZhBh2jS
2rSrWummnhXVBSFECEklJMRCRIVU0KrELAkSn2/uWXySc8/vPO49j9/CvYd3
5OPOue2QgKORc53wh8NfGEw6dwkaoQkq3rk4Du9jzg0hT2OzBXkrtOK3GN0i
+Ij8CU7gU4AUpOEM307DU3gGL+EFnIVzhuQxeA79xOiDemiAODFi0A4H4RE2
D8n9AI6Zz5jlUK7V2MzivpN8X4X8D12C8wzYw/m4D76K0ax86PqgARbAdXTj
sWB/A7nMHbqgCqrhLro7cAjycBOGoRX2SY/NNvxzkEf+5UMs1XAn8Uc534Yc
HIBubM5DCtJwH909y6FcZXy6oAZmQwmbIhRU6yjURLWJwMMIPrdgP2ShF10P
1ME8uAxDkIGV8IMY07AJ281wAbkXamFOFO6Ys5iKnbbeluCUUbI7li1HndW0
32ao0XIq94j846FH65Bf+dCrKehB/kDO8SjMlGZLM6nZbNdbo9AT1VM9/Y38
Lgq1boP5nF9zzsbCjO5GnkmOaptJzWbeeqcejFrP1LurcM2HGdAsDMDFZJhZ
ze5JKPowk/VWI9Uqa7UetllYis8S26FB61mN9UC9eOPDW1WD5mSouWr/k1gV
2yHt0jJ0y1Ub5G+wHnkDbIQWH3qm3kmnb1PI36EJuRFWQMYHnb61mO/bKNRK
NZrLuQOO2Mxp9nb5sOvagSs+1GDA3qS3fcX/C6zh21roRNdhNVatI74l7J+i
f4tsZKs3TNqMp2yntFufYSIKd9bdvc2yYip2xt6inMqtmqg2E+ZbSYR/kXYu
aztaZTtSshmutR3rtp0p2B1116L19jE8gf/VLJxo
           "]], 
          
          PolygonBox[{{1839, 1838, 1963, 527, 1841}, {1725, 444, 1651, 1648, 
           1649}, {1522, 1521, 1434, 330, 1428}, {1427, 330, 1319, 1425, 
           1426}, {1498, 361, 1567, 1500, 1501}, {1790, 516, 1893, 1793, 
           1794}, {1520, 1519, 1600, 370, 1523}, {1730, 1729, 1658, 445, 
           1655}, {1523, 370, 1435, 1521, 1522}, {1705, 1704, 1633, 476, 
           1706}, {1388, 1387, 1269, 322, 1389}, {1742, 488, 1670, 1740, 
           1741}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9918313039901352, 0.849578259975338, 0.5746770423694191], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFkk0rRGEUxx/D8zzCqFmZnWRhMYXJQk123sbWR5BS1713vGxmw0LKxgof
wEoh5QPYW40PMDUohWQhVkryO51TFv/+//Nyzz0vz8hKYzkvOOdqoBt0vHNJ
l3NteDSoFt8D7EkM4BN7E/sLfgMN9DS5Y9G5IvFbdIZ/Fn8Kn2N30KvwOjwP
5sA+9gvcknx4ESyAuukcNL3m7xjL9yn4tpqX8JJ9I31IPelhEExE5TP4irx7
YmtwEbsX/xBcsZ5Po9aSmhfwVtRZA9wEEd0vbPqGnA/bwwx60v5VjdqP9LIB
nr3ONk7OsNfYkdc5ZY7MbPEfw9dBd50E7UP6kf3tWs8l+N1r7Rr+3PYs+05N
//TorHIvqVWN//soRPX/yr3sHo/yrfklntodZN8D9l/ZmdwssRvU7T4yZ9mr
fej1bpnF+mzOPbhksQPrMbE38Oo1dyroe5J9yl4rQft4Qp+YX95dy97MHbzt
tYaH/wDj502O
           "]], 
          PolygonBox[CompressedData["
1:eJwtkksrhVEUhveWvT+51RmQopAwOCUyUDJzn/oJUsrl4CBncJTLwIARJvwA
M5JL5B4hlB+gXEoh8QOU5FmtPXi+3r322nu9a3+rvHuoK5FhjKmDTPjl02yN
aYFRZ8xaZEw+CXkQR+94Y57Z86x30SXEimERliBJbAQO4NBrTPbKoBzGiY3B
MZxALzxZvXMTXQ8J9CC8UX8SWtFtkI3uYf/R6pl19AOxPqueE+hZasxAARTC
AswHj+J1SO6HLdiGjVBf7vxBp2ACTuEM9mEvnJGz0zAFl3DltSfpbQVW4ZbY
TciR3BqvvQxA3OubydtFQqQ1TsObyNv8gctQT+LtAs6DJ/EW40xWOJ9CN4gv
q2/24dSTeEvDJDTCsNWcT6f/5CD0JL35SP1IzQF0TqR3SyyJvifn3eoM1LJ2
TmdD/knKac/SeyVURVozHTyL9yVyOq16+Ea/QL/Vf1bB/gLrDqs5peg5aLca
K0Jfe5098XCHnnE6C5ITQ786fVu5s9prDak1AsvoI6/9yJvlhpkoCDMhs3ES
ZlFmVma3yetZueOL8//iCmB8
           "]], 
          
          PolygonBox[{{1715, 1714, 1642, 479, 1716}, {1815, 520, 1918, 1922, 
           1923}, {1739, 487, 1668, 1737, 1738}, {1830, 1829, 1952, 525, 
           1831}}]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFUM0KQWEUPKhzwl1TsrHhfTyCB3BLKRsL2drZeQ2UIilFuS/h/znMNF9Z
nGbm3HNn5t7OIO8Py2bWwlQw8zCrYtEEfkpmdfAMM3azF/QJ2Antl8AZ9Bf7
GzCDfoAfwAP8Dr4F37j42uX5Tr7MoeezJA8+Y1Y3hKvQLW9q0CPX7TF14fvc
t0O4AO5cHfauPObmrn7MKFyduGevaep0ATbSt/MfFOn+6upAf3aeJH0G9uLf
9wdb/yzM
           "]], 
          
          PolygonBox[{{1939, 523, 522, 1820}, {1932, 522, 521, 1814}, {1946, 
           524, 523, 1825}, {1735, 486, 524, 1831}, {1734, 485, 486, 1665}, {
           1805, 482, 481, 1804}, {1728, 483, 484, 1656}, {1726, 482, 483, 
           1653}, {1731, 484, 485, 1661}, {1724, 481, 480, 1799}, {1723, 481, 
           482, 1650}, {1647, 480, 481, 1720}, {1815, 521, 482, 
           1805}}]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1715, 1647, 1720, 1723, 1650, 1726, 1653, 1728, 1656, 1731,
            1661, 1734, 1665, 1738, 1739, 1735, 1831, 1830, 1946, 1825, 1939, 
           1820, 1932, 1814, 1923, 1815, 1805, 1804, 1724, 1799, 1717, 1716, 
           1715}]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1388, 1276, 1395, 1285, 1400, 1405, 1290, 1410, 1297, 1415,
            1304, 1420, 1311, 1426, 1427, 1517, 1428, 1522, 1523, 1520, 1596, 
           1516, 1594, 1514, 1591, 1512, 1587, 1510, 1582, 1579, 1507, 1575, 
           1504, 1571, 1501, 1498, 1390, 1389, 1388}], 
          
          LineBox[{1712, 1642, 1714, 1646, 1719, 1722, 1649, 1725, 1652, 1727,
            1655, 1730, 1660, 1733, 1664, 1737, 1668, 1741, 1742, 1840, 1841, 
           1839, 1958, 1835, 1952, 1829, 1945, 1824, 1938, 1819, 1931, 1813, 
           1922, 1918, 1809, 1912, 1803, 1906, 1798, 1900, 1794, 1790, 1710, 
           1785, 1707, 1706, 1705, 1636, 1709, 1639, 1712}]}, "1.75`"], 
        Annotation[#, 1.75, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1387, 1275, 1394, 1284, 1399, 1404, 1289, 1409, 1296, 1414,
            1303, 1419, 1310, 1425, 1319, 1433, 1434, 1521, 1435, 1526, 1527, 
           1525, 1600, 1519, 1595, 1515, 1593, 1513, 1590, 1511, 1586, 1509, 
           1581, 1578, 1506, 1574, 1503, 1570, 1500, 1567, 1497, 1564, 1495, 
           1561, 1492, 1489, 1375, 1374, 1373, 1259, 1379, 1264, 1383, 1269, 
           1387}], 
          
          LineBox[{1651, 1589, 1654, 1592, 1657, 1658, 1729, 1659, 1732, 1663,
            1736, 1667, 1740, 1670, 1744, 1674, 1746, 1747, 1848, 1849, 1847, 
           1968, 1844, 1963, 1838, 1957, 1834, 1951, 1828, 1944, 1823, 1937, 
           1818, 1930, 1812, 1921, 1917, 1808, 1911, 1802, 1905, 1797, 1899, 
           1793, 1893, 1789, 1889, 1784, 1884, 1780, 1776, 1701, 1700, 1699, 
           1630, 1703, 1633, 1704, 1635, 1708, 1638, 1711, 1641, 1713, 1645, 
           1718, 1721, 1648, 1651}]}, "1.5`"], 
        Annotation[#, 1.5, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0s9Lk3EcwPFvuDRPHkRJpOHoBw6UGomXmGH6F0QZolKMkpihddklkSGM
nHaYp7y4lVqHLl469EeIJmUEQVCEREQ7NMhigq8HDy/ez+F5Pg98v59EZub6
9IkQwjLZkyH8j4XwSBvI8ZhT5GmhQDuLnKHEBVbooUKKdTb4x0vqHEbzGW4M
4UCvaU2v6m9N6xwDzDNIgSGesMAORXZZ4gNP2eNj9G2TeaR5yxXe0M8ml3lN
LxskKXOWZ8Qp0UGRVvLM0kKOZh4SI0vgLnX/v6N/dUz/6C2t6i9e8IMKZVYZ
5Xn0PmtM8Cqaw226yHCOe3Rzn4tM8YBL9JHie3QPmuSr5/P6RRP6WeP6STuj
89LT+l7b9J226rZuMcJNbvDNXozqvo7rT81oVSe1FjvenyO4qEsI
           "]]}, "1.25`"], Annotation[#, 1.25, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0TsoBmAUgOHP9TchuSUGSikGKYsscltcQiGUkMGCxcLwLwYGfhO5Diwo
FoPBYCVJKbkMyiBJGSglhUeGp3c5nb6+Uzg41j4aF0KIMpIUwmdiCOMazwST
RIiSyjRZzJJPjGKWKGWDcjapZJsdvtjlmz1Ccghx1NPAHI3ME+OaBW64pS5i
llqOqeGIag6p4oBK9qlghzK2KGGdIhYpIEYuM2QQZYpUJkhhjARG+PGOIf3S
fv3QHn3TTn3VDn3RVn3SZ1ZZYflvjjW66SL7bwd59FHAlf/J0UvN1AvN0HNN
1zNN0xM9pYVmmrhzvza91w590G591F591gF91WF9T/y/+y9JO0Dv
           "]]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0TsoBVAYwPHjcVlQymZSJovFoCyyeJW4SAySpDtdi4VBSWJSBo+BgYWB
PJJBUuRRNummS0peIRKlZOF3M/z6f8vpO51T1N0XjaeFEIY5jIRQw3lmCAmq
zRdar0lt1GuN6o226b126JN26Zv26KfG9Fv7NI1+BshiiFxGKGCcQiYoZpoS
5illgTKWKGeFCtZY55cN0rNC2NIMzWTHHNE6apjkikuqs0M4YJ8q9qhklx2+
2OaTTd5Z5ZVlnlnkkTnumOKGCa4Z44oko1wwSIJ+zolzRoxeftytM7Vf2/VD
W/VNo/qiDam9Wq8PessUd8zSRAszqbM0k8+p98jTE83RYz2iNvL//38CqE4I

           "]]}, "0.75`"], Annotation[#, 0.75, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzz0oBGAYwPFX+VhsNhsmi8WglMFA4c5XBovFYsJgYpbtNiYGFgZS4o6r
o4vL4rPruuQzX1GkrtQlkp/h179ned/nqRke7x8rCSFM0VYWwmZpCFlytJvz
2qkX2qPXesUWd8R5JMEL27yzQ4EURfb4JXgjrZW6r1Wa0Wo91BqtJUYdc9Sz
QAOLNLJME6s0s07L//60kmCHFEl26Si3h3ZpWqPaTYRbbjiocKO2a4Yfvknz
xS5FknwSp8AGH6zxxgqvLPHMPA/Mckfs/x9muOSCafJMkmOCLKOcM8IZw5wy
xAmDHDPAEX1EidDLk3vumaXT/Af19VDu
           "]], 
          LineBox[{1547, 1348, 1549, 1618, 1686}]}, "0.5`"], 
        Annotation[#, 0.5, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzmsvFnAYwOG/0/M8KEIpHUQh5VARJcJ4k1esj9AHyHdxCpVDDhUV2ZqV
tSaTQ0l9AbK12dra2trM2qTLi2u/e/eb+86/237nXlwIYYquxBC66aSH+zyg
l4f08Yh+BhhklCHGGGacxzxhhKc84zkTvGCSl0zximlmeMNb5tjhHXvs857U
pBDmNVMXNEcXNU+XtFiXtUxXtEJXtVo/aY1+1jpd03ptYIZGXjNLE18O/tD1
g9v6Vef1m37QZiKREKLESGbBrlVT6KCN73TSEg1hU1f0Nqssczjmdz2kHzVV
F3WPFHMyf80x3dWo7mhE/2iS/tZE/aUJ+lPjdVvj9IcG3dJ9NvhHml06mRwh
iwyOkc1RjnOCHE5yilxOc5Yz5JHPec5RQCFlFFHOBS5TzBUucpVLVFBCJaVc
o4ob1FDNdW5SRy23qKeBRv4DYG9TYg==
           "]]}, "0.25`"], Annotation[#, 0.25, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"TKE Fitch adv=1\"", TraditionalForm], 
     PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.37666679105101947`, 
              0.43608098088055, 0.5976463592543528}, {0.5596996530388906, 
              0.5004056288635079, 0.49004876626467775`}, {0.7427325150267617, 
              0.5647302768464658, 0.3824511732750027}, {0.9041158749224654, 
              0.6302896873061633, 0.3027592122596425}, {0.9333543512783553, 
              0.7033858781958882, 0.3933984889629013}, {0.9625928276342453, 
              0.7764820690856131, 0.4840377656661602}, {0.9918313039901352, 
              0.849578259975338, 0.5746770423694191}, {1., 0.95, 0.75}}}, {{
                Rational[-225, 2], 
                Rational[-15, 2]}, {
                Rational[225, 2], 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[-225, 2], 
                  Rational[-15, 2]}, {
                  Rational[-225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[-15, 2]}}, {{-112.5, -7.5}, {-112.5, 7.5}, {112.5, 
                7.5}, {112.5, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-87.5, 
                    Rational[-15, 2]}, {-87.5, 
                    Rational[15, 2]}}, {{-87.5, -7.5}, {-87.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-62.5, 
                    Rational[-15, 2]}, {-62.5, 
                    Rational[15, 2]}}, {{-62.5, -7.5}, {-62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-37.5, 
                    Rational[-15, 2]}, {-37.5, 
                    Rational[15, 2]}}, {{-37.5, -7.5}, {-37.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-12.5, 
                    Rational[-15, 2]}, {-12.5, 
                    Rational[15, 2]}}, {{-12.5, -7.5}, {-12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{12.5, 
                    Rational[-15, 2]}, {12.5, 
                    Rational[15, 2]}}, {{12.5, -7.5}, {12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{37.500000000000014`, 
                    Rational[-15, 2]}, {37.500000000000014`, 
                    Rational[15, 2]}}, {{37.500000000000014`, -7.5}, {
                  37.500000000000014`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{62.500000000000014`, 
                    Rational[-15, 2]}, {62.500000000000014`, 
                    Rational[15, 2]}}, {{62.500000000000014`, -7.5}, {
                  62.500000000000014`, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{87.50000000000001, 
                    Rational[-15, 2]}, {87.50000000000001, 
                    Rational[15, 2]}}, {{87.50000000000001, -7.5}, {
                  87.50000000000001, 7.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               LineBox[{{-112.5, -7.5}, {112.5, -7.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-62.5, -7.5}, 
                    Offset[{0, -4.}, {-62.5, -7.5}]}, {{-12.5, -7.5}, 
                    Offset[{0, -4.}, {-12.5, -7.5}]}, {{37.5, -7.5}, 
                    Offset[{0, -4.}, {37.5, -7.5}]}, {{87.5, -7.5}, 
                    Offset[{0, -4.}, {87.5, -7.5}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["0.5`", TraditionalForm], 
                    Offset[{0., -7.}, {-62.5, -7.5}], {0., 1.}, Automatic, {1,
                     0}], 
                    InsetBox[
                    FormBox["1", TraditionalForm], 
                    Offset[{0., -7.}, {-12.5, -7.5}], {0., 1.}, Automatic, {1,
                     0}], 
                    InsetBox[
                    FormBox["1.5`", TraditionalForm], 
                    Offset[{0., -7.}, {37.5, -7.5}], {0., 1.}, Automatic, {1, 
                    0}], 
                    InsetBox[
                    FormBox["2", TraditionalForm], 
                    Offset[{0., -7.}, {87.5, -7.5}], {0., 1.}, Automatic, {1, 
                    0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {225, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.02101057395339012`", ",", "2.158604860305786`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.25`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.75`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.25`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.75`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"2.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8135779271613846`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X1", "=", 
   RowBox[{
    RowBox[{"xlatlongd03", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"PL2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ";;", 
        RowBox[{
         RowBox[{"PL2", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "NLA", "-", "1"}]}], ",", 
       RowBox[{"PL2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y1", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"z", ",", "39"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"X1", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Y1", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "X1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "Y1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7904244359100437`*^9, 3.79042454348353*^9}, {
  3.790424586903467*^9, 3.7904246151183257`*^9}, {3.7904249193160133`*^9, 
  3.7904249288616333`*^9}, {3.790425545864244*^9, 3.7904255506182556`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchABlue", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Wind Speed Fitch\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.790425082171939*^9}, {3.7904251545992684`*^9, 3.7904251558237486`*^9}, 
   3.790425220305675*^9, {3.7904253561856956`*^9, 3.7904253654911857`*^9}, 
   3.7904254259902124`*^9, {3.7904255033112087`*^9, 3.7904255034805574`*^9}, {
   3.813579820993947*^9, 3.813579823284566*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3HlcTtv3B/BUpMlQZAoRCZE5itqFUIZGhGiWkhSV8TYJESJjpiSZM5OQ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     "], {{{}, {
        EdgeForm[], 
        RGBColor[
        0.23895798538982202`, 0.3805322141054567, 0.6251828752063413], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNULsNwkAUewccBdS0SIyRKZDYAAqggjGORAIRwQJMcAlDUNMQGmo+QyBh
61xQWH7P7/yek9FsPVm1zGwItIHKmxXOrARfOmZjaA9wr2v2hf6EfgVq1G/w
HMhQD3wC6wW4At9deneEH2QncOPSHs4CEIGNeno4zzSbAn3d5f2tT9oS/PHJ
81KWQv5S+WtwVH5+R0SfQ99rR9Ddm/I02svZzqcZs+VC/MtXqY/yUzvoFm/m
esMcZ+XjPwt6T98Pxqg5AA==
           "]], 
          
          PolygonBox[{{1511, 471, 509, 1547}, {1512, 433, 471, 1513}, {1185, 
           1, 79, 1171}, {1510, 509, 469, 1579}, {1457, 394, 433, 1458}, {
           1383, 313, 353, 1421}, {1422, 353, 392, 1423}, {1423, 392, 393, 
           1455}, {1424, 393, 394, 1456}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.4474845255674782, 0.46096900259559936`, 0.5560154865673611], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVDtwjFEYvbv571V4zohBacSYJIY+j0KMygzJtkYThMiIobE9nexjxKtJ
DCoVslm2U2VE6VFklyi94lmhEec4x0hx5tz7/fd+j/N99982fKYwng8hjAFt
QCUXwkOgCvQBR4F+YF8Uj4HvR9mrXGchFHDvCXgWthbwCriMb8fBp8GTwAjW
4+Be8LB9c90O9ADLwALwGwhIqGnbJPx2wnQL3J1C2I5vb6PO8jvPlYBaTvEn
gBnvefYA0AF8w9398LFplfK69O9s1PqBecb2mn23bFvwfh5+fkCo70nxWGvd
elG3R8DqpDreRd1t2l/ZOda9b63Yv/b9ivdcjziXkvvQZ+1qUb6ugW8i1mHk
UwN3QachoBu4molvZ7KdB4pBeTP/BB0Gg+5QX+pCfXaCL+LMWpyp2mebz3R6
nXeMzPfveAY4C5nP0F7wOcYfdA5DRpdto4jxGA6LSfPBmq94diasQdMzQb3u
RWlQAdejdL8BPuae8t5slI7Xbe+3fnX3i1o/Rby7SHQRPAX3c8A0cAj7c4h1
JCnfKdufw1cD9xpRsZlDOSr2395H1VV03Zy9s56/r777IsrfkuNtjZr/veBf
EO4TbFuwvuCesrfzmXwugkejZmAAvCGpjqWoWduR13vYk6TVGvBBa0uNe/zW
NuYUn8x4u5Pu7kqqs+g+rU/S6qNnre7Z/OC39x780nWxvpOeGc7OZtfF+uib
+XX4HVIP2kpROZ2IslEr6l7ymyiveIe0Dbgv7M8618hap91H9vNzlCbUpuHc
mOOcNWe9X6Le6DPwm0zffoJPxf//uT/6tqlS
           "]], 
          PolygonBox[CompressedData["
1:eJwtkztMVUEURefinUsCIgXfloAFUeloABN5iRWJIbRECkAERY022lMS4Cm/
ypegFRV/pKNSKVEbIx87QUBjpzbK2tmv2Mm6M+fsOWfm3Ib+Rz0PS0IIrShF
nTGE6iSEdnQDfsfiU9a70RL8FRXgt+gQXstC6L0QwiIqwPPkTJGbRxtwLapK
7FkH9xHzmAO30S34IHPub7QD3yfmOrGDaBQejq6lDU3Ak6i/WJ/2aor+p9Qz
BGel9rpJbb/wex7tNYCW4bnUfV5Bs8CzzLVUkDMMzxAzpLPQLJzPvKcex+B8
tJdqWIIfoDuJc6bhCmK+wAHPS/Cf1Hd1hv7Cp8Tss7+HKtk/43sz8doP+I0E
b6GP8Kdo1tpP+Bh9hlfRLvyhGC8PeZ1Ee6sG1fIqda896HXqntTbJFqDO4np
otYnKAfPRe/pDdfhI/Qv8Znf4QU8mt1emIEPdIfBM6HZuIrH5RJ7ylszo9lR
zjS8gsd48X31NupBvWhtFa6Pviu9qWbnbvTb61tvfQ3P/4nPaIE3o2dNd6C7
u5i5OMUodp8zXwbPsGb5GzGN7DehMvbfp74b9bAD3858F5pRzWqO+I7EM3kv
Oke5upPyzDOqXjQDL6L/Gc2mckbgc2rDbxw=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.6644934581706143, 0.5372341226797686, 0.42844474024475077`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVktQlmUY/b7//94XFqXVxC/VlOHCtAFsKmtXgiLaKDVeWknNtBGRSxdt
EttRrTMQE0iBagNtGlNHLk60ELI2yEy14dYmqDRSF6bTTOfMOc24eOa8l+d9
7s/zfWVvtO5qySVJchWUBx3CZifoHdBKHCwCVwDvAy35jPuNea3bou4+jNo/
Z17K6QEdtqyToG7LoszfLGuj3yx6v2R+8lJGnZFySqBjIU2S5ZAkf4JmsJ4C
VuF8B+7LgcM4m0/FV4n9WpxXAGexD1jPAS+kQvJRRpbTfVOU/iPAGtCTWD8F
LBQlyfYsSdYBX4vypT5KRsxJzlXbQ7vuxV2K89+xXol1Dus/sB633/R13Pgd
6Fuf8ywPWp+TbjxN8CwpB13G5ivE5xxwHe5eNl8x7mBWUgk6hbt28Jyx/idy
4p3E3TXQX4lyy5gwXm3Y94OOWgb1VSR6V+e3OSN1MaYjqWI8CD0f5KXveeec
eey2H8z9kv1b9J7rXtCuKHw96qzHbwaiZJ4F1jnOjHePa4Cy26Nq5mNgQ1Tc
3ovyYQD0fqJ4drvmel07lPFRlK3HgP8AVyOnj2fy6Tio0zRsPzsQ/BeBzcBL
7pEJ0KqgdQH4CegF1g5wOq8cXQFNQscUcAZ4y2fcTzgXzMmPUW9mgSucM9ZO
hev2HtqZSfct4MPQsYz1v1h3Y90EvT3AM6D99AF4FnQA6xNBfOR/JEjnhH34
BvsG8HQF2cVYTNu2vkT6yF+SqmYawVfAujpozzXlHsa+GeveoJgytn1RvvVb
323Lpo5fwHcR/D8H7ambsSFPGWy9A+xyLkZBn9KPVG9+9RnzcjHobjToPfNI
efNRMm5E8S343bxzesHyqGMMtNf18iqow/fkuxY0D6ZtJ2uENl6hnzg/H9Sn
7FHOjkHndsg0Zd/Su3roum2jjSfx/iDkHAqaIZxLnCND7qlB9zlr6QfPj/We
DUOWzbtZzy6+vx7k69+eQ3nbttf9TT/Xerazv9mr9e5dxn4baA3oZhQWFcnv
2kz3/Y75WFD8Rh3DvqCYjhjHnK/oucV5Uub4UV6ba4z1sRyVuwhds8DTOJsD
fpkpJ18DW9yTrIk99oU+labqO/bnpqBarQI+9P+Za5S1uiqVr/R5X14xYqwK
UfbtTiR7q+fBasfijmPzbpAdn7HfU/Ud80c/jiSy+/NM/g5kmqUVnsmVtndD
ohiXOaZvQlY1ZGwP0tvs8/OusXNBNdlsfYxBi/esU97RllrbTBljzhH7Y4P1
Mo5N5u2w3ce8pz2tmb5tlY4B3xT7e8fvXrF9oLzTzv1wkH97fFfuGPLsRCbe
LzLNROboYFD+Rlw3a1xv1MF3bZZV4/w9Bnw2qiceiPKxxW9qHasW18sl19MB
1wBroc+zhzVWlWrWMdYv4W4z8O2gvPVZ95ao7+krUXycn5udb8b8FLDRcWP8
xv194Xem4BlZ4vpsc41uCarRR62TMinjqO0aMO9u11Cz88M8t9pX+ljvbyzn
Qp17lz38TFTf3x9V0+3u532uc34jd/hfivzV/keq8v9Dnf8hjmf6x+gCPu1/
nhr/R3Xapp13/YvV+XvKt61B8d0GfND5Yt4K/j6WBn3j+Q1ujOLd73xs8rrK
+WbetwIXMsXmdqbvBGfJzaAeZi0xppOZYjaRaUawxr8H/hQ0f264txoc98uZ
5t98pthPOv6lnhXU/ZbzxBqZc23NZPqm0s5O4H9Vul5+
           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsTlEUx+/7vnffZyFVQ0sNERaoNGqI2KGD0kQMlViphY3ONVVU7Axr
U7Wl6YQNFhKtKCViQVs2VcSmk40gHVQX1Vr4/XO6+OX7fffed969551zVx2r
LKiIOeeOQginvHM5gXMlcBrfH/HLgr2QjR+A/XgVHMQ/saaDtdfhGf6PIGPE
GYel/P8DL5nrhM94NqTiKVCsdxEjPWYxc/E0xkZ5dgQW4yWMNTD3BkrxjbA+
Zs/oWY1p7geU4Tk8sziwd5TgxYy9Zq4e9uHljO1gbrv2jFfAzsDGbuCT8Cqw
PX/xdkadVXsowBdAhHvYgs+PzEPYhC+EocDWLMKvwta4c0lwKbI1WqszbNb+
ve1Fe9be+8lfE2evhi45a47ELcZFPMtb7pQj5UoxFfs78YrwAejj/zQM4pch
Gd8GV/BueKBY0IjvIUYW8bLhBN7NOw8T+wL04FPw1tmeBvCh0OZaYRhfwTNL
eDYNduHvifkobnv4gP+GKbwXuvA7rCljbTlU4W2MPYzbMz14vre9qAZPeqtB
1WIp1OPvQsvNIXgcGvIMuIvvnv2eOlMl3kLMQuUeWvEOxmqYuwVNeKNqILAx
zT33NlcLzapfnpnh2dXEnsRfeJurgxad3VutKkd/WTMDXc56QL0wHVquNKa5
e5DpLMf3NRfa3gnjavDls/WrnObiZ7ydXTm7jY/BYGA9p95r8JZLneEsfhOO
B5YD1XZ7ZGdXjpXrlIRzebxnJYzzv47fOc72VBtaj6pXv8EE/hMCaisG81if
CWtjNpYkJ155aDEV+5e3tXFIVvzZ71cM7d7uCN0V1+Cjcg1Fge35iXLrba3G
2vDqyHpbNXwe7/SWe/XoV/ypt1h6h94VJexsqjnVXmpkZxnWnYOPe3P1qHr1
XGS9oztCd0Wet1pW/lRLGZHdfWtgA94cWS+pplRb/ZHVtnpKvVUY2V2jO1N3
55PIek09rF6eG1ks5VC5VI+qV1VjE5HlTLnr5/0jvL8PBgL75vr2vd7mNDaK
JxJWm/n6jvi6hHklpOPLvN3FqinV1n8Sz7/3
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.8815023907737504, 0.6134992427639379, 0.30087399392214037`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV0lwlkUQ/f78/8xvCB7YFNkpkKCAsomK3EAQAggRyqhVhsDNLUAiJGEJ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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsjlEUhr+//3/v3xILYmg6mkKjREMNC8u2qoZUVSQkxtgInVSptolN
ETsshCodqJVFiSGoproQLVaGEhG0SCxER7N63pwu3nzPvd85995zzzl3xs7i
gqKYIAh2owj67YKgMxQED9BreIkPgnEYxKFp8HWMtmC3GXXDddjkYJuNzsFl
KAtORnnwWWwmYJuJWrQBc8N8RtB0eJS5ocDmUhlXscdX9poSDoJqeBKaz3gB
yoRPoRX824VOw9/wifIvVj6MLzAuZu9cVA+XOzubznQWHkS9cB96Af9i/0fs
3YzewydZYzlrT0RH4Q1oI2tXoUI4H58ZY+sfhCtRHrwaFcK13ny/YH8YfoJa
Gfegp9585LsKrYebvcVyAl2Cs9F6fNPRIngdNtNDtucceKK3f7qTxXClt706
0V54yFlsH9FL+ErE7l45uwYfcra3zlwA31eO4DLUBv/FpiuwO0nQ+dB+/pWj
Gvg8WhmynB+ALzv7V4fa4XlRzswa5Sgd7uZMV3WX6Cbcy3wLaz9BffAHdCSw
Of3bhk09sVSgAm85V+6V48lwDnsksNcg9inwHVQSspxfhF+hDvgz+gFP9VYb
qt9+xtu95bIR7RA7y53ib1JundWm6nemszn90x1Uw0ne1v6ERhg3MN4atppR
7ezxlgvFoFg6dGch66k3cDIaYP1+lOUsBsWiuWx4GT7jY6zn4uFEZ7bKiXLz
LmK1WqM5OAebhTFWoyu99ahi1dxSbzFrrJofgFvx2YRvBroM53u763yUBWd4
Y9WgajHRW6yqp2H8fzp7G3THuuvv/J/LOmkojnz/i1hu1dPq7fqxelfNVMBF
2D+MsR4v1nmj5quaiYenojx4FoqFo1HjP9zvEPY3UG3Y7rwJfhSxu1BMik01
r7O2ox5nb5BymYRK4bUoNWQ9NdvZG6a3TDX4GB7x9hAqJsU2PLaecpLAeJ+3
2lEMiqVtrD5KUaN6y9leiajEWQ1p/xS9EfA7fJ5z9mdoAL7rzFc13AB/YG40
bGcYhm95exv0htz21kPqJd1BF/ze29siH/mqB9WLqrkWeI2zvRXzLPiYt7dV
b+hx+K23s6hHH8O5zs6uHiuG7zm7S70ReisGveVCMSiWNPJTErGcKXeXIlZb
cegM/B/h0NAe
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9317110740218668, 0.6992776850546669, 0.38830432946778703`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV2lslUUU/dr3zTyJrIHIKvvaIipLiybsiUpkKVsBLUUNUMEImlBapKyl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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVlslUUYhuf85585LogaiCJLoEKrrQRXFE2ERBOVSClCaRSJC8EYTRRN
RKAULDXEBRNxiwkGIQqtRCFaF9QrRUAvpEW9skUUbV0TuYFSKAGeN+9/8eY8
Z2a+b2a+Zf6qRUvmPp6FEJpRjuoqISwFGtAouC6GcJLxiaUQ5sHvphAWl0O4
Gb0GH2NsOA7+Zn4QfpGxMczdgl6Hp6HrmF+AZsLjktdr7Ea4jM2P+D+OquHV
jB3J7OMFODDWzU8XGg/PR5PYqxpNhqtY8x/8LzrJ/wnJ/A86wf+R6AL9x346
fCq3rw7UBzdF+6pBU+DHsP+O/d9BD8IbWHMha6eh9+C3UT1cg7bDnazp4Kyt
aC98Ezo/8x1114fweR++b0Dr4A5spmI7HLXDHYwtY245elaMTT+2b6KH4Z1o
Xdkx36J4577LLjSC9a2oAds5aCE8Cw0ydwzdCd+b7Gsmqofro2OtNRPhT/C3
MPhMnblzrFwrxlfAz6DZJe+xAL4EH9fgaxgaDc+IvptivBh+mbFry75DG7ya
sfqSfdwD3x0da41p7lvWdJUdw154B2d4KjjGu+HTrNnL2j3oIDyWNecV8VXt
zUGXMjfE+gb4MPNjsTuKv5z6/YP/PfDP6Ci8j7m24Dvr7luK++k8q+CIza25
fYyAz0VT4EY0Gh7ARym3T/n+FL4fX2tRN9ybOzdvoQH4HGxq+c3QIOsPJZ+l
E3XBW9lzaREfneU5xi5i7jD3a4FnM3ai6I9J8J7cvhWjHngk/h/NfebqimOk
WKknTsE70AfwWrRP/VvkYxZqgW9jjyb2ugpdnxxDxVJ71sB3JPduK2qCq6Jr
az8qRfeYek01P5753uj+241+gT9kbE3ZNbERPpCcG+X8f7i56D/VWyM8j7GW
zGe6PTlmip1ifjb328WaTazdjL6BVxTvgWp2Lvw12gg/jb6Ca7Ef0luA6uDl
RX2rZu6C30h+qx5BW7UWVXLnfBj79Ufb/oTOYq6GsVdyx/xKeEZyb2kP7XV5
ET+9mQl+UjWX+U1bBf+JfmWvhP1xzSXXgnr8c/iyIt/yEeG26N7WG6G3orro
X63J1XvYXJ25J9Wbv+d+29ag7+Exyb2qnhmQbfRbrZz1wFOTcy8fo+BFqD3z
mZ+AP87tSz2j3lkZXTvKmXI3VORfOVfuVROqDb3ZE+B+bN4PfuMz/l9c8bel
tuiN+cm1pT2192/RuVXPH9J7U3HvNaPJ8Mrk3tAbvSS5xlRryvkB+KXoWteb
uz26BlQL6rF2eFvut1w9+5m+Bbl7V2fUWb/E53pysRN1w/uT+SDqS86Zcqca
+Qt+IPlboZpthF9N/jaqh5/X2xZdO+rBPvij5G+FekK9IZ/yrZr4Ad4W/S1Q
javW25NrU2f6Aj4D6ZsAHw==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.9663770376964892, 0.7859425942412229, 0.4957688168591164], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV2lQllUUfvm+994X0bEEa6aShJKsbCIoFdemQrTRfpRBhKIC7YW0N02G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           "]], 
          PolygonBox[CompressedData["
1:eJwtlllsVlUUhe//955ToIi2JSYCUSpUSrFUQZBiAYcHUfBBlKEURCk4PViF
qDFGqYhoBQWNQgQxzoClOCQqVTEq04NCFXAATASlFBOBF9CIDH4r6z6s5Ltn
2ufss/c+t2xm44T78kmSvIhS1DUmyTIaNqK74CEhSXK5JKlA9XAhbX3p+5fv
S+B61Jj3HM19HJ2Ad6DH4HbmjM17zE18X4Vq4BnoRngMKst7jMZOQQNYO0GT
4Y5gW7JZwdj32GQt3Q2oDX4g2tZqdD88MZqfQJPgqegL+GU0Gx4b3VePboDH
R/fJCXXw5zp/QZIsR2vhAej6vO2Pgj/G5kJs344+hS+kbTh956GL4IHs9yf6
fkQRHhFtaxiqgS9GpXn7oBZez5gWzrcTHYSvpu0gfUXYnw9/j41m1voAHUrt
A+1FPquMMpIkR3Jesx+8XGdkbiNaDd+J/sjbBw/COXSM8UdROTw6+uw64ziN
zfyt/US+N2HzFczMQb/AlfSfTnxGnXVH8FjN6cL4OWg3a51E8+B9zPmasYdR
KWP7R9vWnrX3E/R3gl+hYvo/pK2Ovc9Dr8LfZevLR7/LNiph7b/4PgM/HB2r
8pl8dza4T+v/Bq+J9oXuVHfbu5CYwGYTqoK30badvuPoKNyTOecydziaBY8K
ZrXNhG9DlfAgNAO+LDhWlSNFwTGt2F6IJuv+0AbWfgG1w++jd7PzbYZXRvMU
tB7ezxrbWOsNtFl7YY9DU++5j/ZL21v0vY2egSehs2zhDLoUXhIdO0PQNMU6
uhzuhp5TfgSP1R0OCh6jsfL5KuUCug7ug16CH4qeqxhqghcrXwscY8uic1Tn
1x4Gw89Gz1UNaIY/iz77vagNbmDM9My/zcF3rPPLJ1vhLbS9mXOMpnyX8N0j
5xiphYcF+/4WdCW8LnVsjkPfpM5J5WYN+gQ+zRrdU/uwB/5bm7qvBK1J7WP5
+hG0SfGCJsA3oyfhDalrjXJQufg0bRNzvgPdxWu0jadvLtoM/4m9jgLbPAXP
zs67ALXKP8GsthZ4Veq990ct8MjoWqGaotryOm3liW20wl2Y83N231XBManY
lI/ugBdn6ytftss/WX1R27fBOanc1B0ugvdGx75y4IhiM/quFAPvKH6yeB+I
psE98eE97GMpqoY3RtfKL9FO1UvG7GZvu/SeqD4wbl3imtkOf5TFv+ztg/ek
zn3VmOPwliwfNWaP4oG2FYlryN/wrmhb8vFh+Bz2UC2/oO7wSdoO0LcfdcK/
ZufrTX9KfwffbQXOyR/ggui7VMwp9v6LXktraK2C4LPoDPngmqLaohw9AFcE
13qdOcB5bPRKbVO+1ZtZkflvKByic1c2t/L9FLo155gaCT8fXQuUsytkn/Wu
Sb1mMVyEJqY+s84+PzhWdUe6q+nBtvR9he47s683tQ5eybzzE7+heksPRftK
PpFvxmT1TvG5CO5M/fYo5gr5bsrW15pT4bXBuaOcUe5UZfVF9aArPIs1W/N+
E+bC1Vm9Us3opveAMyzBxt1oMHwBejT1GXvBx6Lv7lpUyncoNCsGy+GSQs+V
j/rBC4Jrg3w6Av4n9dujHBnNdxnrFef9hugt6Rv9dqvtlP4/omu39tyg9zl1
bisG98L/AyOmIjs=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.8733376043875569, 0.6062580082266693], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmWmwlcURhs/2zbmggGsBsolsLqBEWRLZLmqQxfxxAwVcLojgdUEUSCyV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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElslVUYhk//e/5zQa0MYogRQVrAnaKAMseVCejKoCCCCkUFBQpOEWKI
RAZFYUWggIQFIUiLJSxIhLa0UCVQu2GotKibkjCDlCExUdDnzXsXz73Pf4bv
jN8ZOrf61cVZCGERRPiNn2r+F0MHfjwP4VZZCO3Qho+BHI/wNt4OJ/G/IaUQ
yuBRAk6CDC8UQ3iROO9DJX4+d9sh1I+gvi/f5xmrCc7Spphc95Ji4Gei56L5
ncYfJ8ZK/t+EJ/BfaNNeCOE2XMfvQTl1F/j+F++EHrwNruIV9JlH/WQow4fA
XLwKnsSzomM9xvc12j/L/H5n7HPwYO4y1WlN/Wg7MnddFzyAD6N+QOY9GJ48
hsYaCH3xPrTpDl6z1r4WXmc/esEavII+4zPHqMRD0X21Bq1laNFz1Rq0li7+
m2l2Afrl3nPt/U2dEd6HNqOj9+Rh/Jncc+2E3nj/os9mAzyND4Y50XvyH/3f
oc1oYo2BOXghOXYPHFN/KC9zG7V9K/fdKKgMn6AYmdc0EZ8BazOXTcfvwyPR
Y2rsKvrMou9XUIe/R303bXuz/i/xzTAFr4BN+EfwD/Ud8Al+lTgfsLYF0IjX
EmMXsVbACfwMbY4VPKbGXpd7rFr4Ff8uObZifot/ljz2SFiPn9JeEfsAXIqO
qdg6w6/xy8l3rxku4ftgV8F3tAufB/WZ96AKf4g+fxDrTyjH91L2Gm2nQR3e
AsvxZXA4GfnnUItPhkXE2ghv4Jej56aYiv0jZTtp+wUcxbfBioLn9HNyDMXS
nnTgTyXnnmK+jLcm545inMX35t4r5Xw33kjZUuqWwB78dPLaa+BU8puht0Nn
oLNQzip3dScH4Tf4/zD4zJrwCbQplvKhh+8fkmPrzHfjrySvtQHexZuSx9Ic
NJdW+tQE58Sd6JxSLMUcj69MPsvpsBVfXRovwVh8du67m8Eo/G50bumOT9Tb
l3z39SbqbdxG/STqB8L30W+Y3rJNcDt6DRpfOX8L36F3EJ8KddFvmt62hdCC
H1JuB8c8iI/LPTfN8S++G6Lv9nw4qbFz56Zy5hvdH8qWBu9BJ34kei7Vpbdd
fdRXd1h3eVUpvt70F/DnS++7yq5TfxH203ad3hh8ZvLeKyc/xX+KrtOcNfft
0WvTHI7iz+XeS72heku3JN9F3XHd9ZvRa9cdOIxfic4FzeGa9i73W6U5FHPn
uHJdOfQxviH5LHWn65NzRrmjnKnB/wcsxd0H
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1Uj1SQmEMjPLxaHSkEEoVDuEMg17CI3gAPQCHoNEZ7ZRStPUHkEEtfJQq
CEdQ0MdDe3V3shaZzcuXbDbJK+3u7+wtmlkFloH1gtkB8AW4kTPbAq4DR8AO
4vmsG/0VYAHxGQoTWBl52/guAbuR2QliPeCZfMYWlMPcc3zXED8GLoPrEpxL
wCe81+G3gUPVkoO92GcV2FQtOX4jj62Bcwo/RXwMvIc14F8Aj5Tf1Hs/47pp
sfQn8h9hRc31P19fb4ynqhuLy3Leh/ynsA/kXCE80c4OOYuMPvf7rTfutQu7
gZ8Gz+F7y1wH+Tj/V/DYPLiWhvT8aPYB8DU4/13wu1FrQbvkbqkpVi15uS/W
kmMUOe9D5Ddg/nvw/4B6BsHvVhT3s3h5q7xuytsOpYFaYvXhHDPNWAH3J/xr
+JtZ56JG6phrxirit8pJuCftcwp8U1/2/wP4/mt6
           "]], 
          PolygonBox[CompressedData["
1:eJwtkD1OgkEQhjcyu1SoBbGgES5hQpRLcAQPgAfgEDSYaCf0tIh+/Gph7AGv
ICJo5AD4TF6KJ/vO785M5fqm3jgKIZTAIORD+M2FcIbxlYD3EXcfCpEY9hP6
GSboKTkP5Hdghp7jaxO7hQW6GpU/gA32+tDP7RF6Zerdgk/0kh5ber3BBP0K
7znNtEZfRv3tPX/In+Mrmmq81mf22Wtwyi7ncGXK2RPLTH/5DEPTDt7PZ56i
K3nVek0ZPTPtMoSdaUfftQl36IuoXbzft89hsn2+MfokqjaDY/R9Um0XXpJ8
2eGef+T3kmK+80fSDfwWfuMF+h9lIkWJ
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1233, 1211, 1212, 1259, 1213, 1262, 1214, 1264, 1215, 1216,
            1235, 1236, 1237, 1238, 1217, 1267, 1239, 1296, 1295, 1294, 1266, 
           1265, 1339, 1263, 1337, 1261, 1334, 1260, 1258, 1293, 1292, 1257, 
           1256, 1234, 1233}], 
          
          LineBox[{1707, 1688, 1729, 1728, 1726, 1706, 1749, 1727, 1750, 1748,
            1790, 1822, 1791, 1823, 1824, 1825, 1826, 1793, 1808, 1770, 1792, 
           1752, 1771, 1731, 1751, 1709, 1730, 1689, 1708, 1707}]}, "15"], 
        Annotation[#, 15, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxTsuAwAYAOC/tOqR1AHKQBkbz6YNTmAUCYmUBDMJdosiaWcGdvQEXh3V
Y2q4Q9UdNOk3fPkmdg/XDhIRsc5tMuKGOk8880iLNr+kUxGD5BlihmFmGWGO
ebZYoMwi2+xQoMgZJSoscc4F71zySZ0vPkgNRDTd7zcn3UeCaaYIckyywjKr
bLDJHvscc8IRp1SpccU1d9zzwgOvNPjmhw5//NMlk44YZYxxsuTpAaI7J3E=

           "]], 
          
          LineBox[{1183, 1195, 1181, 1218, 1196, 1240, 1219, 1268, 1241, 1297,
            1269, 1340, 1298, 1376, 1377, 1378, 1341, 1417, 1379, 1451, 1418, 
           1483, 1452, 1506, 1484, 1542, 1507, 1574, 1543, 1597, 1575, 1611, 
           1598, 1625, 1612, 1637, 1626, 1653, 1638, 1664, 1654, 1677, 1665, 
           1690, 1678, 1710, 1691, 1732, 1711, 1753, 1733, 1773, 1754, 1794, 
           1772, 1809, 1795, 1827, 1810, 1838, 1828}]}, "14"], 
        Annotation[#, 14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzTkyAwAYgNEfSRThADFjSZGxZdQ4AS2TWCZVDmA5gNgqamnSIzkAhpLU
wgWIGeEMdi/Fm6/8suXNpY2eiChRS0TUaXDJFRe0uKdDbzKijxwJxkkyQYpJ
plhmmgJ5isywwioV1thlnT1K7HPAOYfUaXDLHU3avPDMH0/88kM2FfGtY/qp
ozrCPMPMMcsiCxQpUGaLbXaocMQxJ1Q55YxrbmjxwCuPdHjjg/funy8G+iMG
STNEhjz/pDAxkA==
           "]], 
          
          LineBox[{1184, 1197, 1182, 1220, 1198, 1242, 1221, 1270, 1243, 1299,
            1271, 1342, 1300, 1380, 1343, 1419, 1381, 1453, 1420, 1485, 1454, 
           1508, 1486, 1544, 1509, 1576, 1578, 1577, 1599, 1487, 1613, 1627, 
           1545, 1639, 1655, 1600, 1666, 1679, 1628, 1693, 1712, 1713, 1692, 
           1734, 1714, 1755, 1735, 1774, 1756, 1796, 1775, 1811, 1797, 1829, 
           1812, 1839, 1830}]}, "13"], Annotation[#, 13, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzr0uA2AYhuGvCRVOoPWTUBoDM86AAUX1AJAY2470x8zMZNWqHQmbmqt2
yqB1CpRIcHW4ck9v3iexk0/nIiGEXU77QqhxwSXXNLmiwQNtOrzzyx/j/Y6Z
IEKCSZZZYYpVkqSYZo119thgnzQFMhQpcUaZCgdUOeeOGnXueeGVFj88880T
X3QZi4bwqaP6oSM6zAJx5ogxzyJLbJJhi22y5MhToswhRxxzQoUqN9zS5JE3
2r3fdHpb6DI4YKMOaYw4M8zyDyGCOOI=
           "]]}, "12"], Annotation[#, 12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxrkuA3AAwOG/BLUqOiiSbmyuN9BSJvoCEosEUXfCzm5y0woPIEHi3JXV
MVFvQNvJkfQbvvx+iYlsZrYmhDDJdm0IW5xwyhkPFCjyyQ+//NFaF8K/xrWN
JO2k6GCQIbKkmWOYeUZYYJEdlthlj2X2WeGAQ6444pocN+S5455b3nilwgtl
ninxTaw+hBa+fJM200+UPhrpoZcU3QyQZJQxMowzxTQzrLLGOhtskiPPMRec
U+CSR55454MSRcpUiERCaCBGJ11UAQQqOmo=
           "]]}, "11"], Annotation[#, 11, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxT0zwgEcAOCfO/4WYfE2Nlm8fAXVrqtdg0lestr5AK4UE3d8AXeVfAMZ
yRq7SmxsnuG5J717XKxMRESBxmREnVvuuOeJLn0+eOeXP5anIhZZYoUMW5TJ
sk+OAw6pckSNChfUadKgxSVtrnigwyuPvDGmxxcvDBkxn0QMPOdPpzzLJjOs
s8EaGbLk2aHENmVO2OOMc065ock1z/Tp8kMyHfHtBa/yD/I+LjU=
           "]]}, "10"], Annotation[#, 10, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1172, 1185, 1171, 1199, 1222, 1244}], 
          
          LineBox[{1382, 1301, 1383, 1421, 1384, 1422, 1423, 1455, 1424, 1456,
            1425, 1457, 1458, 1488, 1512, 1513, 1511, 1547, 1546, 1510, 
           1579}]}, "9"], Annotation[#, 9, "Tooltip"]& ], {}, {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"Wind Speed Fitch\"", TraditionalForm], 
     PlotRange -> {{53.85099411010742, 54.37454605102539}, {
      3.7245514195993406`, 646.199220740953}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.23895798538982202`, 
              0.3805322141054567, 0.6251828752063413}, {0.4474845255674782, 
              0.46096900259559936`, 0.5560154865673611}, {0.6644934581706143, 
              0.5372341226797686, 0.42844474024475077`}, {0.8815023907737504, 
              0.6134992427639379, 0.30087399392214037`}, {0.9317110740218668, 
              0.6992776850546669, 0.38830432946778703`}, {0.9663770376964892, 
              0.7859425942412229, 0.4957688168591164}, {1., 
              0.8733376043875569, 0.6062580082266693}, {1., 0.95, 0.75}}}, {{
                Rational[-225, 2], 
                Rational[-15, 2]}, {
                Rational[225, 2], 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[-225, 2], 
                  Rational[-15, 2]}, {
                  Rational[-225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[-15, 2]}}, {{-112.5, -7.5}, {-112.5, 7.5}, {112.5, 
                7.5}, {112.5, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-87.5, 
                    Rational[-15, 2]}, {-87.5, 
                    Rational[15, 2]}}, {{-87.5, -7.5}, {-87.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-62.5, 
                    Rational[-15, 2]}, {-62.5, 
                    Rational[15, 2]}}, {{-62.5, -7.5}, {-62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-37.50000000000006, 
                    Rational[-15, 2]}, {-37.50000000000006, 
                    Rational[
                    15, 2]}}, {{-37.50000000000006, -7.5}, \
{-37.50000000000006, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-12.5, 
                    Rational[-15, 2]}, {-12.5, 
                    Rational[15, 2]}}, {{-12.5, -7.5}, {-12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{12.5, 
                    Rational[-15, 2]}, {12.5, 
                    Rational[15, 2]}}, {{12.5, -7.5}, {12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{37.49999999999994, 
                    Rational[-15, 2]}, {37.49999999999994, 
                    Rational[15, 2]}}, {{37.49999999999994, -7.5}, {
                  37.49999999999994, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{62.5, 
                    Rational[-15, 2]}, {62.5, 
                    Rational[15, 2]}}, {{62.5, -7.5}, {62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{87.49999999999994, 
                    Rational[-15, 2]}, {87.49999999999994, 
                    Rational[15, 2]}}, {{87.49999999999994, -7.5}, {
                  87.49999999999994, 7.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{-112.50000000000001`, -7.5}, {
                112.49999999999999`, -7.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-62.49999999999997, -7.5}, 
                    
                    Offset[{
                    0, -4.}, {-62.49999999999997, -7.5}]}, \
{{-12.50000000000002, -7.5}, 
                    Offset[{0, -4.}, {-12.50000000000002, -7.5}]}, {{
                    37.49999999999999, -7.5}, 
                    Offset[{0, -4.}, {37.49999999999999, -7.5}]}, {{
                    87.49999999999994, -7.5}, 
                    Offset[{0, -4.}, {87.49999999999994, -7.5}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["9", TraditionalForm], 
                    Offset[{0., -7.}, {-62.49999999999997, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["11", TraditionalForm], 
                    Offset[{0., -7.}, {-12.50000000000002, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["13", TraditionalForm], 
                    Offset[{0., -7.}, {37.49999999999999, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["15", TraditionalForm], 
                    Offset[{0., -7.}, {87.49999999999994, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {225, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"7.979396577785343`", ",", "15.19108128231342`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"8.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"9.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"10.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"11.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"12.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"13.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"14.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"15.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.7904255208710814`*^9, {3.790425553626294*^9, 3.7904255817612944`*^9}, 
   3.7904256262493687`*^9, 3.7904903383158927`*^9, 3.812877394761292*^9, 
   3.813579824204688*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"WSflights", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"\"\<C:\\\\My_Matlab_Programs\\\\OffshoreWake\\\\WS\>\"", "<>", 
       RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<_2km.dat\>\""}], "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "THESE", " ", "ARE", " ", "FLIGHT", " ", "DATA", " ", "FROM", " ", "THE", 
     " ", "WEBSITE"}], ",", " ", 
    RowBox[{"ONE", " ", "HAS", " ", "TO", " ", "DOWNLOAD", " ", "ONESELF"}]}],
    "*)"}]}]], "Input",
 CellChangeTimes->{{3.806983975467538*^9, 3.806983983525291*^9}, {
  3.8069840277157416`*^9, 3.8069840358008647`*^9}, {3.806984093905423*^9, 
  3.8069841084204445`*^9}, {3.816923499615644*^9, 3.8169235366703944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TKEflights", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"\"\<C:\\\\My_Matlab_Programs\\\\OffshoreWake\\\\TKE\>\"", "<>", 
       RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<_2km.dat\>\""}], "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "THESE", " ", "ARE", " ", "FLIGHT", " ", "DATA", " ", "FROM", " ", "THE", 
    " ", "WEBSITE"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.806983975467538*^9, 3.806983983525291*^9}, {
   3.8069840277157416`*^9, 3.8069840358008647`*^9}, {3.806984093905423*^9, 
   3.8069841084204445`*^9}, {3.806984941714613*^9, 3.806984947526766*^9}, 
   3.8169235250454173`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gflightWS", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"WSflights", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12", ",", "17"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8069841576697435`*^9, 3.806984225098834*^9}, 
   3.81357991929751*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gflightTKE", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"TKEflights", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2.2"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8069841576697435`*^9, 3.806984225098834*^9}, {
   3.8069849540587034`*^9, 3.806984966933761*^9}, 3.813579922699786*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"II", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"XX", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1415A", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YY", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1415B", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZZ", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1415C", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"g15", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"gflightWS", ",", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"XX", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Red", "}"}]}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 15:30 250 m adv=0\>\"", "}"}]}]}], "]"}], 
      ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"YY", ",", 
        RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 15:30 250 m adv=0.25\>\"", "}"}]}]}], "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"ZZ", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Black", "}"}]}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 15:30 250 m adv=1\>\"", "}"}]}]}], "]"}], 
      ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"9", ",", "18"}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Latitude\>\"", ",", "\"\<Wind speed 250 m\>\""}], 
        "}"}]}], ",", 
      RowBox[{"Axes", "\[Rule]", "False"}], ",", 
      RowBox[{"TextStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7891902184348288`*^9, 3.789190218853706*^9}, {
   3.789190354521365*^9, 3.7891903555585866`*^9}, {3.7891919135379505`*^9, 
   3.7891919286026235`*^9}, {3.789192102694022*^9, 3.789192102830656*^9}, {
   3.7891931103156977`*^9, 3.789193110438419*^9}, {3.7891931868530626`*^9, 
   3.7891931869517765`*^9}, {3.7891933535997567`*^9, 3.789193353986679*^9}, {
   3.789193752402523*^9, 3.789193752898196*^9}, {3.7893013566199837`*^9, 
   3.789301361039996*^9}, {3.7898155601554375`*^9, 3.78981556053452*^9}, {
   3.7898156534066005`*^9, 3.789815677624525*^9}, {3.7898160703340583`*^9, 
   3.7898160723383236`*^9}, {3.7898161565481367`*^9, 3.78981627451482*^9}, {
   3.789816304556006*^9, 3.7898163599157047`*^9}, {3.789816407893401*^9, 
   3.789816413787544*^9}, {3.789816464155415*^9, 3.7898165677030387`*^9}, {
   3.789834317865444*^9, 3.7898343192677846`*^9}, {3.78983435967904*^9, 
   3.789834369569143*^9}, {3.7898344233154125`*^9, 3.7898344252364054`*^9}, {
   3.7898344672856903`*^9, 3.7898344718288546`*^9}, {3.789875380982077*^9, 
   3.7898753819149866`*^9}, 3.7898755579673843`*^9, 3.7898757328596005`*^9, {
   3.789876062848647*^9, 3.789876103145445*^9}, {3.7898765882500696`*^9, 
   3.7898765891527185`*^9}, {3.7898847498074293`*^9, 3.789884764380109*^9}, {
   3.789884840838374*^9, 3.7898849132398434`*^9}, {3.789885105442763*^9, 
   3.789885179692976*^9}, {3.7898852429994097`*^9, 3.7898852434154987`*^9}, {
   3.7898853304730453`*^9, 3.7898853360541706`*^9}, {3.7898857602591467`*^9, 
   3.789885784007618*^9}, {3.7898858236510096`*^9, 3.789885872566098*^9}, {
   3.7898859152866297`*^9, 3.789886134909547*^9}, {3.789904951211275*^9, 
   3.78990496558702*^9}, {3.789905001319987*^9, 3.7899050085602703`*^9}, {
   3.7899050507272415`*^9, 3.7899051764161263`*^9}, {3.7899067790405135`*^9, 
   3.789906852602389*^9}, {3.7906731027037725`*^9, 3.790673113726987*^9}, {
   3.790673144535911*^9, 3.7906731779737296`*^9}, {3.806983801424115*^9, 
   3.8069838321876264`*^9}, {3.806983885899906*^9, 3.806983944503209*^9}, {
   3.8069841380138845`*^9, 3.8069841540983315`*^9}, {3.8069842380225277`*^9, 
   3.8069842559971757`*^9}, {3.8069842870086117`*^9, 
   3.8069843264060717`*^9}, {3.8135851423253326`*^9, 
   3.8135852351000276`*^9}, {3.8135860206795487`*^9, 
   3.8135860221416373`*^9}, {3.8135872648484683`*^9, 
   3.8135872908120685`*^9}, {3.8135874378566427`*^9, 3.81358744166881*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.8069842275681763`*^9, 3.806984256629509*^9}, 
   3.8069843276038866`*^9, 3.812877583001238*^9, 3.8135851682931423`*^9, {
   3.813585206197322*^9, 3.813585235975154*^9}, 3.8135860228918934`*^9, {
   3.8135872661225157`*^9, 3.8135872915696983`*^9}, 3.813587442421238*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVz31MU2cYBfBCASkWhEL5kC9x4lzvvW1JJjJx4VQDHfedUpTJWqhYhWTV
iQtGXQiig4m4dRiwTorUoGBZ3IwERGBDEkNodZFttihE1zAmOpkbssGGorZ7
98eTJ7+c889J2rF3c4mvQCBIpff/j7INGCrneJhWjNTY5xQwPHVFa/7hoU9v
++OdXAWyr2R5Ev+ledhyp3RUjsKO3lvT1IX6npNVjXLcOzGZ0T/PI04pkfrY
5FjRnqCvfUb7jWUe8W05TCkH5jc/51G+asuC9jc5CjY92hm3wOP+ofDvDCoF
Kq3zgQ+p+xNEB774SIGBeJ/aSy94PHY+eStkSAFNkcm2/yUPrWhaVjKrgL3k
m0frXvEYaaiMTkpTQtRaVSD08JiK0KXodEqcdul7blIbNePGlX5KNIUMBtd7
eWxrMY5uXODQVV6TohUQ3B+cickPYdEpLbMl+RD0HRsry5Uw6BSkfz9FnfP7
J0tcCgZtR5/1dvoSjF74kMuZlmF8y9vqCiFBCmu+nHtahu0O1VK1H0F6eMQc
7DLMPTBaJf4EvPWVVJrNQGR44XVTL6vpm5VzLBwq2dhXAQS3Zp6XHpGwMJnr
/MsWEVT1OrWDySwSzngOrw0k8G/+8Y0dFxm41sQ2CkUElV1Xw653U4eeOjtM
7RZrdgsaGHhUjhZLEEGzTejnvsvg6lCJ6oPFBONn9tndtXTPjeU5aWKC1VPq
Ly9ZGMgD0iYCgwmkjqMX2vsZHKze2zBGXdB2NlFzjoVwQVfXHkJg9o2XWMQc
itdne/cvIXi3XB073Mchs6hlQhVKkFdaPd9awaFC+Zk9KIzgTq72sulTDuTp
moM/UR8WOYuZUg6tUU6tWULw67r1+uZiDq+JyV/vhxN4z6+d0BzhsOja368v
iyBAcP29lYc4hPKf73xC7TZu+MXbRPuRmYZvpQTHr2d2dNDcsjVPZ4okUDIB
bU35HGaslsjtUQTMRlZ9IpbDrrTHe1ZHE4TdiXHagjgUvJmoWhxD9zm6qlJ9
OEQRu2uC+mcXs+GkgEP3w/fae5YS+CbeTJ78k0VwqsdoiiUY+TjvXPIki/GW
+oyiOILhY6equ2dZeLP2FSniCfJ3mezmARbWK1nMS+o96du+rqlj8cP5zMKh
BIKkjOObLuax+A+aGWSW
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0n9Q03UYB/CxAQKTJsJgG+iowcH23ZfdTuToCO5tUuj3Awz8QQ44BEGI
FHCSQFrRFeIlVMoPhUNKAuJSEmZ0cpHJYecdcNeiZptA/FAhQZOOwcBk1Kc/
nnvudc/zx/M897x4qGjPYT6Px3uZxv95peiY3LyV4Kk8u/i+E4OSJnODD7Vm
vtBhlDI4GVIh2L+FwG57qzA5kMEP3+1trQsg+HPlsGgHrWflLheb/Qn27P0q
N9GDwejGgl4f6jlrc6HQk0FPUjIvRUZQp706nerC4MjgwKWLUoKqpLpSJ1r/
UBhltUoIIoakayc2MOiId3wtpTaEDzpf3c6gQn66LNWPoKS/KnZrHoMAkdmt
yZcgjL2jC7vFYOFzi2FMTOA6ejk/wVON4vQj3f7U7affC4pNVuOge8rOdB+C
PmH9w4tZakgyyyXN3gQV0g6RU4QaEewzycRmgvH+a/UxCwy8hnYROfXcumko
9DqDYlZzJdOLwFKe1iDqZjD2vbG/ZRPBQsk99/URBt76+XP3RXSexYrEAVc1
KoST+xXU7n83q84uM+AGNfbsFwjKDRHxNQMMqn/rDm3zJEhuKamtpPeaEhS4
PtxI0Brsr2vMV2Glr3lJQZ1XI06Ty1WIe9TRmiOk/Z0nfn5gVmI81ahr9yBo
Ycwx3ypUMM6UBsy6E+wYztFfCVLBdq1uJpj6tQurPhatCi6tBm2uG8Gbifpf
FrepkBrP3GnfQPCuINLR1K2E3f74mxlXgvrAggNRKiUk10cOBlGvys9pye1Q
BDviTIdcCErb3lmcfBCKs1tyHl12JjijsJkYNyWmtn/UOyGg/+FrskcfVyIy
/VhlAHWhm/FVpy+VYG+yaal8gulssfjShBKqv24aGpwI5v2yrPE3lOjNOBBi
4RG8pJ86+Qnd/2lgUpMvdfS0349vzzAQPfl0d8q/HDJeF5gSz7MI31cZe2Gd
g6UrOu/oQBgSu2yzdx0cthl0sYNvaNCZT2rF1NX5H4828jXYOSa9sW+Nw+O4
eqtnYRjuZYzoa59zyE0v08iWWJR19NSM/MPhVtJaUeMcC5fxyeMiaq+UaKnC
zuIV5773E55x6BXzq2TPWdQkxHlXr3I4xTk2ffCEhdzIixxe4TCo+4yvnGWR
qe2UeVAXtJpc2T9Y/N7Qk7fLzqErK6p+9S715l+PVi7T+WLahSEmFqdsw1/8
tMRBHt4mM9xm8R/IC3c2
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0n9Q03UcBvDpmBJKTJgzBOHU+LV9P3xmuuK6uD2TEP1+CM1lwKaRDijk
t5kE1Zni4IpEAbF2MDG5mHXCRkhCxaUJjgvCEzW8QDp/QHSYisBA0q1vf7zv
udc9fzz/vFfuyt2aNl8kEqmF+z/3W86YsqZ4vOUY7XgqpZiy9GrU0zzq6RtV
faspttltW12CAy/sjDqlpXA3hX/hcPJIztOF/bydwtrpvalihsclacvQP2YK
D5fvJ4ZZHv2FNxta2ylMPZcDwh7zkF+vHS/ppliK/OppwdaQP+2vlVHYK978
+9Icj8fG4NDWDyl+Gfv2nvlfHlH3Z35vraRwrZauyn7Cw5lR7ruphELT0czh
KY8DBwuGD3upUP99wOQSFw9t12RVTaQKi0tvXb4t+JukjQPOcBVMcseOFjcP
5ckXVfuqImEUW0aLRQzeV/ndeTsJckwX83TzGJJSzYkfSzgknVbT4PkMdwy9
W2aNSqQfOjL9l+A9fj3bh75UIILEi2xihqnsQUvEZATS4r5qK/BguNjY193h
r8Bdo25wvYRBXLutR1YXgdiGSr10AUPdLeOiTKHXuzUzw4KvfvdysyZBgfcf
Rh9oXMhA9dotD3IUCBq//0KRJ4PsWtiNlRoFZruC1sU+w/B86vG9iZ8rsDwm
NMPHi+H8tfGiD9wKrPXqEA8K1h5XRf9gU8KUstF8ehHDunn1tSqzEklHnyQW
LGZ4+1X3RPmcEtlFg3UbvBlemgjsDr2nxJUuh5/8WQbH9Zy1ny3k8GlGtXZE
8Iq7H50J3svhhM6Q3+rDMFf4ypGbdzhcyXgUUipl4DutA02UINd/bLd+ibAX
c2HuRhxBY0tnLvFlKB3mGtSbCfrCh064BKc+Ki0T7yEobrPG/+bHMLos+V1X
JcHYekO7WcbgXzct5toIPCNV4tSlDCNfGzS0n2DgncxjRM7gzgqcSe4hSHNb
bjsFj6UQZ81PBPE+xybOL2Pw3HfSY9d7BOXpB/WHn2OILQibSg8gOEfVUTv8
GYobqlNkZzkY+uMWqJYzmKWvP8jczyH/XJZIEsCwgZfYpIUcQqz29j8E94oT
9BXCq8X8OmKzBzKUnVoTtXmUQ8KPNkfJCmEveqDmrJRA8lBXaAhiSG+WN62R
EfwH8uBp2A==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0GtMk3cUBvCClAE6tAVFLBJbSKDv2xZkA2UiPqlsi+8/zpYxKJeWyyAp
WwzJNjEjFcIlzUBxEbWw6qCSjTqySAU7QigVkA42w0IBCUK4SWC6iZvpGEU2
uncfTp78knOeD0dYUJJa5M3hcBLZ+T9tHc+/mggnUIr92tYIjTubj03BrAe/
MDia36DRE/Xr2AcHCfirTYdFITQS5IoTjWEEzoY/B0qCaFRd2Bh8LCDQH8gg
eygajSGG7IOsF2xpiuN5NG6JOOV5BwjSxlIWt0poJI384dcaStBuyTwWU0vj
0+yB1if7CXqGA+ynKmg0N+ieilhnmQtdJ2/RCLbk/lYQQjA7qE4IstC4u+KM
aN1HUKMyl5Y5aSSeb1cv7SXYqBtI8ZmjcfFkivkQa25x7nWtm8bo/A5uXjCB
3VDn7QyUYLpt15umIIK+Gc8DFy1Bh6trcpHP3mfJKlUpEmiKve1C1kl63v6H
ORKIPt9dn88jKLctiNrTJTDa3JdNewgq+m29M6ESrFfXZS7sZve56RHzXTQm
grLqw1lzJ7asXrk0RE/OfagJJMirWjRMzVDoOVv7bsvrBKlxvLJ99yn0X9Ok
L+0iWEmmmuSVFK69/d1kJOv+7YKLy80Ujo1EeH+0k6A3cohTdJ5CAlcu7wgg
2PltmKM2jUK5yb/C5U/QvfrOXs+YGAM/Ld6IZx3PH53VVYgxLfxFU+pHYC3p
M6nXozHW3OL7w2vsP2s6lbGd0Yh45vhx3ZdA1XIuvcoSDWP+9+541tqcaaX+
djSSReLYUi5BdX/W8DOhGAvWzZF7PgQvp2KvKvuiEX6cuvRyB0HXHd2wzwUx
llYLH0hZW+u+eVitEqM5rWyu2Jvg/sfdhWcOUzA/Dyho8yJYjbOP3H5E4cj2
zeFlDoGAnusWbNE4kaoaELI+Xd6ozFRIobQWc/I8DGTc0MibWhlyqo1DX28z
aDI6aiujYpD2ivPl7L8M4sJsR34+GgPHpTNFoaxNEKj14zLItW9lZPzDYGMo
W6dTyWDnkavXtxgIfk9ZMbmlyPV/ypl8xeD9/BzNIbsU815HO/msA6furRna
pNhWPPJK3WSg/aTdp+8zKeo9Ne4rbgZ3X1w+nVggBV+VmDy+wUCRseyIN0ph
tzuK+awtnWp5ENt/do3uTf2bgb+rTO9JlsHXzDM1rDNYso/XaN6TgbcpSHL+
xWA06UVpVIQM/wEQboXA
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzXtMU2cABfBSpxZ5DbClRUqshkdvufdrxkYUEA4bIL2fgBIf1LKozWAm
WzJloAJNVaZjgIxNBBunIigqKgacCz6AOdSB01ZQmctWZsycggYDVAoWAa9/
nJz8cv44KuNXGdlikUj0oZB3Hbmo64HpFY+m08bfi64T2OW2qPQxHs1JkmND
Lwjy+1KTVU4e157H6yX3CEbJDxWjgrVdTdVXHQRlxkXKznEeqdmDDSPCLg1p
zKyc4GFQ0pJHdwksP+ctNLzmcexgoe5AB8EvnZa0UBcPtZQzlf1DcC4oZO+I
YKu3UlXlroXvULtH+yQPt6o/X25QaVHqrG8pfcNDo/AJuLpWi1aLISFzSviX
O28n7dAiRXtlKnyaR8ff4u8dxVoU3e+PfSO47Ybftr9WapEXlxHbO8ND2WM3
GFIJcmMy7p8SUayL2h37o5HF8/Kcw2Y3irCK6AnWpMEFq37ZajFFTDDxaP6C
gWf5Gc/wWRQ7nSmFrkoGW6uU+12CAxzZrV8mMrixR7f+znsUH3/rOGBKZxAS
XhJ2dDbFcZ8i/1yTGtcO+u3eMocid1kO7soYxHjrxxLnUuzvr2/a+BED25qC
tQskFHVNpZWfWBksH/4gziF4V2KWYu9NBrqCRultd4qaoU3nlf8ziFR31NXN
o7A6v065zGnwX8OnPts9KH7zetSTX6uBudt8inpSzOu6NeB0aXBihXrVQi+K
6V0D0s0XIyA7oT/9SnDAnovt4lAWT0THN3V7U1iSNZahEhZ5xsfxh30oKlqt
OzfXsojSHNJtfZ8icey7b252skia8F2X7EsxadeVjfeziGy3iwL9KGQ1rvFq
NQfFxiNnXwieCbNl/vo5B/clT73a/CkutYlbtpzl0D3M1uybT1G8OK1kWx+H
ZpX6SZaUwpYX4atwJ/gpvi6NlVFU2xuSsgIJbAOD16cFd8srJ3NYgktz/rD0
BlCIEqIZWQhBsUdkX4Oc4tCMPrhvKYHarcVWqKDwf3onfXkEwarsW7krAynY
DYsln0kIyu/F9YYuoBiNkQ8+7OFQIGk8PyWYqbXOCjrJIT+rOfNBEIU8wa8w
vJZDvTk0+oySIn7i4XBZK4cLFf8WmIMp0kaeTRoec3gL6nRd8g==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzntQlGUUBnBAkJtcVtsFFEjGYpZv3/3WQe5I8yBozvcaJAhDKkoQxEUE
TLHGMuSiGHFRXDXwwjA7sUAiOorFxUKxodXU8QbJBLNbqyiXBVJYCNbe/jhz
5vfHc57jlZwTk2phZmYWwub//TQsOP+xJ4WLb+Zg0ho5tr5f2ShhPnFh/7q2
EYJvK6QRCR4UmqB9E7XtBAvr99TWuFN8cLtHX/A9waEAn6Q/V1CEm45Z2zQQ
9O4Ye3slc/TG7lTHJgJRwPb45OUU68GfD7tFYFHWKVO5USg81t7lJwjcE4wp
z1wpru9wsQqylyNOddLDh7nnXM65bTbsnxG/LbtcKMpvdC/3fUpwYeDxzosS
ikqPjheiswTiCKN2Usz6ntM2/QGCSONrSz9m10mucOwYgddDSvPfokgOrQs6
fJcgC8rwn5ZRoErbFjxI0KrI5OaXUrSUuQ5Wmwjup++78x7zO5vOWF9+RlBl
Gi0+JKK4JrLymNUSJE7k6m46U+wp+utwD+vvH+9eWMwc0ZNY8qiaYNo1O1hw
othwsa6xXkGQ8qpAX+5IcSTHqzxkVAa7J+6rHjhQ9Pl7G1WnZJD7bJ2SMMeI
+pf9mCND8YbBme1LKDY5SXXN6TLUVHwxXm9PYZMeuOS8owwDo/ezh+0oPtNO
RY63ctCUVIfJmb39Vd0GOQex8k1lni2FuiFzba0fh5YkZeUVG4p4y91VdQUc
uFO7UmesKULDpsrJVQ5oHHIOYe6NfpgVF81BFmv75MvFFEUffXfv6wofiOV1
1j9bUUQ9n5wMaJYiqrP1gBlzVeiI4dGoFFYmUek6Swr7oZcvk3N90CQ9OFe8
iMI8+Opmv1IOOsuPpb0WFNkjt8oeCDIcb/8wwZ55kUNfRkChDPemLhmizCmm
Pc9Mxk/LcCnLtLrajCKI5pc66wl69pq6+t4I2PtrRX2LhAdEHRkrmPvVTs1u
L3h0Xl+YTzQJcFuVVpqwWoGz7uab6xYEXInRKFVyBT75I82om2f5mnl1E6dA
Wpcp413mFMNXjRpbBbxjt9h9+q+A2Bve2f7XePg2hYSr5wT80n7z89ASHpfj
jnYOzwqwOEgMzdU89M5jGinz6Zpt/wTe5qHz1O5MNwqYyfzmpCO7V3h6Yrd6
RkDS0d98/57nsV+MH4anBTTk8VyMlQIByu47UuaulUsdBswVCFwTH5v+WkDk
7/q5vA4es+MWEvUrAb65yqKhEzz+AyNnjCo=
           "]]}}}, {}}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5HBZ5JG05UccByG3Q/ublMLMhPvkVvy6I
/6Dqh5dD2NYdNp2eYH7DqV9eDpvzL8yuDgHzFaT+ejmc8FnY47EZrP9A5n8v
h+ifH08/n6IFlt/J6O2wSkpF8/kqDbA8B4u3w7OrxhUpemB+QgSbt8PtWl+v
x//VwepXcHg7zGmVVdCUAcs3fOfydiiwSAh+WgXmM7jzeju8Dbh54TUP2PwD
0/i9HeS0nl3YHKANNu+ZoLfDxj9H/Q/eBfMfmIp4OwQEz5ItVAC7L6FVzNvh
vYtK2RM3MF/hqoS3w6/883t3e0PcryLt7aDrUsIYZAZRXyLr7WC7Xvz7dXUw
/8FheW8HMUvfQ3ZAPgBaFGpu
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5HAu56PnZStcByG3Q/ubl0GMXdKawDMx/
UPXDy+HzriWuWyog8qd+eTk8eZjkkZQH5itI/fVy6Ba3Oj2VGcw/kPnfyyGY
d/PmI0u0wfI7Gb0dHsgxzfMX1gLLc7B4Oyyxz+3mMdAE8RMi2LwdNjnrTn1z
TQOsfgWHt8NPlppY3vtgfsN3Lm+Hnoy76YlxYPUM7rzeDjtcTgU7+kPMm8bv
7SAna2h6Wh9sX8IzQW+Hcq+0s1rLwPwHpiLeDi+YLolx3ITIt4p5O2S+2bfN
6BfEfVclvB1kIi5FKX4F8w+oSHs7vAy16t0JVV8i6+1wT/Xnj3kXIOYdlvd2
OGZ48theIB8APwVrWA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5PMjeyT/LVdcByG3Q/ubl0HOFJWdGDZj/
oOqHl0PROvsj0Q0Q+VO/vBw+/jq7wqEazFeQ+uvlkFAkKe23RgfEP5D538tB
Z470/vw2LbD8TkZvh3DxOdLvszTA8hws3g5eGvNYhSvVQfyECDZvh8smMzQs
NcF8hRUc3g4lu9x1VwaB+Q3fubwdill/hC79A+YzuPN6O3B17NcOLdUEmzeN
39vB5rCImNldsH0JzwS9HeSdhWa1T9AGu99UxNuhOe7fe/erYH5Cq5i3g2Bd
6/NuBrB7Fa5KeDsICW+8s5EN4n4VaW+HZyfCagL/QtSXyHo73Li6RYLrD8S8
w/LeDj8VJL8s+6ntAAAV2GdY
          "]]}}}, {}}}, {PlotRange -> {9, 18}, Frame -> True, FrameLabel -> {
       FormBox["\"Latitude\"", TraditionalForm], 
       FormBox["\"Wind speed 250 m\"", TraditionalForm]}, Axes -> False, 
     TextStyle -> {FontSize -> 14}, PlotRange -> {12, 17}, DisplayFunction -> 
     Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, DisplayFunction -> Identity,
      AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0.25\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=1\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8069842283733654`*^9, 3.806984256671372*^9}, 
   3.8069843276836967`*^9, 3.812877583100977*^9, 3.81358516836594*^9, {
   3.8135852063170166`*^9, 3.8135852360909033`*^9}, 3.8135860230046816`*^9, {
   3.813587266197818*^9, 3.813587291687598*^9}, 3.81358744253498*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"II", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"XX", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1414A", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1414A", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YY", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1414B", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZZ", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"fitchrow1414C", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"g14", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"gflightWS", ",", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"XX", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Red", "}"}]}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 14:30 250 m adv=0\>\"", "}"}]}]}], "]"}], 
      ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"YY", ",", 
        RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 14:30 250 m adv=0.25\>\"", "}"}]}]}], "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"ZZ", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Black", "}"}]}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Fitch 14:30 250 m adv=1\>\"", "}"}]}]}], "]"}], 
      ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"9", ",", "18"}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Latitude\>\"", ",", "\"\<Wind speed 250 m\>\""}], 
        "}"}]}], ",", 
      RowBox[{"Axes", "\[Rule]", "False"}], ",", 
      RowBox[{"TextStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7891902184348288`*^9, 3.789190218853706*^9}, {
   3.789190354521365*^9, 3.7891903555585866`*^9}, {3.7891919135379505`*^9, 
   3.7891919286026235`*^9}, {3.789192102694022*^9, 3.789192102830656*^9}, {
   3.7891931103156977`*^9, 3.789193110438419*^9}, {3.7891931868530626`*^9, 
   3.7891931869517765`*^9}, {3.7891933535997567`*^9, 3.789193353986679*^9}, {
   3.789193752402523*^9, 3.789193752898196*^9}, {3.7893013566199837`*^9, 
   3.789301361039996*^9}, {3.7898155601554375`*^9, 3.78981556053452*^9}, {
   3.7898156534066005`*^9, 3.789815677624525*^9}, {3.7898160703340583`*^9, 
   3.7898160723383236`*^9}, {3.7898161565481367`*^9, 3.78981627451482*^9}, {
   3.789816304556006*^9, 3.7898163599157047`*^9}, {3.789816407893401*^9, 
   3.789816413787544*^9}, {3.789816464155415*^9, 3.7898165677030387`*^9}, {
   3.789834317865444*^9, 3.7898343192677846`*^9}, {3.78983435967904*^9, 
   3.789834369569143*^9}, {3.7898344233154125`*^9, 3.7898344252364054`*^9}, {
   3.7898344672856903`*^9, 3.7898344718288546`*^9}, {3.789875380982077*^9, 
   3.7898753819149866`*^9}, 3.7898755579673843`*^9, 3.7898757328596005`*^9, {
   3.789876062848647*^9, 3.789876103145445*^9}, {3.7898765882500696`*^9, 
   3.7898765891527185`*^9}, {3.7898847498074293`*^9, 3.789884764380109*^9}, {
   3.789884840838374*^9, 3.7898849132398434`*^9}, {3.789885105442763*^9, 
   3.789885179692976*^9}, {3.7898852429994097`*^9, 3.7898852434154987`*^9}, {
   3.7898853304730453`*^9, 3.7898853360541706`*^9}, {3.7898857602591467`*^9, 
   3.789885784007618*^9}, {3.7898858236510096`*^9, 3.789885872566098*^9}, {
   3.7898859152866297`*^9, 3.789886134909547*^9}, {3.789904951211275*^9, 
   3.78990496558702*^9}, {3.789905001319987*^9, 3.7899050085602703`*^9}, {
   3.7899050507272415`*^9, 3.7899051764161263`*^9}, {3.7899067790405135`*^9, 
   3.789906852602389*^9}, {3.7906731027037725`*^9, 3.790673113726987*^9}, {
   3.790673144535911*^9, 3.7906731779737296`*^9}, {3.806983801424115*^9, 
   3.8069838321876264`*^9}, {3.806983885899906*^9, 3.806983944503209*^9}, {
   3.8069841380138845`*^9, 3.8069841540983315`*^9}, {3.8069842380225277`*^9, 
   3.8069842559971757`*^9}, {3.8069842870086117`*^9, 
   3.8069843264060717`*^9}, {3.8135851423253326`*^9, 
   3.8135852351000276`*^9}, {3.813585982039775*^9, 3.813586027343154*^9}, {
   3.81358755838034*^9, 3.8135875623403015`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.813586000789946*^9, 3.8135860280482965`*^9}, 
   3.8135875631468163`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVz31MU2cYBfBCASkWhEL5kC9x4lzvvW1JJjJx4VQDHfedUpTJWqhYhWTV
iQtGXQiig4m4dRiwTorUoGBZ3IwERGBDEkNodZFttihE1zAmOpkbssGGorZ7
98eTJ7+c889J2rF3c4mvQCBIpff/j7INGCrneJhWjNTY5xQwPHVFa/7hoU9v
++OdXAWyr2R5Ev+ledhyp3RUjsKO3lvT1IX6npNVjXLcOzGZ0T/PI04pkfrY
5FjRnqCvfUb7jWUe8W05TCkH5jc/51G+asuC9jc5CjY92hm3wOP+ofDvDCoF
Kq3zgQ+p+xNEB774SIGBeJ/aSy94PHY+eStkSAFNkcm2/yUPrWhaVjKrgL3k
m0frXvEYaaiMTkpTQtRaVSD08JiK0KXodEqcdul7blIbNePGlX5KNIUMBtd7
eWxrMY5uXODQVV6TohUQ3B+cickPYdEpLbMl+RD0HRsry5Uw6BSkfz9FnfP7
J0tcCgZtR5/1dvoSjF74kMuZlmF8y9vqCiFBCmu+nHtahu0O1VK1H0F6eMQc
7DLMPTBaJf4EvPWVVJrNQGR44XVTL6vpm5VzLBwq2dhXAQS3Zp6XHpGwMJnr
/MsWEVT1OrWDySwSzngOrw0k8G/+8Y0dFxm41sQ2CkUElV1Xw653U4eeOjtM
7RZrdgsaGHhUjhZLEEGzTejnvsvg6lCJ6oPFBONn9tndtXTPjeU5aWKC1VPq
Ly9ZGMgD0iYCgwmkjqMX2vsZHKze2zBGXdB2NlFzjoVwQVfXHkJg9o2XWMQc
itdne/cvIXi3XB073Mchs6hlQhVKkFdaPd9awaFC+Zk9KIzgTq72sulTDuTp
moM/UR8WOYuZUg6tUU6tWULw67r1+uZiDq+JyV/vhxN4z6+d0BzhsOja368v
iyBAcP29lYc4hPKf73xC7TZu+MXbRPuRmYZvpQTHr2d2dNDcsjVPZ4okUDIB
bU35HGaslsjtUQTMRlZ9IpbDrrTHe1ZHE4TdiXHagjgUvJmoWhxD9zm6qlJ9
OEQRu2uC+mcXs+GkgEP3w/fae5YS+CbeTJ78k0VwqsdoiiUY+TjvXPIki/GW
+oyiOILhY6equ2dZeLP2FSniCfJ3mezmARbWK1nMS+o96du+rqlj8cP5zMKh
BIKkjOObLuax+A+aGWSW
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0n9Q03UYB/CxAQKTJsJgG+iowcH23ZfdTuToCO5tUuj3Awz8QQ44BEGI
FHCSQFrRFeIlVMoPhUNKAuJSEmZ0cpHJYecdcNeiZptA/FAhQZOOwcBk1Kc/
nnvudc/zx/M897x4qGjPYT6Px3uZxv95peiY3LyV4Kk8u/i+E4OSJnODD7Vm
vtBhlDI4GVIh2L+FwG57qzA5kMEP3+1trQsg+HPlsGgHrWflLheb/Qn27P0q
N9GDwejGgl4f6jlrc6HQk0FPUjIvRUZQp706nerC4MjgwKWLUoKqpLpSJ1r/
UBhltUoIIoakayc2MOiId3wtpTaEDzpf3c6gQn66LNWPoKS/KnZrHoMAkdmt
yZcgjL2jC7vFYOFzi2FMTOA6ejk/wVON4vQj3f7U7affC4pNVuOge8rOdB+C
PmH9w4tZakgyyyXN3gQV0g6RU4QaEewzycRmgvH+a/UxCwy8hnYROfXcumko
9DqDYlZzJdOLwFKe1iDqZjD2vbG/ZRPBQsk99/URBt76+XP3RXSexYrEAVc1
KoST+xXU7n83q84uM+AGNfbsFwjKDRHxNQMMqn/rDm3zJEhuKamtpPeaEhS4
PtxI0Brsr2vMV2Glr3lJQZ1XI06Ty1WIe9TRmiOk/Z0nfn5gVmI81ahr9yBo
Ycwx3ypUMM6UBsy6E+wYztFfCVLBdq1uJpj6tQurPhatCi6tBm2uG8Gbifpf
FrepkBrP3GnfQPCuINLR1K2E3f74mxlXgvrAggNRKiUk10cOBlGvys9pye1Q
BDviTIdcCErb3lmcfBCKs1tyHl12JjijsJkYNyWmtn/UOyGg/+FrskcfVyIy
/VhlAHWhm/FVpy+VYG+yaal8gulssfjShBKqv24aGpwI5v2yrPE3lOjNOBBi
4RG8pJ86+Qnd/2lgUpMvdfS0349vzzAQPfl0d8q/HDJeF5gSz7MI31cZe2Gd
g6UrOu/oQBgSu2yzdx0cthl0sYNvaNCZT2rF1NX5H4828jXYOSa9sW+Nw+O4
eqtnYRjuZYzoa59zyE0v08iWWJR19NSM/MPhVtJaUeMcC5fxyeMiaq+UaKnC
zuIV5773E55x6BXzq2TPWdQkxHlXr3I4xTk2ffCEhdzIixxe4TCo+4yvnGWR
qe2UeVAXtJpc2T9Y/N7Qk7fLzqErK6p+9S715l+PVi7T+WLahSEmFqdsw1/8
tMRBHt4mM9xm8R/IC3c2
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0n9Q03UcBvDpmBJKTJgzBOHU+LV9P3xmuuK6uD2TEP1+CM1lwKaRDijk
t5kE1Zni4IpEAbF2MDG5mHXCRkhCxaUJjgvCEzW8QDp/QHSYisBA0q1vf7zv
udc9fzz/vFfuyt2aNl8kEqmF+z/3W86YsqZ4vOUY7XgqpZiy9GrU0zzq6RtV
faspttltW12CAy/sjDqlpXA3hX/hcPJIztOF/bydwtrpvalihsclacvQP2YK
D5fvJ4ZZHv2FNxta2ylMPZcDwh7zkF+vHS/ppliK/OppwdaQP+2vlVHYK978
+9Icj8fG4NDWDyl+Gfv2nvlfHlH3Z35vraRwrZauyn7Cw5lR7ruphELT0czh
KY8DBwuGD3upUP99wOQSFw9t12RVTaQKi0tvXb4t+JukjQPOcBVMcseOFjcP
5ckXVfuqImEUW0aLRQzeV/ndeTsJckwX83TzGJJSzYkfSzgknVbT4PkMdwy9
W2aNSqQfOjL9l+A9fj3bh75UIILEi2xihqnsQUvEZATS4r5qK/BguNjY193h
r8Bdo25wvYRBXLutR1YXgdiGSr10AUPdLeOiTKHXuzUzw4KvfvdysyZBgfcf
Rh9oXMhA9dotD3IUCBq//0KRJ4PsWtiNlRoFZruC1sU+w/B86vG9iZ8rsDwm
NMPHi+H8tfGiD9wKrPXqEA8K1h5XRf9gU8KUstF8ehHDunn1tSqzEklHnyQW
LGZ4+1X3RPmcEtlFg3UbvBlemgjsDr2nxJUuh5/8WQbH9Zy1ny3k8GlGtXZE
8Iq7H50J3svhhM6Q3+rDMFf4ypGbdzhcyXgUUipl4DutA02UINd/bLd+ibAX
c2HuRhxBY0tnLvFlKB3mGtSbCfrCh064BKc+Ki0T7yEobrPG/+bHMLos+V1X
JcHYekO7WcbgXzct5toIPCNV4tSlDCNfGzS0n2DgncxjRM7gzgqcSe4hSHNb
bjsFj6UQZ81PBPE+xybOL2Pw3HfSY9d7BOXpB/WHn2OILQibSg8gOEfVUTv8
GYobqlNkZzkY+uMWqJYzmKWvP8jczyH/XJZIEsCwgZfYpIUcQqz29j8E94oT
9BXCq8X8OmKzBzKUnVoTtXmUQ8KPNkfJCmEveqDmrJRA8lBXaAhiSG+WN62R
EfwH8uBp2A==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0GtMk3cUBvCClAE6tAVFLBJbSKDv2xZkA2UiPqlsi+8/zpYxKJeWyyAp
WwzJNjEjFcIlzUBxEbWw6qCSjTqySAU7QigVkA42w0IBCUK4SWC6iZvpGEU2
uncfTp78knOeD0dYUJJa5M3hcBLZ+T9tHc+/mggnUIr92tYIjTubj03BrAe/
MDia36DRE/Xr2AcHCfirTYdFITQS5IoTjWEEzoY/B0qCaFRd2Bh8LCDQH8gg
eygajSGG7IOsF2xpiuN5NG6JOOV5BwjSxlIWt0poJI384dcaStBuyTwWU0vj
0+yB1if7CXqGA+ynKmg0N+ieilhnmQtdJ2/RCLbk/lYQQjA7qE4IstC4u+KM
aN1HUKMyl5Y5aSSeb1cv7SXYqBtI8ZmjcfFkivkQa25x7nWtm8bo/A5uXjCB
3VDn7QyUYLpt15umIIK+Gc8DFy1Bh6trcpHP3mfJKlUpEmiKve1C1kl63v6H
ORKIPt9dn88jKLctiNrTJTDa3JdNewgq+m29M6ESrFfXZS7sZve56RHzXTQm
grLqw1lzJ7asXrk0RE/OfagJJMirWjRMzVDoOVv7bsvrBKlxvLJ99yn0X9Ok
L+0iWEmmmuSVFK69/d1kJOv+7YKLy80Ujo1EeH+0k6A3cohTdJ5CAlcu7wgg
2PltmKM2jUK5yb/C5U/QvfrOXs+YGAM/Ld6IZx3PH53VVYgxLfxFU+pHYC3p
M6nXozHW3OL7w2vsP2s6lbGd0Yh45vhx3ZdA1XIuvcoSDWP+9+541tqcaaX+
djSSReLYUi5BdX/W8DOhGAvWzZF7PgQvp2KvKvuiEX6cuvRyB0HXHd2wzwUx
llYLH0hZW+u+eVitEqM5rWyu2Jvg/sfdhWcOUzA/Dyho8yJYjbOP3H5E4cj2
zeFlDoGAnusWbNE4kaoaELI+Xd6ozFRIobQWc/I8DGTc0MibWhlyqo1DX28z
aDI6aiujYpD2ivPl7L8M4sJsR34+GgPHpTNFoaxNEKj14zLItW9lZPzDYGMo
W6dTyWDnkavXtxgIfk9ZMbmlyPV/ypl8xeD9/BzNIbsU815HO/msA6furRna
pNhWPPJK3WSg/aTdp+8zKeo9Ne4rbgZ3X1w+nVggBV+VmDy+wUCRseyIN0ph
tzuK+awtnWp5ENt/do3uTf2bgb+rTO9JlsHXzDM1rDNYso/XaN6TgbcpSHL+
xWA06UVpVIQM/wEQboXA
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzXtMU2cABfBSpxZ5DbClRUqshkdvufdrxkYUEA4bIL2fgBIf1LKozWAm
WzJloAJNVaZjgIxNBBunIigqKgacCz6AOdSB01ZQmctWZsycggYDVAoWAa9/
nJz8cv44KuNXGdlikUj0oZB3Hbmo64HpFY+m08bfi64T2OW2qPQxHs1JkmND
Lwjy+1KTVU4e157H6yX3CEbJDxWjgrVdTdVXHQRlxkXKznEeqdmDDSPCLg1p
zKyc4GFQ0pJHdwksP+ctNLzmcexgoe5AB8EvnZa0UBcPtZQzlf1DcC4oZO+I
YKu3UlXlroXvULtH+yQPt6o/X25QaVHqrG8pfcNDo/AJuLpWi1aLISFzSviX
O28n7dAiRXtlKnyaR8ff4u8dxVoU3e+PfSO47Ybftr9WapEXlxHbO8ND2WM3
GFIJcmMy7p8SUayL2h37o5HF8/Kcw2Y3irCK6AnWpMEFq37ZajFFTDDxaP6C
gWf5Gc/wWRQ7nSmFrkoGW6uU+12CAxzZrV8mMrixR7f+znsUH3/rOGBKZxAS
XhJ2dDbFcZ8i/1yTGtcO+u3eMocid1kO7soYxHjrxxLnUuzvr2/a+BED25qC
tQskFHVNpZWfWBksH/4gziF4V2KWYu9NBrqCRultd4qaoU3nlf8ziFR31NXN
o7A6v065zGnwX8OnPts9KH7zetSTX6uBudt8inpSzOu6NeB0aXBihXrVQi+K
6V0D0s0XIyA7oT/9SnDAnovt4lAWT0THN3V7U1iSNZahEhZ5xsfxh30oKlqt
OzfXsojSHNJtfZ8icey7b252skia8F2X7EsxadeVjfeziGy3iwL9KGQ1rvFq
NQfFxiNnXwieCbNl/vo5B/clT73a/CkutYlbtpzl0D3M1uybT1G8OK1kWx+H
ZpX6SZaUwpYX4atwJ/gpvi6NlVFU2xuSsgIJbAOD16cFd8srJ3NYgktz/rD0
BlCIEqIZWQhBsUdkX4Oc4tCMPrhvKYHarcVWqKDwf3onfXkEwarsW7krAynY
DYsln0kIyu/F9YYuoBiNkQ8+7OFQIGk8PyWYqbXOCjrJIT+rOfNBEIU8wa8w
vJZDvTk0+oySIn7i4XBZK4cLFf8WmIMp0kaeTRoec3gL6nRd8g==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzntQlGUUBnBAkJtcVtsFFEjGYpZv3/3WQe5I8yBozvcaJAhDKkoQxEUE
TLHGMuSiGHFRXDXwwjA7sUAiOorFxUKxodXU8QbJBLNbqyiXBVJYCNbe/jhz
5vfHc57jlZwTk2phZmYWwub//TQsOP+xJ4WLb+Zg0ho5tr5f2ShhPnFh/7q2
EYJvK6QRCR4UmqB9E7XtBAvr99TWuFN8cLtHX/A9waEAn6Q/V1CEm45Z2zQQ
9O4Ye3slc/TG7lTHJgJRwPb45OUU68GfD7tFYFHWKVO5USg81t7lJwjcE4wp
z1wpru9wsQqylyNOddLDh7nnXM65bTbsnxG/LbtcKMpvdC/3fUpwYeDxzosS
ikqPjheiswTiCKN2Usz6ntM2/QGCSONrSz9m10mucOwYgddDSvPfokgOrQs6
fJcgC8rwn5ZRoErbFjxI0KrI5OaXUrSUuQ5Wmwjup++78x7zO5vOWF9+RlBl
Gi0+JKK4JrLymNUSJE7k6m46U+wp+utwD+vvH+9eWMwc0ZNY8qiaYNo1O1hw
othwsa6xXkGQ8qpAX+5IcSTHqzxkVAa7J+6rHjhQ9Pl7G1WnZJD7bJ2SMMeI
+pf9mCND8YbBme1LKDY5SXXN6TLUVHwxXm9PYZMeuOS8owwDo/ezh+0oPtNO
RY63ctCUVIfJmb39Vd0GOQex8k1lni2FuiFzba0fh5YkZeUVG4p4y91VdQUc
uFO7UmesKULDpsrJVQ5oHHIOYe6NfpgVF81BFmv75MvFFEUffXfv6wofiOV1
1j9bUUQ9n5wMaJYiqrP1gBlzVeiI4dGoFFYmUek6Swr7oZcvk3N90CQ9OFe8
iMI8+Opmv1IOOsuPpb0WFNkjt8oeCDIcb/8wwZ55kUNfRkChDPemLhmizCmm
Pc9Mxk/LcCnLtLrajCKI5pc66wl69pq6+t4I2PtrRX2LhAdEHRkrmPvVTs1u
L3h0Xl+YTzQJcFuVVpqwWoGz7uab6xYEXInRKFVyBT75I82om2f5mnl1E6dA
Wpcp413mFMNXjRpbBbxjt9h9+q+A2Bve2f7XePg2hYSr5wT80n7z89ASHpfj
jnYOzwqwOEgMzdU89M5jGinz6Zpt/wTe5qHz1O5MNwqYyfzmpCO7V3h6Yrd6
RkDS0d98/57nsV+MH4anBTTk8VyMlQIByu47UuaulUsdBswVCFwTH5v+WkDk
7/q5vA4es+MWEvUrAb65yqKhEzz+AyNnjCo=
           "]]}}}, {}}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5fHp14n69oJ4DkNug/c3LIWld6smAR7og
/oOqH14ODlJbZnyZC+Y3nPrl5SCTabv3awOYryD1FygfYsQsulQHxD+Q+d/L
4e7dYB1GWy2w/E5GbweHVDVtLX0NsDwHi7dD1P0Tzgan1EH8hAg2bwf7babc
u7aB+QorOLwd9i259Xf1RTC/4TuXt8OqdPXs9RJg/QzuvN4OnTfW2Gzq1QSb
N43f20H4VLyv1UawfQnPBL0drlS6Loix1Qa731TE2yFC+9yWkjlgfkKrmLfD
1oPHt+y4A+YrXJUAuk/oxhfW32D+ARVpbwctGQ2xtzxg/ySUyHo7+DlOCrbS
AvMfHJYHmm/4OHFSko4DAOMaaQI=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5BJ6TcX+7TNcByG3Q/ubloDbbr7azDMx/
UPXDy4Evr2F1lhdE/tQvL4etiyctsjUC8xWk/no5vBGc6H9itQ6IfyDzv5dD
eNj/CwLO2mD5nYzeDr96lwjsX6kJludg8XY4z+ln9uiCBoifEMHm7RAsPCW3
fxKYr7CCw9uhOGTaX945YH7Ddy5vh4CLPzad5gHrZ3Dn9XZIve9f9IZbC2ze
NH5vB19JVvmXv8D8hGeC3g69x1+tnd0Ntv+BqYi3w92cW4sfPgDzE1rFvB0u
xUW2lLGD3atwVcLbwV1mXfvEH2D5AyrS3g5bUiZvDH8DUV8i6+2wQCrg3Xpp
sPoHh+W9HZxYljDwp+k4AAChaWtd
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5zDz2fE/QWl0HILdB+xuQ3zP/ye0iMP9B
1Q8vhyMPGVk3BkLkT/3yctC5fmnCUhcwX0Hqr5cDzx2f4L1hOiD+gcz/Xg58
DEvnPFLWAsvvZPR2SHCZqKbGrwGW52Dxdsh3aHav91UH8RMi2Lwdlu7pq36m
C+YrrODwdmg6fiRkWySY3/Cdy9shb9GdGV13wHwGd15vh4MndzD9NtEEmzeN
39vB3zN63tI5YPsSngl6O0w5P4knskQb7H5TEW8HsxbPL2tOgfkJrWLeDgXN
Fz0F7oH5ClclvB0uSHYVqdwC8w+oSHs7uDZ5Rr28DFFfIuvtwObvUNf6B2Le
YXlvhwlFrn+S03UcAEXpa6Q=
          "]]}}}, {}}}, {PlotRange -> {9, 18}, Frame -> True, FrameLabel -> {
       FormBox["\"Latitude\"", TraditionalForm], 
       FormBox["\"Wind speed 250 m\"", TraditionalForm]}, Axes -> False, 
     TextStyle -> {FontSize -> 14}, PlotRange -> {12, 17}, DisplayFunction -> 
     Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, DisplayFunction -> Identity,
      AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=0\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=0.25\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=1\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8135860009066706`*^9, 3.8135860281230955`*^9}, 
   3.813587563230796*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"g14", ",", "g15"}], "]"}]], "Input",
 CellChangeTimes->{{3.813586030529133*^9, 3.813586034741329*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.813586035506657*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVz31MU2cYBfBCASkWhEL5kC9x4lzvvW1JJjJx4VQDHfedUpTJWqhYhWTV
iQtGXQiig4m4dRiwTorUoGBZ3IwERGBDEkNodZFttihE1zAmOpkbssGGorZ7
98eTJ7+c889J2rF3c4mvQCBIpff/j7INGCrneJhWjNTY5xQwPHVFa/7hoU9v
++OdXAWyr2R5Ev+ledhyp3RUjsKO3lvT1IX6npNVjXLcOzGZ0T/PI04pkfrY
5FjRnqCvfUb7jWUe8W05TCkH5jc/51G+asuC9jc5CjY92hm3wOP+ofDvDCoF
Kq3zgQ+p+xNEB774SIGBeJ/aSy94PHY+eStkSAFNkcm2/yUPrWhaVjKrgL3k
m0frXvEYaaiMTkpTQtRaVSD08JiK0KXodEqcdul7blIbNePGlX5KNIUMBtd7
eWxrMY5uXODQVV6TohUQ3B+cickPYdEpLbMl+RD0HRsry5Uw6BSkfz9FnfP7
J0tcCgZtR5/1dvoSjF74kMuZlmF8y9vqCiFBCmu+nHtahu0O1VK1H0F6eMQc
7DLMPTBaJf4EvPWVVJrNQGR44XVTL6vpm5VzLBwq2dhXAQS3Zp6XHpGwMJnr
/MsWEVT1OrWDySwSzngOrw0k8G/+8Y0dFxm41sQ2CkUElV1Xw653U4eeOjtM
7RZrdgsaGHhUjhZLEEGzTejnvsvg6lCJ6oPFBONn9tndtXTPjeU5aWKC1VPq
Ly9ZGMgD0iYCgwmkjqMX2vsZHKze2zBGXdB2NlFzjoVwQVfXHkJg9o2XWMQc
itdne/cvIXi3XB073Mchs6hlQhVKkFdaPd9awaFC+Zk9KIzgTq72sulTDuTp
moM/UR8WOYuZUg6tUU6tWULw67r1+uZiDq+JyV/vhxN4z6+d0BzhsOja368v
iyBAcP29lYc4hPKf73xC7TZu+MXbRPuRmYZvpQTHr2d2dNDcsjVPZ4okUDIB
bU35HGaslsjtUQTMRlZ9IpbDrrTHe1ZHE4TdiXHagjgUvJmoWhxD9zm6qlJ9
OEQRu2uC+mcXs+GkgEP3w/fae5YS+CbeTJ78k0VwqsdoiiUY+TjvXPIki/GW
+oyiOILhY6equ2dZeLP2FSniCfJ3mezmARbWK1nMS+o96du+rqlj8cP5zMKh
BIKkjOObLuax+A+aGWSW
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0n9Q03UYB/CxAQKTJsJgG+iowcH23ZfdTuToCO5tUuj3Awz8QQ44BEGI
FHCSQFrRFeIlVMoPhUNKAuJSEmZ0cpHJYecdcNeiZptA/FAhQZOOwcBk1Kc/
nnvudc/zx/M897x4qGjPYT6Px3uZxv95peiY3LyV4Kk8u/i+E4OSJnODD7Vm
vtBhlDI4GVIh2L+FwG57qzA5kMEP3+1trQsg+HPlsGgHrWflLheb/Qn27P0q
N9GDwejGgl4f6jlrc6HQk0FPUjIvRUZQp706nerC4MjgwKWLUoKqpLpSJ1r/
UBhltUoIIoakayc2MOiId3wtpTaEDzpf3c6gQn66LNWPoKS/KnZrHoMAkdmt
yZcgjL2jC7vFYOFzi2FMTOA6ejk/wVON4vQj3f7U7affC4pNVuOge8rOdB+C
PmH9w4tZakgyyyXN3gQV0g6RU4QaEewzycRmgvH+a/UxCwy8hnYROfXcumko
9DqDYlZzJdOLwFKe1iDqZjD2vbG/ZRPBQsk99/URBt76+XP3RXSexYrEAVc1
KoST+xXU7n83q84uM+AGNfbsFwjKDRHxNQMMqn/rDm3zJEhuKamtpPeaEhS4
PtxI0Brsr2vMV2Glr3lJQZ1XI06Ty1WIe9TRmiOk/Z0nfn5gVmI81ahr9yBo
Ycwx3ypUMM6UBsy6E+wYztFfCVLBdq1uJpj6tQurPhatCi6tBm2uG8Gbifpf
FrepkBrP3GnfQPCuINLR1K2E3f74mxlXgvrAggNRKiUk10cOBlGvys9pye1Q
BDviTIdcCErb3lmcfBCKs1tyHl12JjijsJkYNyWmtn/UOyGg/+FrskcfVyIy
/VhlAHWhm/FVpy+VYG+yaal8gulssfjShBKqv24aGpwI5v2yrPE3lOjNOBBi
4RG8pJ86+Qnd/2lgUpMvdfS0349vzzAQPfl0d8q/HDJeF5gSz7MI31cZe2Gd
g6UrOu/oQBgSu2yzdx0cthl0sYNvaNCZT2rF1NX5H4828jXYOSa9sW+Nw+O4
eqtnYRjuZYzoa59zyE0v08iWWJR19NSM/MPhVtJaUeMcC5fxyeMiaq+UaKnC
zuIV5773E55x6BXzq2TPWdQkxHlXr3I4xTk2ffCEhdzIixxe4TCo+4yvnGWR
qe2UeVAXtJpc2T9Y/N7Qk7fLzqErK6p+9S715l+PVi7T+WLahSEmFqdsw1/8
tMRBHt4mM9xm8R/IC3c2
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0n9Q03UcBvDpmBJKTJgzBOHU+LV9P3xmuuK6uD2TEP1+CM1lwKaRDijk
t5kE1Zni4IpEAbF2MDG5mHXCRkhCxaUJjgvCEzW8QDp/QHSYisBA0q1vf7zv
udc9fzz/vFfuyt2aNl8kEqmF+z/3W86YsqZ4vOUY7XgqpZiy9GrU0zzq6RtV
faspttltW12CAy/sjDqlpXA3hX/hcPJIztOF/bydwtrpvalihsclacvQP2YK
D5fvJ4ZZHv2FNxta2ylMPZcDwh7zkF+vHS/ppliK/OppwdaQP+2vlVHYK978
+9Icj8fG4NDWDyl+Gfv2nvlfHlH3Z35vraRwrZauyn7Cw5lR7ruphELT0czh
KY8DBwuGD3upUP99wOQSFw9t12RVTaQKi0tvXb4t+JukjQPOcBVMcseOFjcP
5ckXVfuqImEUW0aLRQzeV/ndeTsJckwX83TzGJJSzYkfSzgknVbT4PkMdwy9
W2aNSqQfOjL9l+A9fj3bh75UIILEi2xihqnsQUvEZATS4r5qK/BguNjY193h
r8Bdo25wvYRBXLutR1YXgdiGSr10AUPdLeOiTKHXuzUzw4KvfvdysyZBgfcf
Rh9oXMhA9dotD3IUCBq//0KRJ4PsWtiNlRoFZruC1sU+w/B86vG9iZ8rsDwm
NMPHi+H8tfGiD9wKrPXqEA8K1h5XRf9gU8KUstF8ehHDunn1tSqzEklHnyQW
LGZ4+1X3RPmcEtlFg3UbvBlemgjsDr2nxJUuh5/8WQbH9Zy1ny3k8GlGtXZE
8Iq7H50J3svhhM6Q3+rDMFf4ypGbdzhcyXgUUipl4DutA02UINd/bLd+ibAX
c2HuRhxBY0tnLvFlKB3mGtSbCfrCh064BKc+Ki0T7yEobrPG/+bHMLos+V1X
JcHYekO7WcbgXzct5toIPCNV4tSlDCNfGzS0n2DgncxjRM7gzgqcSe4hSHNb
bjsFj6UQZ81PBPE+xybOL2Pw3HfSY9d7BOXpB/WHn2OILQibSg8gOEfVUTv8
GYobqlNkZzkY+uMWqJYzmKWvP8jczyH/XJZIEsCwgZfYpIUcQqz29j8E94oT
9BXCq8X8OmKzBzKUnVoTtXmUQ8KPNkfJCmEveqDmrJRA8lBXaAhiSG+WN62R
EfwH8uBp2A==
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0GtMk3cUBvCClAE6tAVFLBJbSKDv2xZkA2UiPqlsi+8/zpYxKJeWyyAp
WwzJNjEjFcIlzUBxEbWw6qCSjTqySAU7QigVkA42w0IBCUK4SWC6iZvpGEU2
uncfTp78knOeD0dYUJJa5M3hcBLZ+T9tHc+/mggnUIr92tYIjTubj03BrAe/
MDia36DRE/Xr2AcHCfirTYdFITQS5IoTjWEEzoY/B0qCaFRd2Bh8LCDQH8gg
eygajSGG7IOsF2xpiuN5NG6JOOV5BwjSxlIWt0poJI384dcaStBuyTwWU0vj
0+yB1if7CXqGA+ynKmg0N+ieilhnmQtdJ2/RCLbk/lYQQjA7qE4IstC4u+KM
aN1HUKMyl5Y5aSSeb1cv7SXYqBtI8ZmjcfFkivkQa25x7nWtm8bo/A5uXjCB
3VDn7QyUYLpt15umIIK+Gc8DFy1Bh6trcpHP3mfJKlUpEmiKve1C1kl63v6H
ORKIPt9dn88jKLctiNrTJTDa3JdNewgq+m29M6ESrFfXZS7sZve56RHzXTQm
grLqw1lzJ7asXrk0RE/OfagJJMirWjRMzVDoOVv7bsvrBKlxvLJ99yn0X9Ok
L+0iWEmmmuSVFK69/d1kJOv+7YKLy80Ujo1EeH+0k6A3cohTdJ5CAlcu7wgg
2PltmKM2jUK5yb/C5U/QvfrOXs+YGAM/Ld6IZx3PH53VVYgxLfxFU+pHYC3p
M6nXozHW3OL7w2vsP2s6lbGd0Yh45vhx3ZdA1XIuvcoSDWP+9+541tqcaaX+
djSSReLYUi5BdX/W8DOhGAvWzZF7PgQvp2KvKvuiEX6cuvRyB0HXHd2wzwUx
llYLH0hZW+u+eVitEqM5rWyu2Jvg/sfdhWcOUzA/Dyho8yJYjbOP3H5E4cj2
zeFlDoGAnusWbNE4kaoaELI+Xd6ozFRIobQWc/I8DGTc0MibWhlyqo1DX28z
aDI6aiujYpD2ivPl7L8M4sJsR34+GgPHpTNFoaxNEKj14zLItW9lZPzDYGMo
W6dTyWDnkavXtxgIfk9ZMbmlyPV/ypl8xeD9/BzNIbsU815HO/msA6furRna
pNhWPPJK3WSg/aTdp+8zKeo9Ne4rbgZ3X1w+nVggBV+VmDy+wUCRseyIN0ph
tzuK+awtnWp5ENt/do3uTf2bgb+rTO9JlsHXzDM1rDNYso/XaN6TgbcpSHL+
xWA06UVpVIQM/wEQboXA
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVzXtMU2cABfBSpxZ5DbClRUqshkdvufdrxkYUEA4bIL2fgBIf1LKozWAm
WzJloAJNVaZjgIxNBBunIigqKgacCz6AOdSB01ZQmctWZsycggYDVAoWAa9/
nJz8cv44KuNXGdlikUj0oZB3Hbmo64HpFY+m08bfi64T2OW2qPQxHs1JkmND
Lwjy+1KTVU4e157H6yX3CEbJDxWjgrVdTdVXHQRlxkXKznEeqdmDDSPCLg1p
zKyc4GFQ0pJHdwksP+ctNLzmcexgoe5AB8EvnZa0UBcPtZQzlf1DcC4oZO+I
YKu3UlXlroXvULtH+yQPt6o/X25QaVHqrG8pfcNDo/AJuLpWi1aLISFzSviX
O28n7dAiRXtlKnyaR8ff4u8dxVoU3e+PfSO47Ybftr9WapEXlxHbO8ND2WM3
GFIJcmMy7p8SUayL2h37o5HF8/Kcw2Y3irCK6AnWpMEFq37ZajFFTDDxaP6C
gWf5Gc/wWRQ7nSmFrkoGW6uU+12CAxzZrV8mMrixR7f+znsUH3/rOGBKZxAS
XhJ2dDbFcZ8i/1yTGtcO+u3eMocid1kO7soYxHjrxxLnUuzvr2/a+BED25qC
tQskFHVNpZWfWBksH/4gziF4V2KWYu9NBrqCRultd4qaoU3nlf8ziFR31NXN
o7A6v065zGnwX8OnPts9KH7zetSTX6uBudt8inpSzOu6NeB0aXBihXrVQi+K
6V0D0s0XIyA7oT/9SnDAnovt4lAWT0THN3V7U1iSNZahEhZ5xsfxh30oKlqt
OzfXsojSHNJtfZ8icey7b252skia8F2X7EsxadeVjfeziGy3iwL9KGQ1rvFq
NQfFxiNnXwieCbNl/vo5B/clT73a/CkutYlbtpzl0D3M1uybT1G8OK1kWx+H
ZpX6SZaUwpYX4atwJ/gpvi6NlVFU2xuSsgIJbAOD16cFd8srJ3NYgktz/rD0
BlCIEqIZWQhBsUdkX4Oc4tCMPrhvKYHarcVWqKDwf3onfXkEwarsW7krAynY
DYsln0kIyu/F9YYuoBiNkQ8+7OFQIGk8PyWYqbXOCjrJIT+rOfNBEIU8wa8w
vJZDvTk0+oySIn7i4XBZK4cLFf8WmIMp0kaeTRoec3gL6nRd8g==
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVzntQlGUUBnBAkJtcVtsFFEjGYpZv3/3WQe5I8yBozvcaJAhDKkoQxEUE
TLHGMuSiGHFRXDXwwjA7sUAiOorFxUKxodXU8QbJBLNbqyiXBVJYCNbe/jhz
5vfHc57jlZwTk2phZmYWwub//TQsOP+xJ4WLb+Zg0ho5tr5f2ShhPnFh/7q2
EYJvK6QRCR4UmqB9E7XtBAvr99TWuFN8cLtHX/A9waEAn6Q/V1CEm45Z2zQQ
9O4Ye3slc/TG7lTHJgJRwPb45OUU68GfD7tFYFHWKVO5USg81t7lJwjcE4wp
z1wpru9wsQqylyNOddLDh7nnXM65bTbsnxG/LbtcKMpvdC/3fUpwYeDxzosS
ikqPjheiswTiCKN2Usz6ntM2/QGCSONrSz9m10mucOwYgddDSvPfokgOrQs6
fJcgC8rwn5ZRoErbFjxI0KrI5OaXUrSUuQ5Wmwjup++78x7zO5vOWF9+RlBl
Gi0+JKK4JrLymNUSJE7k6m46U+wp+utwD+vvH+9eWMwc0ZNY8qiaYNo1O1hw
othwsa6xXkGQ8qpAX+5IcSTHqzxkVAa7J+6rHjhQ9Pl7G1WnZJD7bJ2SMMeI
+pf9mCND8YbBme1LKDY5SXXN6TLUVHwxXm9PYZMeuOS8owwDo/ezh+0oPtNO
RY63ctCUVIfJmb39Vd0GOQex8k1lni2FuiFzba0fh5YkZeUVG4p4y91VdQUc
uFO7UmesKULDpsrJVQ5oHHIOYe6NfpgVF81BFmv75MvFFEUffXfv6wofiOV1
1j9bUUQ9n5wMaJYiqrP1gBlzVeiI4dGoFFYmUek6Swr7oZcvk3N90CQ9OFe8
iMI8+Opmv1IOOsuPpb0WFNkjt8oeCDIcb/8wwZ55kUNfRkChDPemLhmizCmm
Pc9Mxk/LcCnLtLrajCKI5pc66wl69pq6+t4I2PtrRX2LhAdEHRkrmPvVTs1u
L3h0Xl+YTzQJcFuVVpqwWoGz7uab6xYEXInRKFVyBT75I82om2f5mnl1E6dA
Wpcp413mFMNXjRpbBbxjt9h9+q+A2Bve2f7XePg2hYSr5wT80n7z89ASHpfj
jnYOzwqwOEgMzdU89M5jGinz6Zpt/wTe5qHz1O5MNwqYyfzmpCO7V3h6Yrd6
RkDS0d98/57nsV+MH4anBTTk8VyMlQIByu47UuaulUsdBswVCFwTH5v+WkDk
7/q5vA4es+MWEvUrAb65yqKhEzz+AyNnjCo=
            "]]}}}, {}}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5BJ6TcX+7TNcByG3Q/ubloDbbr7azDMx/
UPXDy4Evr2F1lhdE/tQvL4etiyctsjUC8xWk/no5vBGc6H9itQ6IfyDzv5dD
eNj/CwLO2mD5nYzeDr96lwjsX6kJludg8XY4z+ln9uiCBoifEMHm7RAsPCW3
fxKYr7CCw9uhOGTaX945YH7Ddy5vh4CLPzad5gHrZ3Dn9XZIve9f9IZbC2ze
NH5vB19JVvmXv8D8hGeC3g69x1+tnd0Ntv+BqYi3w92cW4sfPgDzE1rFvB0u
xUW2lLGD3atwVcLbwV1mXfvEH2D5AyrS3g5bUiZvDH8DUV8i6+2wQCrg3Xpp
sPoHh+W9HZxYljDwp+k4AAChaWtd
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5fHp14n69oJ4DkNug/c3LIWld6smAR7og
/oOqH14ODlJbZnyZC+Y3nPrl5SCTabv3awOYryD1FygfYsQsulQHxD+Q+d/L
4e7dYB1GWy2w/E5GbweHVDVtLX0NsDwHi7dD1P0Tzgan1EH8hAg2bwf7babc
u7aB+QorOLwd9i259Xf1RTC/4TuXt8OqdPXs9RJg/QzuvN4OnTfW2Gzq1QSb
N43f20H4VLyv1UawfQnPBL0drlS6Loix1Qa731TE2yFC+9yWkjlgfkKrmLfD
1oPHt+y4A+YrXJUAuk/oxhfW32D+ARVpbwctGQ2xtzxg/ySUyHo7+DlOCrbS
AvMfHJYHmm/4OHFSko4DAOMaaQI=
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5zDz2fE/QWl0HILdB+xuQ3zP/ye0iMP9B
1Q8vhyMPGVk3BkLkT/3yctC5fmnCUhcwX0Hqr5cDzx2f4L1hOiD+gcz/Xg58
DEvnPFLWAsvvZPR2SHCZqKbGrwGW52Dxdsh3aHav91UH8RMi2Lwdlu7pq36m
C+YrrODwdmg6fiRkWySY3/Cdy9shb9GdGV13wHwGd15vh4MndzD9NtEEmzeN
39vB3zN63tI5YPsSngl6O0w5P4knskQb7H5TEW8HsxbPL2tOgfkJrWLeDgXN
Fz0F7oH5ClclvB0uSHYVqdwC8w+oSHs7uDZ5Rr28DFFfIuvtwObvUNf6B2Le
YXlvhwlFrn+S03UcAEXpa6Q=
           "]]}}}, {}}}, {{{{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVz31MU2cYBfBCASkWhEL5kC9x4lzvvW1JJjJx4VQDHfedUpTJWqhYhWTV
iQtGXQiig4m4dRiwTorUoGBZ3IwERGBDEkNodZFttihE1zAmOpkbssGGorZ7
98eTJ7+c889J2rF3c4mvQCBIpff/j7INGCrneJhWjNTY5xQwPHVFa/7hoU9v
++OdXAWyr2R5Ev+ledhyp3RUjsKO3lvT1IX6npNVjXLcOzGZ0T/PI04pkfrY
5FjRnqCvfUb7jWUe8W05TCkH5jc/51G+asuC9jc5CjY92hm3wOP+ofDvDCoF
Kq3zgQ+p+xNEB774SIGBeJ/aSy94PHY+eStkSAFNkcm2/yUPrWhaVjKrgL3k
m0frXvEYaaiMTkpTQtRaVSD08JiK0KXodEqcdul7blIbNePGlX5KNIUMBtd7
eWxrMY5uXODQVV6TohUQ3B+cickPYdEpLbMl+RD0HRsry5Uw6BSkfz9FnfP7
J0tcCgZtR5/1dvoSjF74kMuZlmF8y9vqCiFBCmu+nHtahu0O1VK1H0F6eMQc
7DLMPTBaJf4EvPWVVJrNQGR44XVTL6vpm5VzLBwq2dhXAQS3Zp6XHpGwMJnr
/MsWEVT1OrWDySwSzngOrw0k8G/+8Y0dFxm41sQ2CkUElV1Xw653U4eeOjtM
7RZrdgsaGHhUjhZLEEGzTejnvsvg6lCJ6oPFBONn9tndtXTPjeU5aWKC1VPq
Ly9ZGMgD0iYCgwmkjqMX2vsZHKze2zBGXdB2NlFzjoVwQVfXHkJg9o2XWMQc
itdne/cvIXi3XB073Mchs6hlQhVKkFdaPd9awaFC+Zk9KIzgTq72sulTDuTp
moM/UR8WOYuZUg6tUU6tWULw67r1+uZiDq+JyV/vhxN4z6+d0BzhsOja368v
iyBAcP29lYc4hPKf73xC7TZu+MXbRPuRmYZvpQTHr2d2dNDcsjVPZ4okUDIB
bU35HGaslsjtUQTMRlZ9IpbDrrTHe1ZHE4TdiXHagjgUvJmoWhxD9zm6qlJ9
OEQRu2uC+mcXs+GkgEP3w/fae5YS+CbeTJ78k0VwqsdoiiUY+TjvXPIki/GW
+oyiOILhY6equ2dZeLP2FSniCfJ3mezmARbWK1nMS+o96du+rqlj8cP5zMKh
BIKkjOObLuax+A+aGWSW
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0n9Q03UYB/CxAQKTJsJgG+iowcH23ZfdTuToCO5tUuj3Awz8QQ44BEGI
FHCSQFrRFeIlVMoPhUNKAuJSEmZ0cpHJYecdcNeiZptA/FAhQZOOwcBk1Kc/
nnvudc/zx/M897x4qGjPYT6Px3uZxv95peiY3LyV4Kk8u/i+E4OSJnODD7Vm
vtBhlDI4GVIh2L+FwG57qzA5kMEP3+1trQsg+HPlsGgHrWflLheb/Qn27P0q
N9GDwejGgl4f6jlrc6HQk0FPUjIvRUZQp706nerC4MjgwKWLUoKqpLpSJ1r/
UBhltUoIIoakayc2MOiId3wtpTaEDzpf3c6gQn66LNWPoKS/KnZrHoMAkdmt
yZcgjL2jC7vFYOFzi2FMTOA6ejk/wVON4vQj3f7U7affC4pNVuOge8rOdB+C
PmH9w4tZakgyyyXN3gQV0g6RU4QaEewzycRmgvH+a/UxCwy8hnYROfXcumko
9DqDYlZzJdOLwFKe1iDqZjD2vbG/ZRPBQsk99/URBt76+XP3RXSexYrEAVc1
KoST+xXU7n83q84uM+AGNfbsFwjKDRHxNQMMqn/rDm3zJEhuKamtpPeaEhS4
PtxI0Brsr2vMV2Glr3lJQZ1XI06Ty1WIe9TRmiOk/Z0nfn5gVmI81ahr9yBo
Ycwx3ypUMM6UBsy6E+wYztFfCVLBdq1uJpj6tQurPhatCi6tBm2uG8Gbifpf
FrepkBrP3GnfQPCuINLR1K2E3f74mxlXgvrAggNRKiUk10cOBlGvys9pye1Q
BDviTIdcCErb3lmcfBCKs1tyHl12JjijsJkYNyWmtn/UOyGg/+FrskcfVyIy
/VhlAHWhm/FVpy+VYG+yaal8gulssfjShBKqv24aGpwI5v2yrPE3lOjNOBBi
4RG8pJ86+Qnd/2lgUpMvdfS0349vzzAQPfl0d8q/HDJeF5gSz7MI31cZe2Gd
g6UrOu/oQBgSu2yzdx0cthl0sYNvaNCZT2rF1NX5H4828jXYOSa9sW+Nw+O4
eqtnYRjuZYzoa59zyE0v08iWWJR19NSM/MPhVtJaUeMcC5fxyeMiaq+UaKnC
zuIV5773E55x6BXzq2TPWdQkxHlXr3I4xTk2ffCEhdzIixxe4TCo+4yvnGWR
qe2UeVAXtJpc2T9Y/N7Qk7fLzqErK6p+9S715l+PVi7T+WLahSEmFqdsw1/8
tMRBHt4mM9xm8R/IC3c2
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0n9Q03UcBvDpmBJKTJgzBOHU+LV9P3xmuuK6uD2TEP1+CM1lwKaRDijk
t5kE1Zni4IpEAbF2MDG5mHXCRkhCxaUJjgvCEzW8QDp/QHSYisBA0q1vf7zv
udc9fzz/vFfuyt2aNl8kEqmF+z/3W86YsqZ4vOUY7XgqpZiy9GrU0zzq6RtV
faspttltW12CAy/sjDqlpXA3hX/hcPJIztOF/bydwtrpvalihsclacvQP2YK
D5fvJ4ZZHv2FNxta2ylMPZcDwh7zkF+vHS/ppliK/OppwdaQP+2vlVHYK978
+9Icj8fG4NDWDyl+Gfv2nvlfHlH3Z35vraRwrZauyn7Cw5lR7ruphELT0czh
KY8DBwuGD3upUP99wOQSFw9t12RVTaQKi0tvXb4t+JukjQPOcBVMcseOFjcP
5ckXVfuqImEUW0aLRQzeV/ndeTsJckwX83TzGJJSzYkfSzgknVbT4PkMdwy9
W2aNSqQfOjL9l+A9fj3bh75UIILEi2xihqnsQUvEZATS4r5qK/BguNjY193h
r8Bdo25wvYRBXLutR1YXgdiGSr10AUPdLeOiTKHXuzUzw4KvfvdysyZBgfcf
Rh9oXMhA9dotD3IUCBq//0KRJ4PsWtiNlRoFZruC1sU+w/B86vG9iZ8rsDwm
NMPHi+H8tfGiD9wKrPXqEA8K1h5XRf9gU8KUstF8ehHDunn1tSqzEklHnyQW
LGZ4+1X3RPmcEtlFg3UbvBlemgjsDr2nxJUuh5/8WQbH9Zy1ny3k8GlGtXZE
8Iq7H50J3svhhM6Q3+rDMFf4ypGbdzhcyXgUUipl4DutA02UINd/bLd+ibAX
c2HuRhxBY0tnLvFlKB3mGtSbCfrCh064BKc+Ki0T7yEobrPG/+bHMLos+V1X
JcHYekO7WcbgXzct5toIPCNV4tSlDCNfGzS0n2DgncxjRM7gzgqcSe4hSHNb
bjsFj6UQZ81PBPE+xybOL2Pw3HfSY9d7BOXpB/WHn2OILQibSg8gOEfVUTv8
GYobqlNkZzkY+uMWqJYzmKWvP8jczyH/XJZIEsCwgZfYpIUcQqz29j8E94oT
9BXCq8X8OmKzBzKUnVoTtXmUQ8KPNkfJCmEveqDmrJRA8lBXaAhiSG+WN62R
EfwH8uBp2A==
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwV0GtMk3cUBvCClAE6tAVFLBJbSKDv2xZkA2UiPqlsi+8/zpYxKJeWyyAp
WwzJNjEjFcIlzUBxEbWw6qCSjTqySAU7QigVkA42w0IBCUK4SWC6iZvpGEU2
uncfTp78knOeD0dYUJJa5M3hcBLZ+T9tHc+/mggnUIr92tYIjTubj03BrAe/
MDia36DRE/Xr2AcHCfirTYdFITQS5IoTjWEEzoY/B0qCaFRd2Bh8LCDQH8gg
eygajSGG7IOsF2xpiuN5NG6JOOV5BwjSxlIWt0poJI384dcaStBuyTwWU0vj
0+yB1if7CXqGA+ynKmg0N+ieilhnmQtdJ2/RCLbk/lYQQjA7qE4IstC4u+KM
aN1HUKMyl5Y5aSSeb1cv7SXYqBtI8ZmjcfFkivkQa25x7nWtm8bo/A5uXjCB
3VDn7QyUYLpt15umIIK+Gc8DFy1Bh6trcpHP3mfJKlUpEmiKve1C1kl63v6H
ORKIPt9dn88jKLctiNrTJTDa3JdNewgq+m29M6ESrFfXZS7sZve56RHzXTQm
grLqw1lzJ7asXrk0RE/OfagJJMirWjRMzVDoOVv7bsvrBKlxvLJ99yn0X9Ok
L+0iWEmmmuSVFK69/d1kJOv+7YKLy80Ujo1EeH+0k6A3cohTdJ5CAlcu7wgg
2PltmKM2jUK5yb/C5U/QvfrOXs+YGAM/Ld6IZx3PH53VVYgxLfxFU+pHYC3p
M6nXozHW3OL7w2vsP2s6lbGd0Yh45vhx3ZdA1XIuvcoSDWP+9+541tqcaaX+
djSSReLYUi5BdX/W8DOhGAvWzZF7PgQvp2KvKvuiEX6cuvRyB0HXHd2wzwUx
llYLH0hZW+u+eVitEqM5rWyu2Jvg/sfdhWcOUzA/Dyho8yJYjbOP3H5E4cj2
zeFlDoGAnusWbNE4kaoaELI+Xd6ozFRIobQWc/I8DGTc0MibWhlyqo1DX28z
aDI6aiujYpD2ivPl7L8M4sJsR34+GgPHpTNFoaxNEKj14zLItW9lZPzDYGMo
W6dTyWDnkavXtxgIfk9ZMbmlyPV/ypl8xeD9/BzNIbsU815HO/msA6furRna
pNhWPPJK3WSg/aTdp+8zKeo9Ne4rbgZ3X1w+nVggBV+VmDy+wUCRseyIN0ph
tzuK+awtnWp5ENt/do3uTf2bgb+rTO9JlsHXzDM1rDNYso/XaN6TgbcpSHL+
xWA06UVpVIQM/wEQboXA
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVzXtMU2cABfBSpxZ5DbClRUqshkdvufdrxkYUEA4bIL2fgBIf1LKozWAm
WzJloAJNVaZjgIxNBBunIigqKgacCz6AOdSB01ZQmctWZsycggYDVAoWAa9/
nJz8cv44KuNXGdlikUj0oZB3Hbmo64HpFY+m08bfi64T2OW2qPQxHs1JkmND
Lwjy+1KTVU4e157H6yX3CEbJDxWjgrVdTdVXHQRlxkXKznEeqdmDDSPCLg1p
zKyc4GFQ0pJHdwksP+ctNLzmcexgoe5AB8EvnZa0UBcPtZQzlf1DcC4oZO+I
YKu3UlXlroXvULtH+yQPt6o/X25QaVHqrG8pfcNDo/AJuLpWi1aLISFzSviX
O28n7dAiRXtlKnyaR8ff4u8dxVoU3e+PfSO47Ybftr9WapEXlxHbO8ND2WM3
GFIJcmMy7p8SUayL2h37o5HF8/Kcw2Y3irCK6AnWpMEFq37ZajFFTDDxaP6C
gWf5Gc/wWRQ7nSmFrkoGW6uU+12CAxzZrV8mMrixR7f+znsUH3/rOGBKZxAS
XhJ2dDbFcZ8i/1yTGtcO+u3eMocid1kO7soYxHjrxxLnUuzvr2/a+BED25qC
tQskFHVNpZWfWBksH/4gziF4V2KWYu9NBrqCRultd4qaoU3nlf8ziFR31NXN
o7A6v065zGnwX8OnPts9KH7zetSTX6uBudt8inpSzOu6NeB0aXBihXrVQi+K
6V0D0s0XIyA7oT/9SnDAnovt4lAWT0THN3V7U1iSNZahEhZ5xsfxh30oKlqt
OzfXsojSHNJtfZ8icey7b252skia8F2X7EsxadeVjfeziGy3iwL9KGQ1rvFq
NQfFxiNnXwieCbNl/vo5B/clT73a/CkutYlbtpzl0D3M1uybT1G8OK1kWx+H
ZpX6SZaUwpYX4atwJ/gpvi6NlVFU2xuSsgIJbAOD16cFd8srJ3NYgktz/rD0
BlCIEqIZWQhBsUdkX4Oc4tCMPrhvKYHarcVWqKDwf3onfXkEwarsW7krAynY
DYsln0kIyu/F9YYuoBiNkQ8+7OFQIGk8PyWYqbXOCjrJIT+rOfNBEIU8wa8w
vJZDvTk0+oySIn7i4XBZK4cLFf8WmIMp0kaeTRoec3gL6nRd8g==
            "]]}}}, {}}, {{}, {{{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[0.016666666666666666`], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVzntQlGUUBnBAkJtcVtsFFEjGYpZv3/3WQe5I8yBozvcaJAhDKkoQxEUE
TLHGMuSiGHFRXDXwwjA7sUAiOorFxUKxodXU8QbJBLNbqyiXBVJYCNbe/jhz
5vfHc57jlZwTk2phZmYWwub//TQsOP+xJ4WLb+Zg0ho5tr5f2ShhPnFh/7q2
EYJvK6QRCR4UmqB9E7XtBAvr99TWuFN8cLtHX/A9waEAn6Q/V1CEm45Z2zQQ
9O4Ye3slc/TG7lTHJgJRwPb45OUU68GfD7tFYFHWKVO5USg81t7lJwjcE4wp
z1wpru9wsQqylyNOddLDh7nnXM65bTbsnxG/LbtcKMpvdC/3fUpwYeDxzosS
ikqPjheiswTiCKN2Usz6ntM2/QGCSONrSz9m10mucOwYgddDSvPfokgOrQs6
fJcgC8rwn5ZRoErbFjxI0KrI5OaXUrSUuQ5Wmwjup++78x7zO5vOWF9+RlBl
Gi0+JKK4JrLymNUSJE7k6m46U+wp+utwD+vvH+9eWMwc0ZNY8qiaYNo1O1hw
othwsa6xXkGQ8qpAX+5IcSTHqzxkVAa7J+6rHjhQ9Pl7G1WnZJD7bJ2SMMeI
+pf9mCND8YbBme1LKDY5SXXN6TLUVHwxXm9PYZMeuOS8owwDo/ezh+0oPtNO
RY63ctCUVIfJmb39Vd0GOQex8k1lni2FuiFzba0fh5YkZeUVG4p4y91VdQUc
uFO7UmesKULDpsrJVQ5oHHIOYe6NfpgVF81BFmv75MvFFEUffXfv6wofiOV1
1j9bUUQ9n5wMaJYiqrP1gBlzVeiI4dGoFFYmUek6Swr7oZcvk3N90CQ9OFe8
iMI8+Opmv1IOOsuPpb0WFNkjt8oeCDIcb/8wwZ55kUNfRkChDPemLhmizCmm
Pc9Mxk/LcCnLtLrajCKI5pc66wl69pq6+t4I2PtrRX2LhAdEHRkrmPvVTs1u
L3h0Xl+YTzQJcFuVVpqwWoGz7uab6xYEXInRKFVyBT75I82om2f5mnl1E6dA
Wpcp413mFMNXjRpbBbxjt9h9+q+A2Bve2f7XePg2hYSr5wT80n7z89ASHpfj
jnYOzwqwOEgMzdU89M5jGinz6Zpt/wTe5qHz1O5MNwqYyfzmpCO7V3h6Yrd6
RkDS0d98/57nsV+MH4anBTTk8VyMlQIByu47UuaulUsdBswVCFwTH5v+WkDk
7/q5vA4es+MWEvUrAb65yqKhEzz+AyNnjCo=
            "]]}}}, {}}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5hNqs6uh9qeMA5DZof/NysBAsXf1ZXhfE
f1D1w8vBuDfGdI8tmN9w6peXw2/bCavW+4P5ClJ/vRxuCE7/qHAPrP9A5n8v
hzPW93asnqoNlt/J6O3gYrpb7buBFlieg8XbYWJfqmWPryaInxDB5u2wk/X6
zd+XNMDqV3B4O7Tt4xD9vQLMb/jO5e3wOnRZ1W5WsHoGd15vh1WeT2Xd3oH5
B6bxeztkt+qekzgLNj/hmaC3w8ON14Xe+IHtf2Aq4u0QeXr/v3czwfyEVjFv
h+lbV0+dfxzivqsS3g7bUi/e6z8H5h9QkfZ2UO+uKll8AKK+RNbbwerJwgq/
zRDzDst7O+gz/FnsvlrbAQBwHXBV
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5bC45Kb8nTccByG3Q/ublcJrp0Vad62D+
g6ofXg7/Ux9odfHpguVP/fJy+BB36audAZivIPXXy6FDIvWXykKw+gOZ/70c
JF6zzA6cpAWW38no7bBmf2dgyWYNsDwHi7fD5fXr2uT1wPyECDZvhxflga09
D9TB6ldweDuocds/2Q3hN3zn8nZoPMrPFGwIVs/gzuvtMOf13iL1OZpg86bx
eztMv3r0/OvDYPsSngkC5VUdX9yP0Aa731TE20E3O6TC+hSYn9Aq5u1wwtqD
kV0M7F6FqxLeDjf91K6Iq0LcryLt7eCcdkbzmgCYn1Ai6+0w98LC7Ve/Qcw7
LO/t8PCaiA3TS20HAIBJa7c=
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.019444444444444445`], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5dHWobjj/QccByG3Q/ublECy3VPKbsi6I
/6Dqh5eDnu1//0/uYH7DqV9eDg+mP31kEg3mK0j99XJ4eG7rrcYZYP0HMv97
OVx/9385/xwtsPxORm8HzirxCauma4DlOVi8HRLDp3x3m6IO4idEsHk7mHuo
fRNVAvMVVnB4O+TuvVU/URHMb/jO5e2Q856rSWU6mM/gzuvtsExmngoroybY
vGn83g6TLfVvR1eB7Ut4Jujt8PiK1/dnrtpg95uKeDtwbCq/tmsxmJ/QKubt
kB+pG77lFJivcFXC2+Fc4+YjsZfA/AMq0t4O9Q9ML2lcgKgvkfV2ED/Mxv8C
wn9wWN7boZW31UPplrYDAOVKbBg=
           "]]}}}, {}}}}, {PlotRange -> {9, 18}, Frame -> True, FrameLabel -> {
       FormBox["\"Latitude\"", TraditionalForm], 
       FormBox["\"Wind speed 250 m\"", TraditionalForm]}, Axes -> False, 
     TextStyle -> {FontSize -> 14}, PlotRange -> {12, 17}, DisplayFunction -> 
     Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, DisplayFunction -> Identity,
      AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {53.90494606855307, 13.142675406412815`}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
      13.295545088613013`, 16.352938732616995`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=0\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=0.25\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 14:30 250 m adv=1\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0.25\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=1\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.813586035673252*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"II", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"XX", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415A", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"0.5", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"fitchrow1415A", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}]}], 
         "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"YY", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"0.5", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"fitchrow1415B", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}]}], 
         "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZZ", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"0.5", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"fitchrow1415C", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "II", ",", "5"}], "]"}], "]"}], "]"}]}]}], 
         "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{"53.9", "<", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gflightTKE", ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"TKEflights", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"XX", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Red", "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<Fitch 15:30 250 m adv=0\>\"", "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"YY", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<Fitch 15:30 250 m adv=0.25\>\"", "}"}]}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"ZZ", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Black", "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<Fitch 15:30 250 m adv=1\>\"", "}"}]}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2.2"}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Latitude\>\"", ",", "\"\<TKE 250 m\>\""}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"TextStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7891902184348288`*^9, 3.789190218853706*^9}, {
   3.789190354521365*^9, 3.7891903555585866`*^9}, {3.7891919135379505`*^9, 
   3.7891919286026235`*^9}, {3.789192102694022*^9, 3.789192102830656*^9}, {
   3.7891931103156977`*^9, 3.789193110438419*^9}, {3.7891931868530626`*^9, 
   3.7891931869517765`*^9}, {3.7891933535997567`*^9, 3.789193353986679*^9}, {
   3.789193752402523*^9, 3.789193752898196*^9}, {3.7893013566199837`*^9, 
   3.789301361039996*^9}, {3.7898155601554375`*^9, 3.78981556053452*^9}, {
   3.7898156534066005`*^9, 3.789815677624525*^9}, {3.7898160703340583`*^9, 
   3.7898160723383236`*^9}, {3.7898161565481367`*^9, 3.78981627451482*^9}, {
   3.789816304556006*^9, 3.7898163599157047`*^9}, {3.789816407893401*^9, 
   3.789816413787544*^9}, {3.789816464155415*^9, 3.7898165677030387`*^9}, {
   3.789834317865444*^9, 3.7898343192677846`*^9}, {3.78983435967904*^9, 
   3.789834369569143*^9}, {3.7898344233154125`*^9, 3.7898344252364054`*^9}, {
   3.7898344672856903`*^9, 3.7898344718288546`*^9}, {3.789875380982077*^9, 
   3.7898753819149866`*^9}, 3.7898755579673843`*^9, 3.7898757328596005`*^9, {
   3.789876062848647*^9, 3.789876103145445*^9}, {3.7898765882500696`*^9, 
   3.7898765891527185`*^9}, {3.7898847498074293`*^9, 3.789884764380109*^9}, {
   3.789884840838374*^9, 3.7898849132398434`*^9}, {3.789885105442763*^9, 
   3.789885179692976*^9}, {3.7898852429994097`*^9, 3.7898852434154987`*^9}, {
   3.7898853304730453`*^9, 3.7898853360541706`*^9}, {3.7898857602591467`*^9, 
   3.789885784007618*^9}, {3.7898858236510096`*^9, 3.789885872566098*^9}, {
   3.7898859152866297`*^9, 3.789886134909547*^9}, {3.789904951211275*^9, 
   3.78990496558702*^9}, {3.789905001319987*^9, 3.7899050085602703`*^9}, {
   3.7899050507272415`*^9, 3.7899051764161263`*^9}, {3.7899067790405135`*^9, 
   3.789906852602389*^9}, {3.7906731027037725`*^9, 3.790673113726987*^9}, {
   3.790673144535911*^9, 3.7906731779737296`*^9}, {3.806983801424115*^9, 
   3.8069838321876264`*^9}, {3.806983885899906*^9, 3.806983944503209*^9}, {
   3.8069841380138845`*^9, 3.8069841540983315`*^9}, {3.8069842380225277`*^9, 
   3.8069842559971757`*^9}, {3.8069842870086117`*^9, 
   3.8069843264060717`*^9}, {3.806984446080951*^9, 3.806984492075276*^9}, {
   3.8069847020195637`*^9, 3.8069848341261673`*^9}, {3.8069849228608093`*^9, 
   3.8069849274232764`*^9}, {3.8069849768938017`*^9, 
   3.8069849973952765`*^9}, {3.8069851334832597`*^9, 3.806985134180416*^9}, {
   3.8069852124133635`*^9, 3.806985219856459*^9}, {3.8069853023123455`*^9, 
   3.806985326931508*^9}, {3.813585344547123*^9, 3.813585358978232*^9}, {
   3.8135854362600765`*^9, 3.8135854637665157`*^9}, {3.8135858849711637`*^9, 
   3.8135858855582294`*^9}, {3.813586220848941*^9, 3.8135862273599806`*^9}, {
   3.8135873127042694`*^9, 3.8135873218818307`*^9}, {3.8135874126206923`*^9, 
   3.8135874164334135`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.806984984703637*^9, 3.8069849981811748`*^9}, 
   3.806985134849575*^9, 3.806985220909661*^9, {3.80698530326448*^9, 
   3.806985327641204*^9}, 3.812877634586985*^9, 3.813585360383913*^9, {
   3.8135854505158105`*^9, 3.8135854647842894`*^9}, 3.8135858867789493`*^9, 
   3.813586228158495*^9, {3.813587303376979*^9, 3.8135873225954037`*^9}, 
   3.813587419640398*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0GtMk3cYBfByaykIQxCqgEWg25hEJwQQEX2ebqGM9z8FHOpsIdABiRAv
jA3ciNNsUkVsVEYXYKxNndpWvMRWLo1SNi9QVCTYYiQmaAqWSYYWaqEI2O7d
h5OT38dzor85uKPUk8FgpND5vzmqHvERB4VlssWJrR5aENvMK3NmKeR+9Eh2
sv0GZLULXFFzFAZ+Pqy6xdNC/nX9wBvaw4NN6ahsg2dnXkK3k8I7ggaT/r0W
eGpuQd08hQtzD47OJ3WANKHaueMdhQbDACNQ2AWi7RPFkQsUXop5e3KAcxuO
yJ2+VtoS7TofS0UP9Kz2qLu6SGHr8myn4qwBcgqlqqolCt22qRPjL/uhr/TK
RPp7Ch01sfdUAYPAPv+LyMtF4ZpOQ32+aAiazAVd92mPJZpyq+Jew++BdwMa
3BT+/eapZ9prN9yoOZ6wh0Gw0hrVrMjxRF1opSrag+DWm5l/JGpcoGNsfjBJ
u42X8phndcIFybxe50nw+RlJWoxwFl58tSXzsBfBK1Q3Z5D1FoqM/PBMb4IF
/nk1P/Ad4Bgvkwf7ECxJuRjDKp4GtnjRPUr7Ycstu239KzDy145omASPjzxp
5v01DlLZaZ9KFsHUeIlpc8UkcFtdR9N8CX7yuLc1PXoGzBsjmr3YBMV9+qaQ
eDuYg35TPKJ9tbqoM6RxBlx8o7LFj6CPZZMiOdoKnb2l/L3+BNPCp6SzfhbQ
9cdkpy4jyAwji5bcUVjPTLX4BhBsqB2ScHPG4NCxg7+O0D5wCohKPA5eC8LT
6kCC/5SPXncuPYOSz7LcVR8QrA8OfeodOQAZhUoLP4jgbkd/6JT2IRzeUN/n
t5zee+6yPEttBGLbeGiI9oG4oPgtpk44zzHtkQUTdO0s8T72rh1il5GZr0MI
Gi/tXrUpQQ8sg/3jNSsIJt8XXNuV2AFB1Knif2krNd9G8BO0EBuWIb4ZSv89
+eHZn7lt0LIrTygNI+iRXTVsirsA0/KWsCIOQY1t+rmaoYLy1Ff7k1cS/InN
3FdgV4EoKYrvv4rgdpZvbW7xNeCQPrOF9l5e7b5tQg10WHequ8IJ/mid33Ai
9iIEpLjKpBEEv/TvLs/rl8ELZQMURhLUfZ80JrotA7fgu8JPVxOsq2Yx7exz
IG8XxC/RnmPnJTZuuwyDf2bk93IJflGmqKho1MF/haeGMg==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0H1Q03UcB/C1MZOHeJw4cLQ4XAS1kETBCD8fhAv9fSEIhGBxA4xEQ5KB
ijcK7gj4w+MEwQN0gtAYMONpMZVr4oWRJtoJMh62Iew6ngI0d2MjIqRff7zv
fa//3vf2PnY6/ksmg8E4QOf/Xjudy9e+SfBeY3he4NfNcE6mrefQFp64U2kj
qAOpbykr0YsgHvyqhWWrhDs3E+SXeQQ7g5dnrkX/ABnHLfnaXQQXZct2sbIO
0Dvk9HFou7Kqp6RHukAd9ykjyZPgwNavw6aoTsh+eO9anQfB/dKd7U8pJZTY
h05OcgnqF/rFv4w3QVv0ptKDtqTYOF3hfxVK+WXnRTsJfkZF9gbNNgHPSbtd
5k4wYH6yVhgsh78aJySGHQSLhgbPmoztkJ+a3bOLduCtKwOmCBWk2SZFpHII
ipokPu57bwE3vZjb4EaQlezbZeCoYb9wnTvtSnCUhE+lfdsLLkOHCZ+2YWPx
KrOxA/KFATfSXQiWyfkF3doOMPyk+rnZmeDG43WF88kucEtZqvrDiaAGqsyz
CRootZ9J9KE96itnirIGgHoYYP3CkeAQ3j7lGPg7VIz2vNPyBsEUfaWn69gz
MLJyts06ECSFHqEp9SuwpmlY9aH9/vC5cJvIFYhabJNn2hM8MXMp7KXRBFMi
VazCjuC+4Iy7Xt5LoJor4M3b0n/0+e6JO/MCzF2X5wS0NX6aYdbH88CWSwKP
byfIVPo53zQugSj63fuK1wnWsVtx7u0VsFqXO+e2EXyQt5E1L7MC98eRtN20
C8tae4ouWkCwGfXkGJvghZdcF26tGS54ZS422RBs3CvSrfktg3Hfd33TLILN
z/6s/O3uLISk5pbzaA/quGfaqhdA2C/8XMQk+PjB6vM9slnwf94vqX+NYPyB
g921LkvQJ072nWAQLHmSq83QWeDFW3Eyd9rJbEVs/DdWcFq5eCRpi0JudtUr
Q6oJgo6WR9a+olDPCW1XMCbgk27z/NgmhRmZgrMtJYPQcZLU7KDtv+mtF39w
HyIMHreP/kvhe6MMfUjQAOjEIyk1GxQ2XwoI7kIVnG9TV4/8Q6E5zKEozL4X
2FMzeU60sUqg9xSr4SMbTVHMOoX9fjc+TJT2QHVMlFvF3xS27ra1HOK1A1/F
CHm0RmH3ls+Wo1IB6YEdnna0x/VzqTGC72G8Xp112ErhQsOVBF1xE4y7Pj1V
bqHQm61oHQtrgULzo+uDq/S+GmlSQc51+A//555I
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAf52shWz0SkAdiwNXvYubP/SdzD81
9UpAOJ+vqVuwoD9VsK9S/vVKQGHbmfxGNZU//64ol8f2SkARQwRX7tSaP6fE
DUmR90pAwEZYHH0arD8E/hKAW/hKQODOKF3RnKg/hcvPGyf5SkAr0y/BR/Or
PxVAcZX1+UpAuF6UcAC9oz+wkVbpxvpKQIfWPu3zC60/wuiq7Jn7SkA/ACz1
TWKtP/4jECJt/EpAz3HqrDfRuD8/vbEsQP1KQI3o2KVdQ8I/o7Yb8xH+SkCU
sK9YR33IPwyH4c/i/kpA/6OB2cWJ1z+FFsdds/9KQJ4T9qrmmABAYwOd5oMA
S0CRIN6lXQAAQG6Fw3BTAUtAxsKKQvzA/j9YqDUvHwJLQEo8fwoT5fU/ZoSP
9ecCS0CTNAa7XFfvPyktTACvA0tAX2uDJJUB8T9lR6G4dwRLQETJ0rmWTew/
5GNT20IFS0CuSSwSnjDyP0WmkloQBktAt/ccv4Pw8D9a/z/33gZLQFZsPEfQ
dvY/dfA9ga0HS0DnlcpfQN71Px7r7jJ6CEtAVaRzjjKv9j/4xR40RQlLQN0c
uU7JM/Q/GkMmaQ8KS0AC70VwZqXwPzMKvQPbCktAm/x+m5Qa6D+FX0iZqAtL
QHTew5sDFug/WJD8V3cMS0DiyTodqWXiP216259GDUtAMEgG08gQ3T/RxccT
Fg5LQA+3SFuBX9U/iWmVQeUOS0B+Qi1VqHbPP55TW3G1D0tA92MuCvASvT/R
afIlhxBLQDFyJ7gcxrw/bxnoaloRS0A/H9CxYmzAP62zxG8tEktAyA9J+AFv
sj/OKNye/hJLQOIGLjgADbI/g7inTM0TS0CiLONz7UayP+hCW7mZFEtAN3oS
JMoLsj8ILjADZBVLQOH1OGqzPrI/12drlC0WS0A6Bu+cv82yP2X/neL2FktA
ym0U19x9rD9MD5TxwBdLQHy7u2MTPKs/jmaCWo0YS0BG0skbr+GnP7cvNThd
GUtAD60bh7hPnz9b0kcGMBpLQAmhrVK6NZk/cbdsAAUbS0AbDBebI1WbPyWn
sLnaG0tAYFShX59dpD9DyuWvsBxLQKP+ElZYoaQ/Truvx4YdS0BdyuO5/4ii
PwXwU3lbHktAdqh5V6PQqz+iTIFf
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzXlM03cYBvAW1tpyyFpxgFy2eEQ3j0xOB76vMJX8vkygY1pEK5dZWaZs
Hhg3lQSNGQqKqDALlloXK1hkHJ2ihMNJpYtjSBHbGSlVGYcgFCi0wHC//fHk
yeef5xGkZor2OTAYjDA6/3dD1fBVvR/BQtkyjseucrhjNyrcaYsulsqtV25D
/cr+jq98CYrnHecK6xQQHBkHxT4EgywHu9b6XIOcE9MPjd4E/TdoD6u//AWK
PYqSfGmLQ68K17kp4bqQcTJ5CUFWX2BcWo0CwttGOUovgsf8TsxuFyvhUFKL
8pUnweVRB2N1FiXIC48PCGmbhy789Lz8Orj/unco1YMgOatVz4Xcguq+pwHK
jwgGvplSdayshrCjFXvMi+n972NyXM7Uwrmoz1VLaTv59H2a2H0X/uxxZCW7
E1zhlDheMVgHhpsugYpFBLU55wvUzbVQNVHb1csnKIn5e3jCWAmSDIdGAe0D
DmypY4oahMfc8lN4BJ2NWT+SMxqQNdjOKz4kGKEz3caQBrCeOptociPYMCNb
cCSqGfSLduX70Z7uC3EeWNwEwldH0iQLCb7cUfCX/l031O/P3VbmSjAZ4pgs
hRGaL0t2mF0I+poGvUpOm+DylvKuZbSH0g2xC2V98FlbgMM3zgTtMz9Pjg2O
QTArMrLKiaAn17AmFy1wUsHNnuAS7N/IFSwftUCLrrckiHaye1SlW89bMAja
JVkcgobNr/esyLZAh7yM/dsCgrNaQ6e/bgwCBlu1Vjb9dyipojh2CmQpalsQ
7bytynu5EzbYJFy1PotFUKmTS5NipsGksbfVfUDw6+3Rt76Lt4JfxOo8iyPB
wdBzT54VDYH5n/Tf19AuWOrNPj4zCvKEH15mOBB05XRsWBX6FlTDTqk3mQTf
7c5W+R8dg5D50sevGQSjt3D/+PbOOIBI3CKgPdm0TblkZBziNRmM5PcUenIK
3vR/MQK7T8keXZunUFNY1qCP74aEGcaFF/9SOFng8eSBvBla82L3edEOlJp0
5voWiJRu3LlzjkLDPcu63oh6aOSRS1dmKeR1lt7PFClgL3eA0TVD4Y3g9OjZ
3iLoYYbW8Gl3YkJ/jc8lmI97xhTZKRxodz3szS2B/PenbRdtFAqpR+1MvRL4
4rBNndMUDq9Pu79aWg6Nja0ZfNovtmr4TZ/cgP0jHz8QTVE4Ohx+9/FDObBV
PEWhlUKthso8sLYaeHbv8KeTFD6PEohSpJXwHwfcp1I=
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAMyLH1Hz0SkD87BkWuaWkP9wYzjZP
9UpAOxYP6ty2qT911U1GIfZKQN4vZl2/Zqo/8i+QjfL2SkCKCHAVD46iP4pi
Ih3C90pANa7xTVZAlz8VJalYj/hKQP/nRk4Wtpg/mLN0IFv5SkA2L2lCJ4qN
P7XCmE4m+kpAnbakBg9ZiT+sHCWF8fpKQJxStUWqP5c/Ee29C737SkC3ARgI
EdudP4n2orGJ/EpAaNO3eGGfsT+3mFtBWP1KQPMks3Oj4bY/SDC6/Sj+SkBe
xg+6UtiwP3vT3Tz8/kpABGcPyDDPxz90PlI80f9KQKuXb+rqOvE/cjtS06cA
S0Byn6Ad5M4DQOqLZpx+AUtA2H1xeYH1BECyzVk9VAJLQBc5jxgDRwFADIuq
DCgDS0ASwtWrkZHyP3GTHZL6A0tA4ztmDNBV9T/EhElazARLQOsNYitMQPU/
JSiHJ54FS0DsCG34zaH/P8CXEoFwBktAApxLRJny+j87Dln1RAdLQC96XJoP
DPs/zlV5VhsIS0AJvjnR6mDyP0fwMj7zCEtAbRVd22Ov7z9JeakVywlLQL3k
uTYOW/M/Mym+oaEKS0DM3JWEX7LwP+OlXQ93C0tAov8Tl8m+7T9+yH6nSwxL
QG5DkCGVTuE/pEwpUSANS0CQldUYcCPRPxakWaj0DUtALLQbkPoJuz/kAKNh
yA5LQDPhh5/IxKo/dGLhP5wPS0Bj5CJv0VuuPzYrmklxEEtAl52uWvnxrT9F
+BFXRhFLQNxfHzgHhLM/M73cABoSS0A2+cKYdt6xPxlgnavrEktAYxPlryGP
rj8JOOYNvBNLQI9+j/6ZYqE/yPAtlowUS0BQFuZFFRGhP7AhKeRcFUtAc7zJ
iGwUpz+bP6FOLRZLQHQpd113zqg/zujpw/4WS0Dk2nR6N4GnP7gGypjRF0tA
EsmPuAjqpj+CCzPVpRhLQOwXa4Ad4KA/KQGxznoZS0AArw7lG0udP1FlyXJQ
GktAzaxlKH5fmD+L0j7RJhtLQGbSnUTRdJE/eQiprv0bS0BpIhQh03yRP3Vc
sFjUHEtAAcbp/MkolD+ifiY6qh1LQLtooFSCgJY/so3eeX4eS0AeJ8eDbOGj
P6h9c70=
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.016666666666666666`], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0WtU03UYB3CYAwM0oNhEHIgZBBJOLkHQgedRHMX/1xHk5lyAXBJHsIwC
ySORFwLCZCEt5tCaMuaARBQKLyC38pitAwcP2OTiYZ1xuDmR60A2+vfiOd/z
efU85/tsSz0afZhhZmYWTM//+SQk6Fi/C8HQ/o2FYmE1CN4X17JpF6jzjU15
CviuzCOM70ywhNcxfDBJDkbe51UyDkFD9srE30FVcCrAM3l4C8ETDtwmql4K
D5KebXWlXTfbPKcuLQf7gIT4VCeC0mFLAxVZAYyzrV6KzQT/OguLVWVVwOEb
0sYcCSaEh+j0fDnEKX509qT9lvpi1JFBBQim/GOzNhHcWqRi8vtUcG2w/9B1
NsF3m9Rh7ksqYIUZRl+wCD7u/jIi6uUV2GtYYPrT7t4cOysZqIdtjwg55kDQ
mf91Y/66e5CJkt23Xyc45XWx3H2sGxq5n+xYfY1gfsvbHWG2XdArzFWH0ubu
5KWxSzvge9N04Sl7giPXCqLIzTZInPlM221HcGd6vN0HPr/BP/pOoyXt7VOG
PE3ldVh0FAVRtgQPXtJZiXT3IW3+pO7cqwSj0uW+x+segfUAZ3vfRrqv++f8
I4c04O0pmGXTlnBSs1tch6AwfGQpYQPB/p/qjM28QZCVHddfsSEYmJsceSFT
C4PTvaJxa4K3IkIOXOX+Cw+/qQjxpi0saU/aZDENLMmaONuKIIfjVbF3cgIa
kiXi5lfofR+e/ygsQw87KrMOL60n2NfuGO3L0wPWPrULps0dOT3Zs2cOvGKs
BvItCS6Uul7uUS4Ay1u+vt2CYItGdGs0aBb2tTaeMKOdU1Nyl/nODFiY7Ev2
MAkG/HHV52jTFNR5FKwUrqP/u9/pDX+3MdAyUzweMAjmejcknvSZhPN3ovg2
tHUvZKLe2wbomb3xfJ85fc9EsfIJ1wQ3Mk27KswI+v4aGrFsswa/55jaHq9R
mDm6yPi56zmg/d2MLbSF3CIRI74HWu8ZVxNNFGqSVlPK+Eq4xDHfLzdSmD9U
/IXyKxl8rEk3aFcpHF7rPyN3E0N6mynDjbZWpuvqzPkB3GNirY+8pLDmwJsu
ln5y8K0L3q1aodAzOuu9P1kX4Gbct63jyxT23BELpE+rQWf37KEHbUHogFNf
cg1oXUYPCQ0UOkTvwgbZZTgtnflUtURhlXlR+3y2DPJY+Mv4IoWrXGZxfXgl
BEg61R6041LCq9VsKQT6xccIFyicK3S2LfdTwrKewVbNU7jBPXCqNlMB/wHO
lat0
           "]]}}}, {}}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5gGj2zJX2QKpB+xuEn8q5CsR/UPUDzF+w
6tBqsPypXxD5yr8bQHwFqb8QeV2rTSD+gcz/YP4BqZOfwPI7Gb1BfAeD2Z/B
8hwsYH7DG6snIH5CBBuYf4A94A1Y/QoOiLyC9newfd+5wPyEYwVfQXwGd14w
f8HrzZfA5k3jh/BjHc+AzXsmCDHPaDmY/8BUBMxXiJp2FizfKgYx71olWF7h
qgREPrPyNNg8FWmIvHYexLwSWYi8QMs5sHmH5SH+OXHnvD0ACMZVYw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[Large]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5AKkHHALL7IF0g/Y3MD+hx2gjiP+g6geE
v6x4M1j+1C8wn2GhIpivIPUXIv9uy2EQ/0Dmf4j8dua7YPmdjN5g/sbDz8Hy
HCxgvkK/90sQPyGCDcxfcLr+FVj9Cg4wv2Htgzdg+75zgfkHlt55DeIzuPNC
+B9zHoPNm8YPUb/g9FWwec8EIeZfVTwPdr+pCITPm3QWLN8qBrEvTgTMV7gq
AeFv0z0DNk9FGsxPuLrwNFh9iSzE/BoWsPyDw/IQ+5vEztoDANXgV/M=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQJ3Pns5AKkDIXHL7YF0g/Y3MJ/BXmsjiP+g6geE
z/x9A1j+1C8wf8HkX2C+gtRfMD/hO/9lEP9A5n8w/8G59tdg+Z2M3mD1CVyf
wPIcLGD+gXfZH0D8hAg2CF9k60ew+hUcYL5Dr9VXsH3fucB8hvWGYD6DOy+Y
3yDw7xXYvGn8YP6D6Mc3wOY9E4Toz7l6Cux+UxGI/bs4j4PlW8Ug8nvuHQPb
d1UCzFf4mgnmH1CRhvCLhcD8hBJZMD8hhw2s/8FheYh9i7tO2gMAgNVYlQ==

          "]]}}}, {}}}, {PlotRange -> {0, 2.2}, Frame -> True, FrameLabel -> {
       FormBox["\"Latitude\"", TraditionalForm], 
       FormBox["\"TKE 250 m\"", TraditionalForm]}, Axes -> False, 
     TextStyle -> {FontSize -> 14}, PlotRange -> {0, 2.2}, DisplayFunction -> 
     Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {53.90494606855307, 0}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
       0, 2.2893649945005388`}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {53.90494606855307, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{53.9101068669226, 54.24039796257203}, {
       0, 2.2893649945005388`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=0.25\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch 15:30 250 m adv=1\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8069849847854166`*^9, 3.80698499825998*^9}, 
   3.806985134927368*^9, 3.806985220953525*^9, {3.8069853033432927`*^9, 
   3.8069853277180367`*^9}, 3.8128776346474752`*^9, 3.813585360456723*^9, {
   3.8135854506324973`*^9, 3.813585464902032*^9}, 3.81358588691967*^9, 
   3.813586228275673*^9, {3.813587303489685*^9, 3.8135873227111435`*^9}, 
   3.8135874197521286`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EWPfcp1ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp1", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp2ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp2", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp3ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp3", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp4ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp4", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp5ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp5", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp6ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp6", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp7ToPlot", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"EWPfcp7", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8057168368008394`*^9, 3.8057169105307446`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gUprofileModel", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp1ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<1\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp2ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<2\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp3ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<3\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp4ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<4\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp5ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "5", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<5\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp6ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "6", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<6\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp7ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "7", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<7\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"7", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "600"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Wind speed m/s\>\"", ",", "\"\<z m\>\""}], "}"}]}], ",", 
    RowBox[{"TextStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789985315171012*^9, 3.7899853373412533`*^9}, {
   3.7899854180211782`*^9, 3.789985597783063*^9}, {3.7899858265916567`*^9, 
   3.7899858638012743`*^9}, {3.7899859400539503`*^9, 3.78998606179175*^9}, {
   3.789986115371974*^9, 3.7899861711118827`*^9}, {3.78998620856155*^9, 
   3.7899862089416265`*^9}, {3.7899863103949823`*^9, 
   3.7899863172878323`*^9}, {3.7899867186227903`*^9, 3.789986762469351*^9}, {
   3.7899867987594585`*^9, 3.7899868918789945`*^9}, {3.7899902532614017`*^9, 
   3.7899902565512056`*^9}, {3.790762828707341*^9, 3.790762836339243*^9}, {
   3.8057169259456244`*^9, 3.8057170192848268`*^9}, 3.80577521961904*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.790762837578288*^9, 3.8057170201455903`*^9, 
  3.8057752208202963`*^9, 3.805775444319452*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAyv8LWJpTIkCpmFud4csNQAG8HHBN
QyVARaE+0MZ1JkDsSFe53RYmQKzCvhF02jJAC1h69nHBJkB1w0e55po6QN+F
qQubhydAzCrsG6M/QUDcu+lpkf4nQE+Q+0yHRUVAv0YbiQmLKECQeGrIKGFJ
QDGL4vwGFilAdEBljKqUTUAIxSFKfGopQEatyIMX8VBAQJu4L7PoKUCIp4YM
HiZTQJ8s0kVrLipAgE37ycxqVUBwssUMGZsqQNBg2UOgwFdAmMI2BhkGK0DC
uExyRilaQMDI1znPZytAkpZDiZamXEDqckDxG7MrQMoeYmiIOl9ASnRy0fsr
LEBC+r2IovNgQPkMGQphZCxACGBQnJdXYkB1MD4MH+UsQBYI3W1xymNAwYrb
NzoeLUCSnAjjok1lQPdOHY8VdS1AcqszUrviZkD/Qnaa3PItQDodUBlzi2hA
S63/AOciLkBbnZGKr0lqQCWafCwtQy5Awr4RzIYfbEC8v1X403QuQL4LB9E7
D25A6ougkp51LkBGpwMqpQ1wQNl+N63ITi5AWPzVnDkjcUAUOFG6Lh8uQB5W
3vzXSXJAN8eAS1ziLUC0nyyBI4NzQH5pw8dPqS1Aas7F4unQdEDsHKDeMXot
QCWwaT8lNXZAR2uHniE5LUBudUYqArJ3QG/vsOLR9SxArlEr8uBJeUDVT8Ac
u7csQMseYmhU/3pA3LXdj4dpLECNWpEHN9V8QDCBoog79itAqqTlUK7OfkCU
dKaMSUgrQEpUScuXd4BAiH/I/9GYKkCQhPR7R52BQCIWiDzXnClAPL4LB3/a
gkCE7mGqiNYoQKA4CwGYMYRAg88Shw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAd2YeQ5TvHkCpmFud4csNQAVAJsPE
8CFARaE+0MZ1JkC4vGFQ76EiQKzCvhF02jJAPLvC/5U4I0B1w0e55po6QDZr
tsSc5yNAzCrsG6M/QUAHyUVsjoMkQE+Q+0yHRUVAovppdhvgJECQeGrIKGFJ
QJzu1sYUayVAdEBljKqUTUDRtJNuV+UlQEatyIMX8VBAclGdFXJnJkCIp4YM
HiZTQMuuS1n25yZAgE37ycxqVUBc4RcOky0nQNBg2UOgwFdAEvT1cNm2J0DC
uExyRilaQLG2VPfC+idAkpZDiZamXECCwdXQmoEoQMoeYmiIOl9Ay/xmEW7B
KEBC+r2IovNgQApc49k2QSlACGBQnJdXYkBZZXfUgngpQBYI3W1xymNASMkZ
U3v1KUCSnAjjok1lQE3UQP5WOipAcqszUrviZkBm2+fvhXwqQDodUBlzi2hA
wA5PFvntKkBbnZGKr0lqQL80OCjqHCtAwr4RzIYfbECHT1XDvoorQL4LB9E7
D25AOKIX/um3K0BGpwMqpQ1wQBklFURXHyxAWPzVnDkjcUCDICQHMUAsQB5W
3vzXSXJAgJH4PCiDLEC0nyyBI4NzQDV9KXS6oSxAas7F4unQdEC0y6MkRK0s
QCWwaT8lNXZAjEjj5ZaLLEBudUYqArJ3QPpYUXbOIixArlEr8uBJeUCwpiYS
iuQrQMseYmhU/3pAw9u37zhUK0CNWpEHN9V8QFuU5LwXHCtAqqTlUK7OfkC/
t3jumQsrQEpUScuXd4BAu8GcmxDxKkCQhPR7R52BQH2NabT5eSpAPL4LB3/a
gkDAylu4tocpQKA4CwGYMYRAHI4Yug==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.6, 0.4, 0.2], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAj+J1x70nHkCpmFud4csNQKDjbrI/
sSFARaE+0MZ1JkCwHekTb10iQKzCvhF02jJAnIjMHMDuIkB1w0e55po6QKoG
gaPotiNAzCrsG6M/QUC0n66+WR4kQE+Q+0yHRUVASgihDyjKJECQeGrIKGFJ
QEq3fF2WHSVAdEBljKqUTUBjbEmuILglQEatyIMX8VBAqYQ4HTIpJkCIp4YM
HiZTQPZqqE/tiyZAgE37ycxqVUBQ52HhmxEnQNBg2UOgwFdAX9NlMBmHJ0DC
uExyRilaQPUabtG3xCdAkpZDiZamXECGuDyt10ooQMoeYmiIOl9AgeRa1oF6
KEBC+r2IovNgQL2n2W3h4ShACGBQnJdXYkD0lda4RBcpQBYI3W1xymNAp2vV
ELBsKUCSnAjjok1lQALXseBGvilAcqszUrviZkAfh7Bfv+YpQDodUBlzi2hA
wdEa1n5HKkBbnZGKr0lqQAa2gKAloSpAwr4RzIYfbECavHbzqwMrQL4LB9E7
D25Ask6RwaNtK0BGpwMqpQ1wQOJFCErN3StAWPzVnDkjcUBiRn8bg1YsQB5W
3vzXSXJA4h3HQ2TWLEC0nyyBI4NzQBNMFlr3WS1Aas7F4unQdEDADPAistst
QCWwaT8lNXZAx63GrZJFLkBudUYqArJ3QGucto4bdS5ArlEr8uBJeUBqGCyJ
dkUuQMseYmhU/3pA7q/BtL/KLUCNWpEHN9V8QJ0wKpWmPC1AqqTlUK7OfkD8
QBaUslcsQEpUScuXd4BAMKboiZYdK0CQhPR7R52BQPnP9MLUVilAPL4LB3/a
gkBmWp5BVz0oQKA4CwGYMYRAxNQWnQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAjZmEsqfkHkCpmFud4csNQLC22bnm
DCJARaE+0MZ1JkAn3k06frsiQKzCvhF02jJAv1Q9/TOMI0B1w0e55po6QHfH
E0zcBSRAzCrsG6M/QUA7o0DgvKwkQE+Q+0yHRUVA/28HiYJWJUCQeGrIKGFJ
QM6KR9hhqCVAdEBljKqUTUDlqVx+70EmQEatyIMX8VBAFejmNvvCJkCIp4YM
HiZTQEcffbSjMCdAgE37ycxqVUATY4T5rsonQNBg2UOgwFdAjpCujFQTKEDC
uExyRilaQBB4zOd8oChAkpZDiZamXEAN7Xx1DDEpQMoeYmiIOl9A1UBXoOFq
KUBC+r2IovNgQJSn3wgc8ilACGBQnJdXYkA88lGK1R8qQBYI3W1xymNAnruw
HpaMKkCSnAjjok1lQD4/QfFx9ipAcqszUrviZkC5zSBaYCIrQDodUBlzi2hA
IiRr/YSFK0BbnZGKr0lqQH0zVp5HuitAwr4RzIYfbECXmZEFkhgsQL4LB9E7
D25Ayzw4KDR9LEBGpwMqpQ1wQATzJwnfxCxAWPzVnDkjcUCoNWaJGjMtQB5W
3vzXSXJAXxGZ2rypLUC0nyyBI4NzQOT7lE9t5C1Aas7F4unQdEB8p6dFDlMu
QCWwaT8lNXZACzzrW36kLkBudUYqArJ3QFmtUg80yC5ArlEr8uBJeUDz+zhY
Uq8uQMseYmhU/3pAZrLelW5MLkCNWpEHN9V8QF+iA7L0sC1AqqTlUK7OfkBN
p8JYF9IsQEpUScuXd4BA7N/ih5IOLECQhPR7R52BQHSzTyDV/ypAPL4LB3/a
gkDi97WqscQpQKA4CwGYMYRAnU4VOA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA3Fr2VKWjIECpmFud4csNQH5iTKNJ
VCNARaE+0MZ1JkBzkgAfoxIkQKzCvhF02jJA8XocylCwJEB1w0e55po6QIW2
X0DcWCVAzCrsG6M/QUBIPzRxbfYlQE+Q+0yHRUVAu+pq+Y1UJkCQeGrIKGFJ
QJdWvP4s1iZAdEBljKqUTUDA1emrflsnQEatyIMX8VBAounbz9OjJ0CIp4YM
HiZTQPX1SYMYGyhAgE37ycxqVUB4vrzWIpQoQNBg2UOgwFdANFRHPojvKEDC
uExyRilaQFiSUM2SQSlAkpZDiZamXEBGcW371LYpQMoeYmiIOl9AamBBpPY3
KkBC+r2IovNgQLJ2aJo9bipACGBQnJdXYkAl+EJWxd8qQBYI3W1xymNA0GHl
4pJXK0CSnAjjok1lQHXcC2VgyytAcqszUrviZkAv8CdE+EgsQDodUBlzi2hA
hhvZlrp6LEBbnZGKr0lqQNlhlfSE+yxAwr4RzIYfbECUqDtHayUtQL4LB9E7
D25ABxEYemylLUBGpwMqpQ1wQA0XJZvryC1AWPzVnDkjcUC78GBUBS0uQB5W
3vzXSXJAgtD+2sFBLkC0nyyBI4NzQLkOA4stcS5Aas7F4unQdEBFkoW3QI8u
QCWwaT8lNXZAOloA6aSSLkBudUYqArJ3QKlzk3dBii5ArlEr8uBJeUC3d+fJ
FIEuQMseYmhU/3pARldZ0JE/LkCNWpEHN9V8QM+u8Kl+3C1AqqTlUK7OfkBV
vvkflVktQEpUScuXd4BA8EuvBMLDLECQhPR7R52BQKjFu67I6CtAPL4LB3/a
gkD4E9xqVYkqQKA4CwGYMYRABTIYUA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAnw+tDewDIECpmFud4csNQKdcerlL
5iJARaE+0MZ1JkAV/5MZ3aAjQKzCvhF02jJAMLfgVa4/JEB1w0e55po6QFYC
D4sJDCVAzCrsG6M/QUDCg8adNX4lQE+Q+0yHRUVArRREejolJkCQeGrIKGFJ
QOBt8eEUkiZAdEBljKqUTUAcOanubCEnQEatyIMX8VBAIZ9EBDV+J0CIp4YM
HiZTQHFUUnM5CChAgE37ycxqVUCdY4rqg34oQNBg2UOgwFdAXwxcoOkPKUDC
uExyRilaQGtsj3GXUSlAkpZDiZamXECB7pDJjugpQMoeYmiIOl9ArKYlh6c6
KkBC+r2IovNgQOXkGzj41CpACGBQnJdXYkAOTMJLiwsrQBYI3W1xymNA+Cys
2vqWK0CSnAjjok1lQGAvP/MpGixAcqszUrviZkABkAd1tE4sQDodUBlzi2hA
tazCQPfELEBbnZGKr0lqQJjYm9cwOS1Awr4RzIYfbEA2vjG/BmYtQL4LB9E7
D25A0gVmG4bULUBGpwMqpQ1wQC1p0xpjNy5AWPzVnDkjcUAcR08qEJguQB5W
3vzXSXJAJDubbKTGLkC0nyyBI4NzQKNU+VWjES9Aas7F4unQdEAuPF6UOhwv
QCWwaT8lNXZAngVNnTcDL0BudUYqArJ3QMHOKkV9vS5ArlEr8uBJeUB+IIZg
JEEuQMseYmhU/3pAHCyiz4GiLUCNWpEHN9V8QC0ptONFrixAqqTlUK7OfkD8
2wP+4eUrQEpUScuXd4BAZoO1a7OIKkCQhPR7R52BQORyY6TAWilAPL4LB3/a
gkDWpPTIkpYoQKA4CwGYMYRAQkkKuQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 1, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAsuWxRBt7GECpmFud4csNQJwRZ0yM
Xx1ARaE+0MZ1JkDQL/qR35EeQKzCvhF02jJAYQ33Coy+H0B1w0e55po6QNzQ
s53ylyBAzCrsG6M/QUBKxu4jIjYhQE+Q+0yHRUVAKLmTvcfCIUCQeGrIKGFJ
QPzQhDXaXyJAdEBljKqUTUDvkcukc64iQEatyIMX8VBAGf9dBUlBI0CIp4YM
HiZTQOv0K5ia0iNAgE37ycxqVUD8a1hIJRYkQNBg2UOgwFdAjpFa9eyeJEDC
uExyRilaQJ0dD2w4KyVAkpZDiZamXECrOzi3jW0lQMoeYmiIOl9ALqZIh9n0
JUBC+r2IovNgQK4b6Aw8ciZACGBQnJdXYkBr1jsch9AmQBYI3W1xymNAql5V
dgBdJ0CSnAjjok1lQOKd36bIlydAcqszUrviZkBTVV8PfSAoQDodUBlzi2hA
gqTSQ9GrKEBbnZGKr0lqQGEyQVEm6ShAwr4RzIYfbEC+AZuwt24pQL4LB9E7
D25AwZkO+wPtKUBGpwMqpQ1wQD4sX6JgbipAWPzVnDkjcUDdPpkVjAArQB5W
3vzXSXJAyJYuiPw8K0C0nyyBI4NzQMy6xSmg0StAas7F4unQdECGI3HiF2Us
QCWwaT8lNXZAAmltBgWVLEBudUYqArJ3QD8fyCSs+ixArlEr8uBJeUDAn6Hd
m0QtQMseYmhU/3pAgQzPGFpZLUCNWpEHN9V8QPI1KYKoOy1AqqTlUK7OfkCS
sPFbVAEtQEpUScuXd4BA4Jjhw2eNLECQhPR7R52BQE4DI9In1CtAPL4LB3/a
gkC3/HkLX/AqQKA4CwGYMYRAFNcRMg==
          "]]}}}, {}}}, {
    AspectRatio -> 1.2, PlotRange -> {{7, 16}, {0, 600}}, Frame -> True, 
     FrameLabel -> {
       FormBox["\"Wind speed m/s\"", TraditionalForm], 
       FormBox["\"z m\"", TraditionalForm]}, TextStyle -> {FontSize -> 14}, 
     Axes -> False, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {9.0684988239871, 0}, 
     PlotRange -> {{9.16328692575907, 15.229725439165083`}, {
       0, 646.199220740953}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {9.0684988239871, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{9.16328692575907, 15.229725439165083`}, {
       0, 646.199220740953}}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"1\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0.5]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"2\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"3\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.6, 0.4, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0.6, 0.4, 0.2]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.6, 0.4, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.6, 0.4, 0.2], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"4\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"5\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"6\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"7\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.790762837693405*^9, 3.805717020205472*^9, 
  3.8057752209483724`*^9, 3.805775444448167*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"III", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp1ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp1", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp2ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp2", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp3ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp3", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp4ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp4", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp5ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp5", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp6ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp6", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWPfcp7ToPlot", "=", 
   RowBox[{"0.5", " ", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"EWPfcp7", "[", 
        RowBox[{"[", "III", "]"}], "]"}], ",", "39"}], "]"}], "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8057168368008394`*^9, 3.8057169105307446`*^9}, {
  3.805775267940384*^9, 3.8057752985838895`*^9}, {3.805775361146657*^9, 
  3.8057753820220113`*^9}, {3.8072576548502626`*^9, 3.8072576564975615`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gTKEprofileModel", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp1ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<1\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp2ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<2\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp3ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<3\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp4ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<4\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp5ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "5", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<5\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp6ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "6", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<6\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"EWPfcp7ToPlot", ",", 
         RowBox[{"z", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yanse", "[", 
          RowBox[{"[", "7", "]"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", "\"\<7\>\"", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0.6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "600"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<TKE\>\"", ",", "\"\<z m\>\""}], "}"}]}], ",", 
    RowBox[{"TextStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontSize", "\[Rule]", "14"}], "}"}]}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789985315171012*^9, 3.7899853373412533`*^9}, {
   3.7899854180211782`*^9, 3.789985597783063*^9}, {3.7899858265916567`*^9, 
   3.7899858638012743`*^9}, {3.7899859400539503`*^9, 3.78998606179175*^9}, {
   3.789986115371974*^9, 3.7899861711118827`*^9}, {3.78998620856155*^9, 
   3.7899862089416265`*^9}, {3.7899863103949823`*^9, 
   3.7899863172878323`*^9}, {3.7899867186227903`*^9, 3.789986762469351*^9}, {
   3.7899867987594585`*^9, 3.7899868918789945`*^9}, {3.7899902532614017`*^9, 
   3.7899902565512056`*^9}, {3.790762828707341*^9, 3.790762836339243*^9}, {
   3.8057169259456244`*^9, 3.8057170192848268`*^9}, 3.80577521961904*^9, {
   3.805775308558014*^9, 3.805775317975804*^9}, {3.8057753964462366`*^9, 
   3.805775403470197*^9}, {3.805775451648574*^9, 3.805775453426667*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.8057753188074613`*^9, {3.805775386027062*^9, 3.80577540430529*^9}, {
   3.805775454555619*^9, 3.805775459898882*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQHDq14YL9yRvTch6d5HYD8BTLtD+1dF9pdOFaq
BuI7/Mh8YL/m0D7BkltGIH5D+eP79qWH3Xc+m2UFluc9es/+jNYb6cX2jiD+
A8nbd+39J/z2aXd1BfEVZC/fsZ9QkXVCI9ETrD665LZ9iUNqz6opviD+AYbe
W/Zua080i38MAJv/XOOmfcfyNh45tWAw3zbmhn2D7++TZ7JCwfxCo+v2FxJu
Oi84EA7iJzDdvmp/aIdPkZtmFNg+kcgr9pOmOXdOWxYD4jP88Lxsf0ouKaPD
Kh7M70q7aO/0a2/Hos8JYPN8Oi/YcyQEzJkengQ27+6XM/ZiHHdzC08lg9Vf
XXbKftIcjseLfFPB8uscj9sXrTYO2v0oDRxeG2YftreSDZAs7s4Am9dbuN8+
eu7ErvWeWWD9u5P22AOD70ybfA6Y/zVim/0+bvaL1vx54PDq4tlq77acWWsp
bwFYfpvaFvuIP1fnWCoXguVtD262lwu79+e6ZxHYf7y7N9tvma/TqNxcDA4/
Ua3N9lnnjj56eaEELP9SZ7O96oZMe1XTMrB7zitssc8rddNi2lQO5r+ZudV+
XaD2pweelWC+RN52+9PA8An5XwX2j0PeLvveqIns5ldrwHwXt/32q5Y8DVh3
rg7Mn8l9xN4rxPP09PIGcHgcCDluP6HlS7X73Eawe0MijtjbAD1Yf6sJ7B4p
n832Cyy4GWcYtjgAAGO36RU=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQL5v+6ar9yRvTch6d5HYD8hsq46/auC+0uHCtV
A/EVLnNfs19zaJ9gyS0jEJ/hwp6r9qWH3Xc+m2UFltduvGp/RuuN9GJ7R7C8
4acr9v4Tfvu0u7qC5cvWX7GfUJF1QiPREyx/r+CKfYlDas+qKb4g/oFpjFfs
3daeaBb/GADiOxRGXrbvWN7GI6cWDObPiblk3+D7++SZrFAQf8G82xftLyTc
dF5wIBys/86DC/aHdvgUuWlGgc3/GnnBftI0585py2LA/ITJ5+xPySVldFjF
g/li5WftnX7t7Vj0OQGs/7LFaXuOhIA508OTwP4XNj1lL8ZxN7fwVDLYfrmf
x+0nzeF4vMg3FczftvuYfdFq46Ddj9LA+vWjj9pbyQZIFndngPWrvj1kHz13
Ytd6zyywe9e9PmgPDL4zbfI5YPunl+2338fNftGaPw/Ef7B76V57t+XMWkt5
C8DqTVfvtI/4c3WOpXIhWP2C3h32cmH3/lz3LIKET/Z2+y3zdRqVm4vB4Vuo
uNk+69zRRy8vlIDV503fYK+6IdNe1bQMbN787A32eaVuWkybykH8hHOGG+zX
BWp/euBZCXa/2s4N9qeB4RPyvwpsfuf7Dfa9URPZza/WgNUzWq+1X7XkacC6
c3Vg/03/udbeK8Tz9PTyBrB9j/k22E9o+VLtPrcRrH7XqbX2NkAP1t9qAvOr
GzfaL7DgZpxh2OIAAMh46nA=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.6, 0.4, 0.2], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQJ06Wv2K+cET334WleByC/wVX8qr3rQrsLx0rV
QHyHYuvL9msO7RMsuWUE4i9grL1kX3rYfeezWVYgPsOSrIv2Z7TeSC+2dwTL
Gx66YO8/4bdPu6srWD7Z8rz9hIqsExqJnmDzFf+ctS9xSO1ZNcUXzHc4cdre
be2JZvGPASD+A/0/J+07lrfxyKkFg83jtTxh3+D7++SZrFCwe66vPWp/IeGm
84ID4SD+gW/7Dtkf2uFT5KYZBeZvKD1oP2mac+e0ZTFg9cey9tqfkkvK6LCK
B5tfI7Xb3unX3o5FnxNA/IRzjjvsORIC5kwPTwKr93y31V6M425u4alksP3l
3lvsJ83heLzINxWs//eLTfZFq42Ddj9KA9vX8HWTvZVsgGRxdwZYv9TfzfbR
cyd2rffMAssHc261BwbfmTb5HLB/leu22e/jZr9ozZ8HDh99ye32bsuZtZby
FoD4CvP8t9tH/Lk6x1K5EGzfUvPt9nJh9/5c9ywC8zU3bLPfMl+nUbm5GOy+
P71b7bPOHX308kIJWD5g0WZ71Q2Z9qqmZWD71+httM8rddNi2lQOln+xcq39
ukDtTw88K8H+l16y0v40MHxC/leB7deTWmbfGzWR3fxqDdi9RxoX269a8jRg
3bk6ML9FeqG9V4jn6enlDWD9gtPn2k9o+VLtPrcRbN/al9PtbYAerL/VBHYf
P8dU+wUW3IwzDFscAJ0s6xM=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQKzoFX7VfOiJ778DSvA5B/4Mema/auC+0uHCtV
A/ETvtldtV9zaJ9gyS0jsHy9/RX70sPuO5/NsgLxGR7sv2x/RuuN9GJ7RxD/
gbLjZXv/Cb992l1dQXyH/9mX7CdUZJ3QSPQE6699d9G+xCG1Z9UUXxB/QZHe
RXu3tSeaxT8GgNX/mHTBvmN5G4+cWjBYvcaV8/YNvr9PnskKBfNFZ521v5Bw
03nBgXCwfcHbz9gf2uFT5KYZBeI3/M87bT9pmnPntGUxYPPkjpywPyWXlNFh
FQ/mF184bu/0a2/Hos8JYPV/fxy150gImDM9PAns37b0o/ZiHHdzC08lg+17
/f+I/aQ5HI8X+aaC9T/PPmxftNo4aPejNLD7bzAftreSDZAs7s4Aq7f5fsg+
eu7ErvWeWWD5dfsP2QOD70ybfA6Ir+Dbdch+Hzf7RWv+PLD6p3sP2rstZ9Za
ylsAtr/X5aB9xJ+rcyyVC8Hhe+fiAXu5sHt/rnsWgf17Rm2f/Zb5Oo3KzcVg
90zZvcc+69zRRy8vlID1a7/bba+6IdNe1bQMbB8z2y77vFI3LaZN5WD+w7Yd
9usCtT898KwE86V2b7M/DQyfkP9VYP3mF7bY90ZNZDe/WgOWj9fdZL9qydOA
defqwPJRyqvtvUI8T08vbwC756/mQvsJLV+q3ec2gtULT59qbwP0YP2tJnD4
3oyYYL/AgptxhmGLAwDmGfAh
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQKPMdu2q+cET334WleByA/YYLMbXvXhXYXjpWq
gfgLRO1u2q85tE+w5JYRWL6g/oZ96WH3nc9mWYH4Dpm3r9uf0XojvdjeEaxe
+/U1e/8Jv33aXV1BfAWH+Gv2EyqyTmgkeoLlu/dftS9xSO1ZNcUXrN/iwhV7
t7UnmsU/BoD4DJ0BV+w7lrfxyKkFg+X7lly2b/D9ffJMViiI/yBvxSX7Cwk3
nRccCAebv+PfRftDO3yK3DSjwPIVwRftJ01z7py2LAbsXoOCC/an5JIyOqzi
QfwD7G3n7J1+7e1Y9DkBrH5r6ll7joSAOdPDk0D8BpOrp+3FOO7mFp5KBqtv
lDxlP2kOx+NFvqlgvtD34/ZFq42Ddj9KA/P5Nh6xt5INkCzuzgC7x7rusH30
3Ild6z2zwPzwlwfsgcF3pk0+B2x+Bs8B+33c7Bet+fPA+hfY7LF3W86stZS3
AMxX+7HLPuLP1TmWyoVg9S3dO+zlwu79ue5ZBJavObHdfst8nUbl5mKw/1w/
b7PPOnf00csLJWD7HM222atuyLRXNS0D82P/brfPK3XTYtpUDg7/S7822a8L
1P70wLMSLH/l3Fr708DwCflfBQ6Pf0eW2fdGTWQ3v1oDlp9/Zp79qiVPA9ad
qwPr33dqsr1XiOfp6eUNYPWs67rsJ7R8qXaf2wiOP9b2ZnsboAfrbzWB5Wef
qrRfYMHNOMOwxQEA4+nt/w==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQKulrX7VfOiJ778DSvA5CfwPflhr3rQrsLx0rV
QPyGbc+u2a85tE+w5JYRiM/ApHTNvvSw+85ns6xAfIVC7av2Z7TeSC+2dwTx
D/S2X7H3n/Dbp93VFcR/4Ln8sv2EiqwTGomeYP6JT5fsSxxSe1ZN8QXzP7Bf
sndbe6JZ/GMAiL8gvvCifcfyNh45tWCwe7pbL9g3+P4+eSYrFGy/z9Lz9hcS
bjovOBAO4jvYOZ21P7TDp8hNMwps/3SPM/aTpjl3TlsWAzb/7uJT9qfkkjI6
rOLB8j+YTto7/drbsehzAtj97O+P2XMkBMyZHp4E5vMrHLMX47ibW3gqGaxe
7MgR+0lzOB4v8k0Fu6/31UH7otXGQbsfpYHVW/w9YG8lGyBZ3J0Bdu/yzfvt
o+dO7FrvmQXWn3Jxlz0w+M60yeeA1Tv677Tfx81+0Zo/D+yfl3O227stZ9Za
ylsA1m+ivMU+4s/VOZbKhWD7zr9fay8Xdu/Pdc8isLx16Ur7LfN1GpWbiyHh
O2uJfda5o49eXiiBhNfyxfaqGzLtVU3LwPzdKUvs80rdtJg2lYPVty9cYL8u
UPvTA89KcPweTZxpfxoYPiH/q8Du2btumn1v1ER286s1YPUfCyfZr1ryNGDd
uTow/6Rjt71XiOfp6eUNYPN9J7TYT2j5Uu0+txEsv21Dqb0N0IP1t5rA8i4R
OfYLLLgZZxi2OAAAC1fsrw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 1, 0], 
          Thickness[0.01]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQQNiUbH7VfOiJ778DSvA5B/QJjtlL3rQrsLx0rV
QHyFLxuO2685tE+w5JYRWJ41+Lh96WH3nc9mWYH4DJLax+3PaL2RXmzvCOZH
LT9m7z/ht0+7qyuI/4BP/pj9hIqsExqJniB+g7DAUfsSh9SeVVN8QfwFrgeO
2LutPdEs/jEAxHfw2n/EvmN5G4+cWjBYvfH5w/YNvr9PnskKBfETJvQctr+Q
cNN5wYFwsH3X5hy2P7TDp8hNMwpsntnuQ/aTpjl3TlsWAzaPqe+Q/Sm5pIwO
q3iwfya/OGTv9Gtvx6LPCWD/nCo/ZM+REDBnengSWP/fykP2Yhx3cwtPJYPd
/2ce0Lw5HI8X+aaC1Xs9O2RftNo4aPejNLD9MYJH7K1kAySLuzMg7q85bB89
d2LXes8sSPjMBLpvn+CZNvkcsPs1Thyx38fNftGaPw8sbyB11N5tObPWUt4C
sP1rc4/aR/y5OsdSuRCs3gvoP7mwe3+uexaB7S9WOmy/Zb5Oo3JzMdg/3jcP
22edO/ro5YUSMP8sz0F71Q2Z9qqmZWD1Py7st88rddNi2lQONm+Ny377dYHa
nx54VoLdG1251/40MHxC/leB+Tee7rLvjZrIbn61Buy+e4u22a9a8jRg3bk6
sDxn1iZ7rxDP09PLG8Dmv1y81n5Cy5dq97mN4PiKTF1ubwP0YP2tJjD//adF
9gssuBlnGLY4AADMEuiT
          "]]}}}, {}}}, {
    AspectRatio -> 1.2, PlotRange -> {{0, 0.6}, {0, 600}}, Frame -> True, 
     FrameLabel -> {
       FormBox["\"TKE\"", TraditionalForm], 
       FormBox["\"z m\"", TraditionalForm]}, TextStyle -> {FontSize -> 14}, 
     Axes -> False, DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.5477431416511536}, {0, 646.199220740953}}, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{0, 0.5477431416511536}, {0, 646.199220740953}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"1\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 (CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification])}]], 
                    "\[InvisibleSpace]"}], "GrayLevel[0.5]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"2\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"3\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.6, 0.4, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0.6, 0.4, 0.2]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.6, 0.4, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.6, 0.4, 0.2], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"4\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"5\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"6\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"7\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0], 
                    Thickness[0.18]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0], 
                    Thickness[0.18]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8057753189340982`*^9, {3.805775386086917*^9, 3.805775404369134*^9}, {
   3.805775454685297*^9, 3.8057754600355744`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"weightednofarm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1nofarms100mLeft", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".32"}], "+", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1nofarms100m", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".68"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"weightedEWP", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1EWP100mLeft", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".32"}], "+", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1EWP100m", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".68"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"weightedFitch", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1Fitch100mLeft", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".32"}], "+", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"tsFINO1Fitch100m", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}], " ", 
     ".68"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"obstime", ",", 
        RowBox[{"wsFINO120171014", "[", 
         RowBox[{"[", 
          RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<OBS\>\"", "}"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"wrftime", ",", "weightednofarm"}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<no farm\>\"", "}"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"wrftime", ",", "weightedEWP"}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Cyan"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<EWP Left\>\"", "}"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"wrftime", ",", "weightedFitch"}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch Left\>\"", "}"}]}]}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.805635288714334*^9, 3.805635319557908*^9}, {
  3.805635628457425*^9, 3.805635657231531*^9}, {3.805636040612009*^9, 
  3.8056361090211964`*^9}, {3.805636259095194*^9, 3.805636260645007*^9}, {
  3.8056364347138376`*^9, 3.8056364354738035`*^9}, {3.805701009647505*^9, 
  3.805701133071615*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.01388888888888889], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         PointBox[CompressedData["
1:eJxdlD1MU1EYhq9EjDb+IFYE7P/v7W0pbW9/XJr7xQUHl5IQFxZNZHEQBxdd
WFhccNWBRQdTExYXFheNccHBoWFhsIMO4kBMagyJib3ne99L2pMQ0nue8573
+zlf8t7D5fsTlmU9H/75/7mehneW+k8KsmLWJ2//1Xo7dMfB7563uvVhYB84
ovQ378vecN3m/ncvvnnY2d125G3XXz+9jwN7eIT8keerh3dK2P/t/ersxjYP
eX7gtUPDG98Xwf/1jJ/jIvhjzzWrBP6ft+wf75TAWzK6f0rW/PWD902I4b9S
/7Ty73j/pBg/D3jfGTHxrpI/K498g0fkz8ktP5wlxhtS/qAA/rzev0b+Ar5T
/6KM5mdKXr7wF/WmZDQ/l+HfBj8tJt8x8tOIn/wV3d+mn3Cwr3w48KP8VY1v
nX5mxNR3j35nxKRji/1xDf7pZ1ZMOXYL4Gfl9bovSH5OtJ/Iz0vIfCA/L398
uQH568hHDnwE8djgI6hvHnwU+cqDj6F+5GP6fYN8HPWnn0SQX91PaLyXeD4h
ptx96iehRz4pBf/CN3nwSdH3RP8p3bd5fwrxUz815j8dnFc+jX6iflr93KV+
Rkw7bJLPaD4fUz8jRi7MfsiO1SeL+8lnRd8r84N7Nsjngvwrn0M+6T+PfmK8
+SD/yp/sK2/DP/Npj/m38T7pp6D5e0b9Au7Pgcdvl/oO/DI/DupF3sF7Il9E
/alfhB75IvqR+S8FcShfwnthvCXNd5r6C8G+8gtj/hcQL/ky+pl8OdBTvqzv
8Sb9LOr7mSO/iPlE/UW8R/IV9D/0nAr0GE9F591n5H8DfIfvt6L9Usb86VWC
+qh+FfMhC/3q2HuoIl72WRX+wXerQR+qPs/Tfw31oX4N9ctAv4Z+y0C/pv02
Sf0a5jn4HvXAWy7eWwb6rsZzg/ou5mEK+uD7aei7mG8p6Lvod/BWHfVPQr+O
fk1Av47zCeif7Kv+GN+r4/2CtxqYp+CdBupJ/Qb6i3ON+/DTbaDfqd9A/qnf
xPk49JuIPwb9JuZLHPpNMeVoR6Hf1H7cj0KffAT6LcyrCPRbqFcE+i30VxT6
LczPGPRb8As/vVbg7z8PjyxT
          "]]}, {}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.016666666666666666`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJw90WlIVFEYxvHByhixcsFSG0KvM87M1RnvbPeafXnUzLIPmaUtUEhWIlqW
maPQMkYIbeIWhQppNWkalmUbaLZZJmGmTZElFkFaOpaFGQot5ns6cLhffvy5
73kDt2QmbHORyWTL/96p7/TRIDLkSrgUyyPx39HArW8oMkLJo75u6miw3+Lu
VzSpxbTXol0vJkY91ZLXQvmh29MlX0tei2bb/E2/dczzyBj9MZmynHkeqrMF
tWvymOfBCWfOHzcyHwJ9Rpe54ZuGfAjujFWn//ysIR+C6x9vHsl5rSEfCoW4
trazivlQvPa8M3TwBPOh8LDa3lxNY14Hr6dcR2MO8zpwh9dVlv/3OrTmneO8
TjOvR/yhd/6zK5nXo/mXwaOpgnk9OP+2XkMN82F4MBoxWnuB+TB4NDb7anuZ
D4Oip1axdjObV0D8YMOMPQ/pPXgBI9bS4vXz2D4ElMm/Jy9cw097m4C0rq++
nkfYfgTMm+k8qrpB3iEgVpoVUdxDXmaA644ce3U9ed6AKsUv+8Ri1jdgp3NZ
yYtu+h+bAZqm/sJraWw/BnxvDx9rW0D7cxiQ71mTOdDG5jWiaHtuRmwhzccb
EZOltY/nsvmNGGxSRpZvJW8zYl/JXXmQkb2HEbnD9uwvI2rqG1EysTN39XM1
9U0QhYLTjYFq6psweSBbXpocTH0TnOOjqrg3wdQ3wXuj/zPfl8HUN8F1Ij+r
LZq8w4Se7G3qyzUq6psxvMW+NCZTRX0zkkZKTa9OqqhvhnP2CkXBI/I2M9yl
tLmrOsnXmeHTcs/DHEPeYYa4qKM3sVpJfQuOXeoYkEFJfQvmlsl/hA4EUd+C
JRt1Ge/zg6hvwVCRNcUZHUR9C6K+pD55qybvsKAvuUXe4k1eJuJ23Lvgsk8c
9UV0j6W6frBz1BfxsWhve8JJjvoihMsd6UuLydeJiEsyfbMWkneIaO6/v3v8
FHmZhBSpZYNbOetLGOZaO+dUsL4E90NZu0bqWF+Cdc7KAL+LrC8B0e63fC6x
voSAx7q7jSUc/gBzTqh1
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.016666666666666666`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 1]], 
         LineBox[CompressedData["
1:eJw10X9MzHEcx/GLyHQ5ocuPuetcP+5H9/N7d1+s1QtlqmlXrjkns525yAyF
jbAz2VBn2pWRwmjkbpbsbERttUL5keEQ5keGoq0lQ37/en8+23fffx577vN5
v2XOdTkrRwgEggV/vr///0eBgRmaVEOnArn/jgKB0IA706OA3/f3KJAXLFns
zVHgv1ei4tfshNpw5pXo7Guq6j6WQF6J+2+yHw/IEsirEBHQVRxISiCvgita
bCsuYl6FgbQtx34kMa/G+as9yyuexpNX41DJvDst/njyahTfutneXBZPPhGb
XwlfPuOYT8SHlFFm2xjmEzHfNanO1R9HXgN1x2Hdw6E48hqcGh6zqiGKeQ02
OeqvHVeyvhbdedXVmWrW16LvVlv+XD3zWmSVt9jrZjGvwz40iaUK5nWI9Yuu
PEhnXoeZUvmZvY+Y1+Oe5lAgfwXNQ6WHZK095XUHm5ceu4Wiq2+jaf5uPSK5
8UujVrD96HFX5N2YVkv7COqR5C3I3RVk+zKg7qBFyLWSVxlgS5aUhjjZ/gzo
ShEv2v6T5u82QNul++JZy/ZjwPXK9HmBELpP0AB+oebb8yPs/kaEjS7b0GOl
96mMGH2j/MhZJXu/EeFHXd+Hx5F3G+FqKN608UUc9Y1w5BWIl1TTPoJGFGpT
+zJL2L44VEy7fOn051jqc1Dwa7wnJsZSn4P9y+r166fFUp/DT/7B7l1p5H0c
mm8kl5e1y6nPoVXofy2Mk1PfBPuCd/uzw+TUN2G4sco+GEk+14RRQ2Wpe6PI
u00Inyu0eiLJ+0xItpZyvZ4Z1DdhaSDsQtczGfXNGNl/sbdjm4z6ZlR5ttqs
s2XUNyOwRhTiex9DfTPMorH8C18M9c3o9fbvOL45hvpmNH466MjIIi+wwGkZ
Mcc5nbzKghp5cU12qZT6FqCgPnp+hJT6FhRGvC09GZRQ34I925bnhXZKqG/B
148tbTtl5AU8kip1kx3LpNTnkV5Qb5riYH0e1qKng3vSWJ+HMGPqnZFa8j4e
51prJpwIJR/kIXgypzbmtgS/AcrQm3s=
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.016666666666666666`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJw10XlI02Ecx/FVJB12F2XMY9PN7ec2t98uOlwfZTO7tHIulYqUWiVkKR1a
RlKUlZVhh0UalXlsUZYYGaHWyuy0jGaRiJpRjPCIpNIku77PAz9+/7x483yf
ryh58/J1wwUCQdSf7+///5HhpPnMWt4TjLh/R4YHxfKUouPBuOL8e2R403Su
fWF0MP57OUyKlubtY5iXw2tggbKhREpejrL2L8UlEVLyHMSrCmbPWyElz8FQ
OmxcdA7zHOJ3cY0XFjMfgsmWIaFvl4R8CKp7W31yn0rIh6C0cvdAfbmEvAKX
V5an79zEvAI6nxzl42TmFbjXbinKW8a8Eq8Tfi5dnsC8EnKTy9GVybwSzzMm
LBp7kHkVtiZeFfrkMK9CvMZ5PGIb8yq8jbmtjjzAfCi6E+dnVu9hPhRbFsfL
djqZD8X0GyPrpirZvGq0rvuW3HeB3oNTo+hTbb/4I3svNVJfbfBtU9D7Z6th
Lyy4Ykhl+1GjIjNy17RK2odbjUHhnUcbOti+NBjq9Yya7yLPaTAhYk7qYRvb
nwZhduuxlEG6T7YGP8y2mSez2H408I7hDyWOoPu4NUja2HL/9Ck2L4+ss+4j
+rk0H8ej6tSNnoERbH4e1iXh9b86g6jPY8ekMKvUEUR9Hq6v0x+2ZQRRn8cL
SXCDeBN5gRbjz4R7iToDqa+FYM/ZjR/8AqmvxVC/Lc3xUkx9LfLLLhX3Voip
r8X+6N15KouY+lrsO52bv6VZRH0dvp94dzTploj6OryPfLxU/ExEfR2sATUL
vZvIZ+twLC1um+saeacOfa8fdfSbybt1KLRk1nLVAdTXwx74TPUkMYD6evT0
xLaUcgHU12NrRUaUudmf+npwnZrrptX+1NcjfSZ/boa3P/X1EHk8TcJKP+ob
MLe1sS7N5Ed9A45Mnri+5JYv9Q1Id7i4/AW+1DcgdvybilndQuobEBXr7XXT
KaS+AYM/p9gLLgqpb4S58W5hXg15zoi9GcmOV43k44wYLE8zcR3ks42oWlNe
/eA96xtx/rM6qe8T6xsx2janRFYlxG+fPqu7
          "]]}}}, {}}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 23.833333333333332`}, {0, 14.45}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{0, 23.833333333333332`}, {0, 14.45}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"OBS\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.01388888888888889`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "False", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"no farm\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.016666666666666666`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"EWP Left\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.016666666666666666`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0., 0.6666666666666666, 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch Left\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.3], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.016666666666666666`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0.5]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False]}],
                    "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.805701134855812*^9, 3.806304421358844*^9, 
  3.806304476149428*^9, 3.8063046010453625`*^9, 3.806375588054096*^9, 
  3.8135665124825354`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"EWP14", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<EWP 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch14B", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Green", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Green", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0.25 14:00-15:00\>\"", "}"}]}]}], "]"}], 
   ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch14C", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Black", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=1 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch14", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "LightGreen", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "LightGreen", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"NWF14", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Gray", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Gray", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<No Farm 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"wstest14", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"wstestmean", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Pink"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<FINO1 OBS 14:00-14:50\>\"", "}"}]}]}], "]"}], ","}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<WS \!\(\*SuperscriptBox[\(ms\), \(-1\)]\)\>\"", ",", 
      "\"\<Height   m\>\""}], "}"}]}], ",", 
   RowBox[{"TextStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "16"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8135844881904764`*^9, 
   3.813584590828185*^9}, {3.8135846420825224`*^9, 3.81358464706649*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.805699113554099*^9, 3.805699154058837*^9}, 
   3.8057025595194607`*^9, 3.8057026115582156`*^9, 3.80570267722068*^9, {
   3.806376276284086*^9, 3.8063762829396477`*^9}, 3.8135673558985524`*^9, 
   3.8135845927520456`*^9, 3.813584648635744*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAXuXQjiSjHkCpmFud4csNQPd3kGvZ
oSFARaE+0MZ1JkC8qARja0kiQKzCvhF02jJAl6octmrQIkB1w0e55po6QNcw
tOOKVSNAzCrsG6M/QUD4mchjldgjQE+Q+0yHRUVAwmkRIXcsJECQeGrIKGFJ
QCbASmPGgiRAdEBljKqUTUAWWXP2eO4kQEatyIMX8VBAlViOzRguJUCIp4YM
HiZTQLJE4cCUjSVAgE37ycxqVUBzmbcWKPYlQNBg2UOgwFdAduMM4d4zJkDC
uExyRilaQEdv6YlgpiZAkpZDiZamXEDY/DUcAucmQMoeYmiIOl9Ak/34ktVj
J0BC+r2IovNgQHqhfedjqydACGBQnJdXYkCuXAbQLCgoQBYI3W1xymNAM9vt
uyehKECSnAjjok1lQMFmP+l0JylAcqszUrviZkA/PJcxkHspQDodUBlzi2hA
3YpgUVADKkBbnZGKr0lqQEDEtyTfjCpAwr4RzIYfbEDIoiCBkBQrQL4LB9E7
D25A6QAw1sKfK0BGpwMqpQ1wQP6Rn75vGCxAWPzVnDkjcUAfWeQdBqAsQB5W
3vzXSXJADvAHRTUvLUC0nyyBI4NzQG1x9pd4bS1Aas7F4unQdECo4T8inOEt
QCWwaT8lNXZAzql0XglmLkBudUYqArJ3QCZacBxm2y5ArlEr8uBJeUByH7zb
TS8vQMseYmhU/3pAbJJj15VfL0CNWpEHN9V8QBymp5UERC9AqqTlUK7OfkD3
26PLBJAuQEpUScuXd4BAMjAx44nULECQhPR7R52BQBqI9aDaditAPL4LB3/a
gkDwRHjvIKYpQKA4CwGYMYRArJITeA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAACeJtNCk0HkCpmFud4csNQMtBIEjj
ZyFARaE+0MZ1JkAUgjKnZw4iQKzCvhF02jJAP+MusnaWIkB1w0e55po6QJot
Dgk3GCNAzCrsG6M/QUDk79f9F50jQE+Q+0yHRUVAyNg65HTvI0CQeGrIKGFJ
QJl6Lc4mVCRAdEBljKqUTUA1bTJEY7UkQEatyIMX8VBArk3ItqIDJUCIp4YM
HiZTQLL95+jCWiVAgE37ycxqVUCx06vRhcclQNBg2UOgwFdA8j8FNVQIJkDC
uExyRilaQMSAHOJjfiZAkpZDiZamXEBlF1B5GsQmQMoeYmiIOl9Aqm35vOhB
J0BC+r2IovNgQCA5609llSdACGBQnJdXYkCiSOd4ShMoQBYI3W1xymNAzkye
yaaSKECSnAjjok1lQJOpW4goFClAcqszUrviZkCPOdt/1oEpQDodUBlzi2hA
7Ytc38sAKkBbnZGKr0lqQCAEFJPVfypAwr4RzIYfbEBPIT7Jo/UqQL4LB9E7
D25AKqLvnFB5K0BGpwMqpQ1wQFa5jzhs+StAWPzVnDkjcUDJnezARnksQB5W
3vzXSXJAQnDoxIgELUC0nyyBI4NzQNhpjFfeUi1Aas7F4unQdEBY+35CQt0t
QCWwaT8lNXZA+g3d3AdfLkBudUYqArJ3QEYxNjJuxi5ArlEr8uBJeUDM/sg4
FAYvQMseYmhU/3pAatM8o30OL0CNWpEHN9V8QDhzWiIwuS5AqqTlUK7OfkC7
8+t82wMuQEpUScuXd4BA1FAe7XCYLECQhPR7R52BQDi3RW1GdCtAPL4LB3/a
gkB8/IC6880qQKA4CwGYMYRAC8IRhA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAB0NJuZ8GHkCpmFud4csNQPy4+s2Y
SyFARaE+0MZ1JkBc/B3OLvEhQKzCvhF02jJAre1xzTh3IkB1w0e55po6QObu
KSNG+iJAzCrsG6M/QUB1n7nUE30jQE+Q+0yHRUVAzL7C2LDOI0CQeGrIKGFJ
QHZPN2uMQCRAdEBljKqUTUCWYHd634ckQEatyIMX8VBATIeIj2r2JECIp4YM
HiZTQGDjyRgsNyVAgE37ycxqVUC40SaQPKolQNBg2UOgwFdARmYUqGbsJUDC
uExyRilaQLJz7O/EZSZAkpZDiZamXEDL/OuZ56omQMoeYmiIOl9A8FkK+o0n
J0BC+r2IovNgQIEtP36ohydACGBQnJdXYkBYpCe1xwMoQBYI3W1xymNAHXXS
IdF6KECSnAjjok1lQETh+vld9ihAcqszUrviZkAWUhiqBHQpQDodUBlzi2hA
9g5VL07yKUBbnZGKr0lqQJi0w7EtbypAwr4RzIYfbEC2bSqvFNsqQL4LB9E7
D25ACVrkC51dK0BGpwMqpQ1wQLucWlbV2CtAWPzVnDkjcUB+GdBqPUosQB5W
3vzXSXJA3iKLWCDHLEC0nyyBI4NzQKSf1qzrKS1Aas7F4unQdECCHl4i2Zkt
QCWwaT8lNXZANda5t1v6LUBudUYqArJ3QFV0jfr0Ry5ArlEr8uBJeUBu3WqZ
NHwuQMseYmhU/3pARirzz/WHLkCNWpEHN9V8QHrad95KRS5AqqTlUK7OfkDC
Urb85ZktQEpUScuXd4BAtbUlebw5LECQhPR7R52BQNDrbWhyYStAPL4LB3/a
gkBEqp/EaVQqQKA4CwGYMYRAvrwZ7Q==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAeLGga5L9HUCpmFud4csNQOPbenoO
SCFARaE+0MZ1JkDCcRDdrewhQKzCvhF02jJAlgHOsARyIkB1w0e55po6QImC
cv1i+SJAzCrsG6M/QUCqLxlEv3QjQE+Q+0yHRUVAgGuFrzDPI0CQeGrIKGFJ
QObU+AEHPiRAdEBljKqUTUBeZWjXoYYkQEatyIMX8VBA12SyELv4JECIp4YM
HiZTQFzqFPwKPSVAgE37ycxqVUDOkXdUNrElQNBg2UOgwFdAK8mZL9fzJUDC
uExyRilaQOXs7Q+3cCZAkpZDiZamXEC8sU6MgLYmQMoeYmiIOl9Agg7ZL7sz
J0BC+r2IovNgQJQ2GSrymidACGBQnJdXYkCpFevVFRkoQBYI3W1xymNA6MZm
MwqDKECSnAjjok1lQF5NwBEyAilAcqszUrviZkAeKq4zaIQpQDodUBlzi2hA
HNk5k0HxKUBbnZGKr0lqQB60bZCYZCpAwr4RzIYfbECuEkoOT+wqQL4LB9E7
D25A6/XGehB6K0BGpwMqpQ1wQGB8mugwxytAWPzVnDkjcUBtVH1OxD0sQB5W
3vzXSXJAvUCwxFitLEC0nyyBI4NzQFzKjE+sFS1Aas7F4unQdEACfdzk0W0t
QCWwaT8lNXZA+mkkTSvJLUBudUYqArJ3QCq6TmqQAy5ArlEr8uBJeUB+JQ5A
8jouQMseYmhU/3pA+vPxKhBULkCNWpEHN9V8QAf/gM7nNS5AqqTlUK7OfkCa
LprIXK4tQEpUScuXd4BAFme6UuG2LECQhPR7R52BQNg+C4QumitAPL4LB3/a
gkAZhz0fQQ0qQKA4CwGYMYRAlPAPOA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAnX63mkIjHkCpmFud4csNQGa104+6
XCFARaE+0MZ1JkB1iQWhfAEiQKzCvhF02jJARBBsYPyHIkB1w0e55po6QObD
2GJEICNAzCrsG6M/QUAZmUVPon4jQE+Q+0yHRUVAu7Gy15X7I0CQeGrIKGFJ
QAY20cvISSRAdEBljKqUTUCYeY4ThqckQEatyIMX8VBAyFhDIXQaJUCIp4YM
HiZTQGCJoOvJXiVAgE37ycxqVUBUbq5Yt9ElQNBg2UOgwFdApvkIaLEVJkDC
uExyRilaQIBACIMCkCZAkpZDiZamXECNuVRPFtcmQMoeYmiIOl9A7qYoV6tS
J0BC+r2IovNgQLPDR1iOuydACGBQnJdXYkCYnscF9zwoQBYI3W1xymNAx5yq
n+CSKECSnAjjok1lQJOWlDKPESlAcqszUrviZkA4hyjEyo0pQDodUBlzi2hA
5Z2xVLcMKkBbnZGKr0lqQBKHqagmiSpAwr4RzIYfbEDgIr3HWOEqQL4LB9E7
D25AinsvxqhuK0BGpwMqpQ1wQF8chghbwCtAWPzVnDkjcUB6WyLNbEQsQB5W
3vzXSXJAW6qozYCILEC0nyyBI4NzQHYc1TejBy1Aas7F4unQdECSq3KjYTot
QCWwaT8lNXZAZKjkq7mRLUBudUYqArJ3QOjwJ4GM5C1ArlEr8uBJeUCVd2Gd
9SIuQMseYmhU/3pARggIr+RDLkCNWpEHN9V8QDjgwOy6My5AqqTlUK7OfkDQ
2wTavbktQEpUScuXd4BAcDbiQNcbLUCQhPR7R52BQJb36+P0pytAPL4LB3/a
gkBCBlqjaWkqQKA4CwGYMYRAg9wUPw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAWg6/Cb1UHkCpmFud4csNQL2aO32i
dSFARaE+0MZ1JkBWDS1r2hwiQKzCvhF02jJAoLC1pRujIkB1w0e55po6QEYc
PhxhOyNAzCrsG6M/QUCsS3IAHpojQE+Q+0yHRUVAEuDldLsGJECQeGrIKGFJ
QAeLxRr/eCRAdEBljKqUTUBUHWTd4sAkQEatyIMX8VBADgUbdD4wJUCIp4YM
HiZTQPQnkH9ccyVAgE37ycxqVUCtC9S+dOUlQNBg2UOgwFdAdVqvx6ApJkDC
uExyRilaQHdO/0dsoSZAkpZDiZamXECLMkskV+YmQMoeYmiIOl9Ajtaz8aBi
J0BC+r2IovNgQCSwk9mGvydACGBQnJdXYkAuLERaUUUoQBYI3W1xymNAIBnw
C9CSKECSnAjjok1lQDBb5nAVFSlAcqszUrviZkCSyZ4AkJgpQDodUBlzi2hA
ykvO2WUCKkBbnZGKr0lqQHnEvuLzjSpAwr4RzIYfbEDMtlS3AdYqQL4LB9E7
D25AwLa2iCBwK0BGpwMqpQ1wQIjgD5kvtStAWPzVnDkjcUCg4H7j4kYsQB5W
3vzXSXJAdwXsorWJLEC0nyyBI4NzQLIi4nTeDy1Aas7F4unQdEAPxiiTRUIt
QCWwaT8lNXZAtmbWZOKcLUBudUYqArJ3QP52kQHE2i1ArlEr8uBJeUB5hqSL
2AIuQMseYmhU/3pACl/gDvT/LUCNWpEHN9V8QG47PWMPwS1AqqTlUK7OfkAI
uIfpm3stQEpUScuXd4BAhowy1ZKiLECQhPR7R52BQIQuoI05oytAPL4LB3/a
gkBqiv+o7CUqQKA4CwGYMYRAdKkPvQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAWg6/Cb1UHkCpmFud4csNQL2aO32i
dSFARaE+0MZ1JkBWDS1r2hwiQKzCvhF02jJAoLC1pRujIkB1w0e55po6QEYc
PhxhOyNAzCrsG6M/QUCsS3IAHpojQE+Q+0yHRUVAEuDldLsGJECQeGrIKGFJ
QAeLxRr/eCRAdEBljKqUTUBUHWTd4sAkQEatyIMX8VBADgUbdD4wJUCIp4YM
HiZTQPQnkH9ccyVAgE37ycxqVUCtC9S+dOUlQNBg2UOgwFdAdVqvx6ApJkDC
uExyRilaQHdO/0dsoSZAkpZDiZamXECLMkskV+YmQMoeYmiIOl9Ajtaz8aBi
J0BC+r2IovNgQCSwk9mGvydACGBQnJdXYkAuLERaUUUoQBYI3W1xymNAIBnw
C9CSKECSnAjjok1lQDBb5nAVFSlAcqszUrviZkCSyZ4AkJgpQDodUBlzi2hA
ykvO2WUCKkBbnZGKr0lqQHnEvuLzjSpAwr4RzIYfbEDMtlS3AdYqQL4LB9E7
D25AwLa2iCBwK0BGpwMqpQ1wQIjgD5kvtStAWPzVnDkjcUCg4H7j4kYsQB5W
3vzXSXJAdwXsorWJLEC0nyyBI4NzQLIi4nTeDy1Aas7F4unQdEAPxiiTRUIt
QCWwaT8lNXZAtmbWZOKcLUBudUYqArJ3QP52kQHE2i1ArlEr8uBJeUB5hqSL
2AIuQMseYmhU/3pACl/gDvT/LUCNWpEHN9V8QG47PWMPwS1AqqTlUK7OfkAI
uIfpm3stQEpUScuXd4BAhowy1ZKiLECQhPR7R52BQIQuoI05oytAPL4LB3/a
gkBqiv+o7CUqQKA4CwGYMYRAdKkPvQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA6jizKbzKIECpmFud4csNQDYZFXf4
EyJARaE+0MZ1JkAVQA9Z1J0iQKzCvhF02jJAjscxyqnuIkB1w0e55po6QLJ5
UkaMJCNAzCrsG6M/QUBrHj+Egk8jQE+Q+0yHRUVA2O7Keqp1I0CQeGrIKGFJ
QG62aFNUmiNAdEBljKqUTUBEYT5Ptb8jQEatyIMX8VBAyJ4j6NLmI0CIp4YM
HiZTQKR2w+b1ESRAgE37ycxqVUBmTEAEh0AkQNBg2UOgwFdAtGoloSt1JEDC
uExyRilaQFR/xN/AsSRAkpZDiZamXEBPLytXVvgkQMoeYmiIOl9AN6mJcNRO
JUBC+r2IovNgQA0F7Sv7HyZACGBQnJdXYkD52pTOIwonQBYI3W1xymNA4PIr
jAy2J0CSnAjjok1lQNKScU9fUyhAcqszUrviZkBW9+BFhOkoQDodUBlzi2hA
8/PfEbCMKUBbnZGKr0lqQPACDO918SlAwr4RzIYfbEAfM8uZi5IqQL4LB9E7
D25AaMdNfmErK0BGpwMqpQ1wQKaFYoWvwStAWPzVnDkjcUBY/2T3d08sQB5W
3vzXSXJAYPb7olnXLEC0nyyBI4NzQBLS8Lc8Yy1Aas7F4unQdEBcW0DkIKEt
QCWwaT8lNXZAvhu18DwDLkBudUYqArJ3QIHf2ny1Ui5ArlEr8uBJeUBQ5Oy0
LIAuQMseYmhU/3pAWiej75agLkCNWpEHN9V8QIwQh0W3li5AqqTlUK7OfkA8
FlWdWUcuQEpUScuXd4BATqazxP6aLUCQhPR7R52BQI0LJ5/QtixAPL4LB3/a
gkBkFRrXqxQrQKA4CwGYMYRAo9wT4A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA+E/i1fyoIECpmFud4csNQPY1bMh7
7iFARaE+0MZ1JkCS7BseInciQKzCvhF02jJA1NpV+qHHIkB1w0e55po6QLrW
bizg/SJAzCrsG6M/QUCAXntPlSkjQE+Q+0yHRUVAiUeeNHdQI0CQeGrIKGFJ
QMxxBWc+diNAdEBljKqUTUAm0UXQ05sjQEatyIMX8VBAcqLZ9yjEI0CIp4YM
HiZTQDg3jR2A7yNAgE37ycxqVUCmRi8y8x8kQNBg2UOgwFdAa+Jdhj9VJEDC
uExyRilaQIrthY+mkiRAkpZDiZamXEAgBSDlvtokQMoeYmiIOl9A4+dr9JIy
JUBC+r2IovNgQNVLAlNSAyZACGBQnJdXYkCeb5on+vEmQBYI3W1xymNAbt6o
QD+iJ0CSnAjjok1lQJCVbdfoQihAcqszUrviZkBEssZLI9koQDodUBlzi2hA
TMv3/qFzKUBbnZGKr0lqQAVJSZXb4ylAwr4RzIYfbEDyUTa/jX8qQL4LB9E7
D25Aq7ZPCuMQK0BGpwMqpQ1wQE8yPk4GnytAWPzVnDkjcUDyOw6qsiQsQB5W
3vzXSXJApaYRI1WoLEC0nyyBI4NzQOhwX4gYBC1Aas7F4unQdEDorPEJP2gt
QCWwaT8lNXZAMh/Z4m7DLUBudUYqArJ3QLAVaUIFEy5ArlEr8uBJeUDFoQNM
EVguQMseYmhU/3pADDFVNBN9LkCNWpEHN9V8QOBOZYwgdi5AqqTlUK7OfkCA
xfZYHRouQEpUScuXd4BAmNOmmmFgLUCQhPR7R52BQNSqNDgtWCxAPL4LB3/a
gkBa3szTmcIqQKA4CwGYMYRACGkQuQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAMLVxNWaeIECpmFud4csNQIf1sFMv
5yFARaE+0MZ1JkB80qa78HEiQKzCvhF02jJAYuv6StjBIkB1w0e55po6QM75
VIvr+CJAzCrsG6M/QUCJ4PwSqyQjQE+Q+0yHRUVANBICeV1MI0CQeGrIKGFJ
QF502n1YcSNAdEBljKqUTUArCalHzJcjQEatyIMX8VBAI3VtDE6/I0CIp4YM
HiZTQOz/TTso7CNAgE37ycxqVUCjJrYhYhskQNBg2UOgwFdAUx5AEhNSJEDC
uExyRilaQJW2V8ijkCRAkpZDiZamXEBxX6ZACdokQMoeYmiIOl9AIOl6Ndcx
JUBC+r2IovNgQIhWPGTC/yVACGBQnJdXYkBViZmSru4mQBYI3W1xymNA1x7s
jTCiJ0CSnAjjok1lQBDkBpPAQyhAcqszUrviZkB6qK//S9YoQDodUBlzi2hA
hQ9sxg1sKUBbnZGKr0lqQAzyvpCH1ylAwr4RzIYfbEASsIVC8XUqQL4LB9E7
D25A2sAK067uKkBGpwMqpQ1wQFV4XfC8citAWPzVnDkjcUBVW+OHKPIrQB5W
3vzXSXJAzXJcYSF6LEC0nyyBI4NzQAEGT3ebuyxAas7F4unQdEBDmMEMxyUt
QCWwaT8lNXZAS7QFITCELUBudUYqArJ3QNKKZMQ50y1ArlEr8uBJeUDcWbM4
dBAuQMseYmhU/3pAf8EnPnA3LkCNWpEHN9V8QNS0NoHaOS5AqqTlUK7OfkAw
7xQ10+YtQEpUScuXd4BA24/W64gvLUCQhPR7R52BQEfJbHSgISxAPL4LB3/a
gkD98kkgMaYqQKA4CwGYMYRAkO0Raw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAfmRn/UOoIECpmFud4csNQAn//rKh
8yFARaE+0MZ1JkDmaEhOWH0iQKzCvhF02jJABm+qUJzOIkB1w0e55po6QHVe
87LwBCNAzCrsG6M/QUAKXd7TgzEjQE+Q+0yHRUVA64vOEnpYI0CQeGrIKGFJ
QMUI8HM8fiNAdEBljKqUTUANUrJXFKUjQEatyIMX8VBAZYBleCbNI0CIp4YM
HiZTQNBtlCqy+CNAgE37ycxqVUBSDmbhuSgkQNBg2UOgwFdAV7Y4ZvhfJEDC
uExyRilaQDWVU+BknSRAkpZDiZamXEAy0rv8buckQMoeYmiIOl9Axkng16A/
JUBC+r2IovNgQKH1oPCYESZACGBQnJdXYkA+mKWorgInQBYI3W1xymNAsAAO
5FWyJ0CSnAjjok1lQLJaCVO8VChAcqszUrviZkCEabcIy+koQDodUBlzi2hA
WrF3rQ5wKUBbnZGKr0lqQHY8vzBZ+ylAwr4RzIYfbEB8K69qaYEqQL4LB9E7
D25ApMgerI4cK0BGpwMqpQ1wQHhPx7U9hStAWPzVnDkjcUBYhV5xdwksQB5W
3vzXSXJADfSdWrOULEC0nyyBI4NzQMSAJRtf4yxAas7F4unQdEByZWxb90st
QCWwaT8lNXZANOsOgQGoLUBudUYqArJ3QEny8kLe9S1ArlEr8uBJeUDDSFUr
2zMuQMseYmhU/3pAe1QYJ5taLkCNWpEHN9V8QPCyEiTGUi5AqqTlUK7OfkC0
SFpUAf0tQEpUScuXd4BAHvSXmFkyLUCQhPR7R52BQArfTXgVPixAPL4LB3/a
gkDUHniXHgMrQKA4CwGYMYRAUjgOyw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAALNhWUivGIECpmFud4csNQHkuHSFL
ESJARaE+0MZ1JkBRb4jIGpsiQKzCvhF02jJARkxkRbvrIkB1w0e55po6QKUV
e6h0IiNAzCrsG6M/QUD1uk50U04jQE+Q+0yHRUVA8SJV9xB1I0CQeGrIKGFJ
QJ9I6o1cmyNAdEBljKqUTUAcFxAdXsEjQEatyIMX8VBA/6hlNILpI0CIp4YM
HiZTQHHAJXbsEyRAgE37ycxqVUApX+trUUQkQNBg2UOgwFdAj8XcVTN6JEDC
uExyRilaQGoop+EqtyRAkpZDiZamXEAtGO2bbP8kQMoeYmiIOl9AnqjGERJV
JUBC+r2IovNgQBClP6C3IiZACGBQnJdXYkC41wJ8axQnQBYI3W1xymNAVqIR
UZXHJ0CSnAjjok1lQEuUh2jJZihAcqszUrviZkCsmgO79P4oQDodUBlzi2hA
DsLZhGxvKUBbnZGKr0lqQHQgcLFDIipAwr4RzIYfbEAoVUJtH4IqQL4LB9E7
D25AVp4tNQ8QK0BGpwMqpQ1wQGpyDr4WmytAWPzVnDkjcUDCZazX8iosQB5W
3vzXSXJAxPzn7QWQLEC0nyyBI4NzQMShLMxpBS1Aas7F4unQdECQ8wtqAWwt
QCWwaT8lNXZASq3jaeLBLUBudUYqArJ3QHLxKoSTBC5ArlEr8uBJeUBFOfrE
azMuQMseYmhU/3pAckd7FrxELkCNWpEHN9V8QDzseeImOC5AqqTlUK7OfkCT
IcE14NktQEpUScuXd4BAwMNODSrrLECQhPR7R52BQM30fxSw2StAPL4LB3/a
gkABL1/o5KcqQKA4CwGYMYRAFfkKdA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAhbtd1f/WIECpmFud4csNQLm1LCkJ
ISJARaE+0MZ1JkCLoiU1z6oiQKzCvhF02jJAs9Ji+Eb8IkB1w0e55po6QIcp
YITtMiNAzCrsG6M/QUDMe7jf2V0jQE+Q+0yHRUVAlsrsCLqEI0CQeGrIKGFJ
QOIpuU40qiNAdEBljKqUTUBbtC/Lps8jQEatyIMX8VBAikueHx35I0CIp4YM
HiZTQAqh7vmmIyRAgE37ycxqVUA6PPeH71MkQNBg2UOgwFdAXyiw4KqJJEDC
uExyRilaQHKzPhnkxiRAkpZDiZamXEBnqy92rA8lQMoeYmiIOl9AzCgra9pk
JUBC+r2IovNgQKA3MDfjMSZACGBQnJdXYkBzlfoqHh8nQBYI3W1xymNAHLkT
31/RJ0CSnAjjok1lQLLzSKkxbyhAcqszUrviZkCtoV8PaRMpQDodUBlzi2hA
RLpDBKxzKUBbnZGKr0lqQFz8s2yrKSpAwr4RzIYfbEBOCIQ/s40qQL4LB9E7
D25ArhbYObgdK0BGpwMqpQ1wQHGFkY3KritAWPzVnDkjcUCGUPPNzkYsQB5W
3vzXSXJA3tsv6D6fLEC0nyyBI4NzQEzr36g3DS1Aas7F4unQdEAT6/evqXQt
QCWwaT8lNXZAzmEXQx2pLUBudUYqArJ3QCaImFkE2i1ArlEr8uBJeUCETV/v
sfstQMseYmhU/3pA6thZ0Jv+LUCNWpEHN9V8QPvbG2Xa1i1AqqTlUK7OfkA2
u+i5sIgtQEpUScuXd4BAYgSijrvZLECQhPR7R52BQFSSikQRzStAPL4LB3/a
gkA9qYeuw6IqQKA4CwGYMYRA1ywXNw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAhbtd1f/WIECpmFud4csNQLm1LCkJ
ISJARaE+0MZ1JkCLoiU1z6oiQKzCvhF02jJAs9Ji+Eb8IkB1w0e55po6QIcp
YITtMiNAzCrsG6M/QUDMe7jf2V0jQE+Q+0yHRUVAlsrsCLqEI0CQeGrIKGFJ
QOIpuU40qiNAdEBljKqUTUBbtC/Lps8jQEatyIMX8VBAikueHx35I0CIp4YM
HiZTQAqh7vmmIyRAgE37ycxqVUA6PPeH71MkQNBg2UOgwFdAXyiw4KqJJEDC
uExyRilaQHKzPhnkxiRAkpZDiZamXEBnqy92rA8lQMoeYmiIOl9AzCgra9pk
JUBC+r2IovNgQKA3MDfjMSZACGBQnJdXYkBzlfoqHh8nQBYI3W1xymNAHLkT
31/RJ0CSnAjjok1lQLLzSKkxbyhAcqszUrviZkCtoV8PaRMpQDodUBlzi2hA
RLpDBKxzKUBbnZGKr0lqQFz8s2yrKSpAwr4RzIYfbEBOCIQ/s40qQL4LB9E7
D25ArhbYObgdK0BGpwMqpQ1wQHGFkY3KritAWPzVnDkjcUCGUPPNzkYsQB5W
3vzXSXJA3tsv6D6fLEC0nyyBI4NzQEzr36g3DS1Aas7F4unQdEAT6/evqXQt
QCWwaT8lNXZAzmEXQx2pLUBudUYqArJ3QCaImFkE2i1ArlEr8uBJeUCETV/v
sfstQMseYmhU/3pA6thZ0Jv+LUCNWpEHN9V8QPvbG2Xa1i1AqqTlUK7OfkA2
u+i5sIgtQEpUScuXd4BAYgSijrvZLECQhPR7R52BQFSSikQRzStAPL4LB3/a
gkA9qYeuw6IqQKA4CwGYMYRA1ywXNw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAe8KN+bL4IUCpmFud4csNQJPJWLlL
HSNARaE+0MZ1JkDRy7vXiZ0jQKzCvhF02jJAYtjO/bHrI0B1w0e55po6QB5O
s814IyRAzCrsG6M/QUCYRjFDQE8kQE+Q+0yHRUVAgr6J2f52JECQeGrIKGFJ
QOmyiByAnSRAdEBljKqUTUD5AF9SjsUkQEatyIMX8VBAks/rBsXuJECIp4YM
HiZTQK3Du0IkGiVAgE37ycxqVUB58SyJ40glQNBg2UOgwFdAjWzAd4N8JUDC
uExyRilaQMHueWe3tSVAkpZDiZamXEBwLpzs0vUlQMoeYmiIOl9AJF1ymrU/
JkBC+r2IovNgQLb5D4CYmyZACGBQnJdXYkBGz67xcv0mQBYI3W1xymNALrXe
uI5nJ0CSnAjjok1lQDvtQD4f1SdAcqszUrviZkCCPICtWUAoQDodUBlzi2hA
u70uztrdKEBbnZGKr0lqQLjrkzUlVylAwr4RzIYfbEDC6drZQtspQL4LB9E7
D25AOl9DJF90KkBGpwMqpQ1wQPyeIigiHytAWPzVnDkjcUAqiqYNnb8rQB5W
3vzXSXJAEugwlyRfLEC0nyyBI4NzQPPjYuy7/CxAas7F4unQdEASdKHeWI0t
QCWwaT8lNXZAEEekDWwCLkBudUYqArJ3QKfAL/gLWC5ArlEr8uBJeUCU+/p5
L4YuQMseYmhU/3pAzhW6YAmmLkCNWpEHN9V8QHqDNrYPmy5AqqTlUK7OfkCn
JtkJBUIuQEpUScuXd4BAFv/yrmOHLUCQhPR7R52BQGDcO+zamixAPL4LB3/a
gkDSzgskTPgqQKA4CwGYMYRAPW0ZlA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAUDYa3EHfIUCpmFud4csNQGI4jPBG
ASNARaE+0MZ1JkC+eMgfMoEjQKzCvhF02jJAGzx/9drPI0B1w0e55po6QNag
HipJByRAzCrsG6M/QUBKUcPQlDMkQE+Q+0yHRUVAKXBpX45bJECQeGrIKGFJ
QFLgDCfAgiRAdEBljKqUTUCdnd/fuaokQEatyIMX8VBAzfh5ijHUJECIp4YM
HiZTQG7UmRWYACVAgE37ycxqVUBCAkn49y8lQNBg2UOgwFdAYMyxCDRjJUDC
uExyRilaQDAAvgLTnCVAkpZDiZamXECg42/TtN0lQMoeYmiIOl9At8vThl0p
JkBC+r2IovNgQGtTLSF4hSZACGBQnJdXYkDYTFKxq+YmQBYI3W1xymNApmlZ
ohhOJ0CSnAjjok1lQFfDXJrvwydAcqszUrviZkAeOBOvujEoQDodUBlzi2hA
Em5P0pTAKEBbnZGKr0lqQBJiPakPPylAwr4RzIYfbEBUoccUsMYpQL4LB9E7
D25AXB0A4C13KkBGpwMqpQ1wQLj4EIDT7ipAWPzVnDkjcUCEezkJpocrQB5W
3vzXSXJAkAc0ZLQmLEC0nyyBI4NzQBjf521EnixAas7F4unQdED2UiWaEiMt
QCWwaT8lNXZAVpqV4S2bLUBudUYqArJ3QD5t3vO6+y1ArlEr8uBJeUCYo9SY
/kguQMseYmhU/3pAPoS4DrVxLkCNWpEHN9V8QElpIL++ay5AqqTlUK7OfkA+
YyqtOQ0uQEpUScuXd4BAO8DsCYhRLUCQhPR7R52BQCi3IesmRSxAPL4LB3/a
gkAyK5LvKroqQKA4CwGYMYRA72kLzA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAtnSPoWbMIUCpmFud4csNQM90sSvE
7iJARaE+0MZ1JkDWq9IdQG8jQKzCvhF02jJA09sjY0y9I0B1w0e55po6QEFt
LMqw9CNAzCrsG6M/QUADdLiHECIkQE+Q+0yHRUVAdqI/UnVKJECQeGrIKGFJ
QJTxMnd2cSRAdEBljKqUTUDu+WqOz5kkQEatyIMX8VBA78WtgWTDJECIp4YM
HiZTQJ9Z8pnF7yRAgE37ycxqVUBszf5BNh8lQNBg2UOgwFdA5EVh9BZUJUDC
uExyRilaQMLHQ3bUjSVAkpZDiZamXEBzMikmws8lQMoeYmiIOl9AFeVEIbca
JkBC+r2IovNgQIR7N6OzdyZACGBQnJdXYkCz69b0EtsmQBYI3W1xymNAXFC8
uX1LJ0CSnAjjok1lQHZ5SQF3wCdAcqszUrviZkC2B9HtpDMoQDodUBlzi2hA
yBp2YUGsKEBbnZGKr0lqQDwm4qROIilAwr4RzIYfbED0obyhTbQpQL4LB9E7
D25A/GAth4RiKkBGpwMqpQ1wQHpUMh6T1SpAWPzVnDkjcUC9PQlswWMrQB5W
3vzXSXJAUIMO/ZcLLEC0nyyBI4NzQMITDLM4aCxAas7F4unQdEDE3VZzaPQs
QCWwaT8lNXZAAvciQNtxLUBudUYqArJ3QMypE9Vn0S1ArlEr8uBJeUB8vpga
MBQuQMseYmhU/3pA4fMD0ys7LkCNWpEHN9V8QKRJWeikOS5AqqTlUK7OfkDC
4cRQVdstQEpUScuXd4BArIWzD8ocLUCQhPR7R52BQKuAGLYZAixAPL4LB3/a
gkBMnIQPyYEqQKA4CwGYMYRAxKETNg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAACFwmHePYIUCpmFud4csNQLjTzQkj
/SJARaE+0MZ1JkA4hYLFtH0jQKzCvhF02jJA21tS1AzNI0B1w0e55po6QARx
xogVBCRAzCrsG6M/QUCAs2CFPDEkQE+Q+0yHRUVA+/LIY9dZJECQeGrIKGFJ
QNC0LVL5gCRAdEBljKqUTUAKf1vfuKgkQEatyIMX8VBAqn4c7o/SJECIp4YM
HiZTQFV+UG2s/yRAgE37ycxqVUAkqbjFNy4lQNBg2UOgwFdAEYXkoPZjJUDC
uExyRilaQAjaNZo3niVAkpZDiZamXEByPG/xwOAlQMoeYmiIOl9AvvNA98Es
JkBC+r2IovNgQNJOAI2IiSZACGBQnJdXYkBk1tSILuwmQBYI3W1xymNA1odo
LWBaJ0CSnAjjok1lQFjlzr7MzCdAcqszUrviZkAEr8hweEooQDodUBlzi2hA
HrO+Muq5KEBbnZGKr0lqQGMZdDVmQSlAwr4RzIYfbEBFxjxb5LopQL4LB9E7
D25Ads4f0UBuKkBGpwMqpQ1wQCCRPYCH6SpAWPzVnDkjcUBMgXc38nQrQB5W
3vzXSXJAcA7YAKMgLEC0nyyBI4NzQHyM8ACTiCxAas7F4unQdEAbltHMCBUt
QCWwaT8lNXZAeqJPzDqNLUBudUYqArJ3QE1HC6r+5y1ArlEr8uBJeUCGJ6AV
xSouQMseYmhU/3pAGg0JpwxSLkCNWpEHN9V8QEogo+WTSC5AqqTlUK7OfkCu
d1xhte8tQEpUScuXd4BA1nONeY8cLUCQhPR7R52BQBCvP3/uJSxAPL4LB3/a
gkAUXpN82+sqQKA4CwGYMYRARakQ1Q==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAApL6jKU78IUCpmFud4csNQJffgTKL
ICNARaE+0MZ1JkB8OZzhMKEjQKzCvhF02jJAL7lcHp3wI0B1w0e55po6QHcN
F7VgKCRAzCrsG6M/QUDZlEdcn1UkQE+Q+0yHRUVA/3SFTRZ9JECQeGrIKGFJ
QNEdLc3JpSRAdEBljKqUTUBveZO1z8wkQEatyIMX8VBAXrH1QXf1JECIp4YM
HiZTQDyT2sjcISVAgE37ycxqVUBq39ktp1AlQNBg2UOgwFdAXJBxOtaEJUDC
uExyRilaQMd1EDGrviVAkpZDiZamXEDwJWtEEQAmQMoeYmiIOl9Arj0jQ/RJ
JkBC+r2IovNgQHUwHN7apCZACGBQnJdXYkBzxVVGHwYnQBYI3W1xymNAlk/j
ZhVwJ0CSnAjjok1lQJBkkLkA3ydAcqszUrviZkCe8yRuqlIoQDodUBlzi2hA
VP1lEgK4KEBbnZGKr0lqQIatRiAOailAwr4RzIYfbEBEs+TTaOgpQL4LB9E7
D25Afp2zPclcKkBGpwMqpQ1wQBRPORtS5SpAWPzVnDkjcUBKiJYEmIsrQB5W
3vzXSXJAivK84rIRLEC0nyyBI4NzQHkSRcwsryxAas7F4unQdEBAoW77lDot
QCWwaT8lNXZAkiav1tOqLUBudUYqArJ3QE3TbKMq+C1ArlEr8uBJeUDALVYe
Iy0uQMseYmhU/3pAqxaooDlALkCNWpEHN9V8QFe03HKgMi5AqqTlUK7OfkCi
nkv+Ic4tQEpUScuXd4BARCQsA8LWLECQhPR7R52BQN9BB3YDxStAPL4LB3/a
gkCW/YOcyZQqQKA4CwGYMYRAWfYOhg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAtYXKaU8MIkCpmFud4csNQLhf1ohr
MSNARaE+0MZ1JkBH6ldjBbIjQKzCvhF02jJAUGpGJUABJEB1w0e55po6QAjJ
Zp99OCRAzCrsG6M/QUDtSVIYrWUkQE+Q+0yHRUVALnB5DteNJECQeGrIKGFJ
QEfTkaJStCRAdEBljKqUTUDWvW5nkNskQEatyIMX8VBAZ5G4t00EJUCIp4YM
HiZTQO0V5JbnLyVAgE37ycxqVUBItBwJel8lQNBg2UOgwFdApxZ4H0+TJUDC
uExyRilaQOyjCYvMzCVAkpZDiZamXEB2LWFRbA0mQMoeYmiIOl9AttG8vSFY
JkBC+r2IovNgQJZKxXAgsyZACGBQnJdXYkAYSGPpIxQnQBYI3W1xymNApM3X
gRN8J0CSnAjjok1lQLRTpUGu6CdAcqszUrviZkCb2Z4yYF8oQDodUBlzi2hA
utF5e97DKEBbnZGKr0lqQCQadmzCeSlAwr4RzIYfbEBhCcO8T/QpQL4LB9E7
D25A+n7Ml7NrKkBGpwMqpQ1wQF9ovZK4BytAWPzVnDkjcUDUUW7fTMErQB5W
3vzXSXJALDQYDCIrLEC0nyyBI4NzQJraQoaUvixAas7F4unQdEC3fJhX8Uot
QCWwaT8lNXZAfkvBfXyQLUBudUYqArJ3QMQ64zv6yC1ArlEr8uBJeUAyoYbv
5u0tQMseYmhU/3pAKBUNWbnzLUCNWpEHN9V8QNijubgE0i1AqqTlUK7OfkA+
38lHvYEtQEpUScuXd4BAwVKlTo/KLECQhPR7R52BQBCHH0JMtytAPL4LB3/a
gkBaxb9S45AqQKA4CwGYMYRABDcQyw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAtYXKaU8MIkCpmFud4csNQLhf1ohr
MSNARaE+0MZ1JkBH6ldjBbIjQKzCvhF02jJAUGpGJUABJEB1w0e55po6QAjJ
Zp99OCRAzCrsG6M/QUDtSVIYrWUkQE+Q+0yHRUVALnB5DteNJECQeGrIKGFJ
QEfTkaJStCRAdEBljKqUTUDWvW5nkNskQEatyIMX8VBAZ5G4t00EJUCIp4YM
HiZTQO0V5JbnLyVAgE37ycxqVUBItBwJel8lQNBg2UOgwFdApxZ4H0+TJUDC
uExyRilaQOyjCYvMzCVAkpZDiZamXEB2LWFRbA0mQMoeYmiIOl9AttG8vSFY
JkBC+r2IovNgQJZKxXAgsyZACGBQnJdXYkAYSGPpIxQnQBYI3W1xymNApM3X
gRN8J0CSnAjjok1lQLRTpUGu6CdAcqszUrviZkCb2Z4yYF8oQDodUBlzi2hA
utF5e97DKEBbnZGKr0lqQCQadmzCeSlAwr4RzIYfbEBhCcO8T/QpQL4LB9E7
D25A+n7Ml7NrKkBGpwMqpQ1wQF9ovZK4BytAWPzVnDkjcUDUUW7fTMErQB5W
3vzXSXJALDQYDCIrLEC0nyyBI4NzQJraQoaUvixAas7F4unQdEC3fJhX8Uot
QCWwaT8lNXZAfkvBfXyQLUBudUYqArJ3QMQ64zv6yC1ArlEr8uBJeUAyoYbv
5u0tQMseYmhU/3pAKBUNWbnzLUCNWpEHN9V8QNijubgE0i1AqqTlUK7OfkA+
38lHvYEtQEpUScuXd4BAwVKlTo/KLECQhPR7R52BQBCHH0JMtytAPL4LB3/a
gkBaxb9S45AqQKA4CwGYMYRABDcQyw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAMAFUkzOVIUCpmFud4csNQPRZ9/ux
4SJARaE+0MZ1JkCALqnl2H8jQKzCvhF02jJA+PCQ61/dI0B1w0e55po6QCq7
glaMGiRAzCrsG6M/QUChGTbcC0gkQE+Q+0yHRUVAoDatyKtvJECQeGrIKGFJ
QC5OQ+2VlSRAdEBljKqUTUDgrkkP4rkkQEatyIMX8VBA4qCKIrrgJECIp4YM
HiZTQBXhZOcsCiVAgE37ycxqVUBD+gtpBDklQNBg2UOgwFdApFyocnptJUDC
uExyRilaQIcQk73rpyVAkpZDiZamXEDMe+x+nPslQMoeYmiIOl9AYrKaPSVY
JkBC+r2IovNgQGECAVKbyiZACGBQnJdXYkBL5QnjHU0nQBYI3W1xymNAsGj5
ZxXMJ0CSnAjjok1lQGY8PrZoSyhAcqszUrviZkCU7AtsY8soQDodUBlzi2hA
GcsoJMlKKUBbnZGKr0lqQH5XH00GyClAwr4RzIYfbEBqUzLFEEkqQL4LB9E7
D25AblvhFyrOKkBGpwMqpQ1wQGDJ82WATytAWPzVnDkjcUC8RkW6UMErQB5W
3vzXSXJAszJ81clhLEC0nyyBI4NzQHpRM1hj3ixAas7F4unQdEAk+d/Bfkkt
QCWwaT8lNXZAoNkhvW28LUBudUYqArJ3QHzRl7GTSy5ArlEr8uBJeUDWRW9A
UcEuQMseYmhU/3pAMPWoQ8UTL0CNWpEHN9V8QOT1up7pKS9AqqTlUK7OfkDK
gWDtUrUuQEpUScuXd4BA51H7pmUjLUCQhPR7R52BQLTlpISyyCtAPL4LB3/a
gkAKFZQlYOEpQKA4CwGYMYRAOyETzA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAArxovTRp9IUCpmFud4csNQFqMo0z7
yCJARaE+0MZ1JkBIWKLqCmojQKzCvhF02jJAObBMAVPII0B1w0e55po6QBaa
Y/KqBiRAzCrsG6M/QUAPVnJJfDQkQE+Q+0yHRUVAwjGv4IJdJECQeGrIKGFJ
QCD8HvA4hCRAdEBljKqUTUBW0keeXaokQEatyIMX8VBAk0Dyux3SJECIp4YM
HiZTQBQIsJml/SRAgE37ycxqVUARojZqfy0lQNBg2UOgwFdANBmHLcliJUDC
uExyRilaQCtBOHUkoCVAkpZDiZamXECLzgJURvYlQMoeYmiIOl9ANE6Xop5S
JkBC+r2IovNgQCRxz1pnxyZACGBQnJdXYkCfiW4VilAnQBYI3W1xymNA3BGA
MD3SJ0CSnAjjok1lQJxLmv+EUyhAcqszUrviZkCIuoebedYoQDodUBlzi2hA
Stk6zQZWKUBbnZGKr0lqQH4b/Bu3zClAwr4RzIYfbEDCOheJFUUqQL4LB9E7
D25AZ4cf8PPMKkBGpwMqpQ1wQF52HIr9SytAWPzVnDkjcUBc4vqqDMYrQB5W
3vzXSXJAIg6PwcJELEC0nyyBI4NzQK4A2kFSySxAas7F4unQdECQtaY7JiUt
QCWwaT8lNXZAMIAvtS2xLUBudUYqArJ3QLK11E3+MS5ArlEr8uBJeUCqgoxA
UJMuQMseYmhU/3pAujh+AFnHLkCNWpEHN9V8QJExQZ1Qqi5AqqTlUK7OfkCB
jz24tSQuQEpUScuXd4BAwO42iEnfLECQhPR7R52BQKKtUhc5nitAPL4LB3/a
gkDOvKzUy9sqQKA4CwGYMYRANbILwQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAUmIfaeZxIUCpmFud4csNQICKJhHL
uyJARaE+0MZ1JkAQKR9611kjQKzCvhF02jJAyqVKAj63I0B1w0e55po6QML6
Jm4b9CNAzCrsG6M/QUCNBB0oDSIkQE+Q+0yHRUVApR/E+cxKJECQeGrIKGFJ
QMWhMqm/cSRAdEBljKqUTUBxQMuaPpgkQEatyIMX8VBA4LsdPgjAJECIp4YM
HiZTQMyimMmw6yRAgE37ycxqVUBkfpqH2BslQNBg2UOgwFdAweBFnY9RJUDC
uExyRilaQBhg4EG7jSVAkpZDiZamXEAs38oGR+IlQMoeYmiIOl9AeL96NztC
JkBC+r2IovNgQGZc4NlxuCZACGBQnJdXYkAsgliRdUMnQBYI3W1xymNArjqI
cmjGJ0CSnAjjok1lQLkgyYIXSShAcqszUrviZkCO7jLe9MYoQDodUBlzi2hA
B0Jz9NlBKUBbnZGKr0lqQMK816FxtilAwr4RzIYfbEAIp5pvsTkqQL4LB9E7
D25AuxGNqnGxKkBGpwMqpQ1wQHzOjbkyMitAWPzVnDkjcUAuQp11rJwrQB5W
3vzXSXJAOLpBlWAVLEC0nyyBI4NzQGrujgi0fyxAas7F4unQdEBKMieTZ+ks
QCWwaT8lNXZAvcWtSWteLUBudUYqArJ3QFBiN4wtwS1ArlEr8uBJeUBQ3FeE
9Q4uQMseYmhU/3pAvox05/I2LkCNWpEHN9V8QKNnIvlNFi5AqqTlUK7OfkBX
Ug64cqgtQEpUScuXd4BA5heKlaxsLECQhPR7R52BQB6p1bniiStAPL4LB3/a
gkBgSu97J18qQKA4CwGYMYRAopEQCA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAZO2Q8eF1IUCpmFud4csNQEuJ9HtG
wCJARaE+0MZ1JkD5oX++418jQKzCvhF02jJACJy9Nia8I0B1w0e55po6QHJu
Trhw+SNAzCrsG6M/QUA6Oh5dTyckQE+Q+0yHRUVALtgfv15QJECQeGrIKGFJ
QIJWHWv9dyRAdEBljKqUTUCZq3+K1Z0kQEatyIMX8VBA1ADpoOLGJECIp4YM
HiZTQHokkl+s8iRAgE37ycxqVUBz+qB6GiIlQNBg2UOgwFdA1Fn7UFJZJUDC
uExyRilaQDy8UioklSVAkpZDiZamXEBXJNFRTOglQMoeYmiIOl9AwbWuPrNI
JkBC+r2IovNgQGCGhUWjvSZACGBQnJdXYkBy39Q1W0gnQBYI3W1xymNA5zZt
rmvNJ0CSnAjjok1lQMzkE7kHTyhAcqszUrviZkAWYy2knc0oQDodUBlzi2hA
UClEIk9HKUBbnZGKr0lqQHgcyAyjtylAwr4RzIYfbECOimV6ZEEqQL4LB9E7
D25A2YSLXAWxKkBGpwMqpQ1wQGaI0oa7JitAWPzVnDkjcUC0e5UYlaQrQB5W
3vzXSXJAYNsZ3in+K0C0nyyBI4NzQBQFWZweeCxAas7F4unQdEBIxKHvldQs
QCWwaT8lNXZAOgake/8/LUBudUYqArJ3QEiQd/DUoy1ArlEr8uBJeUDqw4iC
UtYtQMseYmhU/3pADgkBH0MLLkCNWpEHN9V8QK7qys0rBS5AqqTlUK7OfkBp
sOq4QLQtQEpUScuXd4BAYvSpPqbwLECQhPR7R52BQEibVWy+3StAPL4LB3/a
gkBEQ7hMS0oqQKA4CwGYMYRAfLkQ9A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA5AvRQ16MIUCpmFud4csNQLToY3ra
1yJARaE+0MZ1JkA84MJb3nkjQKzCvhF02jJA6d1wfcnYI0B1w0e55po6QFbW
0nWhFiRAzCrsG6M/QUCaDlzAs0UkQE+Q+0yHRUVAdjIxLa5vJECQeGrIKGFJ
QLhaQmd3liRAdEBljKqUTUBoCDiKMr4kQEatyIMX8VBAajWBjkLnJECIp4YM
HiZTQKgEGxO9EyVAgE37ycxqVUB3g0/lMEQlQNBg2UOgwFdAKT7Cqe15JUDC
uExyRilaQDkdneDqtiVAkpZDiZamXED5pAB3SAUmQMoeYmiIOl9AVyxbqj1m
JkBC+r2IovNgQOzpNZNc2yZACGBQnJdXYkAe956vsmInQBYI3W1xymNAW1QC
luXlJ0CSnAjjok1lQDnec5XiZShAcqszUrviZkDLDGvHNOMoQDodUBlzi2hA
0ssAcJdeKUBbnZGKr0lqQCzQaCvVuClAwr4RzIYfbEDqe9lZ+UUqQL4LB9E7
D25AKCkM+NPIKkBGpwMqpQ1wQPgvC26UHitAWPzVnDkjcUB4enP9MqIrQB5W
3vzXSXJANlY3iArxK0C0nyyBI4NzQPD1tlFkbyxAas7F4unQdEAySMv6HuMs
QCWwaT8lNXZAX3gFZsoQLUBudUYqArJ3QIltbsGCei1ArlEr8uBJeUCLuF7p
os0tQMseYmhU/3pAtDRK+yoALkCNWpEHN9V8QP8UVKg+CC5AqqTlUK7OfkBV
JjO5DastQEpUScuXd4BA1L6aqU0oLUCQhPR7R52BQNoQxaRQwCtAPL4LB3/a
gkCqDQhiengqQKA4CwGYMYRAMwsQPg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAfeWlbQedIUCpmFud4csNQOgtqlo9
6SJARaE+0MZ1JkCkZd6XUYsjQKzCvhF02jJAd0AjFn7qI0B1w0e55po6QHk/
GV5DJyRAzCrsG6M/QUDRPCQr1VckQE+Q+0yHRUVAcr4MggWAJECQeGrIKGFJ
QGKw3v/NpiRAdEBljKqUTUBSnM1xAM4kQEatyIMX8VBAE8NeOvH1JECIp4YM
HiZTQF/5FYzZIiVAgE37ycxqVUAqATja+1ElQNBg2UOgwFdAzXgPSwuIJUDC
uExyRilaQMAOK5yXxCVAkpZDiZamXEAKGsj3IA0mQMoeYmiIOl9AGqmaJnRw
JkBC+r2IovNgQNYcfPpd5CZACGBQnJdXYkAd1Y2RU2knQBYI3W1xymNAYr2B
/EjpJ0CSnAjjok1lQD9taOtNZyhAcqszUrviZkDKeiQpDeIoQDodUBlzi2hA
9SxBCQpdKUBbnZGKr0lqQFS7cz3kuylAwr4RzIYfbEArGQR7dD4qQL4LB9E7
D25Am1GGVEDLKkBGpwMqpQ1wQFmZ5m8rGytAWPzVnDkjcUBOgm4JfagrQB5W
3vzXSXJArjvjOwXuK0C0nyyBI4NzQOY6BAJbhCxAas7F4unQdEB+ZC8hH9os
QCWwaT8lNXZAmiwtuR0vLUBudUYqArJ3QDr2Jq5qhC1ArlEr8uBJeUD6ka98
vMAtQMseYmhU/3pAISQ+7uzLLUCNWpEHN9V8QErGuai5ny1AqqTlUK7OfkDH
wZU00mYtQEpUScuXd4BAEqe0pz+nLECQhPR7R52BQAsuAtToxCtAPL4LB3/a
gkBp8eaGhzwqQKA4CwGYMYRA+tIKtg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAfeWlbQedIUCpmFud4csNQOgtqlo9
6SJARaE+0MZ1JkCkZd6XUYsjQKzCvhF02jJAd0AjFn7qI0B1w0e55po6QHk/
GV5DJyRAzCrsG6M/QUDRPCQr1VckQE+Q+0yHRUVAcr4MggWAJECQeGrIKGFJ
QGKw3v/NpiRAdEBljKqUTUBSnM1xAM4kQEatyIMX8VBAE8NeOvH1JECIp4YM
HiZTQF/5FYzZIiVAgE37ycxqVUAqATja+1ElQNBg2UOgwFdAzXgPSwuIJUDC
uExyRilaQMAOK5yXxCVAkpZDiZamXEAKGsj3IA0mQMoeYmiIOl9AGqmaJnRw
JkBC+r2IovNgQNYcfPpd5CZACGBQnJdXYkAd1Y2RU2knQBYI3W1xymNAYr2B
/EjpJ0CSnAjjok1lQD9taOtNZyhAcqszUrviZkDKeiQpDeIoQDodUBlzi2hA
9SxBCQpdKUBbnZGKr0lqQFS7cz3kuylAwr4RzIYfbEArGQR7dD4qQL4LB9E7
D25Am1GGVEDLKkBGpwMqpQ1wQFmZ5m8rGytAWPzVnDkjcUBOgm4JfagrQB5W
3vzXSXJArjvjOwXuK0C0nyyBI4NzQOY6BAJbhCxAas7F4unQdEB+ZC8hH9os
QCWwaT8lNXZAmiwtuR0vLUBudUYqArJ3QDr2Jq5qhC1ArlEr8uBJeUD6ka98
vMAtQMseYmhU/3pAISQ+7uzLLUCNWpEHN9V8QErGuai5ny1AqqTlUK7OfkDH
wZU00mYtQEpUScuXd4BAEqe0pz+nLECQhPR7R52BQAsuAtToxCtAPL4LB3/a
gkBp8eaGhzwqQKA4CwGYMYRA+tIKtg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAABfyGPTM/IUCpmFud4csNQFe9e3CZ
viNARaE+0MZ1JkAms/pRL4IkQKzCvhF02jJAVlFkgyoZJUB1w0e55po6QLgj
zMitxyVAzCrsG6M/QUDRwWIFISwmQE+Q+0yHRUVAXpQOBNuvJkCQeGrIKGFJ
QBwwk2aI/CZAdEBljKqUTUBY5KkGzGAnQEatyIMX8VBAvaineGrKJ0CIp4YM
HiZTQI7kKscpBihAgE37ycxqVUDf9lsNU2soQNBg2UOgwFdAHDZUqM6gKEDC
uExyRilaQDFrCbKsBylAkpZDiZamXECK6JXWLTkpQMoeYmiIOl9AJtI5TrKk
KUBC+r2IovNgQOAJXdYk1SlACGBQnJdXYkAQHpRsP0cqQBYI3W1xymNARVmm
KxZ1KkCSnAjjok1lQAw7qmNQ6ipAcqszUrviZkDzeCtJhRYrQDodUBlzi2hA
F4wgw2iAK0BbnZGKr0lqQG6mkLyC5CtAwr4RzIYfbEDIhGOrvUksQL4LB9E7
D25AVPl0Cd63LEBGpwMqpQ1wQEB/C/kz+yxAWPzVnDkjcUASD7eggmstQB5W
3vzXSXJA8oNTKsLaLUC0nyyBI4NzQHv9wFBf9i1Aas7F4unQdEDVwqcxCXUu
QCWwaT8lNXZAkL6vAtLlLkBudUYqArJ3QKIHCvXNOi9ArlEr8uBJeUCaVhNt
y28vQMseYmhU/3pAZNAk98BzL0CNWpEHN9V8QDpZ1eHdBC9AqqTlUK7OfkDG
vTkx2O0tQEpUScuXd4BAcGznQtb3K0CQhPR7R52BQLyw+p0euCpAPL4LB3/a
gkDb249D8PcoQKA4CwGYMYRAfgsRxw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAlecsF4kbIUCpmFud4csNQNbsMTNt
mSNARaE+0MZ1JkBhE9bvQVskQKzCvhF02jJA7z90c0DyJEB1w0e55po6QNOW
Suc6oSVAzCrsG6M/QUCiMe4tsAcmQE+Q+0yHRUVACQuy1FqNJkCQeGrIKGFJ
QATOMbz23CZAdEBljKqUTUDCmlUo600nQEatyIMX8VBAJhfOmJKTJ0CIp4YM
HiZTQC69IT0z7idAgE37ycxqVUD4SoW1SlUoQNBg2UOgwFdA2RG+63+NKEDC
uExyRilaQOV1XUlL9ihAkpZDiZamXECHz35WDyspQMoeYmiIOl9AESAtP4KY
KUBC+r2IovNgQCccMUdVySlACGBQnJdXYkDxkZ5SOTwqQBYI3W1xymNAF2eF
ctJ4KkCSnAjjok1lQLdw6nly6ypAcqszUrviZkDW38IFvRkrQDodUBlzi2hA
Im1lwBaFK0BbnZGKr0lqQHue0V/v9itAwr4RzIYfbEDy1JzigyAsQL4LB9E7
D25AQGcvVmeILEBGpwMqpQ1wQIYFKe/b7yxAWPzVnDkjcUAQuC7f3kMtQB5W
3vzXSXJARpQzvKe9LUC0nyyBI4NzQPxCfX/m8S1Aas7F4unQdEDQjmah9m4u
QCWwaT8lNXZAbCked/TQLkBudUYqArJ3QKQh98j3ES9ArlEr8uBJeUCrmxSe
fSgvQMseYmhU/3pA2pkAYkb1LkCNWpEHN9V8QELF1CmASi5AqqTlUK7OfkCg
c0BDEGotQEpUScuXd4BAAeN4upbXK0CQhPR7R52BQDL0GTzvBytAPL4LB3/a
gkACK9Uyb0kqQKA4CwGYMYRADW4QnA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAkXy6007/IECpmFud4csNQGX1la0D
eCNARaE+0MZ1JkBZVAYbcDgkQKzCvhF02jJAaHFloInPJEB1w0e55po6QKgi
35rJeyVAzCrsG6M/QUBBnhBibOElQE+Q+0yHRUVAvrW2d6FnJkCQeGrIKGFJ
QBvMgmlRtiZAdEBljKqUTUBKghsk+B4nQEatyIMX8VBAqgkedBmIJ0CIp4YM
HiZTQLi0MUmVxSdAgE37ycxqVUB+8h5TJjAoQNBg2UOgwFdAEHeA27JpKEDC
uExyRilaQCJvp+w/1ChAkpZDiZamXEAelgI3pAkpQMoeYmiIOl9AkoNcn3d5
KUBC+r2IovNgQFBJ7XoGrSlACGBQnJdXYkBxaQbY/iEqQBYI3W1xymNA2Ck7
Bs9UKkCSnAjjok1lQNXe1eeUwCpAcqszUrviZkDK3/8lDBkrQDodUBlzi2hA
VEBSswtqK0BbnZGKr0lqQAh4KTL60itAwr4RzIYfbEBPpWTafgosQL4LB9E7
D25APj7tB3drLEBGpwMqpQ1wQIycl/lDwSxAWPzVnDkjcUC3WSZJQhUtQB5W
3vzXSXJA1oKCvNt4LUC0nyyBI4NzQEKIDOkr0C1Aas7F4unQdECewb0cdCQu
QCWwaT8lNXZAjg1HAD1oLkBudUYqArJ3QIZiIVV0mS5ArlEr8uBJeUDce81Z
uasuQMseYmhU/3pAFsUPZ5KDLkCNWpEHN9V8QD2Xvxp2/S1AqqTlUK7OfkCM
q/2IW/ssQEpUScuXd4BAGAir1MmeK0CQhPR7R52BQGCFC4B1/ypAPL4LB3/a
gkCs+vXLmOMpQKA4CwGYMYRA0VwOGg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAD7mm0Rf9IECpmFud4csNQEztutdz
dyNARaE+0MZ1JkBvzcNdOzckQKzCvhF02jJAwfwamcrOJEB1w0e55po6QF8+
327leiVAzCrsG6M/QUAafUIwu+ElQE+Q+0yHRUVA6oDnUrdnJkCQeGrIKGFJ
QA6wQSWotSZAdEBljKqUTUAToJxplx4nQEatyIMX8VBAuL13cXGMJ0CIp4YM
HiZTQDiUEKjnyCdAgE37ycxqVUDMnZW+ETEoQNBg2UOgwFdAEswiyrF2KEDC
uExyRilaQLGLZhPS4ShAkpZDiZamXEBWwPb/FhcpQMoeYmiIOl9ABxO9haeE
KUBC+r2IovNgQHq4lTsyuSlACGBQnJdXYkCM9iKlpCIqQBYI3W1xymNA6ldL
HRSWKkCSnAjjok1lQPBHOyn2xCpAcqszUrviZkAkqb/v6DIrQDodUBlzi2hA
sQX6bD1gK0BbnZGKr0lqQHwQ7bJlwCtAwr4RzIYfbEDQSPOXFxwsQL4LB9E7
D25AQuxCDWuCLEBGpwMqpQ1wQICFgyd1ryxAWPzVnDkjcUCVKlPr3gstQB5W
3vzXSXJA/FukkhZaLUC0nyyBI4NzQNaN1ARuqS1Aas7F4unQdEAAQ9t7luAt
QCWwaT8lNXZAGhuUgNMtLkBudUYqArJ3QEymoIBRRi5ArlEr8uBJeUBkO/dL
smIuQMseYmhU/3pAgMOvxlFLLkCNWpEHN9V8QHOmx8Q/9S1AqqTlUK7OfkBo
2j6I8PosQEpUScuXd4BA/tSsePDkK0CQhPR7R52BQGoW5/mgySpAPL4LB3/a
gkBPWNf8cDMpQKA4CwGYMYRAgTkXRw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1egOS4EEIUCpmFud4csNQHz8WqQO
giNARaE+0MZ1JkBISJMzm0IkQKzCvhF02jJAlMdjIDjaJEB1w0e55po6QFJL
eqVviCVAzCrsG6M/QUBoVsTtMO4lQE+Q+0yHRUVAOLfuAmJ2JkCQeGrIKGFJ
QJqM8qTJxCZAdEBljKqUTUBz18AWvy0nQEatyIMX8VBAONgoT2KWJ0CIp4YM
HiZTQFpnOR/o8ydAgE37ycxqVUBcmkrcLCwoQNBg2UOgwFdAIoRXnJqNKEDC
uExyRilaQGog5eDX9ihAkpZDiZamXEB3X5ZVTywpQMoeYmiIOl9AEWDIYfqW
KUBC+r2IovNgQIZUdxUCzClACGBQnJdXYkAM8kc3yjAqQBYI3W1xymNAjVVb
RzefKkCSnAjjok1lQJh4H/ye0SpAcqszUrviZkD66JsGGD4rQDodUBlzi2hA
etqABGJrK0BbnZGKr0lqQAzWcn3U0StAwr4RzIYfbECcQaL3xwMsQL4LB9E7
D25A0HXnoHFvLEBGpwMqpQ1wQNqYC0dYoixAWPzVnDkjcUDScsFP2QktQB5W
3vzXSXJADtO+IxMsLUC0nyyBI4NzQBTno9SelC1Aas7F4unQdEBvmiXflq4t
QCWwaT8lNXZApZSjeR/5LUBudUYqArJ3QAIj5PDzMy5ArlEr8uBJeUA84ipA
Y1YuQMseYmhU/3pA9EX0Vc9aLkCNWpEHN9V8QFrY1YqmEi5AqqTlUK7OfkAY
GAhqWlYtQEpUScuXd4BArCYRLe2tLECQhPR7R52BQGjMCo/dECtAPL4LB3/a
gkDw2U+LQgYqQKA4CwGYMYRAWssO5Q==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA+PCmtD4SIUCpmFud4csNQAXJnmT7
jyNARaE+0MZ1JkD4CALY6FAkQKzCvhF02jJAPvtTedTnJEB1w0e55po6QIK+
CJQ0liVAzCrsG6M/QUD+DqbsKfwlQE+Q+0yHRUVAVruX0gWCJkCQeGrIKGFJ
QO22fbER0SZAdEBljKqUTUD1T0qJKDcnQEatyIMX8VBAJDWzgvyZJ0CIp4YM
HiZTQNqr9hfB/ydAgE37ycxqVUABnypnzjgoQNBg2UOgwFdAv3mjIhKYKEDC
uExyRilaQAbPHfGD/ShAkpZDiZamXEC6Qf+mFTIpQMoeYmiIOl9AGDI+pEyd
KUBC+r2IovNgQCh5exrUzilACGBQnJdXYkB+OUZcFj0qQBYI3W1xymNA+JCl
BrRmKkCSnAjjok1lQB5+9OKJ0ypAcqszUrviZkCQmqBl6j4rQDodUBlzi2hA
ElQ5eAtpK0BbnZGKr0lqQHYXur7Z1CtAwr4RzIYfbEACQin1GAAsQL4LB9E7
D25ApBC+pihxLEBGpwMqpQ1wQBgPB6Y/myxAWPzVnDkjcUBCxszRJQwtQB5W
3vzXSXJA6XIh2D0sLUC0nyyBI4NzQFV8XAVBlC1Aas7F4unQdEDYSyF7eLYt
QCWwaT8lNXZALi87KLbxLUBudUYqArJ3QJ6t39dyFy5ArlEr8uBJeUB622+q
tScuQMseYmhU/3pAbfMo69wILkCNWpEHN9V8QGaSFImply1AqqTlUK7OfkBu
HzMxDUctQEpUScuXd4BA9kVythwmLECQhPR7R52BQI6nU+kNEytAPL4LB3/a
gkDm5yqs7KkpQKA4CwGYMYRAX/oNkA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA+PCmtD4SIUCpmFud4csNQAXJnmT7
jyNARaE+0MZ1JkD4CALY6FAkQKzCvhF02jJAPvtTedTnJEB1w0e55po6QIK+
CJQ0liVAzCrsG6M/QUD+DqbsKfwlQE+Q+0yHRUVAVruX0gWCJkCQeGrIKGFJ
QO22fbER0SZAdEBljKqUTUD1T0qJKDcnQEatyIMX8VBAJDWzgvyZJ0CIp4YM
HiZTQNqr9hfB/ydAgE37ycxqVUABnypnzjgoQNBg2UOgwFdAv3mjIhKYKEDC
uExyRilaQAbPHfGD/ShAkpZDiZamXEC6Qf+mFTIpQMoeYmiIOl9AGDI+pEyd
KUBC+r2IovNgQCh5exrUzilACGBQnJdXYkB+OUZcFj0qQBYI3W1xymNA+JCl
BrRmKkCSnAjjok1lQB5+9OKJ0ypAcqszUrviZkCQmqBl6j4rQDodUBlzi2hA
ElQ5eAtpK0BbnZGKr0lqQHYXur7Z1CtAwr4RzIYfbEACQin1GAAsQL4LB9E7
D25ApBC+pihxLEBGpwMqpQ1wQBgPB6Y/myxAWPzVnDkjcUBCxszRJQwtQB5W
3vzXSXJA6XIh2D0sLUC0nyyBI4NzQFV8XAVBlC1Aas7F4unQdEDYSyF7eLYt
QCWwaT8lNXZALi87KLbxLUBudUYqArJ3QJ6t39dyFy5ArlEr8uBJeUB622+q
tScuQMseYmhU/3pAbfMo69wILkCNWpEHN9V8QGaSFImply1AqqTlUK7OfkBu
HzMxDUctQEpUScuXd4BA9kVythwmLECQhPR7R52BQI6nU+kNEytAPL4LB3/a
gkDm5yqs7KkpQKA4CwGYMYRAX/oNkA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.33, 33.}, {10.66, 40.}, {10.89, 50.}, {11.04, 60.}, {
          11.32, 70.}, {11.72, 80.}, {11.97, 90.}, {12., 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.42, 33.}, {10.65, 40.}, {10.86, 50.}, {11.02, 60.}, {
          11.19, 70.}, {11.47, 80.}, {11.76, 90.}, {11.78, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.44, 33.}, {10.65, 40.}, {10.75, 50.}, {10.86, 60.}, {
          11.06, 70.}, {11.34, 80.}, {11.59, 90.}, {11.57, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.39, 33.}, {10.7, 40.}, {10.88, 50.}, {10.96, 60.}, {
          11.14, 70.}, {11.46, 80.}, {11.79, 90.}, {11.78, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{9.61, 33.}, {9.9, 40.}, {10.2, 50.}, {10.46, 60.}, {10.7, 
          70.}, {11.03, 80.}, {11.34, 90.}, {11.35, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.22, 33.}, {10.44, 40.}, {10.69, 50.}, {10.83, 60.}, {
          11.01, 70.}, {11.3, 80.}, {11.64, 90.}, {11.71, 100.}}]}}}, {}}}, {
    PlotRange -> All, AspectRatio -> 1.2, Frame -> True, FrameLabel -> {
       FormBox[
       "\"WS \\!\\(\\*SuperscriptBox[\\(ms\\), \\(-1\\)]\\)\"", 
        TraditionalForm], 
       FormBox["\"Height   m\"", TraditionalForm]}, 
     TextStyle -> {FontSize -> 16}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {7.533891473957823, 0}, 
     PlotRange -> {{7.659319144725798, 15.686690073876171`}, {
       0, 646.199220740953}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {7.533891473957823, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{7.659319144725798, 15.686690073876171`}, {
       0, 646.199220740953}}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"EWP 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0.25 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=1 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.88, 1, 0.88], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5866666666666667, 0.6666666666666666, 
                    0.5866666666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0.88, 1, 0.88]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.88, 1, 0.88]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.88, 1, 0.88], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"No Farm 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0.5]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False]}],
                    "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8056991136468496`*^9, 3.805699154104714*^9}, 
   3.80570255956734*^9, 3.8057026116051354`*^9, 3.8057026772666016`*^9, {
   3.806376277691851*^9, 3.806376282993504*^9}, 3.8135673559593563`*^9, 
   3.8135845928631115`*^9, 3.813584648753433*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"EWP15", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<EWP 15:00-16:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch15B", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Green", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Green", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0.25 14:00-15:00\>\"", "}"}]}]}], "]"}], 
   ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch15C", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Black", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=1 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch15", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "LightGreen", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "LightGreen", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"NWF15", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Gray", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Gray", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<No Farm 15:00-16:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"wstest15", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"wstestmean", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Pink"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<FINO1 OBS 14:00-14:50\>\"", "}"}]}]}], "]"}], ","}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<WS \!\(\*SuperscriptBox[\(ms\), \(-1\)]\)\>\"", ",", 
      "\"\<Height   m\>\""}], "}"}]}], ",", 
   RowBox[{"TextStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "16"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.80570264985384*^9, 3.805702707119752*^9}, {3.8135847118922386`*^9, 
   3.8135847189880505`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.8057026997953672`*^9, 3.805702708200861*^9}, 
   3.806376290777954*^9, 3.813567372748063*^9, 3.8135847205878487`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAtg0NPQmKHkCpmFud4csNQFK2If+N
iyFARaE+0MZ1JkBEQAEt4jIiQKzCvhF02jJAPuLW2bO5IkB1w0e55po6QEze
llgfTiNAzCrsG6M/QUCUj5Xo4bYjQE+Q+0yHRUVApYy88KUNJECQeGrIKGFJ
QLB7ypw1gSRAdEBljKqUTUDcabnYocgkQEatyIMX8VBAANQYfY82JUCIp4YM
HiZTQPyomdiHdyVAgE37ycxqVUBREsvc9OklQNBg2UOgwFdA2VycnEsrJkDC
uExyRilaQN72qqpCpiZAkpZDiZamXEARYJdtdOkmQMoeYmiIOl9AstiZyYhs
J0BC+r2IovNgQMJKJGJuuidACGBQnJdXYkCUqdwPeUgoQBYI3W1xymNA6ld6
sn2QKECSnAjjok1lQNDcYPPxGClAcqszUrviZkB+j5O2YqYpQDodUBlzi2hA
HL3ObE8DKkBbnZGKr0lqQFEp3IHlkipAwr4RzIYfbEDCjCpwnO4qQL4LB9E7
D25A8CnusJ6EK0BGpwMqpQ1wQDDzb+hmyytAWPzVnDkjcUAcuqKgTE0sQB5W
3vzXSXJAwkQwBPbiLEC0nyyBI4NzQJPOgDjXBi1Aas7F4unQdEB6SSYuW3Et
QCWwaT8lNXZAHWjN9BLFLUBudUYqArJ3QCsTBKAt5i1ArlEr8uBJeUDeRpMc
VfwtQMseYmhU/3pAih+qm3X5LUCNWpEHN9V8QJgybnJHvi1AqqTlUK7OfkAM
mJadPmAtQEpUScuXd4BAhs+3M+uGLECQhPR7R52BQKuaSsFvaytAPL4LB3/a
gkAcU5CFG+8pQKA4CwGYMYRAt+cXDQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAPx+BHjNkHkCpmFud4csNQN8QSatt
cyFARaE+0MZ1JkDaWJJ39BciQKzCvhF02jJAMrMGNKOeIkB1w0e55po6QM1Z
RQ5QISNAzCrsG6M/QUD3agYIY6EjQE+Q+0yHRUVAbWLPDbHxI0CQeGrIKGFJ
QEsba5PGZCRAdEBljKqUTUB4wpr8hqkkQEatyIMX8VBAN7teLCoXJUCIp4YM
HiZTQJgacXtYVyVAgE37ycxqVUB+abyJTL4lQNBg2UOgwFdA6c3EZ0IwJkDC
uExyRilaQFiARt1bcSZAkpZDiZamXED7710QxO0mQMoeYmiIOl9ALJIJfmtv
J0BC+r2IovNgQJHWb8dsuCdACGBQnJdXYkCcUMbuR0ooQBYI3W1xymNALnlF
NO6TKECSnAjjok1lQKQLd6drJClAcqszUrviZkAwn7oh5b0pQDodUBlzi2hA
xDgH4Vz8KUBbnZGKr0lqQICShewEjCpAwr4RzIYfbEDq8Ld5pRwrQL4LB9E7
D25A1t9Ogue5K0BGpwMqpQ1wQN6O9Ehw8ytAWPzVnDkjcUBco1wqT3csQB5W
3vzXSXJAigc5/Yr+LEC0nyyBI4NzQFiSO2czLS1Aas7F4unQdEAgwI1cPXst
QCWwaT8lNXZA7kxibAnCLUBudUYqArJ3QDxL1pGiAC5ArlEr8uBJeUAKz53q
ewouQMseYmhU/3pAehQnZ+4BLkCNWpEHN9V8QMAfrkHZsy1AqqTlUK7OfkBp
9a5RUkgtQEpUScuXd4BAHYr6I5CnLECQhPR7R52BQFTXoonWRStAPL4LB3/a
gkCYhRqARpQpQKA4CwGYMYRAg9gNjA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAM9y/mutRHkCpmFud4csNQHkAwXf2
aSFARaE+0MZ1JkClu3cZsxIiQKzCvhF02jJAlxXyasGYIkB1w0e55po6QEGo
b6pKFyNAzCrsG6M/QUBr0T8d+JojQE+Q+0yHRUVAWRcNbXnuI0CQeGrIKGFJ
QLqHFc+IYSRAdEBljKqUTUAoXUQcIagkQEatyIMX8VBAZjbhhhsWJUCIp4YM
HiZTQOZOK3yGXyVAgE37ycxqVUCEE7CLH8UlQNBg2UOgwFdATpHBWKg5JkDC
uExyRilaQC7iZj1yeSZAkpZDiZamXEAsdtbnvPUmQMoeYmiIOl9A7L4cbERO
J0BC+r2IovNgQIXpjMTi0idACGBQnJdXYkDqqkFyWGEoQBYI3W1xymNAUyY2
IHKnKECSnAjjok1lQG5KWk3SMilAcqszUrviZkBKJf/D18EpQDodUBlzi2hA
gv0RJfdgKkBbnZGKr0lqQLCQVNIAoypAwr4RzIYfbEDommuxuDsrQL4LB9E7
D25Alt/ilgzfK0BGpwMqpQ1wQCdnPyckHixAWPzVnDkjcUBFrrdSHLQsQB5W
3vzXSXJAvorLdOz5LEC0nyyBI4NzQFqGbRa+YC1Aas7F4unQdEDAZAEOd7At
QCWwaT8lNXZAKMQjIHjiLUBudUYqArJ3QDOqe3XV/S1ArlEr8uBJeUCeSCue
SfotQMseYmhU/3pADOE40ALMLUCNWpEHN9V8QLR2PSu4QC1AqqTlUK7OfkAz
HoLBAPMsQEpUScuXd4BA3LBMl5SRK0CQhPR7R52BQNqJOIPUgypAPL4LB3/a
gkC22i1JzBcpQKA4CwGYMYRAFjgPLA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAKKB6KutFHkCpmFud4csNQHusAg28
ZSFARaE+0MZ1JkA6UCVRbAoiQKzCvhF02jJA8oUrP16TIkB1w0e55po6QABm
lCI6ESNAzCrsG6M/QUCQSl1MJZcjQE+Q+0yHRUVAfEE02A3oI0CQeGrIKGFJ
QMK5wh8/XiRAdEBljKqUTUBGdn9SvqQkQEatyIMX8VBA83vRwHIXJUCIp4YM
HiZTQDlL0/zwViVAgE37ycxqVUCHdK6CPcolQNBg2UOgwFdAikC9Fh8oJkDC
uExyRilaQDbmapT4jCZAkpZDiZamXEBqqBl6zw0nQMoeYmiIOl9AjG1dT2hP
J0BC+r2IovNgQE08hX6m1SdACGBQnJdXYkCaTcTBxVEoQBYI3W1xymNAutvW
W4PSKECSnAjjok1lQLrCWumSYSlAcqszUrviZkDALi5G2scpQDodUBlzi2hA
3BxOHZppKkBbnZGKr0lqQDs0/JmJqypAwr4RzIYfbEBOc2zeiEUrQL4LB9E7
D25AWH9eFR7lK0BGpwMqpQ1wQLy9j0o/HixAWPzVnDkjcUBuIWMimqwsQB5W
3vzXSXJAg3OWGTXYLEC0nyyBI4NzQIZutRjnLy1Aas7F4unQdEB6SA76W2gt
QCWwaT8lNXZAxG/umM2BLUBudUYqArJ3QFORpdYzfi1ArlEr8uBJeUAn9lPF
+W4tQMseYmhU/3pACL3xGpIPLUCNWpEHN9V8QJrT9okyVixAqqTlUK7OfkAc
lYFWftUrQEpUScuXd4BAUNFT0SxVKkCQhPR7R52BQN3x6z2UYSlAPL4LB3/a
gkAOuJkp3U0oQKA4CwGYMYRAMcgM7A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAgJ5Bbq1kHkCpmFud4csNQFyOHIE3
fyFARaE+0MZ1JkC4hisd8SUiQKzCvhF02jJAsjWwoxasIkB1w0e55po6QL8C
4NQZQCNAzCrsG6M/QUCoUctF2LAjQE+Q+0yHRUVAyi8gf2wKJECQeGrIKGFJ
QJqO1wLehyRAdEBljKqUTUDkT09ktc8kQEatyIMX8VBActGYkPBHJUCIp4YM
HiZTQD7i32r6iyVAgE37ycxqVUBmZoSoRgcmQNBg2UOgwFdAJKsPvNZJJkDC
uExyRilaQLDZirj5xiZAkpZDiZamXEAcEULitk4nQMoeYmiIOl9Asb7dk/mX
J0BC+r2IovNgQPNhSS54MShACGBQnJdXYkCfzxkDb3coQBYI3W1xymNAKDz4
2GUQKUCSnAjjok1lQD6EHHZHtSlAcqszUrviZkCC9wCYpAQqQDodUBlzi2hA
lrgkg7myKkBbnZGKr0lqQNjvFPn29CpAwr4RzIYfbEAPhEvmi5MrQL4LB9E7
D25AGxdVQE0xLEBGpwMqpQ1wQAAsl/NChixAWPzVnDkjcUD4UYqVrwktQB5W
3vzXSXJAyvgfsNM2LUC0nyyBI4NzQM5RiDU7iC1Aas7F4unQdEDaH5rJhbgt
QCWwaT8lNXZAcD7Ig1DHLUBudUYqArJ3QGKPxmpzwy1ArlEr8uBJeUB8LR9J
eoEtQMseYmhU/3pAVkYRGvcMLUCNWpEHN9V8QBPlkw8EvSxAqqTlUK7OfkBo
ZJvNbqYrQEpUScuXd4BA0kEvcIryKkCQhPR7R52BQEFJiPjsTSlAPL4LB3/a
gkC6pvkfF84nQKA4CwGYMYRAYjsQbg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAOaJPTvThHkCpmFud4csNQLRgZiZb
3SFARaE+0MZ1JkAYKqeMDYkiQKzCvhF02jJAZXg3+JkSI0B1w0e55po6QO1p
4yjftCNAzCrsG6M/QUBJPaINbBckQE+Q+0yHRUVAaMqeSCCbJECQeGrIKGFJ
QMHRDn5x+SRAdEBljKqUTUAHvn9q61QlQEatyIMX8VBAN+JpdDnQJUCIp4YM
HiZTQCQjfYm3FyZAgE37ycxqVUDIbDdFtJMmQNBg2UOgwFdAOB8jqYnYJkDC
uExyRilaQHy9bfg9VidAkpZDiZamXEAfyOWUSt4nQMoeYmiIOl9AgZ7yWEUq
KEBC+r2IovNgQI2oX0ziwyhACGBQnJdXYkA6N/9TGhApQBYI3W1xymNAP9OG
OOmpKUCSnAjjok1lQKiB81d6TypAcqszUrviZkCve9V+JqcqQDodUBlzi2hA
6lsXNnNSK0BbnZGKr0lqQBBzGYn4vStAwr4RzIYfbEC8C2h1AWwsQL4LB9E7
D25AoGa8XRmeLEBGpwMqpQ1wQOxzQU+nLi1AWPzVnDkjcUBqEXNtP6stQB5W
3vzXSXJASsbYdubRLUC0nyyBI4NzQC3LTknlGS5Aas7F4unQdEDZhfVtqEMu
QCWwaT8lNXZA4ArAmdFILkBudUYqArJ3QGjEValBMi5ArlEr8uBJeUDk6K95
r+stQMseYmhU/3pAro7R7vttLUCNWpEHN9V8QJiMVxZsNy1AqqTlUK7OfkA6
p8kMNUksQEpUScuXd4BAXJbThV9gK0CQhPR7R52BQKo6jLUVCypAPL4LB3/a
gkAyJBQjD+QoQKA4CwGYMYRAg+MNpw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAOaJPTvThHkCpmFud4csNQLRgZiZb
3SFARaE+0MZ1JkAYKqeMDYkiQKzCvhF02jJAZXg3+JkSI0B1w0e55po6QO1p
4yjftCNAzCrsG6M/QUBJPaINbBckQE+Q+0yHRUVAaMqeSCCbJECQeGrIKGFJ
QMHRDn5x+SRAdEBljKqUTUAHvn9q61QlQEatyIMX8VBAN+JpdDnQJUCIp4YM
HiZTQCQjfYm3FyZAgE37ycxqVUDIbDdFtJMmQNBg2UOgwFdAOB8jqYnYJkDC
uExyRilaQHy9bfg9VidAkpZDiZamXEAfyOWUSt4nQMoeYmiIOl9AgZ7yWEUq
KEBC+r2IovNgQI2oX0ziwyhACGBQnJdXYkA6N/9TGhApQBYI3W1xymNAP9OG
OOmpKUCSnAjjok1lQKiB81d6TypAcqszUrviZkCve9V+JqcqQDodUBlzi2hA
6lsXNnNSK0BbnZGKr0lqQBBzGYn4vStAwr4RzIYfbEC8C2h1AWwsQL4LB9E7
D25AoGa8XRmeLEBGpwMqpQ1wQOxzQU+nLi1AWPzVnDkjcUBqEXNtP6stQB5W
3vzXSXJASsbYdubRLUC0nyyBI4NzQC3LTknlGS5Aas7F4unQdEDZhfVtqEMu
QCWwaT8lNXZA4ArAmdFILkBudUYqArJ3QGjEValBMi5ArlEr8uBJeUDk6K95
r+stQMseYmhU/3pAro7R7vttLUCNWpEHN9V8QJiMVxZsNy1AqqTlUK7OfkA6
p8kMNUksQEpUScuXd4BAXJbThV9gK0CQhPR7R52BQKo6jLUVCypAPL4LB3/a
gkAyJBQjD+QoQKA4CwGYMYRAg+MNpw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAtRRLcKXZIECpmFud4csNQAyb3qsF
IiJARaE+0MZ1JkCiKdiqXq0iQKzCvhF02jJA52RhMl/9IkB1w0e55po6QNz2
0xBlMyNAzCrsG6M/QUAjLTc7iV4jQE+Q+0yHRUVA2G6HLuCFI0CQeGrIKGFJ
QBA6oqi9qiNAdEBljKqUTUAq31aRstAjQEatyIMX8VBA+KICS9r3I0CIp4YM
HiZTQK/9mA64IiRAgE37ycxqVUBAyWBpdFEkQNBg2UOgwFdAaqpMEDuHJEDC
uExyRilaQILaJx1MxCRAkpZDiZamXECgmiCTJw0lQMoeYmiIOl9AUNoL6yVi
JUBC+r2IovNgQCbeNHahLiZACGBQnJdXYkDm2SCF3xgnQBYI3W1xymNAHvny
UffKJ0CSnAjjok1lQBIFrZJGaChAcqszUrviZkBszJWWsgopQDodUBlzi2hA
pyHard51KUBbnZGKr0lqQMxzPJPQMCpAwr4RzIYfbECwESqm0IsqQL4LB9E7
D25AGrHbbpkoK0BGpwMqpQ1wQBBsFcdwvCtAWPzVnDkjcUDFr7YNO1gsQB5W
3vzXSXJA6VnVE66qLEC0nyyBI4NzQJBxd2NLEy1Aas7F4unQdEABobBc524t
QCWwaT8lNXZA3MRTPxioLUBudUYqArJ3QAj5xyMB1y1ArlEr8uBJeUAWv0bk
CO8tQMseYmhU/3pAdOHBdCTpLUCNWpEHN9V8QFbZgazUsC1AqqTlUK7OfkBJ
ifIVwVEtQEpUScuXd4BAIbdfTDKiLECQhPR7R52BQC2wDlmbZStAPL4LB3/a
gkC6F6vwwyIqQKA4CwGYMYRAt/gO+A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAQplkv0LfIECpmFud4csNQCsRVde+
KyJARaE+0MZ1JkBvzaO4abUiQKzCvhF02jJAjgicoSYII0B1w0e55po6QFCp
vdMrPiNAzCrsG6M/QUCYtMY5Z2kjQE+Q+0yHRUVAm24VNDeRI0CQeGrIKGFJ
QAJQKcfKtiNAdEBljKqUTUC2hdUU0NwjQEatyIMX8VBAE7wSwGAFJECIp4YM
HiZTQKirS3bPLyRAgE37ycxqVUAfObZS5V8kQNBg2UOgwFdAAukPzwaVJEDC
uExyRilaQLdP8oNG0yRAkpZDiZamXEAhN6XE7BolQMoeYmiIOl9A/sTK2e9v
JUBC+r2IovNgQOvk4kDLPSZACGBQnJdXYkBpKUBf1SUnQBYI3W1xymNAJECe
9mDZJ0CSnAjjok1lQJIDk03jdihAcqszUrviZkAM7pSoWBIpQDodUBlzi2hA
/I6H5mKQKUBbnZGKr0lqQBCAyimnTCpAwr4RzIYfbECyRbCJa6UqQL4LB9E7
D25AMCrgZSpBK0BGpwMqpQ1wQIRS4s793StAWPzVnDkjcUAssRVoEHEsQB5W
3vzXSXJAajx+chDkLEC0nyyBI4NzQNoze1iBTy1Aas7F4unQdEC0zer1cXgt
QCWwaT8lNXZA0i5FJr+vLUBudUYqArJ3QB83jtQw2C1ArlEr8uBJeUAeGttu
6eEtQMseYmhU/3pAFB+SPK/bLUCNWpEHN9V8QFUP50aXoC1AqqTlUK7OfkAJ
4Ap5gj4tQEpUScuXd4BA47M7ALqsLECQhPR7R52BQDzerR2AqitAPL4LB3/a
gkB8htIcyl8qQKA4CwGYMYRAO7APow==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAqfnjKdDnIECpmFud4csNQBj4qIKC
NiJARaE+0MZ1JkA5Dm52hMIiQKzCvhF02jJAY+JNyfYSI0B1w0e55po6QEw9
/d3KSiNAzCrsG6M/QUBAZ5nW/nUjQE+Q+0yHRUVAdvf1WJSdI0CQeGrIKGFJ
QKsYBGE5xCNAdEBljKqUTUBOllbE5OojQEatyIMX8VBANW2JrocSJECIp4YM
HiZTQHI86hM+PiRAgE37ycxqVUCVtzO09G4kQNBg2UOgwFdAjEO5/sKkJEDC
uExyRilaQHJmT+an4iRAkpZDiZamXEDD6BgBqSwlQMoeYmiIOl9ARh+oVmGC
JUBC+r2IovNgQDo1t26VVCZACGBQnJdXYkCLckhPvzonQBYI3W1xymNA5CVL
KXruJ0CSnAjjok1lQDjmy/l3jShAcqszUrviZkDCYoKijC8pQDodUBlzi2hA
m/EiD12rKUBbnZGKr0lqQJDIm58NbCpAwr4RzIYfbECeAOYhC8kqQL4LB9E7
D25A2tUXp1F6K0BGpwMqpQ1wQHgNmXhA5itAWPzVnDkjcUClqqAUFHwsQB5W
3vzXSXJA4NHjcrD3LEC0nyyBI4NzQPzieUCaSy1Aas7F4unQdEDiDZzTSHst
QCWwaT8lNXZAmdskPoOgLUBudUYqArJ3QOa2oDl/si1ArlEr8uBJeUAoytTE
tastQMseYmhU/3pAzPUuH26ELUCNWpEHN9V8QAL0R+E1Ei1AqqTlUK7OfkCw
xOsd+JIsQEpUScuXd4BA7Dc39vPUK0CQhPR7R52BQMyaJiNSkCpAPL4LB3/a
gkBC28IaflQpQKA4CwGYMYRAWoEXhg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA3t3KXyTUIECpmFud4csNQPaBWSSK
JiJARaE+0MZ1JkAodIvR77AiQKzCvhF02jJAT/XqE0UDI0B1w0e55po6QCY+
MLm2OSNAzCrsG6M/QUAitPvmXWUjQE+Q+0yHRUVAYWuAydaMI0CQeGrIKGFJ
QIBUcf0MsyNAdEBljKqUTUAW2NyP2tojQEatyIMX8VBACza8SGMDJECIp4YM
HiZTQGh7/dnHMCRAgE37ycxqVUCCetX3A2IkQNBg2UOgwFdAw5TmAYWZJEDC
uExyRilaQPwwkScv2yRAkpZDiZamXEAkGDYQGiclQMoeYmiIOl9Atgb5YL6F
JUBC+r2IovNgQOeTstkIZCZACGBQnJdXYkBW5rpLpEonQBYI3W1xymNAzu3R
/V/+J0CSnAjjok1lQEIzrrv3oyhAcqszUrviZkByV2BySFcpQDodUBlzi2hA
dK18EX/DKUBbnZGKr0lqQB8e81A4kSpAwr4RzIYfbEBKd3hekvAqQL4LB9E7
D25ARIvc5u65K0BGpwMqpQ1wQDJNpR87CCxAWPzVnDkjcUDURoMVipwsQB5W
3vzXSXJASlKQ1pwKLUC0nyyBI4NzQBYwxPxtKi1Aas7F4unQdEA2quVmlFAt
QCWwaT8lNXZAoT5+WB9bLUBudUYqArJ3QPCGq1jVQi1ArlEr8uBJeUBkiv6y
dgstQMseYmhU/3pAHfk7CzmtLECNWpEHN9V8QEEJOmJl8itAqqTlUK7OfkD+
yXqKNmkrQEpUScuXd4BAGiFbg2JSKkCQhPR7R52BQLIKU8EtxyhAPL4LB3/a
gkAyLsIs0+cnQKA4CwGYMYRAjkgPKw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1R5ABAPmIECpmFud4csNQKTX3ZRw
RSJARaE+0MZ1JkA+MAsJWtMiQKzCvhF02jJAsa7Ab3AmI0B1w0e55po6QFQj
VH3EXSNAzCrsG6M/QUB2iFaf74ojQE+Q+0yHRUVAEG1Sx3WyI0CQeGrIKGFJ
QMrzn3Vt2SNAdEBljKqUTUDCV3DorQAkQEatyIMX8VBAllh4DVspJECIp4YM
HiZTQHI1rk5ZVyRAgE37ycxqVUCYmBVlvokkQNBg2UOgwFdAFUSM+G7CJEDC
uExyRilaQIyda+DiAyVAkpZDiZamXEC35k/vUlIlQMoeYmiIOl9Acuktmryv
JUBC+r2IovNgQFhr0t5HjSZACGBQnJdXYkB5cSY3LXknQBYI3W1xymNAJT2e
yP4xKECSnAjjok1lQDj/LY603ShAcqszUrviZkBREB1z5Z8pQDodUBlzi2hA
RGTy9JgEKkBbnZGKr0lqQKrt7cPH2SpAwr4RzIYfbEB0br8x1zorQL4LB9E7
D25AXt6AZvsHLEBGpwMqpQ1wQITZnRUXYSxAWPzVnDkjcUB6TYVn8OUsQB5W
3vzXSXJASBXg820/LUC0nyyBI4NzQNAABPVQVy1Aas7F4unQdEDU4/qNUm8t
QCWwaT8lNXZA8vYACm9qLUBudUYqArJ3QHCFhjGaXy1ArlEr8uBJeUBP3cA3
NhotQMseYmhU/3pAwMc5ZOvXLECNWpEHN9V8QDmb8gN5KyxAqqTlUK7OfkBG
PTridrArQEpUScuXd4BARjE7dYjlKkCQhPR7R52BQPwh8JjQaClAPL4LB3/a
gkCiKtjBqN8nQKA4CwGYMYRAUsgSjQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAUJvdm4Y2IUCpmFud4csNQMlbj577
riJARaE+0MZ1JkAyXZyXkEMjQKzCvhF02jJAOcdxIyCbI0B1w0e55po6QNfg
LgJ31SNAzCrsG6M/QUCjFKvQCgMkQE+Q+0yHRUVAlNiwFPksJECQeGrIKGFJ
QGglxA6IVCRAdEBljKqUTUCQQJ1CL30kQEatyIMX8VBAmqyAkKmmJECIp4YM
HiZTQIh2azpz1CRAgE37ycxqVUCwgUGf1gclQNBg2UOgwFdAlEVQBRNAJUDC
uExyRilaQMX4UHoigSVAkpZDiZamXECWB9IdzM0lQMoeYmiIOl9AxNx/660p
JkBC+r2IovNgQCKa3aWMAidACGBQnJdXYkBFdCLiyfAnQBYI3W1xymNAlRYN
CXitKECSnAjjok1lQB/magDyWSlAcqszUrviZkDL3t1+cB4qQDodUBlzi2hA
gOkvAKyDKkBbnZGKr0lqQPhY875ZVCtAwr4RzIYfbEDaRxoLl7krQL4LB9E7
D25AEDevqx9wLEBGpwMqpQ1wQBqLWdlWEC1AWPzVnDkjcUCYTWTA+nwtQB5W
3vzXSXJAWHGnwy27LUC0nyyBI4NzQHXJYEJN7C1Aas7F4unQdEDImwkFcvst
QCWwaT8lNXZAXAWRvTH9LUBudUYqArJ3QP4VG5H68y1ArlEr8uBJeUDTZPGM
fcEtQMseYmhU/3pADsMrcax9LUCNWpEHN9V8QPQKJOka5SxAqqTlUK7OfkBh
YrcScnssQEpUScuXd4BA1HyiUmqkK0CQhPR7R52BQP5cW0vTPypAPL4LB3/a
gkDk+b9W09koQKA4CwGYMYRAY28RRQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAUJvdm4Y2IUCpmFud4csNQMlbj577
riJARaE+0MZ1JkAyXZyXkEMjQKzCvhF02jJAOcdxIyCbI0B1w0e55po6QNfg
LgJ31SNAzCrsG6M/QUCjFKvQCgMkQE+Q+0yHRUVAlNiwFPksJECQeGrIKGFJ
QGglxA6IVCRAdEBljKqUTUCQQJ1CL30kQEatyIMX8VBAmqyAkKmmJECIp4YM
HiZTQIh2azpz1CRAgE37ycxqVUCwgUGf1gclQNBg2UOgwFdAlEVQBRNAJUDC
uExyRilaQMX4UHoigSVAkpZDiZamXECWB9IdzM0lQMoeYmiIOl9AxNx/660p
JkBC+r2IovNgQCKa3aWMAidACGBQnJdXYkBFdCLiyfAnQBYI3W1xymNAlRYN
CXitKECSnAjjok1lQB/magDyWSlAcqszUrviZkDL3t1+cB4qQDodUBlzi2hA
gOkvAKyDKkBbnZGKr0lqQPhY875ZVCtAwr4RzIYfbEDaRxoLl7krQL4LB9E7
D25AEDevqx9wLEBGpwMqpQ1wQBqLWdlWEC1AWPzVnDkjcUCYTWTA+nwtQB5W
3vzXSXJAWHGnwy27LUC0nyyBI4NzQHXJYEJN7C1Aas7F4unQdEDImwkFcvst
QCWwaT8lNXZAXAWRvTH9LUBudUYqArJ3QP4VG5H68y1ArlEr8uBJeUDTZPGM
fcEtQMseYmhU/3pADsMrcax9LUCNWpEHN9V8QPQKJOka5SxAqqTlUK7OfkBh
YrcScnssQEpUScuXd4BA1HyiUmqkK0CQhPR7R52BQP5cW0vTPypAPL4LB3/a
gkDk+b9W09koQKA4CwGYMYRAY28RRQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAADM99B9YFIkCpmFud4csNQByvDPsP
LCNARaE+0MZ1JkA2iUxnMK0jQKzCvhF02jJAeF/A/cb8I0B1w0e55po6QGtD
MabsMyRAzCrsG6M/QUAsZEpf7WAkQE+Q+0yHRUVAXGS8MsWIJECQeGrIKGFJ
QG+YCwlSryRAdEBljKqUTUDG2aSl8NYkQEatyIMX8VBAJuXUrHL/JECIp4YM
HiZTQIM/3PwNKiVAgE37ycxqVUAKg1dsCFolQNBg2UOgwFdA3RUDlc2MJUDC
uExyRilaQEYHbuCsxiVAkpZDiZamXEDVXhEuUQcmQMoeYmiIOl9A+6YtpGxR
JkBC+r2IovNgQF+BIxurqyZACGBQnJdXYkA2dZ2fxQonQBYI3W1xymNAAp9n
YRByJ0CSnAjjok1lQJFYwAoN3idAcqszUrviZkDweCpLX1IoQDodUBlzi2hA
eEhnhuC5KEBbnZGKr0lqQIjM8YnxdilAwr4RzIYfbEDMFd5OEfIpQL4LB9E7
D25A3IWJfqNiKkBGpwMqpQ1wQHCe/lLsAytAWPzVnDkjcUA1NysrjKorQB5W
3vzXSXJArYG0V31SLEC0nyyBI4NzQAa2eQbPwyxAas7F4unQdEBr9iRYxD4t
QCWwaT8lNXZAaEjMLLObLUBudUYqArJ3QIUy6qnmzi1ArlEr8uBJeUCXAKm1
lectQMseYmhU/3pAmJUY0iHgLUCNWpEHN9V8QFhf5ggkoi1AqqTlUK7OfkBa
d7m56D0tQEpUScuXd4BA5PZwUPKJLECQhPR7R52BQO6FqzR6QitAPL4LB3/a
gkDnAqNoFAYqQKA4CwGYMYRAREsOmA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAxavG/n4VIkCpmFud4csNQDop43I9
PSNARaE+0MZ1JkCdN3VGmL8jQKzCvhF02jJASljhz2gPJEB1w0e55po6QDb2
psDBRyRAzCrsG6M/QUBTpZJfnnQkQE+Q+0yHRUVAK+kzx6GdJECQeGrIKGFJ
QKBi7mCzwyRAdEBljKqUTUAzsFdAT+skQEatyIMX8VBA24KCpBAUJUCIp4YM
HiZTQCHWMsp3PyVAgE37ycxqVUCOAa1MbG4lQNBg2UOgwFdAhKGRrj2hJUDC
uExyRilaQNfaKmjF2iVAkpZDiZamXEB3pOUM0homQMoeYmiIOl9APVX9wuRk
JkBC+r2IovNgQPMN7Rh/viZACGBQnJdXYkDxBP/hZR4nQBYI3W1xymNARnCE
UuWKJ0CSnAjjok1lQH6/uKoB9idAcqszUrviZkA8LFcR0WkoQDodUBlzi2hA
KvIAlPHUKEBbnZGKr0lqQHdfbrafmSlAwr4RzIYfbEA7/pNc4A8qQL4LB9E7
D25A0bO6ny6OKkBGpwMqpQ1wQNpRMJlDIStAWPzVnDkjcUCq5AO6rcsrQB5W
3vzXSXJA7uhsl/RuLEC0nyyBI4NzQDjHRIObCC1Aas7F4unQdECMqidjC1Qt
QCWwaT8lNXZA/Dl/8jidLUBudUYqArJ3QHKK/ZlvyS1ArlEr8uBJeUCpxLX5
LtYtQMseYmhU/3pA2K+xeLHNLUCNWpEHN9V8QFK7XqCAiy1AqqTlUK7OfkCg
d+Dk5SktQEpUScuXd4BA3Y4XzrKRLECQhPR7R52BQAA+Sh1ckytAPL4LB3/a
gkACV2F020EqQKA4CwGYMYRAaSIXfA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA6BM+1yEQIkCpmFud4csNQFqTt98F
OSNARaE+0MZ1JkDPmXXiXrsjQKzCvhF02jJAG8F+AIoKJEB1w0e55po6QOld
H+s+QyRAzCrsG6M/QUDlWXAGu28kQE+Q+0yHRUVAXpXQ0vqXJECQeGrIKGFJ
QNqnv618vyRAdEBljKqUTUCuFx4oXuYkQEatyIMX8VBAvCellWwPJUCIp4YM
HiZTQDD1ZsfzOyVAgE37ycxqVUCjB3Gvc2slQNBg2UOgwFdAcXJVaRifJUDC
uExyRilaQDrSryqP2CVAkpZDiZamXED2qr0hOBomQMoeYmiIOl9ApYY3ZHxl
JkBC+r2IovNgQDWV26HdwSZACGBQnJdXYkD0Nm1acSYnQBYI3W1xymNA4Uca
DhiNJ0CSnAjjok1lQGYgOZn19SdAcqszUrviZkCiaqSeIX0oQDodUBlzi2hA
UavBkVvnKEBbnZGKr0lqQN3eBuBzsylAwr4RzIYfbEAWnuLF1BsqQL4LB9E7
D25AKpIU47PEKkBGpwMqpQ1wQM32aJqNWStAWPzVnDkjcUB4WMqVDg0sQB5W
3vzXSXJAEP00eJuuLEC0nyyBI4NzQLlMvmkvNi1Aas7F4unQdEAif75eRnEt
QCWwaT8lNXZAMJCgY4CgLUBudUYqArJ3QCutZ6fZsC1ArlEr8uBJeUBn721d
WKgtQMseYmhU/3pAslzeezZ9LUCNWpEHN9V8QMzpnqeGAC1AqqTlUK7OfkAu
1MJ0AIcsQEpUScuXd4BA0eAhajS4K0CQhPR7R52BQE+livtgbypAPL4LB3/a
gkD2PnW4xEApQKA4CwGYMYRAka8SiA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAAt+xgeT9IUCpmFud4csNQP8hF9ql
KSNARaE+0MZ1JkAIq6NogKsjQKzCvhF02jJAlcZzqg/8I0B1w0e55po6QJS1
2dKeMyRAzCrsG6M/QUCDdKYj4mAkQE+Q+0yHRUVAamLaRfmJJECQeGrIKGFJ
QMw5IH8GsSRAdEBljKqUTUBEUC2zZNkkQEatyIMX8VBAQMRoZbMCJUCIp4YM
HiZTQFYCqp3GMCVAgE37ycxqVUDME/21fmElQNBg2UOgwFdABGd6ztWWJUDC
uExyRilaQClv9WJ60iVAkpZDiZamXEDAc0YfJBcmQMoeYmiIOl9ALiqdE8Bl
JkBC+r2IovNgQNExOkj3xCZACGBQnJdXYkB7aVyBzionQBYI3W1xymNAXtdp
LdeWJ0CSnAjjok1lQILXQgaxAihAcqszUrviZkD0JJGW6pgoQDodUBlzi2hA
GFz5F28EKUBbnZGKr0lqQIvos23N2ilAwr4RzIYfbEDUODZK00oqQL4LB9E7
D25Ad+ZYSOLgKkBGpwMqpQ1wQPihtXivvytAWPzVnDkjcUDWV9f2XxMsQB5W
3vzXSXJAGQXdyFDDLEC0nyyBI4NzQPhrcIvpEy1Aas7F4unQdEBU0YkjaFEt
QCWwaT8lNXZAJCSQNoFgLUBudUYqArJ3QBaS2oyJSy1ArlEr8uBJeUAJbUid
nBAtQMseYmhU/3pATkVmRcCyLECNWpEHN9V8QB6Pw9ps7StAqqTlUK7OfkDp
1TiPYWQrQEpUScuXd4BA/I25n9kyKkCQhPR7R52BQImeySLsrShAPL4LB3/a
gkAc1REbC9YnQKA4CwGYMYRA86cSPw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA3ll+NrggIkCpmFud4csNQOmdfM/a
UCNARaE+0MZ1JkDseEn5ANcjQKzCvhF02jJA1KpF3EUpJEB1w0e55po6QLPd
aPN4YiRAzCrsG6M/QUB23YtWkJEkQE+Q+0yHRUVAFu+H9R27JECQeGrIKGFJ
QPxLc2JJ4yRAdEBljKqUTUA+2Y8B/gslQEatyIMX8VBAIXiA4AU2JUCIp4YM
HiZTQPnuy4f5ZCVAgE37ycxqVUB8cWHf1JUlQNBg2UOgwFdAfzzr/ljMJUDC
uExyRilaQAcBk+B5CCZAkpZDiZamXEB/503iW00mQMoeYmiIOl9A6Sr2U0Cc
JkBC+r2IovNgQOrNWEvG/CZACGBQnJdXYkBmVeEgz2YnQBYI3W1xymNA5lP3
QIHUJ0CSnAjjok1lQNzZjcn4PihAcqszUrviZkBij+HX3ugoQDodUBlzi2hA
EStSLA9OKUBbnZGKr0lqQDB5nZbWKipAwr4RzIYfbECKS/T65aQqQL4LB9E7
D25A4sIX6qMmK0BGpwMqpQ1wQCueL84d7ytAWPzVnDkjcUAyv6nS5JYsQB5W
3vzXSXJAfqVPGrf3LEC0nyyBI4NzQJxAlqYBVS1Aas7F4unQdEAc9rMFw3Qt
QCWwaT8lNXZAs9AbGR5yLUBudUYqArJ3QFSBoDNKaC1ArlEr8uBJeUDAQO0S
vx0tQMseYmhU/3pAsh2rWY7bLECNWpEHN9V8QL0P8n1pKCxAqqTlUK7OfkBE
zN3VsK0rQEpUScuXd4BAQHshI9PRKkCQhPR7R52BQBzNJFihUilAPL4LB3/a
gkCOT9mypdEnQKA4CwGYMYRALpkZ+g==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVQKmaf12IkCpmFud4csNQB3tG85g
tCNARaE+0MZ1JkA2uXF1+EAkQKzCvhF02jJA2ji0RFuXJEB1w0e55po6QHQ6
NV0w1CRAzCrsG6M/QUA6vLq3CgMlQE+Q+0yHRUVAUTfuxQMvJUCQeGrIKGFJ
QLInu09KWCVAdEBljKqUTUB5TDxm4oElQEatyIMX8VBAGLk1WGGtJUCIp4YM
HiZTQHhgy2Oe2yVAgE37ycxqVUCPAtXC2QwmQNBg2UOgwFdA6vN7WG1DJkDC
uExyRilaQDmjuLOHfyZAkpZDiZamXEBu56sWE8QmQMoeYmiIOl9AkFnZxDgT
J0BC+r2IovNgQAA3i0RkcidACGBQnJdXYkAO5C55V98nQBYI3W1xymNAL0OU
ZLtNKECSnAjjok1lQBSibtWP4ihAcqszUrviZkBh+dXuy1MpQDodUBlzi2hA
lEB/Jq7ZKUBbnZGKr0lqQKa3EqC+aypAwr4RzIYfbEDFT21p/TArQL4LB9E7
D25AX0kFJYmuK0BGpwMqpQ1wQLL2bwM1cixAWPzVnDkjcUBKi8elhhstQB5W
3vzXSXJANjDa29SDLUC0nyyBI4NzQOw0Qm4P3i1Aas7F4unQdED20ISwC/st
QCWwaT8lNXZAvA6F1bgALkBudUYqArJ3QK7VFlNo9y1ArlEr8uBJeUApasOI
WcEtQMseYmhU/3pAZsMHVrGALUCNWpEHN9V8QGT8QnCR4SxAqqTlUK7OfkBh
UR1NxXIsQEpUScuXd4BABvzuoJSNK0CQhPR7R52BQGQXA4fJJipAPL4LB3/a
gkDafQan2cMoQKA4CwGYMYRA1LwPVA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVQKmaf12IkCpmFud4csNQB3tG85g
tCNARaE+0MZ1JkA2uXF1+EAkQKzCvhF02jJA2ji0RFuXJEB1w0e55po6QHQ6
NV0w1CRAzCrsG6M/QUA6vLq3CgMlQE+Q+0yHRUVAUTfuxQMvJUCQeGrIKGFJ
QLInu09KWCVAdEBljKqUTUB5TDxm4oElQEatyIMX8VBAGLk1WGGtJUCIp4YM
HiZTQHhgy2Oe2yVAgE37ycxqVUCPAtXC2QwmQNBg2UOgwFdA6vN7WG1DJkDC
uExyRilaQDmjuLOHfyZAkpZDiZamXEBu56sWE8QmQMoeYmiIOl9AkFnZxDgT
J0BC+r2IovNgQAA3i0RkcidACGBQnJdXYkAO5C55V98nQBYI3W1xymNAL0OU
ZLtNKECSnAjjok1lQBSibtWP4ihAcqszUrviZkBh+dXuy1MpQDodUBlzi2hA
lEB/Jq7ZKUBbnZGKr0lqQKa3EqC+aypAwr4RzIYfbEDFT21p/TArQL4LB9E7
D25AX0kFJYmuK0BGpwMqpQ1wQLL2bwM1cixAWPzVnDkjcUBKi8elhhstQB5W
3vzXSXJANjDa29SDLUC0nyyBI4NzQOw0Qm4P3i1Aas7F4unQdED20ISwC/st
QCWwaT8lNXZAvA6F1bgALkBudUYqArJ3QK7VFlNo9y1ArlEr8uBJeUApasOI
WcEtQMseYmhU/3pAZsMHVrGALUCNWpEHN9V8QGT8QnCR4SxAqqTlUK7OfkBh
UR1NxXIsQEpUScuXd4BABvzuoJSNK0CQhPR7R52BQGQXA4fJJipAPL4LB3/a
gkDafQan2cMoQKA4CwGYMYRA1LwPVA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA2G7Bf6qiIUCpmFud4csNQPpbU9N+
7iJARaE+0MZ1JkBJ3P+iL44jQKzCvhF02jJA7iqmBb/sI0B1w0e55po6QPpX
1inZKSRAzCrsG6M/QUCySN6JE1gkQE+Q+0yHRUVAHNCQHnCBJECQeGrIKGFJ
QEweiDMhpyRAdEBljKqUTUCM+0Srts0kQEatyIMX8VBAzoNFwpj1JECIp4YM
HiZTQCYNMWK/ICVAgE37ycxqVUBKtHD0ElAlQNBg2UOgwFdAdFqtHBmHJUDC
uExyRilaQCl/rGHXxCVAkpZDiZamXEBUvC+9YAwmQMoeYmiIOl9Ae0xW5ANw
JkBC+r2IovNgQKSjdYe/5SZACGBQnJdXYkCF0mI+x2gnQBYI3W1xymNATpTC
cvjpJ0CSnAjjok1lQCcNup9FaChAcqszUrviZkBuWp2HVuMoQDodUBlzi2hA
wSH+uB1dKUBbnZGKr0lqQPCn/mC45ClAwr4RzIYfbEB6KNtDH0AqQL4LB9E7
D25AJBRrJJrRKkBGpwMqpQ1wQHqIb+ZISytAWPzVnDkjcUA495rpS58rQB5W
3vzXSXJAEV/0zB8xLEC0nyyBI4NzQG+y2a3RrixAas7F4unQdEDgRNkoXeks
QCWwaT8lNXZAPN82ar9ZLUBudUYqArJ3QMYa1BWMoy1ArlEr8uBJeUC1jfl5
sLstQMseYmhU/3pAYqQy/DnPLUCNWpEHN9V8QGRjGr12ny1AqqTlUK7OfkD0
5oJnFk8tQEpUScuXd4BALJvuyHqTLECQhPR7R52BQFJhjtj0gStAPL4LB3/a
gkBLgQR4lP0pQKA4CwGYMYRArLkWaw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1+L4BFaPIUCpmFud4csNQChsTuIv
3CJARaE+0MZ1JkADM1lB63ojQKzCvhF02jJAV2s9BnrYI0B1w0e55po6QFQc
BIKBFyRAzCrsG6M/QUCcfWjNZkYkQE+Q+0yHRUVAbkhqhExuJECQeGrIKGFJ
QLjST39IlSRAdEBljKqUTUBoGo2XBLskQEatyIMX8VBA2xOAL2vjJECIp4YM
HiZTQPwt1RcRDiVAgE37ycxqVUBJZLMuEj4lQNBg2UOgwFdAWDGqkEJ1JUDC
uExyRilaQOTOQasStiVAkpZDiZamXEBoiPJJsAEmQMoeYmiIOl9AxLWTrBRn
JkBC+r2IovNgQCJ1JqdP3SZACGBQnJdXYkDGocgssGMnQBYI3W1xymNAZRdP
lr7nJ0CSnAjjok1lQJFr5Z9maihAcqszUrviZkBBiS4Z7+koQDodUBlzi2hA
NqAmpvhpKUBbnZGKr0lqQIkadFtC+ClAwr4RzIYfbECq78MqOFIqQL4LB9E7
D25A+6q8uXDoKkBGpwMqpQ1wQIrfIYOnfCtAWPzVnDkjcUBaKh4Fzb8rQB5W
3vzXSXJAofdoWlhYLEC0nyyBI4NzQOuUPDCV0SxAas7F4unQdECs6qnlbgct
QCWwaT8lNXZAPq5LdjxtLUBudUYqArJ3QP3Hvuf4ti1ArlEr8uBJeUBePbzw
GNwtQMseYmhU/3pAag/2/FzfLUCNWpEHN9V8QByqHGsPqS1AqqTlUK7OfkA5
J8OqnkYtQEpUScuXd4BAc6+X96LBLECQhPR7R52BQF9id1N0iStAPL4LB3/a
gkDJoqm7cM0pQKA4CwGYMYRAaxcQcw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAJeWnT9eSIUCpmFud4csNQN+M4jSv
3SJARaE+0MZ1JkDnDw4DxX8jQKzCvhF02jJAzikSD6ndI0B1w0e55po6QNz7
6JoPHSRAzCrsG6M/QUBJRyyhzkwkQE+Q+0yHRUVAazk7ILJ2JECQeGrIKGFJ
QPpJc9vgnSRAdEBljKqUTUAiyOqZi8UkQEatyIMX8VBAxDDUE/3uJECIp4YM
HiZTQLoV9qYPHCVAgE37ycxqVUBDy9DWiEwlQNBg2UOgwFdA2E+5MEaGJUDC
uExyRilaQDilVEAzxiVAkpZDiZamXEA0bhTmaxEmQMoeYmiIOl9A3zVbebl4
JkBC+r2IovNgQOrxKDGb8CZACGBQnJdXYkALIu86SXknQBYI3W1xymNAScVm
GQoAKECSnAjjok1lQDS95E9EhChAcqszUrviZkBCOw69QwcpQDodUBlzi2hA
Frm2W/qGKUBbnZGKr0lqQAF1GNpKICpAwr4RzIYfbEDeA3kuPncqQL4LB9E7
D25AiGpeE/oWK0BGpwMqpQ1wQLNuYpmIgStAWPzVnDkjcUCTECq21Q4sQB5W
3vzXSXJArveuk9iNLEC0nyyBI4NzQG71ZHu/0CxAas7F4unQdEDYwJiewkct
QCWwaT8lNXZAbFSu3piTLUBudUYqArJ3QOAaRmO0xi1ArlEr8uBJeUDvrVPD
dMUtQMseYmhU/3pAJkheJiqzLUCNWpEHN9V8QNQaOasZNi1AqqTlUK7OfkDt
MTqoze4sQEpUScuXd4BAlqtlXcObK0CQhPR7R52BQOlNmhNtkSpAPL4LB3/a
gkDfWPTEXhcpQKA4CwGYMYRAb5kQaA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA9isoZxCPIUCpmFud4csNQAw/7fko
2SJARaE+0MZ1JkCBQPOkaHkjQKzCvhF02jJAYotGWHfYI0B1w0e55po6QPGa
X0eFFyRAzCrsG6M/QUAN7am0MUckQE+Q+0yHRUVAsEN8rCJvJECQeGrIKGFJ
QEuaBkdflyRAdEBljKqUTUBB47o93L0kQEatyIMX8VBAsH5/1trnJECIp4YM
HiZTQFehURdmEyVAgE37ycxqVUA4SRzrTEYlQNBg2UOgwFdA7lpHebh/JUDC
uExyRilaQHgJFC5zwCVAkpZDiZamXEBmoZ0wOwsmQMoeYmiIOl9AoqfZjEJ0
JkBC+r2IovNgQLpI5/E17iZACGBQnJdXYkB2gZgmBnknQBYI3W1xymNACkzN
4+f+J0CSnAjjok1lQF0BIYDCgihAcqszUrviZkBPbvs6DgkpQDodUBlzi2hA
Al7KXKaSKUBbnZGKr0lqQI6mpw1dJCpAwr4RzIYfbECIa1iiV3gqQL4LB9E7
D25AV5T1AMEiK0BGpwMqpQ1wQPhzsbVfcitAWPzVnDkjcUBSKgOtZyEsQB5W
3vzXSXJAopj7YZxqLEC0nyyBI4NzQN629lxNtixAas7F4unQdEDmEnir1hot
QCWwaT8lNXZAguiASG4+LUBudUYqArJ3QCKazwBMTy1ArlEr8uBJeUDJ+9V5
JEYtQMseYmhU/3pAqom/zRYFLUCNWpEHN9V8QOklS9sJVCxAqqTlUK7OfkDo
Aw51qN8rQEpUScuXd4BAZhGYHV1rKkCQhPR7R52BQHri2LwxYClAPL4LB3/a
gkCyA4PnVzsoQKA4CwGYMYRAR+ELOg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAEtowX0GlIUCpmFud4csNQAwgj+Xy
8yJARaE+0MZ1JkAWxRWPbZojQKzCvhF02jJAAKOEB1z6I0B1w0e55po6QGjg
hRGGOiRAzCrsG6M/QUD5YKGBoGokQE+Q+0yHRUVAvgskxweWJECQeGrIKGFJ
QAZy9WjXvCRAdEBljKqUTUAJ0SSBROUkQEatyIMX8VBA5lJiXy8PJUCIp4YM
HiZTQO5fBzPtPCVAgE37ycxqVUBTZVUe928lQNBg2UOgwFdAcExYKHqqJUDC
uExyRilaQPYV0WhT7CVAkpZDiZamXECi4sSKYDUmQMoeYmiIOl9AWFTkB9yf
JkBC+r2IovNgQJ1mDvrGGidACGBQnJdXYkByM8qsxagnQBYI3W1xymNA5w4Y
B3MyKECSnAjjok1lQD6ijPivuyhAcqszUrviZkDuRooVrkYpQDodUBlzi2hA
9vuBaTXWKUBbnZGKr0lqQNjyVfUMaypAwr4RzIYfbECOUi5hbsMqQL4LB9E7
D25AF+6eCrBxK0BGpwMqpQ1wQPVLIvHqvStAWPzVnDkjcUBh89TJ6m0sQB5W
3vzXSXJAc3ex7mrLLEC0nyyBI4NzQDYvHLw/Dy1Aas7F4unQdECbgYuhw2ct
QCWwaT8lNXZA9BgOvq2OLUBudUYqArJ3QBi8ox+XmC1ArlEr8uBJeUARhkZv
YHItQMseYmhU/3pA0nfqImUJLUCNWpEHN9V8QExhA/Cq0SxAqqTlUK7OfkBQ
WRIPx8UrQEpUScuXd4BARrEOgkQhK0CQhPR7R52BQO/leHg/iClAPL4LB3/a
gkDN0Lcs6e8nQKA4CwGYMYRAXpcQgA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAARn8LIV/yIUCpmFud4csNQPnpsoQT
UiNARaE+0MZ1JkDOt0aItQAkQKzCvhF02jJAjtUxvadnJEB1w0e55po6QFCC
FyjtqyRAzCrsG6M/QUDg866w9d8kQE+Q+0yHRUVAVouQBvQMJUCQeGrIKGFJ
QDJpVGa9NiVAdEBljKqUTUB9RRGc82AlQEatyIMX8VBAVvdfrfiMJUCIp4YM
HiZTQEP0F1fFvSVAgE37ycxqVUCaRpmCYPIlQNBg2UOgwFdAF7EFvxQtJkDC
uExyRilaQOEa/DYIcSZAkpZDiZamXEBWv7TgQcImQMoeYmiIOl9A/P2vmuks
J0BC+r2IovNgQD8tQmE8rCdACGBQnJdXYkD3wio1WzwoQBYI3W1xymNA00J1
xdzJKECSnAjjok1lQKimJHFkVilAcqszUrviZkBXoN1BzeYpQDodUBlzi2hA
ZjDrJsZ9KkBbnZGKr0lqQCxWYDeU7CpAwr4RzIYfbEAZ/uB3x4orQL4LB9E7
D25AhjlAkVIULEBGpwMqpQ1wQKx52h6pWyxAWPzVnDkjcUAmcKFBkBEtQB5W
3vzXSXJAvCtHjhJlLUC0nyyBI4NzQBKewFbbqC1Aas7F4unQdEBSNw62r/8t
QCWwaT8lNXZAAkRDL5ENLkBudUYqArJ3QC6W+LKnEC5ArlEr8uBJeUD6bnua
294tQMseYmhU/3pA0h5VeXFrLUCNWpEHN9V8QLiH/vl3MS1AqqTlUK7OfkDg
Ah6veGAsQEpUScuXd4BACLDJfpyAK0CQhPR7R52BQKVlswgWJypAPL4LB3/a
gkDjQ/2tKegoQKA4CwGYMYRA08cRaw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAARn8LIV/yIUCpmFud4csNQPnpsoQT
UiNARaE+0MZ1JkDOt0aItQAkQKzCvhF02jJAjtUxvadnJEB1w0e55po6QFCC
FyjtqyRAzCrsG6M/QUDg866w9d8kQE+Q+0yHRUVAVouQBvQMJUCQeGrIKGFJ
QDJpVGa9NiVAdEBljKqUTUB9RRGc82AlQEatyIMX8VBAVvdfrfiMJUCIp4YM
HiZTQEP0F1fFvSVAgE37ycxqVUCaRpmCYPIlQNBg2UOgwFdAF7EFvxQtJkDC
uExyRilaQOEa/DYIcSZAkpZDiZamXEBWv7TgQcImQMoeYmiIOl9A/P2vmuks
J0BC+r2IovNgQD8tQmE8rCdACGBQnJdXYkD3wio1WzwoQBYI3W1xymNA00J1
xdzJKECSnAjjok1lQKimJHFkVilAcqszUrviZkBXoN1BzeYpQDodUBlzi2hA
ZjDrJsZ9KkBbnZGKr0lqQCxWYDeU7CpAwr4RzIYfbEAZ/uB3x4orQL4LB9E7
D25AhjlAkVIULEBGpwMqpQ1wQKx52h6pWyxAWPzVnDkjcUAmcKFBkBEtQB5W
3vzXSXJAvCtHjhJlLUC0nyyBI4NzQBKewFbbqC1Aas7F4unQdEBSNw62r/8t
QCWwaT8lNXZAAkRDL5ENLkBudUYqArJ3QC6W+LKnEC5ArlEr8uBJeUD6bnua
294tQMseYmhU/3pA0h5VeXFrLUCNWpEHN9V8QLiH/vl3MS1AqqTlUK7OfkDg
Ah6veGAsQEpUScuXd4BACLDJfpyAK0CQhPR7R52BQKVlswgWJypAPL4LB3/a
gkDjQ/2tKegoQKA4CwGYMYRA08cRaw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAB7aU9fInIUCpmFud4csNQKEv7bOn
oSNARaE+0MZ1JkAQqhv0D2MkQKzCvhF02jJAzUhFJPb5JEB1w0e55po6QDyU
aBShpSVAzCrsG6M/QUBKCQh6fgsmQE+Q+0yHRUVA/idtk+2QJkCQeGrIKGFJ
QFnUEoB23yZAdEBljKqUTUDNTvXarksnQEatyIMX8VBAnn36j9eYJ0CIp4YM
HiZTQLYy+7B/AihAgE37ycxqVUDX8KhInzooQNBg2UOgwFdAUILgGgecKEDC
uExyRilaQC4Lvkp/9yhAkpZDiZamXEC9blnULS8pQMoeYmiIOl9ANudL3SSg
KUBC+r2IovNgQOKJGXUAzylACGBQnJdXYkAYCtwnOz8qQBYI3W1xymNAXbCp
l9FtKkCSnAjjok1lQAYxQkNt2CpAcqszUrviZkAQ6l8rekcrQDodUBlzi2hA
+jSunqhzK0BbnZGKr0lqQJ5fbgPE4ytAwr4RzIYfbEBYMorWbhksQL4LB9E7
D25AOEzGt4OHLEBGpwMqpQ1wQEpKOvq8qyxAWPzVnDkjcUDMcztboQstQB5W
3vzXSXJAP6DtmSp7LUC0nyyBI4NzQMOMeI0WiC1Aas7F4unQdEBMqhomIdUt
QCWwaT8lNXZAWkIeRGcRLkBudUYqArJ3QMP0dQYAFS5ArlEr8uBJeUDEO+Ib
rhwuQMseYmhU/3pAnOib9l7wLUCNWpEHN9V8QKYKHMKKpS1AqqTlUK7OfkBy
y7FMhyQtQEpUScuXd4BAJlgF3jP4K0CQhPR7R52BQBcJY6xj+SpAPL4LB3/a
gkBkNrPVi4cpQKA4CwGYMYRAdwUMyw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAABo0KYEQeIUCpmFud4csNQCXpEUiH
kiNARaE+0MZ1JkBnxWQ1IlQkQKzCvhF02jJA+MtLOlPqJEB1w0e55po6QLQN
9zgFliVAzCrsG6M/QUDiP3a0R/slQE+Q+0yHRUVAotoNu2aBJkCQeGrIKGFJ
QCpxDbAo0CZAdEBljKqUTUCPjGJexkQnQEatyIMX8VBAjIX7VL2GJ0CIp4YM
HiZTQMiBa30B9CdAgE37ycxqVUDednzPWS8oQNBg2UOgwFdAvP4xELSbKEDC
uExyRilaQEAtEC890ShAkpZDiZamXEButTyZVj4pQMoeYmiIOl9AjNjL0oZw
KUBC+r2IovNgQFjuCXHa2ilACGBQnJdXYkDa1ARMk0oqQBYI3W1xymNAu4hQ
gs93KkCSnAjjok1lQG7dFoAp5CpAcqszUrviZkBohyfw91IrQDodUBlzi2hA
AuKQ8It6K0BbnZGKr0lqQE42Ivws5itAwr4RzIYfbEChBJ12TU0sQL4LB9E7
D25A1ahrF4OzLEBGpwMqpQ1wQMow/Av21ixAWPzVnDkjcUAnARzAbS8tQB5W
3vzXSXJAikisnT2FLUC0nyyBI4NzQBJkhCZenS1Aas7F4unQdECeEYhWxdst
QCWwaT8lNXZAFjkDCNUDLkBudUYqArJ3QHBNZ823KC5ArlEr8uBJeUCvZG/p
OhguQMseYmhU/3pAbcUj3j7oLUCNWpEHN9V8QNSzJsmPbS1AqqTlUK7OfkDD
begjpOgsQEpUScuXd4BAdU68ZkMHLECQhPR7R52BQDjWTKaXaCpAPL4LB3/a
gkD19wNKo+AoQKA4CwGYMYRAz/gNww==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAN/rSYwcZIUCpmFud4csNQJ72cy+i
jSNARaE+0MZ1JkDRPw1atk8kQKzCvhF02jJAbWnmFwnmJEB1w0e55po6QLR9
FflPlCVAzCrsG6M/QUDG2FK5hvclQE+Q+0yHRUVAYJG7+2iBJkCQeGrIKGFJ
QLjV3jrjziZAdEBljKqUTUC8XgKKXUYnQEatyIMX8VBALkH7eLqJJ0CIp4YM
HiZTQISShvOo+ydAgE37ycxqVUCAXsyN+zYoQNBg2UOgwFdAIhrF2jGnKEDC
uExyRilaQOR7tqdi3ihAkpZDiZamXEAbL7T8Z08pQMoeYmiIOl9AztKF4XyC
KUBC+r2IovNgQEokjID07ylACGBQnJdXYkCodk2KE2MqQBYI3W1xymNA3D3q
42yRKkCSnAjjok1lQL3l1vSo/ipAcqszUrviZkCYmcowtmkrQDodUBlzi2hA
vC8uGCPZK0BbnZGKr0lqQMYEc+yK/CtAwr4RzIYfbEBg0yK05WssQL4LB9E7
D25AJ6rLDhXZLEBGpwMqpQ1wQOCdfvL0AS1AWPzVnDkjcUBuxj2CJGstQB5W
3vzXSXJAYLtgUkeMLUC0nyyBI4NzQCLKlKpY2C1Aas7F4unQdECcBSZqGwcu
QCWwaT8lNXZAPBaPxtocLkBudUYqArJ3QLue1U11Gy5ArlEr8uBJeUAm6+VW
hREuQMseYmhU/3pAWrEZk5CnLUCNWpEHN9V8QPgXosjS8ixAqqTlUK7OfkBh
zCxqY5ssQEpUScuXd4BAJTbAicz+KkCQhPR7R52BQOqug/D6DSpAPL4LB3/a
gkAKRtzY/rsoQKA4CwGYMYRAUi8a1g==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAA0UDKUsVIUCpmFud4csNQIBHPdWy
kCNARaE+0MZ1JkCx/R7F1FEkQKzCvhF02jJAm/hUaSnrJEB1w0e55po6QOYM
Hd5QhCVAzCrsG6M/QUCYpiM94hUmQE+Q+0yHRUVAuYO+tSFtJkCQeGrIKGFJ
QCY8LHGb3SZAdEBljKqUTUDAiYiQ0k4nQEatyIMX8VBA9vFsDcCQJ0CIp4YM
HiZTQPy0vL5C+CdAgE37ycxqVUA9TxFC+10oQNBg2UOgwFdAw/E68aimKEDC
uExyRilaQCPQPN9D/ShAkpZDiZamXEDRF9Lfqm4pQMoeYmiIOl9AIchp6NCg
KUBC+r2IovNgQHh85TcyEipACGBQnJdXYkDEvrpsMI0qQBYI3W1xymNAn+z6
Yn+9KkCSnAjjok1lQJYgVY5ZPStAcqszUrviZkAiBQjx1WYrQDodUBlzi2hA
c9XG5cHiK0BbnZGKr0lqQOLoqxzcDSxAwr4RzIYfbEDMrx18h3ksQL4LB9E7
D25AYFJVhVHeLEBGpwMqpQ1wQLD+VaNF/SxAWPzVnDkjcUDTt1zjdU4tQB5W
3vzXSXJAP03WOVtjLUC0nyyBI4NzQERzY7Uyii1Aas7F4unQdECXCe8nfaIt
QCWwaT8lNXZA37BSWMSrLUBudUYqArJ3QJLmZdX9hi1ArlEr8uBJeUBimlC+
CVUtQMseYmhU/3pAnvYblMyzLECNWpEHN9V8QPI6XEef7CtAqqTlUK7OfkC9
xzRh7D0rQEpUScuXd4BAEF7PcaGmKUCQhPR7R52BQMXGGqM97ChAPL4LB3/a
gkB0IBwP7xEoQKA4CwGYMYRABTsXxA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAvNOKobkqIUCpmFud4csNQFVJH/cT
tSNARaE+0MZ1JkCcoDTt+HYkQKzCvhF02jJALD1bCpwSJUB1w0e55po6QHca
wiQjvSVAzCrsG6M/QUBRMZeipygmQE+Q+0yHRUVA/qyWlNu3JkCQeGrIKGFJ
QPA+IFclCCdAdEBljKqUTUAZH8c7/IInQEatyIMX8VBA9vWMMa7FJ0CIp4YM
HiZTQMImDh1bMShAgE37ycxqVUBWD12UKKMoQNBg2UOgwFdAELG8GCnaKEDC
uExyRilaQBRvJio1SClAkpZDiZamXECccGVp470pQMoeYmiIOl9ACjJwDQH0
KUBC+r2IovNgQEZLbskVcSpACGBQnJdXYkDw4/pjvJ4qQBYI3W1xymNAyKMa
0AwaK0CSnAjjok1lQAIFSeMQmStAcqszUrviZkBYriKYlMYrQDodUBlzi2hA
JYy5xY1DLEBbnZGKr0lqQD6gh+rRaixAwr4RzIYfbEAXm6e6C9YsQL4LB9E7
D25A6ToIggI7LUBGpwMqpQ1wQJd+ZJ3naC1AWPzVnDkjcUBfegZ79bgtQB5W
3vzXSXJApLa30T/NLUC0nyyBI4NzQM7npY9U7S1Aas7F4unQdECS1XAMxPot
QCWwaT8lNXZAjtheKJf4LUBudUYqArJ3QPz/BYgLxC1ArlEr8uBJeUA07xQC
91stQMseYmhU/3pANjqCe/LmLECNWpEHN9V8QLaKucObbyxAqqTlUK7OfkBc
txDOwygrQEpUScuXd4BAkob2+9lvKkCQhPR7R52BQNjkvwQvryhAPL4LB3/a
gkAvSXIsI3cnQKA4CwGYMYRAGIkPcQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAWgGyyTxsIUCpmFud4csNQLSzAHvs
DyRARaE+0MZ1JkBotJV7S9YkQKzCvhF02jJAzs5DLKJzJUB1w0e55po6QGr4
XFmFLCZAzCrsG6M/QUC5AeMe1JcmQE+Q+0yHRUVATaEzfNgpJ0CQeGrIKGFJ
QDusF7GffSdAdEBljKqUTUAIiys5lPwnQEatyIMX8VBA6hp6ZLZDKECIp4YM
HiZTQHjr3JRPsShAgE37ycxqVUA2X2pkFCMpQNBg2UOgwFdAHNOoHFReKUDC
uExyRilaQIJ4Eyw4zilAkpZDiZamXEDSsfoAskcqQMoeYmiIOl9AyD3CRB1+
KkBC+r2IovNgQMHiEUMFACtACGBQnJdXYkDuUHEwpDQrQBYI3W1xymNAKVSP
hi2zK0CSnAjjok1lQBh/3e4OOCxAcqszUrviZkANnMWwwGksQDodUBlzi2hA
9ppkYo/wLEBbnZGKr0lqQH2FaOdhIS1Awr4RzIYfbED9TGyn3pktQL4LB9E7
D25AIVtxEee4LUBGpwMqpQ1wQFfdPr9cBy5AWPzVnDkjcUC273o/fk8uQB5W
3vzXSXJAC553P9heLkC0nyyBI4NzQAIl4I4fdy5Aas7F4unQdECMunHor3Yu
QCWwaT8lNXZAD1pse99rLkBudUYqArJ3QGI/C9uSJi5ArlEr8uBJeUDOzMOC
Sb0tQMseYmhU/3pA8TzmD9w1LUCNWpEHN9V8QBbwrKES5SxAqqTlUK7OfkDU
G8DvgbQrQEpUScuXd4BAkVUez7zVKkCQhPR7R52BQJrMskjVZSlAPL4LB3/a
gkDwQc7HFnAoQKA4CwGYMYRACNAPaw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAWgGyyTxsIUCpmFud4csNQLSzAHvs
DyRARaE+0MZ1JkBotJV7S9YkQKzCvhF02jJAzs5DLKJzJUB1w0e55po6QGr4
XFmFLCZAzCrsG6M/QUC5AeMe1JcmQE+Q+0yHRUVATaEzfNgpJ0CQeGrIKGFJ
QDusF7GffSdAdEBljKqUTUAIiys5lPwnQEatyIMX8VBA6hp6ZLZDKECIp4YM
HiZTQHjr3JRPsShAgE37ycxqVUA2X2pkFCMpQNBg2UOgwFdAHNOoHFReKUDC
uExyRilaQIJ4Eyw4zilAkpZDiZamXEDSsfoAskcqQMoeYmiIOl9AyD3CRB1+
KkBC+r2IovNgQMHiEUMFACtACGBQnJdXYkDuUHEwpDQrQBYI3W1xymNAKVSP
hi2zK0CSnAjjok1lQBh/3e4OOCxAcqszUrviZkANnMWwwGksQDodUBlzi2hA
9ppkYo/wLEBbnZGKr0lqQH2FaOdhIS1Awr4RzIYfbED9TGyn3pktQL4LB9E7
D25AIVtxEee4LUBGpwMqpQ1wQFfdPr9cBy5AWPzVnDkjcUC273o/fk8uQB5W
3vzXSXJAC553P9heLkC0nyyBI4NzQAIl4I4fdy5Aas7F4unQdECMunHor3Yu
QCWwaT8lNXZAD1pse99rLkBudUYqArJ3QGI/C9uSJi5ArlEr8uBJeUDOzMOC
Sb0tQMseYmhU/3pA8TzmD9w1LUCNWpEHN9V8QBbwrKES5SxAqqTlUK7OfkDU
G8DvgbQrQEpUScuXd4BAkVUez7zVKkCQhPR7R52BQJrMskjVZSlAPL4LB3/a
gkDwQc7HFnAoQKA4CwGYMYRACNAPaw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.24, 33.}, {10.51, 40.}, {10.66, 50.}, {10.87, 60.}, {
          11.07, 70.}, {11.36, 80.}, {11.67, 90.}, {11.68, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.05, 33.}, {10.31, 40.}, {10.47, 50.}, {10.67, 60.}, {
          10.88, 70.}, {11.19, 80.}, {11.47, 90.}, {11.57, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{9.85, 33.}, {10.07, 40.}, {10.23, 50.}, {10.36, 60.}, {
          10.53, 70.}, {10.82, 80.}, {11.07, 90.}, {11.13, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{9.94, 33.}, {10.16, 40.}, {10.33, 50.}, {10.52, 60.}, {
          10.74, 70.}, {11.11, 80.}, {11.4, 90.}, {11.55, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.1, 33.}, {10.27, 40.}, {10.43, 50.}, {10.72, 60.}, {
          10.91, 70.}, {11.18, 80.}, {11.38, 90.}, {11.43, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{10.01, 33.}, {10.26, 40.}, {10.42, 50.}, {10.62, 60.}, {
          10.75, 70.}, {11.02, 80.}, {11.19, 90.}, {11.17, 100.}}]}}}, {}}}, {
    PlotRange -> All, AspectRatio -> 1.2, Frame -> True, FrameLabel -> {
       FormBox[
       "\"WS \\!\\(\\*SuperscriptBox[\\(ms\\), \\(-1\\)]\\)\"", 
        TraditionalForm], 
       FormBox["\"Height   m\"", TraditionalForm]}, 
     TextStyle -> {FontSize -> 16}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {7.519831554769487, 0}, 
     PlotRange -> {{7.6348008670060405`, 14.992836850145462`}, {
       0, 646.199220740953}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {7.519831554769487, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{7.6348008670060405`, 14.992836850145462`}, {
       0, 646.199220740953}}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"EWP 15:00-16:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0.25 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=1 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.88, 1, 0.88], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5866666666666667, 0.6666666666666666, 
                    0.5866666666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0.88, 1, 0.88]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.88, 1, 0.88]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.88, 1, 0.88], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"No Farm 15:00-16:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0.5]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False]}],
                    "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.80570269988908*^9, 3.805702708292653*^9}, 
   3.8063762908278236`*^9, 3.8135673728128843`*^9, 3.813584720803273*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"EWP20", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<EWP 20-21\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch20B", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Green", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Green", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0.25 14:00-15:00\>\"", "}"}]}]}], "]"}], 
   ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch20C", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Black", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=1 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"Fitch20", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "LightGreen", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "LightGreen", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<Fitch adv=0 14:00-15:00\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"XX", "=", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{"NWF20", ",", "39"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"XX", ",", 
           RowBox[{"z", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Gray", "}"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"XX", ",", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Gray", "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<No Farm 20-21\>\"", "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"wstest20", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"wstestmean", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Pink"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\"\<FINO1 OBS 14:00-14:50\>\"", "}"}]}]}], "]"}], ","}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<WS \!\(\*SuperscriptBox[\(ms\), \(-1\)]\)\>\"", ",", 
      "\"\<Height   m\>\""}], "}"}]}], ",", 
   RowBox[{"TextStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "16"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.80570264985384*^9, 3.805702707119752*^9}, {3.806645733291117*^9, 
   3.8066457454345903`*^9}, {3.8066457871211767`*^9, 
   3.8066457996227217`*^9}, {3.8135847407662582`*^9, 3.813584750805754*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"OptionValue", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(\\\"TextStyle\\\"\\)\[NoBreak] for \
\[NoBreak]\\!\\(Graphics\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/OptionValue\\\", ButtonNote -> \
\\\"OptionValue::nodef\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.8066457468308544`*^9, 3.806645800931249*^9, 
  3.8135673847428956`*^9, 3.8135847520577717`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA9JCM2TaiFUCpmFud4csNQGx8o4bP
uxpARaE+0MZ1JkCuIWN8+7sbQKzCvhF02jJAvPOucTuyHEB1w0e55po6QD80
p4iF/x1AzCrsG6M/QUDI2LFKKEkfQE+Q+0yHRUVAet0oyvj1H0CQeGrIKGFJ
QMSbinRTiSBAdEBljKqUTUD3O8oX6gohQEatyIMX8VBATivg5QeeIUCIp4YM
HiZTQG9WCQx85CFAgE37ycxqVUAQZ96x3nQiQNBg2UOgwFdAWEjqjlEHI0DC
uExyRilaQBOrt6h/WyNAkpZDiZamXED6WC4BpwEkQMoeYmiIOl9A0ur2Z3JW
JEBC+r2IovNgQD6ErdGi/yRACGBQnJdXYkAXfh4oGX4lQBYI3W1xymNAYvgW
qH4sJkCSnAjjok1lQKjTwAXEzyZAcqszUrviZkBPuyHq+HInQDodUBlzi2hA
V1s5Gmz8J0BbnZGKr0lqQNTGFhKHXyhAwr4RzIYfbEAAMRIH2I0oQL4LB9E7
D25AuF5PAmiVKEBGpwMqpQ1wQHBL9txYjShAWPzVnDkjcUAS122xyIgoQB5W
3vzXSXJAIglqnoCCKEC0nyyBI4NzQIDNyQYjcShAas7F4unQdECEaNkCAlEo
QCWwaT8lNXZAC9m3aYAeKEBudUYqArJ3QD9ztT232CdArlEr8uBJeUDWooYL
SoEnQMseYmhU/3pAcA3Rh2QdJ0CNWpEHN9V8QPwz2k3JryZAqqTlUK7OfkBL
ERDHlj8mQEpUScuXd4BAVS8tBaGqJUCQhPR7R52BQGNAlQ+u6SRAPL4LB3/a
gkA+t2zJ8B4kQKA4CwGYMYRACN0ORw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAYMdixrJEFUCpmFud4csNQAB87JHx
ehpARaE+0MZ1JkBoZGUGZncbQKzCvhF02jJAH/+5mrZtHEB1w0e55po6QFy/
sJHZwR1AzCrsG6M/QUAd9L/4tu0eQE+Q+0yHRUVAnGy5OnkXIECQeGrIKGFJ
QAS+1ZvFZyBAdEBljKqUTUBRAOVFbPogQEatyIMX8VBAc6nOxwCVIUCIp4YM
HiZTQBgcnrCs5CFAgE37ycxqVUBxLHCNwXgiQNBg2UOgwFdA+bqaWPERI0DC
uExyRilaQHj/gYl8eSNAkpZDiZamXEDfaK1HByUkQMoeYmiIOl9Acx70BuCV
JEBC+r2IovNgQJiLDDusRyVACGBQnJdXYkBC6AfDptMlQBYI3W1xymNA9iCH
Yh2HJkCSnAjjok1lQLilkc0aJCdAcqszUrviZkC8JLIBjr8nQDodUBlzi2hA
J6jc7xEuKEBbnZGKr0lqQONi/Kt6cihAwr4RzIYfbEBQxuiQGoYoQL4LB9E7
D25A/k3Em+uAKEBGpwMqpQ1wQJWXJKHreShAWPzVnDkjcUDHt+G7IXQoQB5W
3vzXSXJATGoxW/hhKEC0nyyBI4NzQFRGC3FxPChAas7F4unQdEAcdwbicQoo
QCWwaT8lNXZALq7Rc8fPJ0BudUYqArJ3QLkeWH4piSdArlEr8uBJeUAadtMz
iDInQMseYmhU/3pAqIH6Z4jKJkCNWpEHN9V8QOvwRxDhUSZAqqTlUK7OfkBq
iROQtsAlQEpUScuXd4BAkLfyL3sUJUCQhPR7R52BQE6oFo1/YiRAPL4LB3/a
gkDd3gBiAagjQKA4CwGYMYRAYqkTng==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAh2y3ar7/FECpmFud4csNQLoujG4w
cxpARaE+0MZ1JkCSBpAOKHAbQKzCvhF02jJAmDpdlbtnHEB1w0e55po6QLxw
JxHbwB1AzCrsG6M/QUCq60Ps7OgeQE+Q+0yHRUVApEg0wegbIECQeGrIKGFJ
QJjGicyocyBAdEBljKqUTUBq101qwQkhQEatyIMX8VBAnVO1DkacIUCIp4YM
HiZTQMFZMSXZ/yFAgE37ycxqVUAfA5BQpqUiQNBg2UOgwFdABfOMRIkVI0DC
uExyRilaQDai0SZ9rSNAkpZDiZamXECiKri1SlokQMoeYmiIOl9ASmJI6YTH
JEBC+r2IovNgQOZC75UxeyVACGBQnJdXYkDi9nRrk/YlQBYI3W1xymNA9www
ZQ+EJkCSnAjjok1lQGMzrAElECdAcqszUrviZkCo3kBUx4QnQDodUBlzi2hA
CD3vm9nRJ0BbnZGKr0lqQJigxt+O7idAwr4RzIYfbED8MKxZBvInQL4LB9E7
D25Aphr2ewrwJ0BGpwMqpQ1wQBtnsj7T6CdAWPzVnDkjcUDtEthqU80nQB5W
3vzXSXJAn2IobseaJ0C0nyyBI4NzQDZVDWmDYSdAas7F4unQdEDFFBxkRyUn
QCWwaT8lNXZA/3myoxjlJkBudUYqArJ3QPgFkRuXnyZArlEr8uBJeUDEx70q
lEwmQMseYmhU/3pALN8JXHriJUCNWpEHN9V8QPHN6xLCXiVAqqTlUK7OfkD4
f4lrO80kQEpUScuXd4BAboK41NVEJECQhPR7R52BQLiiaBC0xSNAPL4LB3/a
gkBoalNWcjQjQKA4CwGYMYRA6vsSlw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAfnytR08cFUCpmFud4csNQH++xu9J
lhpARaE+0MZ1JkAAmoKEUZobQKzCvhF02jJAsKQ3CZ2JHEB1w0e55po6QDeD
JOln3B1AzCrsG6M/QUBOSpY7vv4eQE+Q+0yHRUVAjisbilYQIECQeGrIKGFJ
QB5+zXVodSBAdEBljKqUTUAmLR6/GBkhQEatyIMX8VBA87BUbdRqIUCIp4YM
HiZTQGkd4Kc0EiJAgE37ycxqVUA68Y7Wl2YiQNBg2UOgwFdAC0IMUI0RI0DC
uExyRilaQG8HBtAHZyNAkpZDiZamXEByKMLDZhUkQMoeYmiIOl9Anis8m4p1
JEBC+r2IovNgQGtjb73yGSVACGBQnJdXYkAyjvqBJ5IlQBYI3W1xymNAFATM
vPYiJkCSnAjjok1lQIPQ0fkHmCZAcqszUrviZkDX6RYkLA0nQDodUBlzi2hA
DFJvtI1jJ0BbnZGKr0lqQKgVnXDbkydAwr4RzIYfbEBgeCIuAqgnQL4LB9E7
D25AiS9GBC2kJ0BGpwMqpQ1wQFphIIHahidAWPzVnDkjcUDXOp6CIk0nQB5W
3vzXSXJAUsXV2CoGJ0C0nyyBI4NzQGzjOmsOuSZAas7F4unQdEC9Y73tOWMm
QCWwaT8lNXZAet4VOIQGJkBudUYqArJ3QJASMt23pCVArlEr8uBJeUCoab5U
HTUlQMseYmhU/3pAiITnXJqyJECNWpEHN9V8QP4YJdTmIyRAqqTlUK7OfkB7
rA8O3aMjQEpUScuXd4BAGVHbN9k6I0CQhPR7R52BQH8svIFI5SJAPL4LB3/a
gkA8xs31+IYiQKA4CwGYMYRAJZoGhA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAijM0EaPnFECpmFud4csNQKL3Pd9r
DBpARaE+0MZ1JkCXIxGBjAsbQKzCvhF02jJAqOiQfXfyG0B1w0e55po6QHRM
5HdZMR1AzCrsG6M/QUB+mjxvamAeQE+Q+0yHRUVAV/nGLb8qH0CQeGrIKGFJ
QC3TUONCFyBAdEBljKqUTUAg1mUMwpkgQEatyIMX8VBAn0D1GmH2IECIp4YM
HiZTQBUZPFa3liFAgE37ycxqVUBoazcH+uQhQNBg2UOgwFdAPlCLM+iNIkDC
uExyRilaQGs95llu4CJAkpZDiZamXEC85XO/ongjQMoeYmiIOl9AVEheFGYW
JEBC+r2IovNgQOxls1bsuiRACGBQnJdXYkBU2I2Kjh4lQBYI3W1xymNAWgO9
fQTDJUCSnAjjok1lQKL2wN59LCZAcqszUrviZkBUJElvtqMmQDodUBlzi2hA
bvZ7sl0FJ0BbnZGKr0lqQBQVpt36QCdAwr4RzIYfbEAbDUUX4VwnQL4LB9E7
D25AWP/pskZYJ0BGpwMqpQ1wQLnkrg53NidAWPzVnDkjcUDIy6yWgwAnQB5W
3vzXSXJAj04vFYTAJkC0nyyBI4NzQM/ISjPHbCZAas7F4unQdED1UI2ctPgl
QCWwaT8lNXZASoNW31VoJUBudUYqArJ3QP6MH2TyyiRArlEr8uBJeUDzqRdu
XDMkQMseYmhU/3pA6BQ1tay0I0CNWpEHN9V8QCfv6lTLViNAqqTlUK7OfkBQ
y0mRvw0jQEpUScuXd4BA7UNp47W+IkCQhPR7R52BQKzhKsGzbiJAPL4LB3/a
gkCKSStwmNohQKA4CwGYMYRAAWAQ4w==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVK/tdVT8E0CpmFud4csNQEFKwBqL
4RhARaE+0MZ1JkA6v1xI39UZQKzCvhF02jJASo3vYuG1GkB1w0e55po6QPeP
FQt/8xtAzCrsG6M/QUAW4Zb23xsdQE+Q+0yHRUVA7N7DnmDlHUCQeGrIKGFJ
QMwAXt9T2x5AdEBljKqUTUB+1xV/zwYgQEatyIMX8VBACqbgHZ9TIECIp4YM
HiZTQJpmbQzt9iBAgE37ycxqVUDwfFmjaUchQNBg2UOgwFdAW7QHtc/eIUDC
uExyRilaQDDYOy8vhSJAkpZDiZamXEDAd+v2wf4iQMoeYmiIOl9AYOTqeJ6B
I0BC+r2IovNgQDgPd3qFIyRACGBQnJdXYkCxG2Eoqp8kQBYI3W1xymNA8xGi
nGQPJUCSnAjjok1lQIeyMOU4nyVAcqszUrviZkBaYH0waRsmQDodUBlzi2hA
Hx3zH49yJkBbnZGKr0lqQHMFE1NIqiZAwr4RzIYfbECCedG9nccmQL4LB9E7
D25A5iumgJ7JJkBGpwMqpQ1wQKJSTanOqyZAWPzVnDkjcUBuMdPDOHcmQB5W
3vzXSXJAbiKfz2k5JkC0nyyBI4NzQBiGLJa45yVAas7F4unQdEDObV1OBWwl
QCWwaT8lNXZACgKI8j7HJEBudUYqArJ3QP1hqBeuEiRArlEr8uBJeUBPI1UC
2H8jQMseYmhU/3pAcFyBSO8mI0CNWpEHN9V8QDHZWj0/9SJAqqTlUK7OfkA/
/1HhbMAiQEpUScuXd4BAID8r9gZmIkCQhPR7R52BQL+snY41+CFAPL4LB3/a
gkCeL4HcxFghQKA4CwGYMYRAIo0RSA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVK/tdVT8E0CpmFud4csNQEFKwBqL
4RhARaE+0MZ1JkA6v1xI39UZQKzCvhF02jJASo3vYuG1GkB1w0e55po6QPeP
FQt/8xtAzCrsG6M/QUAW4Zb23xsdQE+Q+0yHRUVA7N7DnmDlHUCQeGrIKGFJ
QMwAXt9T2x5AdEBljKqUTUB+1xV/zwYgQEatyIMX8VBACqbgHZ9TIECIp4YM
HiZTQJpmbQzt9iBAgE37ycxqVUDwfFmjaUchQNBg2UOgwFdAW7QHtc/eIUDC
uExyRilaQDDYOy8vhSJAkpZDiZamXEDAd+v2wf4iQMoeYmiIOl9AYOTqeJ6B
I0BC+r2IovNgQDgPd3qFIyRACGBQnJdXYkCxG2Eoqp8kQBYI3W1xymNA8xGi
nGQPJUCSnAjjok1lQIeyMOU4nyVAcqszUrviZkBaYH0waRsmQDodUBlzi2hA
Hx3zH49yJkBbnZGKr0lqQHMFE1NIqiZAwr4RzIYfbECCedG9nccmQL4LB9E7
D25A5iumgJ7JJkBGpwMqpQ1wQKJSTanOqyZAWPzVnDkjcUBuMdPDOHcmQB5W
3vzXSXJAbiKfz2k5JkC0nyyBI4NzQBiGLJa45yVAas7F4unQdEDObV1OBWwl
QCWwaT8lNXZACgKI8j7HJEBudUYqArJ3QP1hqBeuEiRArlEr8uBJeUBPI1UC
2H8jQMseYmhU/3pAcFyBSO8mI0CNWpEHN9V8QDHZWj0/9SJAqqTlUK7OfkA/
/1HhbMAiQEpUScuXd4BAID8r9gZmIkCQhPR7R52BQL+snY41+CFAPL4LB3/a
gkCeL4HcxFghQKA4CwGYMYRAIo0RSA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAxgJB1iTJGUCpmFud4csNQJ4U+1yK
Nh5ARaE+0MZ1JkCf6vuQCzwfQKzCvhF02jJAUEIj0mnlH0B1w0e55po6QNyg
mtYxLSBAzCrsG6M/QUBA4mNVpVkgQE+Q+0yHRUVALrAiOheCIECQeGrIKGFJ
QMul8oXOqSBAdEBljKqUTUAyuYWecdMgQEatyIMX8VBALek21D0BIUCIp4YM
HiZTQAKIlVVJNSFAgE37ycxqVUDytThPVXAhQNBg2UOgwFdAg4wtUC+1IUDC
uExyRilaQNp+zK1FBiJAkpZDiZamXEAw9Pl3rWMiQMoeYmiIOl9AyoQV2IvR
IkBC+r2IovNgQAPHNr/usSNACGBQnJdXYkAMnaRjxYwkQBYI3W1xymNAmdAh
iRd+JUCSnAjjok1lQMGjCxusByZAcqszUrviZkBpakYp3A4nQDodUBlzi2hA
CikN6O+cJ0BbnZGKr0lqQHY3/ch1XShAwr4RzIYfbECOsz/xhq4oQL4LB9E7
D25AmXLsEmbFKEBGpwMqpQ1wQDnObKZfuShAWPzVnDkjcUAaRT8Ty6UoQB5W
3vzXSXJA3N4UrXOBKEC0nyyBI4NzQCitp/RoNihAas7F4unQdECxVqCNpsMn
QCWwaT8lNXZAnXFYbBRQJ0BudUYqArJ3QE4I7IlG3yZArlEr8uBJeUBJcrTZ
bWYmQMseYmhU/3pAQ2Q+TLbuJUCNWpEHN9V8QPFNHZDgjCVAqqTlUK7OfkD6
pS6gGTklQEpUScuXd4BAMNndm+ncJECQhPR7R52BQGoEcFvOYiRAPL4LB3/a
gkD7VHKbxecjQKA4CwGYMYRALb4Q/A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAbj80iJ5/GUCpmFud4csNQCd1HMOE
6B1ARaE+0MZ1JkA/J1uB5eweQKzCvhF02jJArz4LcreVH0B1w0e55po6QPIm
8AumBiBAzCrsG6M/QUCUQ1Zy2jQgQE+Q+0yHRUVAgdh9LXpeIECQeGrIKGFJ
QKqU69jKhyBAdEBljKqUTUAYgKQUtbIgQEatyIMX8VBAwBdqYHfiIECIp4YM
HiZTQDVC+XaeFyFAgE37ycxqVUCcQU6TVVUhQNBg2UOgwFdA7e1/qlObIUDC
uExyRilaQGijMsCu7iFAkpZDiZamXEAykXz94U0iQMoeYmiIOl9AANhUAae+
IkBC+r2IovNgQI4setB4pSNACGBQnJdXYkAj3GPqt4MkQBYI3W1xymNA7NWB
D39ZJUCSnAjjok1lQFBljC80YCZAcqszUrviZkDSbg82GwUnQDodUBlzi2hA
atNv93PEJ0BbnZGKr0lqQHnw+cdoUyhAwr4RzIYfbECkoI1QnbAoQL4LB9E7
D25A4KDhjMq/KEBGpwMqpQ1wQFbl5yUGrChAWPzVnDkjcUA2y5ZBvYkoQB5W
3vzXSXJAZ2DIuJFEKEC0nyyBI4NzQJfOA+Au3ydAas7F4unQdEAwsU3mSoAn
QCWwaT8lNXZAtrg9UcElJ0BudUYqArJ3QE7BJ6xhwSZArlEr8uBJeUChzdKP
elImQMseYmhU/3pAamRnez3dJUCNWpEHN9V8QMumqkt2ZyVAqqTlUK7OfkCA
Ky7HYf8kQEpUScuXd4BACK6AAnyVJECQhPR7R52BQAZMSDttHCRAPL4LB3/a
gkDUV1YWctQjQKA4CwGYMYRAMtERjw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAuBhaTEM/GUCpmFud4csNQKKSb+1S
pB1ARaE+0MZ1JkBu3Hy/wqceQKzCvhF02jJAyn7dyOlUH0B1w0e55po6QKiT
OYTWzh9AzCrsG6M/QUBSEW0iexYgQE+Q+0yHRUVASV+4pvRBIECQeGrIKGFJ
QNDC6+fhbCBAdEBljKqUTUDk7SVMxpkgQEatyIMX8VBAQ1f1yvfKIECIp4YM
HiZTQEwVo96xAiFAgE37ycxqVUDP8HKw5EIhQNBg2UOgwFdAE1V+rR6MIUDC
uExyRilaQLS1rgIF4iFAkpZDiZamXEAWF1VjUUQiQMoeYmiIOl9Abt2ECGu1
IkBC+r2IovNgQK+so9wLnCNACGBQnJdXYkB1fJ0p0nwkQBYI3W1xymNAbHrl
MdVZJUCSnAjjok1lQAEyZjzrUyZAcqszUrviZkCQ42KIXuMmQDodUBlzi2hA
l6Rdwi2dJ0BbnZGKr0lqQBYVO2ymKyhAwr4RzIYfbEBNHF/8Ln4oQL4LB9E7
D25AgGhKT4iIKEBGpwMqpQ1wQN4PDs9+aShAWPzVnDkjcUDayKAdQRQoQB5W
3vzXSXJA6LeEdIWTJ0C0nyyBI4NzQG6etZHjHCdAas7F4unQdEB1AcXEELkm
QCWwaT8lNXZAMO05eZhbJkBudUYqArJ3QIYXmRMH/CVArlEr8uBJeUCVVjMk
65YlQMseYmhU/3pAqjdCIjoxJUCNWpEHN9V8QPgohXjKyyRAqqTlUK7OfkDg
W/PEqGokQEpUScuXd4BAl6D2OOIPJECQhPR7R52BQGb6gfqqsSNAPL4LB3/a
gkCGkUzvoz4jQKA4CwGYMYRAuBYS3A==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAYmI/9WvQGECpmFud4csNQIyJTc1w
Qx1ARaE+0MZ1JkDGsgstyEMeQKzCvhF02jJAzB+nOJ7uHkB1w0e55po6QKp8
LTKVaB9AzCrsG6M/QUBAP6b0eMUfQE+Q+0yHRUVA/gWzLMgMIECQeGrIKGFJ
QG7zb+YPOCBAdEBljKqUTUBeaDmGV2UgQEatyIMX8VBAHOttpFKWIECIp4YM
HiZTQDxCuSv+zSBAgE37ycxqVUAccEuXXg4hQNBg2UOgwFdAOT0cw39YIUDC
uExyRilaQEi3naKurSFAkpZDiZamXECnsuNfRRAiQMoeYmiIOl9AvH1yhrl9
IkBC+r2IovNgQFk2NrmaXyNACGBQnJdXYkAM+4CLvEAkQBYI3W1xymNA2ET+
/LA7JUCSnAjjok1lQCBsdYJS2SVAcqszUrviZkBSdFQQLrImQDodUBlzi2hA
+pKqj6RuJ0BbnZGKr0lqQCjnxbrjBihAwr4RzIYfbEApYIWQlUgoQL4LB9E7
D25AcBMPPJ5BKEBGpwMqpQ1wQLoXIcqv9idAWPzVnDkjcUAIrEb83HInQB5W
3vzXSXJA3soqwgfjJkC0nyyBI4NzQAmlm3HPYCZAas7F4unQdEArY2q0B+sl
QCWwaT8lNXZAtsZh2mp8JUBudUYqArJ3QIMAR6RFFCVArlEr8uBJeUCDqh0t
364kQMseYmhU/3pAfOoZfAhTJECNWpEHN9V8QMWjLzYGACRAqqTlUK7OfkBI
8kgghrYjQEpUScuXd4BAQEJQAhNwI0CQhPR7R52BQO/cxcgZHiNAPL4LB3/a
gkDQ0GUAYbsiQKA4CwGYMYRAKD4Kww==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAwU3awdlKGECpmFud4csNQIesr1tB
tBxARaE+0MZ1JkD+NCB7VrQdQKzCvhF02jJArIkL/CVeHkB1w0e55po6QDQw
uALD0h5AzCrsG6M/QUDGS26N8iwfQE+Q+0yHRUVAKPoijFt+H0CQeGrIKGFJ
QJiM5TIH0B9AdEBljKqUTUCpc01hkRIgQEatyIMX8VBAWrSthBpCIECIp4YM
HiZTQOoOUdSdeCBAgE37ycxqVUCKBdpIUbYgQNBg2UOgwFdACL2M8Kn+IEDC
uExyRilaQFpTyzzgUiFAkpZDiZamXEAqCHDWQbIhQMoeYmiIOl9AuYAyO40a
IkBC+r2IovNgQPYHrcJq8yJACGBQnJdXYkBmVaZv7NYjQBYI3W1xymNAHJi3
sYu6JECSnAjjok1lQDSkiogFdCVAcqszUrviZkDGGIYH+WQmQDodUBlzi2hA
1sXYUWQaJ0BbnZGKr0lqQDTR+vxLjydAwr4RzIYfbEAg2lT+478nQL4LB9E7
D25ArpbNe9GpJ0BGpwMqpQ1wQIvlbG1UUydAWPzVnDkjcUB09RGup9gmQB5W
3vzXSXJAAau0/QtYJkC0nyyBI4NzQG2tO9TZ1SVAas7F4unQdEAyx61BTlIl
QCWwaT8lNXZAMPFfa3nUJEBudUYqArJ3QPh25rgCZCRArlEr8uBJeUB39VzR
SwQkQMseYmhU/3pAfSLqi965I0CNWpEHN9V8QNG1zI6hgiNAqqTlUK7OfkAw
sw5CSlEjQEpUScuXd4BAWicMi+0LI0CQhPR7R52BQA372HrxlyJAPL4LB3/a
gkBO2gGevDsiQKA4CwGYMYRA7XoUzg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAm9VelGyvF0CpmFud4csNQAxlgmta
6xtARaE+0MZ1JkCSIqImLeQcQKzCvhF02jJAUBHr5/eCHUB1w0e55po6QCq9
KZMu9B1AzCrsG6M/QUCbA5veckUeQE+Q+0yHRUVAj1h3KV6RHkCQeGrIKGFJ
QCi/QEyB3R5AdEBljKqUTUCL0bHesC0fQEatyIMX8VBAh9nAQw+HH0CIp4YM
HiZTQAATxJrU7B9AgE37ycxqVUCs6f64DTIgQNBg2UOgwFdA/ftYrMV2IEDC
uExyRilaQEfkYvLFxyBAkpZDiZamXED9/zlv+CMhQMoeYmiIOl9AOGOqMHWI
IUBC+r2IovNgQBJp28JrVyJACGBQnJdXYkDUq72H60gjQBYI3W1xymNAG8H6
zDXtI0CSnAjjok1lQOU4U2zrviRAcqszUrviZkAM5fJOAK4lQDodUBlzi2hA
reK0VqJjJkBbnZGKr0lqQL3KVbGozyZAwr4RzIYfbEAACYNP1fwmQL4LB9E7
D25AtL/3JQTnJkBGpwMqpQ1wQL3RWtZUmCZAWPzVnDkjcUBiozvTsismQB5W
3vzXSXJAYadLRsa5JUC0nyyBI4NzQIHtVP2vQCVAas7F4unQdEBcSUszAsEk
QCWwaT8lNXZAMt9PkJpEJEBudUYqArJ3QBob2dXZ2CNArlEr8uBJeUBD/uxc
I4MjQMseYmhU/3pATIAylkVFI0CNWpEHN9V8QEVdMfoCFiNAqqTlUK7OfkAt
r3rj1uQiQEpUScuXd4BAgKFlJhaaIkCQhPR7R52BQER8Nq/dIiJAPL4LB3/a
gkB2civR05IhQKA4CwGYMYRAARUWoQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAm9VelGyvF0CpmFud4csNQAxlgmta
6xtARaE+0MZ1JkCSIqImLeQcQKzCvhF02jJAUBHr5/eCHUB1w0e55po6QCq9
KZMu9B1AzCrsG6M/QUCbA5veckUeQE+Q+0yHRUVAj1h3KV6RHkCQeGrIKGFJ
QCi/QEyB3R5AdEBljKqUTUCL0bHesC0fQEatyIMX8VBAh9nAQw+HH0CIp4YM
HiZTQAATxJrU7B9AgE37ycxqVUCs6f64DTIgQNBg2UOgwFdA/ftYrMV2IEDC
uExyRilaQEfkYvLFxyBAkpZDiZamXED9/zlv+CMhQMoeYmiIOl9AOGOqMHWI
IUBC+r2IovNgQBJp28JrVyJACGBQnJdXYkDUq72H60gjQBYI3W1xymNAG8H6
zDXtI0CSnAjjok1lQOU4U2zrviRAcqszUrviZkAM5fJOAK4lQDodUBlzi2hA
reK0VqJjJkBbnZGKr0lqQL3KVbGozyZAwr4RzIYfbEAACYNP1fwmQL4LB9E7
D25AtL/3JQTnJkBGpwMqpQ1wQL3RWtZUmCZAWPzVnDkjcUBiozvTsismQB5W
3vzXSXJAYadLRsa5JUC0nyyBI4NzQIHtVP2vQCVAas7F4unQdEBcSUszAsEk
QCWwaT8lNXZAMt9PkJpEJEBudUYqArJ3QBob2dXZ2CNArlEr8uBJeUBD/uxc
I4MjQMseYmhU/3pATIAylkVFI0CNWpEHN9V8QEVdMfoCFiNAqqTlUK7OfkAt
r3rj1uQiQEpUScuXd4BAgKFlJhaaIkCQhPR7R52BQER8Nq/dIiJAPL4LB3/a
gkB2civR05IhQKA4CwGYMYRAARUWoQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAfSny+4p1HECpmFud4csNQHZ91Bpa
JR9ARaE+0MZ1JkBKGeFLTyAgQKzCvhF02jJA9lXsUDh1IEB1w0e55po6QHpR
PXKpsCBAzCrsG6M/QUDr0SfaD+AgQE+Q+0yHRUVARdOI53MLIUCQeGrIKGFJ
QNqIKPGeNCFAdEBljKqUTUBGib+U1l0hQEatyIMX8VBAf1/eigaJIUCIp4YM
HiZTQL+iSyR0uCFAgE37ycxqVUDWblnr+uwhQNBg2UOgwFdAj6o+G6smIkDC
uExyRilaQD/kS0jdaCJAkpZDiZamXEA83lDnbbQiQMoeYmiIOl9ApKpSLRIN
I0BC+r2IovNgQGc2zB95dyNACGBQnJdXYkDK/CitGu8jQBYI3W1xymNA0DaQ
yMR6JECSnAjjok1lQGjteuCsJiVAcqszUrviZkDJ9DdSu78lQDodUBlzi2hA
pwhNgciMJkBbnZGKr0lqQK30AHi1RCdAwr4RzIYfbEDsT1eBoOMnQL4LB9E7
D25ABk0QqPpLKEBGpwMqpQ1wQDa5iawxeyhAWPzVnDkjcUCGEZFyn3coQB5W
3vzXSXJAdQHm395dKEC0nyyBI4NzQJCFrG6QLihAas7F4unQdEAAMfvzltsn
QCWwaT8lNXZAt0exzslhJ0BudUYqArJ3QNFX8r9B3yZArlEr8uBJeUC4CdJx
z2EmQMseYmhU/3pAuHPjKH7rJUCNWpEHN9V8QCkcUrXfiCVAqqTlUK7OfkC8
xH4OdDIlQEpUScuXd4BAPe5FVM3RJECQhPR7R52BQCz5/lx9VSRAPL4LB3/a
gkAwwSzkgNUjQKA4CwGYMYRA020WVw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAHKvTAAYxHECpmFud4csNQF16j3sx
3x5ARaE+0MZ1JkCKdVV4rPgfQKzCvhF02jJAE27aJgpSIEB1w0e55po6QKqo
dstQjiBAzCrsG6M/QUBNKDlapL4gQE+Q+0yHRUVAnnY7tALqIECQeGrIKGFJ
QJukdLiVEyFAdEBljKqUTUDTqYpSWj4hQEatyIMX8VBA38NCbPxpIUCIp4YM
HiZTQLgL/4YxmyFAgE37ycxqVUBPkz+G0dAhQNBg2UOgwFdA7NrYJeMMIkDC
uExyRilaQHlK2lL1UCJAkpZDiZamXEAHF36Z558iQMoeYmiIOl9AoT3ZWYP5
IkBC+r2IovNgQGAMfF82ZiNACGBQnJdXYkCndxqRudsjQBYI3W1xymNAFZg0
UsdVJECSnAjjok1lQFQK/TLkPCVAcqszUrviZkDU9VBUyvQlQDodUBlzi2hA
jyTeF2OjJkBbnZGKr0lqQHprtAKETSdAwr4RzIYfbEADPzIOzugnQL4LB9E7
D25A/dM3LgNYKEBGpwMqpQ1wQOyKYsm9fihAWPzVnDkjcUCWmRQJEHEoQB5W
3vzXSXJAWs9DV15EKEC0nyyBI4NzQH+K0eRu9idAas7F4unQdECDTb/28I4n
QCWwaT8lNXZAID11CcYlJ0BudUYqArJ3QEoqhRHEvCZArlEr8uBJeUBiV2Z+
HE0mQMseYmhU/3pAbpiaEuzVJUCNWpEHN9V8QMOaQhpUYSVAqqTlUK7OfkDY
vrl2mfkkQEpUScuXd4BAtx5GMOGPJECQhPR7R52BQDycUki1FiRAPL4LB3/a
gkAtb9NgaMgjQKA4CwGYMYRA/DMNEQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA9J6l9Q8AHECpmFud4csNQESH53vO
rR5ARaE+0MZ1JkDBOySLksgfQKzCvhF02jJAKtGMSUI6IEB1w0e55po6QNZn
rwMFdyBAzCrsG6M/QUDzAZa8A6ggQE+Q+0yHRUVABCgZOajUIECQeGrIKGFJ
QCMYPTLq/iBAdEBljKqUTUDXrXvXYCohQEatyIMX8VBAC5Y3bIxXIUCIp4YM
HiZTQMRrA2MGiSFAgE37ycxqVUDUhwlN1L8hQNBg2UOgwFdATDSFs4P8IUDC
uExyRilaQJE6N7qgQiJAkpZDiZamXEA0S/Unc5IiQMoeYmiIOl9A13zgtaPu
IkBC+r2IovNgQP1yA/b1WyNACGBQnJdXYkA6g/W0DtgjQBYI3W1xymNA7gXu
sFhSJECSnAjjok1lQKBJmmsNQiVAcqszUrviZkBs+Djys9glQDodUBlzi2hA
szHyr6+BJkBbnZGKr0lqQCsbriJVIydAwr4RzIYfbED+h8mM3MsnQL4LB9E7
D25AFtfse4gmKEBGpwMqpQ1wQDgi0z+7OihAWPzVnDkjcUCJulQsdBMoQB5W
3vzXSXJAwouNONywJ0C0nyyBI4NzQI5vvMVrMSdAas7F4unQdEDun0HEH70m
QCWwaT8lNXZAT98cVx9ZJkBudUYqArJ3QMNE3rBx+CVArlEr8uBJeUAu46hb
p5ElQMseYmhU/3pAOinu6KEsJUCNWpEHN9V8QJvxz9XQxyRAqqTlUK7OfkBl
CB1lemckQEpUScuXd4BA08SHZNgLJECQhPR7R52BQDBhwgt3qyNAPL4LB3/a
gkDXmo3DdzojQKA4CwGYMYRAQngSaQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAxNnfYPmOG0CpmFud4csNQDa9CK+i
UR5ARaE+0MZ1JkBXOmw8U2ofQKzCvhF02jJAiMi3iH8KIEB1w0e55po6QJ4A
VqjKRyBAzCrsG6M/QUCYDoD203ggQE+Q+0yHRUVAeHtUlxelIECQeGrIKGFJ
QAk058nDzyBAdEBljKqUTUBMDXJdZvogQEatyIMX8VBAjjuQMDgoIUCIp4YM
HiZTQKh6RM/lWSFAgE37ycxqVUDnARxcOJAhQNBg2UOgwFdAiJKbnYHNIUDC
uExyRilaQO0zL7P0EiJAkpZDiZamXEAML3LWT2IiQMoeYmiIOl9AGLmj30W9
IkBC+r2IovNgQA95s4bzKiNACGBQnJdXYkACAZMj0aMjQBYI3W1xymNANHu6
DtQ9JECSnAjjok1lQP6WbsRK6iRAcqszUrviZkB6kYPihY4lQDodUBlzi2hA
uzS/AA5IJkBbnZGKr0lqQOBLyb3sHCdAwr4RzIYfbEA5GqXYeZ8nQL4LB9E7
D25ACY/WCEvfJ0BGpwMqpQ1wQGsZJEUb3SdAWPzVnDkjcUDwoZe+wJQnQB5W
3vzXSXJApwvGh2QLJ0C0nyyBI4NzQL6ouumBciZAas7F4unQdEBQ/VWvv+wl
QCWwaT8lNXZAVoSVhEl6JUBudUYqArJ3QJyjUcE2ESVArlEr8uBJeUCfBVjA
haskQMseYmhU/3pAgFA050NQJECNWpEHN9V8QMAlOFFU/SNAqqTlUK7OfkBH
rQX2hrIjQEpUScuXd4BAKdjCqnNqI0CQhPR7R52BQIs2OEiZFyNAPL4LB3/a
gkClMFkWwLYiQKA4CwGYMYRAN7QNww==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAI08189D7GkCpmFud4csNQCwBaD91
wh1ARaE+0MZ1JkCGcTRAW9ceQKzCvhF02jJAhBU3gSaAH0B1w0e55po6QEjt
R9xg9x9AzCrsG6M/QUB4Gh0PcysgQE+Q+0yHRUVA2G1S5hFXIECQeGrIKGFJ
QHUi3YWRgCBAdEBljKqUTUBrn0Q6z6ogQEatyIMX8VBA1NmLhKTXIECIp4YM
HiZTQAyIhBJJCCFAgE37ycxqVUDqfXo0hD0hQNBg2UOgwFdAE96ssx16IUDC
uExyRilaQHLLIGOBvSFAkpZDiZamXEDqjVVrOAoiQMoeYmiIOl9Aku0Ex9Vj
IkBC+r2IovNgQPKvA9bszyJACGBQnJdXYkD7VozV+U4jQBYI3W1xymNActir
4qzfI0CSnAjjok1lQGTJfrqHfCRAcqszUrviZkDdRnYIjiolQDodUBlzi2hA
ZzZWh3QFJkBbnZGKr0lqQPL/gIUYriZAwr4RzIYfbEDW1KKl2RknQL4LB9E7
D25A9sESIuVMJ0BGpwMqpQ1wQCLfIcKNSCdAWPzVnDkjcUD2DpSAgAgnQB5W
3vzXSXJAdMaNEoSIJkC0nyyBI4NzQKbnWhVb7CVAas7F4unQdECK3DC9Wlol
QCWwaT8lNXZAxD1EvHDYJEBudUYqArJ3QGx9ObkxZSRArlEr8uBJeUB/Dn80
/QMkQMseYmhU/3pAASIMhOm4I0CNWpEHN9V8QLM/9TVagCNAqqTlUK7OfkCq
V9lT10wjQEpUScuXd4BAZzjaxowDI0CQhPR7R52BQEjTwyoikSJAPL4LB3/a
gkBA58TLSTIiQKA4CwGYMYRABG0PCg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1iEPg9dMGkCpmFud4csNQFGCrE9D
9BxARaE+0MZ1JkD6zCritP0dQKzCvhF02jJAMAlLe3ueHkB1w0e55po6QABl
JmuzER9AzCrsG6M/QUDqeGQkIWofQE+Q+0yHRUVAgICGhN69H0CQeGrIKGFJ
QP+X3aK2BSBAdEBljKqUTUCRf3nXsi0gQEatyIMX8VBAD/7fWwdYIECIp4YM
HiZTQDkwuMqChiBAgE37ycxqVUDg9TldrLkgQNBg2UOgwFdAIay2ucDyIEDC
uExyRilaQPb+qz8UNCFAkpZDiZamXEBCe4ndTH0hQMoeYmiIOl9ARKsxJPPT
IUBC+r2IovNgQHzOiJ/qOiJACGBQnJdXYkBPdvMk9bMiQBYI3W1xymNAbX2V
ceQ4I0CSnAjjok1lQMWSLzS5uyNAcqszUrviZkDtMgrH04gkQDodUBlzi2hA
t8d+W/NUJUBbnZGKr0lqQJec4ZNX8iVAwr4RzIYfbECZzszZ5VkmQL4LB9E7
D25A0IRuoaGLJkBGpwMqpQ1wQPNN6remjCZAWPzVnDkjcUAKShiGZFYmQB5W
3vzXSXJA6PE+W+voJUC0nyyBI4NzQCS2sr8oWSVAas7F4unQdEBhNb7pb8ok
QCWwaT8lNXZAKfNUwyZIJEBudUYqArJ3QIUB5eCY2SNArlEr8uBJeUAb4Hzx
W4EjQMseYmhU/3pAmLoLdNVBI0CNWpEHN9V8QFSW77OVECNAqqTlUK7OfkBQ
8Tpyj9wiQEpUScuXd4BAqCXATSWPIkCQhPR7R52BQGLj37rjGSJAPL4LB3/a
gkB9RgrB34YhQKA4CwGYMYRA+rcaDQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1iEPg9dMGkCpmFud4csNQFGCrE9D
9BxARaE+0MZ1JkD6zCritP0dQKzCvhF02jJAMAlLe3ueHkB1w0e55po6QABl
JmuzER9AzCrsG6M/QUDqeGQkIWofQE+Q+0yHRUVAgICGhN69H0CQeGrIKGFJ
QP+X3aK2BSBAdEBljKqUTUCRf3nXsi0gQEatyIMX8VBAD/7fWwdYIECIp4YM
HiZTQDkwuMqChiBAgE37ycxqVUDg9TldrLkgQNBg2UOgwFdAIay2ucDyIEDC
uExyRilaQPb+qz8UNCFAkpZDiZamXEBCe4ndTH0hQMoeYmiIOl9ARKsxJPPT
IUBC+r2IovNgQHzOiJ/qOiJACGBQnJdXYkBPdvMk9bMiQBYI3W1xymNAbX2V
ceQ4I0CSnAjjok1lQMWSLzS5uyNAcqszUrviZkDtMgrH04gkQDodUBlzi2hA
t8d+W/NUJUBbnZGKr0lqQJec4ZNX8iVAwr4RzIYfbECZzszZ5VkmQL4LB9E7
D25A0IRuoaGLJkBGpwMqpQ1wQPNN6remjCZAWPzVnDkjcUAKShiGZFYmQB5W
3vzXSXJA6PE+W+voJUC0nyyBI4NzQCS2sr8oWSVAas7F4unQdEBhNb7pb8ok
QCWwaT8lNXZAKfNUwyZIJEBudUYqArJ3QIUB5eCY2SNArlEr8uBJeUAb4Hzx
W4EjQMseYmhU/3pAmLoLdNVBI0CNWpEHN9V8QFSW77OVECNAqqTlUK7OfkBQ
8Tpyj9wiQEpUScuXd4BAqCXATSWPIkCQhPR7R52BQGLj37rjGSJAPL4LB3/a
gkB9RgrB34YhQKA4CwGYMYRA+rcaDQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAZgrUXPIQG0CpmFud4csNQLxrpcDD
+x1ARaE+0MZ1JkBH8d6/PyYfQKzCvhF02jJA5oeFJZfhH0B1w0e55po6QL2k
/WwEMSBAzCrsG6M/QUBeOe/q6mEgQE+Q+0yHRUVAatX9X52KIECQeGrIKGFJ
QNwwZDm1sCBAdEBljKqUTUAGxdg9otcgQEatyIMX8VBAKGREDXIEIUCIp4YM
HiZTQD2MgEXvNiFAgE37ycxqVUCtTg9dNXQhQNBg2UOgwFdA95PajWG3IUDC
uExyRilaQPQwxvxtByJAkpZDiZamXEBYe8BT9GMiQMoeYmiIOl9AIU/S9evZ
IkBC+r2IovNgQFhnzKd/ZCNACGBQnJdXYkC1RYd6egUkQBYI3W1xymNAvTtI
6CSuJECSnAjjok1lQEfpxUGqXyVAcqszUrviZkA0GlrdChwmQDodUBlzi2hA
NIBE9/7PJkBbnZGKr0lqQBLOLbFWcidAwr4RzIYfbEBFRbgMdfwnQL4LB9E7
D25Aogp10IFiKEBGpwMqpQ1wQJ2X3w9ynChAWPzVnDkjcUDqwqPfra8oQB5W
3vzXSXJARh9rki2rKEC0nyyBI4NzQDK62ztsmShAas7F4unQdEAQDupIDXco
QCWwaT8lNXZALUqg8sM8KEBudUYqArJ3QFpT70xD6SdArlEr8uBJeUBCNHxk
dognQMseYmhU/3pAiLaauwcfJ0CNWpEHN9V8QHzuxMLMsCZAqqTlUK7OfkCQ
KKPPADkmQEpUScuXd4BA2+Fb/9yUJUCQhPR7R52BQENZlE3WzSRAPL4LB3/a
gkDuJuCjPfUjQKA4CwGYMYRAtRcUxA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA9tUKE2ntGkCpmFud4csNQFrXUE1K
7R1ARaE+0MZ1JkBKPgGacRgfQKzCvhF02jJAgP085F/YH0B1w0e55po6QDNw
i5aqLiBAzCrsG6M/QUCCU88ZqWEgQE+Q+0yHRUVAxOX7TCqNIECQeGrIKGFJ
QIgkfKM8tiBAdEBljKqUTUB1m5gisd8gQEatyIMX8VBA6ViCPdgPIUCIp4YM
HiZTQEwpgkNmRiFAgE37ycxqVUDEoQbwU4UhQNBg2UOgwFdA4kbJUCLMIUDC
uExyRilaQNSdXyeIHyJAkpZDiZamXEBYWDRWvH4iQMoeYmiIOl9AFoxZgtH4
IkBC+r2IovNgQGHOu/dYiSNACGBQnJdXYkBlSpdMcTAkQBYI3W1xymNAUpM5
6EPfJECSnAjjok1lQDP0s0NQliVAcqszUrviZkBSxxOVGFQmQDodUBlzi2hA
xtscYB4BJ0BbnZGKr0lqQDwqJpNqlCdAwr4RzIYfbEA5Re+tWRIoQL4LB9E7
D25A3qW/9m1rKEBGpwMqpQ1wQK1cis/AlShAWPzVnDkjcUDfO/LNq5woQB5W
3vzXSXJA0MQ3nmWNKEC0nyyBI4NzQLzpsY+CaihAas7F4unQdEBBhy5czi4o
QCWwaT8lNXZAOxCv3/bjJ0BudUYqArJ3QP5LLvI1kidArlEr8uBJeUBSaEDF
cjcnQMseYmhU/3pALFwYSQ3NJkCNWpEHN9V8QB/4QFvQTSZAqqTlUK7OfkBH
3/PHkbQlQEpUScuXd4BAvMOf7uYDJUCQhPR7R52BQD4xHmRcTiRAPL4LB3/a
gkA7BxKK05IjQKA4CwGYMYRAh/oOxg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA/C5xB6rdGkCpmFud4csNQK0wEGbo
8x1ARaE+0MZ1JkCOSYsXLiYfQKzCvhF02jJA2PUM9dTjH0B1w0e55po6QNen
dzeJNiBAzCrsG6M/QUAA5Xn+2GogQE+Q+0yHRUVAYd1LwPWWIECQeGrIKGFJ
QOFylQtSwCBAdEBljKqUTUCf/Jr2guogQEatyIMX8VBAgtb8wQoaIUCIp4YM
HiZTQGqJHSowTyFAgE37ycxqVUAmp9uj24whQNBg2UOgwFdAVCC9SgzRIUDC
uExyRilaQNLpDdPdISJAkpZDiZamXECkZBotynoiQMoeYmiIOl9AVtP8lPjr
IkBC+r2IovNgQD4ESWX+eSNACGBQnJdXYkCcDYGxBhYkQBYI3W1xymNAh1pY
Q569JECSnAjjok1lQGNb4HP0cSVAcqszUrviZkCxtS4Z4BgmQDodUBlzi2hA
qciv0hSyJkBbnZGKr0lqQEIy7L55RCdAwr4RzIYfbEAWtg3brbUnQL4LB9E7
D25AlfNGxS31J0BGpwMqpQ1wQACquV9/CChAWPzVnDkjcUAVV6feeP4nQB5W
3vzXSXJAEl/feObaJ0C0nyyBI4NzQCJPqukinCdAas7F4unQdEDJAUKxFUon
QCWwaT8lNXZA5NHgu3f2JkBudUYqArJ3QBsYEhKipyZArlEr8uBJeUAEp9iI
CFAmQMseYmhU/3pAoa9xVXfjJUCNWpEHN9V8QJJ27D1lYCVAqqTlUK7OfkAl
MH86HdAkQEpUScuXd4BAkg8u2HJFJECQhPR7R52BQPKFunJxxCNAPL4LB3/a
gkDmix8lEy0jQKA4CwGYMYRAPJ8SYg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAcls41TH5GkCpmFud4csNQNqeBpL0
/x1ARaE+0MZ1JkATuBU9HC0fQKzCvhF02jJAkOuo3SvoH0B1w0e55po6QOQh
NuZeNSBAzCrsG6M/QUCeLLNyBWYgQE+Q+0yHRUVAYc51VMiOIECQeGrIKGFJ
QBq3I3iktCBAdEBljKqUTUAclvK53NogQEatyIMX8VBAu/+H0CEFIUCIp4YM
HiZTQFjzEvxENiFAgE37ycxqVUA3bAUGeG4hQNBg2UOgwFdAjnFVdcKuIUDC
uExyRilaQKTRh+om+CFAkpZDiZamXEAnSu8VLk4iQMoeYmiIOl9ABNaAoc+y
IkBC+r2IovNgQF+fpZRHPSNACGBQnJdXYkC1duUaXtUjQBYI3W1xymNAW+3n
+6J5JECSnAjjok1lQFZDdVHFKSVAcqszUrviZkD7IUVLOs4lQDodUBlzi2hA
HCdqDDduJkBbnZGKr0lqQOwEOYkR+CZAwr4RzIYfbEDzq1DzZVsnQL4LB9E7
D25AbORgWnaSJ0BGpwMqpQ1wQOypkGDenSdAWPzVnDkjcUCJ4KaMzYonQB5W
3vzXSXJACX0sUs5WJ0C0nyyBI4NzQDX3+uwGACdAas7F4unQdEBrgXRNj5Am
QCWwaT8lNXZAg7gGTB8ZJkBudUYqArJ3QMxcXVQiqCVArlEr8uBJeUAP/iqq
XDQlQMseYmhU/3pAxdduZemyJECNWpEHN9V8QABvN2XJJCRAqqTlUK7OfkBY
Suwy3KAjQEpUScuXd4BAsEVGBD40I0CQhPR7R52BQJGd702m3SJAPL4LB3/a
gkBWx071o4MiQKA4CwGYMYRAq3MPPA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAAC+C3Rd7GkCpmFud4csNQEIn6x1+
VB1ARaE+0MZ1JkCXEArA1HkeQKzCvhF02jJAro+VV9oyH0B1w0e55po6QHto
UoPxrh9AzCrsG6M/QUCmnoRIQAUgQE+Q+0yHRUVA9qtTjesqIECQeGrIKGFJ
QIyH+1laTyBAdEBljKqUTUBeCzVJ1nQgQEatyIMX8VBAk454bMmdIECIp4YM
HiZTQMtaf+wIzyBAgE37ycxqVUCP0VeVcgUhQNBg2UOgwFdA9NTI4flEIUDC
uExyRilaQJbB9ReajyFAkpZDiZamXEDqQhPmy+UhQMoeYmiIOl9AwpRGAvNJ
IkBC+r2IovNgQL4BDNX51CJACGBQnJdXYkDHNeNY/nAjQBYI3W1xymNAIREe
InMaJECSnAjjok1lQAojTOo+zSRAcqszUrviZkCEqaTvO34lQDodUBlzi2hA
U5bNFAYiJkBbnZGKr0lqQHCljn8bqCZAwr4RzIYfbEDAtSXOyAYnQL4LB9E7
D25AmN6DjRE6J0BGpwMqpQ1wQAIUZZrYSCdAWPzVnDkjcUCABjdJ0TUnQB5W
3vzXSXJA3VE1HLAEJ0C0nyyBI4NzQFh1WN3lsSZAas7F4unQdEDvR3FYkDIm
QCWwaT8lNXZAKcYVnyCTJUBudUYqArJ3QJPFEK6O5iRArlEr8uBJeUAUCcAh
8EQkQMseYmhU/3pA/K/YT3a7I0CNWpEHN9V8QIp6OqCZTiNAqqTlUK7OfkCQ
4RDtv/giQEpUScuXd4BALfE6VTKnIkCQhPR7R52BQApg2lejTiJAPL4LB3/a
gkCUPIs+YM8hQKA4CwGYMYRAKf8NoQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAApRs+ANeVGUCpmFud4csNQP4V4maD
WBxARaE+0MZ1JkA4ckW42HEdQKzCvhF02jJADvUM8QojHkB1w0e55po6QLo4
br/gnh5AzCrsG6M/QUDie6vGCvUeQE+Q+0yHRUVA9kCE2ahAH0CQeGrIKGFJ
QAK8/eBIhh9AdEBljKqUTUB+5ByM+s4fQEatyIMX8VBAIPfcBG4QIECIp4YM
HiZTQOOwItYyQSBAgE37ycxqVUAIdqXOM3ggQNBg2UOgwFdAnEV5viq4IEDC
uExyRilaQFSezFXyAyFAkpZDiZamXEDqksR8WlkhQMoeYmiIOl9A2KYV0Yq9
IUBC+r2IovNgQPKntu3USCJACGBQnJdXYkDIn9GW1OQiQBYI3W1xymNAQ7jv
z02NI0CSnAjjok1lQMmSw6DIPCRAcqszUrviZkByTHrPbPEkQDodUBlzi2hA
PceUUTuUJUBbnZGKr0lqQDwZ9hcPGCZAwr4RzIYfbEBel94zX3QmQL4LB9E7
D25AIB6+aR6oJkBGpwMqpQ1wQHUx/Kc5uSZAWPzVnDkjcUATclqL+awmQB5W
3vzXSXJA6tBQw1t+JkC0nyyBI4NzQD1AnnSHLCZAas7F4unQdEC+hrOJDrIl
QCWwaT8lNXZA99lPw3INJUBudUYqArJ3QNBdI+zUTSRArlEr8uBJeUB4cyp5
FKQjQMseYmhU/3pA9qBtfXwsI0CNWpEHN9V8QFQAV0EA4iJAqqTlUK7OfkBK
pawMXaMiQEpUScuXd4BAo5sTtqFMIkCQhPR7R52BQCSFr0eG4CFAPL4LB3/a
gkAs54Y8ZFMhQKA4CwGYMYRATWATMA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[0.88, 1, 0.88]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAApRs+ANeVGUCpmFud4csNQP4V4maD
WBxARaE+0MZ1JkA4ckW42HEdQKzCvhF02jJADvUM8QojHkB1w0e55po6QLo4
br/gnh5AzCrsG6M/QUDie6vGCvUeQE+Q+0yHRUVA9kCE2ahAH0CQeGrIKGFJ
QAK8/eBIhh9AdEBljKqUTUB+5ByM+s4fQEatyIMX8VBAIPfcBG4QIECIp4YM
HiZTQOOwItYyQSBAgE37ycxqVUAIdqXOM3ggQNBg2UOgwFdAnEV5viq4IEDC
uExyRilaQFSezFXyAyFAkpZDiZamXEDqksR8WlkhQMoeYmiIOl9A2KYV0Yq9
IUBC+r2IovNgQPKntu3USCJACGBQnJdXYkDIn9GW1OQiQBYI3W1xymNAQ7jv
z02NI0CSnAjjok1lQMmSw6DIPCRAcqszUrviZkByTHrPbPEkQDodUBlzi2hA
PceUUTuUJUBbnZGKr0lqQDwZ9hcPGCZAwr4RzIYfbEBel94zX3QmQL4LB9E7
D25AIB6+aR6oJkBGpwMqpQ1wQHUx/Kc5uSZAWPzVnDkjcUATclqL+awmQB5W
3vzXSXJA6tBQw1t+JkC0nyyBI4NzQD1AnnSHLCZAas7F4unQdEC+hrOJDrIl
QCWwaT8lNXZA99lPw3INJUBudUYqArJ3QNBdI+zUTSRArlEr8uBJeUB4cyp5
FKQjQMseYmhU/3pA9qBtfXwsI0CNWpEHN9V8QFQAV0EA4iJAqqTlUK7OfkBK
pawMXaMiQEpUScuXd4BAo5sTtqFMIkCQhPR7R52BQCSFr0eG4CFAPL4LB3/a
gkAs54Y8ZFMhQKA4CwGYMYRATWATMA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA1GpVvGolGkCpmFud4csNQKzy9mPe
jB9ARaE+0MZ1JkDmvTtSzWAgQKzCvhF02jJAFTN/gtbtIEB1w0e55po6QP2/
yRJCoyFAzCrsG6M/QUDwN00qg1AiQE+Q+0yHRUVAOFRhLg+pIkCQeGrIKGFJ
QFQwdPqPPCNAdEBljKqUTUBKewcklscjQEatyIMX8VBArB3mJ0pSJECIp4YM
HiZTQPaWY5fmmCRAgE37ycxqVUADmclVJTIlQNBg2UOgwFdA7GKlREVvJUDC
uExyRilaQDprshGU+SVAkpZDiZamXEAju7CaG4kmQMoeYmiIOl9AAwSB3xHB
JkBC+r2IovNgQATaEMj+WydACGBQnJdXYkBf4ygKLZUnQBYI3W1xymNAnjsm
BWYxKECSnAjjok1lQO4Vad9ZcyhAcqszUrviZkAHl0nii9goQDodUBlzi2hA
Vs/pZJ4BKUBbnZGKr0lqQOD8Ok3mEylAwr4RzIYfbECszvqRIgkpQL4LB9E7
D25AAiNpNaLwKEBGpwMqpQ1wQLQTh+Wl1ShAWPzVnDkjcUBFhuEya7goQB5W
3vzXSXJAiTpxHDOUKEC0nyyBI4NzQBmCf8Q/ZShAas7F4unQdEA9Trzjvi0o
QCWwaT8lNXZAiSWzG+3sJ0BudUYqArJ3QFzLOneXnSdArlEr8uBJeUCceSnP
TEAnQMseYmhU/3pA08qFtSnYJkCNWpEHN9V8QLNAlf3AayZAqqTlUK7OfkCl
R7VhkfUlQEpUScuXd4BAlnlM+ixOJUCQhPR7R52BQDbRfXUJmSRAPL4LB3/a
gkDiKOYiG9gjQKA4CwGYMYRAxDIOAA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAG4hg4/nrGUCpmFud4csNQN/xSajF
ah9ARaE+0MZ1JkB65S5umk4gQKzCvhF02jJA2kxq4hXeIEB1w0e55po6QDMs
CtXclCFAzCrsG6M/QUAhsQ3bHTkiQE+Q+0yHRUVAemm/sLLOIkCQeGrIKGFJ
QIKgzzHUMSNAdEBljKqUTUDgksBPGsYjQEatyIMX8VBAabqw3qRkJECIp4YM
HiZTQF8Lkm8qriRAgE37ycxqVUA77Fj51lAlQNBg2UOgwFdAVu6TM9eVJUDC
uExyRilaQNES2TBOLCZAkpZDiZamXECtqUaqFckmQMoeYmiIOl9A9pAWY6oK
J0BC+r2IovNgQBV5l75TsSdACGBQnJdXYkAEQbwU5e0nQBYI3W1xymNAm9w3
21qJKECSnAjjok1lQLgYUrkyuShAcqszUrviZkAtBHRxkQgpQDodUBlzi2hA
hBjPLB0dKUBbnZGKr0lqQKr50Sk6CylAwr4RzIYfbEB74c+C6OkoQL4LB9E7
D25AjeOa5azNKEBGpwMqpQ1wQEktLTOlryhAWPzVnDkjcUA08jwDCoMoQB5W
3vzXSXJAnWEAuv9KKEC0nyyBI4NzQJBJCtWDEihAas7F4unQdECix0GYpdcn
QCWwaT8lNXZA7uoV4jaVJ0BudUYqArJ3QLSaWfRWRSdArlEr8uBJeUClDgeW
BOcmQMseYmhU/3pATU/PW+R7JkCNWpEHN9V8QJh8OBeE/yVAqqTlUK7OfkDC
4ZK+Z2klQEpUScuXd4BAqLqF+vLGJECQhPR7R52BQMaGWBViJiRAPL4LB3/a
gkCjt3UQsm8jQKA4CwGYMYRAOPwTvw==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA6MyHsIjfGUCpmFud4csNQJgATUXQ
kB9ARaE+0MZ1JkC2Tg5oI2MgQKzCvhF02jJAY1T+Q1XxIEB1w0e55po6QCZn
JaQuqyFAzCrsG6M/QUAdlXNGx0kiQE+Q+0yHRUVAiVhapYj0IkCQeGrIKGFJ
QEbxRgxMUCNAdEBljKqUTUCi2AZL1PojQEatyIMX8VBAaYABSt5VJECIp4YM
HiZTQFGn6It84yRAgE37ycxqVUCstsSib3glQNBg2UOgwFdA7QdJHIbGJUDC
uExyRilaQLuq9caHWiZAkpZDiZamXED34zX8h+wmQMoeYmiIOl9AcsxAeqky
J0BC+r2IovNgQIjTqfLFxCdACGBQnJdXYkAC0I8IZPInQBYI3W1xymNAgEys
kVtRKECSnAjjok1lQBUwfWfPjihAcqszUrviZkBckQCfx6YoQDodUBlzi2hA
IjtiYqigKEBbnZGKr0lqQBk+Hj0IiihAwr4RzIYfbEAq9TxrJnAoQL4LB9E7
D25AXrsRIeFJKEBGpwMqpQ1wQArGNlx1CChAWPzVnDkjcUASDigyQLknQB5W
3vzXSXJAaADimtd0J0C0nyyBI4NzQCPhqoQpNCdAas7F4unQdECwztNJgPMm
QCWwaT8lNXZAkhlP+8CxJkBudUYqArJ3QARDtSApaCZArlEr8uBJeUCDdcMD
5QsmQMseYmhU/3pA4KJE5uuQJUCNWpEHN9V8QJ5pD4/aACVAqqTlUK7OfkBu
MfHiwXckQEpUScuXd4BA1A/DWKj/I0CQhPR7R52BQLS9y6g1hyNAPL4LB3/a
gkDJG8B7DQojQKA4CwGYMYRAp5gOdg==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAA4h/HhrEeGkCpmFud4csNQOxbLKAL
wB9ARaE+0MZ1JkAeQBFLdXwgQKzCvhF02jJAxE2g9r0HIUB1w0e55po6QGSX
GJEpvyFAzCrsG6M/QUBrgVqtnFoiQE+Q+0yHRUVAagNDi+rdIkCQeGrIKGFJ
QO2eIEm5WSNAdEBljKqUTUBUtgQOY+8jQEatyIMX8VBA+vyWB7BHJECIp4YM
HiZTQDuS/+AY6yRAgE37ycxqVUBmx3Fy4S0lQNBg2UOgwFdADDdpDk/OJUDC
uExyRilaQHl4nKQOCiZAkpZDiZamXEC2iAcvvp4mQMoeYmiIOl9AMh6HOPTY
JkBC+r2IovNgQK3h2G/dXSdACGBQnJdXYkAoTtLp1I0nQBYI3W1xymNA+r29
m6frJ0CSnAjjok1lQI0clx7yFyhAcqszUrviZkAlCLPIy0woQDodUBlzi2hA
slka1XNXKEBbnZGKr0lqQAGAk+m/RShAwr4RzIYfbEDjqzlvaCIoQL4LB9E7
D25AJy6qnkDdJ0BGpwMqpQ1wQImL0/JhgCdAWPzVnDkjcUDvSMldcignQB5W
3vzXSXJASNhCplvTJkC0nyyBI4NzQOTJIUzweyZAas7F4unQdECmQK2dxyMm
QCWwaT8lNXZAw884VzrHJUBudUYqArJ3QA45ntq6XCVArlEr8uBJeUAZ0yVJ
HtwkQMseYmhU/3pA4kZ6PSNMJECNWpEHN9V8QN3CbsuYySNAqqTlUK7OfkDQ
nrX8aGMjQEpUScuXd4BAViks8XkFI0CQhPR7R52BQF5x0bhpwCJAPL4LB3/a
gkC6IdLaG2ciQKA4CwGYMYRALWARxQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAJMX6ei2zGUCpmFud4csNQCir2CaM
BR9ARaE+0MZ1JkDYeUQg1h0gQKzCvhF02jJAJFUBSm6jIEB1w0e55po6QCo+
c9YmUiFAzCrsG6M/QUBrqDLLkPIhQE+Q+0yHRUVAyFZadzVVIkCQeGrIKGFJ
QAzo/Z+C7yJAdEBljKqUTUDjphTzL1MjQEatyIMX8VBArC0nC0DKI0CIp4YM
HiZTQKVVobGLZyRAgE37ycxqVUA+Ap7t1qgkQNBg2UOgwFdAFb3BEDRFJUDC
uExyRilaQN1Yy54PfyVAkpZDiZamXEAqCRpS8/4lQMoeYmiIOl9AA/YUoxZ4
JkBC+r2IovNgQMLJqLfG9yZACGBQnJdXYkCXYc5CyCYnQBYI3W1xymNAhgJ3
p4GRJ0CSnAjjok1lQL60WqTLtCdAcqszUrviZkBpxnlGmucnQDodUBlzi2hA
toEZyM7zJ0BbnZGKr0lqQAFZ45/05ydAwr4RzIYfbEBb2YhjV8UnQL4LB9E7
D25AJzIKtlSBJ0BGpwMqpQ1wQJuWW6ApMCdAWPzVnDkjcUCJmiswpN8mQB5W
3vzXSXJA/McrcuWBJkC0nyyBI4NzQAM/B8cJCSZAas7F4unQdEDWOzXYPXcl
QCWwaT8lNXZAItSPb0XZJEBudUYqArJ3QNtdcxikPiRArlEr8uBJeUB/tbja
Dr8jQMseYmhU/3pAx0VnHKVoI0CNWpEHN9V8QAMWjFHGLyNAqqTlUK7OfkDM
koDZW/giQEpUScuXd4BABuRMVt+hIkCQhPR7R52BQM8NF5OxYyJAPL4LB3/a
gkAJCHTGjachQKA4CwGYMYRAVVQNxA==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVwqaYszHGECpmFud4csNQCaYRVEh
7B1ARaE+0MZ1JkA21hXsgxsfQKzCvhF02jJAmmi0jgEQIEB1w0e55po6QCiB
0Y0fvSBAzCrsG6M/QUA1nGzccF8hQE+Q+0yHRUVA6PJmlJDAIUCQeGrIKGFJ
QNXv7ZQjTSJAdEBljKqUTUCDdi8HfOEiQEatyIMX8VBAgELxgwcyI0CIp4YM
HiZTQE7X67501CNAgE37ycxqVUDnGFEoKRckQNBg2UOgwFdANh7K2lWhJEDC
uExyRilaQD8WXA18PyVAkpZDiZamXEBSPLRDW3QlQMoeYmiIOl9AtUU/9V/w
JUBC+r2IovNgQHzKQ+qDcCZACGBQnJdXYkBtBr6pMZ8mQBYI3W1xymNAfuqn
9gD1JkCSnAjjok1lQJ7xZl3yMydAcqszUrviZkAzqLrJEVAnQDodUBlzi2hA
fOnFo3dXJ0BbnZGKr0lqQJRY+nG+TSdAwr4RzIYfbEDMRjr4tzEnQL4LB9E7
D25AiN2HVmHzJkBGpwMqpQ1wQGRyGCSKqiZAWPzVnDkjcUDZ2gE7RFwmQB5W
3vzXSXJA28mQ60r8JUC0nyyBI4NzQCoC3YfadCVAas7F4unQdEA5znZm+skk
QCWwaT8lNXZA5a8CmfYUJEBudUYqArJ3QPOu+hmjgCNArlEr8uBJeUAfUD75
VywjQMseYmhU/3pA8z8aCtkNI0CNWpEHN9V8QKtaRf4m9SJAqqTlUK7OfkDS
Hf7Fx74iQEpUScuXd4BALTBo1zJMIkCQhPR7R52BQJysKY9G4SFAPL4LB3/a
gkBwszaUvhwhQKA4CwGYMYRAFswRuQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         LineBox[CompressedData["
1:eJwBgQJ+/SFib1JlAgAAACcAAAACAAAAVwqaYszHGECpmFud4csNQCaYRVEh
7B1ARaE+0MZ1JkA21hXsgxsfQKzCvhF02jJAmmi0jgEQIEB1w0e55po6QCiB
0Y0fvSBAzCrsG6M/QUA1nGzccF8hQE+Q+0yHRUVA6PJmlJDAIUCQeGrIKGFJ
QNXv7ZQjTSJAdEBljKqUTUCDdi8HfOEiQEatyIMX8VBAgELxgwcyI0CIp4YM
HiZTQE7X67501CNAgE37ycxqVUDnGFEoKRckQNBg2UOgwFdANh7K2lWhJEDC
uExyRilaQD8WXA18PyVAkpZDiZamXEBSPLRDW3QlQMoeYmiIOl9AtUU/9V/w
JUBC+r2IovNgQHzKQ+qDcCZACGBQnJdXYkBtBr6pMZ8mQBYI3W1xymNAfuqn
9gD1JkCSnAjjok1lQJ7xZl3yMydAcqszUrviZkAzqLrJEVAnQDodUBlzi2hA
fOnFo3dXJ0BbnZGKr0lqQJRY+nG+TSdAwr4RzIYfbEDMRjr4tzEnQL4LB9E7
D25AiN2HVmHzJkBGpwMqpQ1wQGRyGCSKqiZAWPzVnDkjcUDZ2gE7RFwmQB5W
3vzXSXJA28mQ60r8JUC0nyyBI4NzQCoC3YfadCVAas7F4unQdEA5znZm+skk
QCWwaT8lNXZA5a8CmfYUJEBudUYqArJ3QPOu+hmjgCNArlEr8uBJeUAfUD75
VywjQMseYmhU/3pA8z8aCtkNI0CNWpEHN9V8QKtaRf4m9SJAqqTlUK7OfkDS
Hf7Fx74iQEpUScuXd4BALTBo1zJMIkCQhPR7R52BQJysKY9G4SFAPL4LB3/a
gkBwszaUvhwhQKA4CwGYMYRAFswRuQ==
          "]]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{8.09, 33.}, {8.2, 40.}, {8.31, 50.}, {8.43, 60.}, {8.52, 
          70.}, {8.65, 80.}, {8.86, 90.}, {8.85, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{7.63, 33.}, {7.71, 40.}, {7.8, 50.}, {7.92, 60.}, {8.04, 
          70.}, {8.22, 80.}, {8.4, 90.}, {8.45, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{7.87, 33.}, {7.96, 40.}, {8.05, 50.}, {8.1, 60.}, {8.11, 
          70.}, {8.25, 80.}, {8.41, 90.}, {8.48, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{7.98, 33.}, {8.12, 40.}, {8.23, 50.}, {8.29, 60.}, {8.3, 
          70.}, {8.44, 80.}, {8.54, 90.}, {8.45, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{7.69, 33.}, {7.8, 40.}, {7.89, 50.}, {7.96, 60.}, {7.99, 
          70.}, {8.14, 80.}, {8.35, 90.}, {8.45, 
          100.}}]}}}, {}}, {{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.019444444444444445`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[{{7.78, 33.}, {7.89, 40.}, {8.02, 50.}, {8.1, 60.}, {8.07, 
          70.}, {8.21, 80.}, {8.34, 90.}, {8.34, 100.}}]}}}, {}}}, {
    PlotRange -> All, AspectRatio -> 1.2, Frame -> True, FrameLabel -> {
       FormBox[
       "\"WS \\!\\(\\*SuperscriptBox[\\(ms\\), \\(-1\\)]\\)\"", 
        TraditionalForm], 
       FormBox["\"Height   m\"", TraditionalForm]}, 
     TextStyle -> {FontSize -> 16}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {5.3008592855349566`, 0}, 
     PlotRange -> {{5.408412360386354, 12.291809150875778`}, {
       0, 646.199220740953}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {5.3008592855349566`, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{5.408412360386354, 12.291809150875778`}, {
       0, 646.199220740953}}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"EWP 20-21\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0.25 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=1 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Fitch adv=0 14:00-15:00\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.88, 1, 0.88]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.88, 1, 0.88], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5866666666666667, 0.6666666666666666, 
                    0.5866666666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "RGBColor[0.88, 1, 0.88]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.88, 1, 0.88]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.88, 1, 0.88], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"No Farm 20-21\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0.5]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False]}],
                    "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", "True", "}"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}]}], 
             "]"}]& ), Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8066457469266596`*^9, 3.8066458009811287`*^9, 
  3.813567384818673*^9, 3.813584752262246*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1263, 621},
WindowMargins->{{Automatic, -471}, {Automatic, -988}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (September 9, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 277, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[860, 27, 244, 3, 70, "Section"],
Cell[1107, 32, 163, 3, 30, "Text"],
Cell[1273, 37, 1830, 51, 132, "Input"],
Cell[3106, 90, 110, 1, 30, "Text"],
Cell[3219, 93, 1887, 55, 72, "Input"],
Cell[5109, 150, 316, 6, 30, "Text"],
Cell[5428, 158, 4801, 105, 192, "Input"],
Cell[10232, 265, 293, 6, 30, "Text"],
Cell[10528, 273, 4820, 103, 232, "Input"],
Cell[15351, 378, 235, 5, 30, "Text"],
Cell[15589, 385, 5061, 106, 212, "Input"],
Cell[20653, 493, 287, 6, 30, "Text"],
Cell[20943, 501, 4753, 96, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25733, 602, 141, 2, 70, "Section"],
Cell[CellGroupData[{
Cell[25899, 608, 672, 11, 79, "Subsection"],
Cell[26574, 621, 987, 16, 31, "Input"],
Cell[CellGroupData[{
Cell[27586, 641, 194, 3, 31, "Input"],
Cell[27783, 646, 596, 10, 31, "Output"]
}, Open  ]],
Cell[28394, 659, 426, 10, 31, "Input"],
Cell[28823, 671, 301, 8, 31, "Input"],
Cell[29127, 681, 399, 10, 31, "Input"],
Cell[29529, 693, 94, 1, 31, "Input"],
Cell[29626, 696, 1034, 23, 31, "Input"],
Cell[CellGroupData[{
Cell[30685, 723, 724, 12, 31, "Input"],
Cell[CellGroupData[{
Cell[31434, 739, 386, 7, 23, "Print"],
Cell[31823, 748, 414, 7, 23, "Print"],
Cell[32240, 757, 508, 11, 23, "Print"]
}, Open  ]],
Cell[32763, 771, 384, 7, 31, "Output"]
}, Open  ]],
Cell[33162, 781, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[33281, 786, 203, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[33509, 794, 168, 4, 23, "Print"],
Cell[33680, 800, 202, 4, 23, "Print"],
Cell[33885, 806, 293, 8, 23, "Print"]
}, Open  ]],
Cell[34193, 817, 170, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34400, 826, 420, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[34845, 840, 362, 6, 23, "Print"],
Cell[35210, 848, 392, 6, 23, "Print"],
Cell[35605, 856, 482, 10, 23, "Print"]
}, Open  ]],
Cell[36102, 869, 363, 6, 31, "Output"]
}, Open  ]],
Cell[36480, 878, 191, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[36696, 887, 476, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[37197, 901, 262, 5, 23, "Print"],
Cell[37462, 908, 290, 5, 23, "Print"],
Cell[37755, 915, 378, 9, 23, "Print"]
}, Open  ]],
Cell[38148, 927, 265, 5, 31, "Output"]
}, Open  ]],
Cell[38428, 935, 959, 18, 52, "Input"],
Cell[39390, 955, 803, 14, 31, "Input"],
Cell[40196, 971, 292, 7, 31, "Input"],
Cell[40491, 980, 797, 14, 31, "Input"],
Cell[41291, 996, 854, 15, 31, "Input"],
Cell[42148, 1013, 342, 8, 31, "Input"],
Cell[42493, 1023, 725, 12, 31, "Input"],
Cell[43221, 1037, 94, 1, 31, "Input"],
Cell[43318, 1040, 96, 1, 31, "Input"],
Cell[43417, 1043, 1009, 15, 31, "Input"],
Cell[44429, 1060, 597, 17, 52, "Input"],
Cell[45029, 1079, 303, 8, 31, "Input"],
Cell[45335, 1089, 89, 1, 52, "Input"],
Cell[45427, 1092, 548, 16, 31, "Input"],
Cell[45978, 1110, 910, 20, 52, "Input"],
Cell[46891, 1132, 912, 20, 52, "Input"],
Cell[47806, 1154, 910, 20, 52, "Input"],
Cell[48719, 1176, 1314, 40, 72, "Input"],
Cell[50036, 1218, 988, 21, 52, "Input"],
Cell[51027, 1241, 985, 21, 52, "Input"],
Cell[52015, 1264, 986, 21, 52, "Input"],
Cell[53004, 1287, 249, 5, 31, "Input"],
Cell[53256, 1294, 1223, 21, 31, "Input"],
Cell[54482, 1317, 357, 9, 31, "Input"],
Cell[54842, 1328, 357, 9, 31, "Input"],
Cell[55202, 1339, 1171, 20, 31, "Input"],
Cell[56376, 1361, 308, 8, 31, "Input"],
Cell[56687, 1371, 306, 8, 31, "Input"],
Cell[56996, 1381, 1055, 29, 92, "Input"],
Cell[58054, 1412, 450, 11, 31, "Input"],
Cell[58507, 1425, 499, 12, 31, "Input"],
Cell[59009, 1439, 501, 12, 31, "Input"],
Cell[59513, 1453, 1982, 49, 152, "Input"],
Cell[61498, 1504, 2140, 52, 172, "Input"],
Cell[63641, 1558, 138, 3, 31, "Input"],
Cell[63782, 1563, 823, 22, 52, "Input"],
Cell[64608, 1587, 825, 22, 52, "Input"],
Cell[65436, 1611, 821, 22, 52, "Input"],
Cell[66260, 1635, 823, 22, 52, "Input"],
Cell[67086, 1659, 869, 23, 52, "Input"],
Cell[67958, 1684, 876, 23, 52, "Input"],
Cell[68837, 1709, 823, 22, 52, "Input"],
Cell[69663, 1733, 821, 22, 52, "Input"],
Cell[70487, 1757, 913, 23, 52, "Input"],
Cell[71403, 1782, 924, 23, 52, "Input"],
Cell[72330, 1807, 870, 23, 52, "Input"],
Cell[73203, 1832, 874, 23, 52, "Input"],
Cell[74080, 1857, 240, 5, 31, "Input"],
Cell[74323, 1864, 847, 22, 52, "Input"],
Cell[75173, 1888, 849, 22, 52, "Input"],
Cell[76025, 1912, 843, 22, 52, "Input"],
Cell[76871, 1936, 847, 22, 52, "Input"],
Cell[77721, 1960, 894, 23, 52, "Input"],
Cell[78618, 1985, 899, 23, 52, "Input"],
Cell[79520, 2010, 845, 22, 52, "Input"],
Cell[80368, 2034, 843, 22, 52, "Input"],
Cell[81214, 2058, 940, 24, 52, "Input"],
Cell[82157, 2084, 951, 24, 52, "Input"],
Cell[83111, 2110, 895, 23, 52, "Input"],
Cell[84009, 2135, 897, 23, 52, "Input"],
Cell[84909, 2160, 868, 21, 31, "Input"],
Cell[85780, 2183, 869, 21, 31, "Input"],
Cell[86652, 2206, 867, 21, 31, "Input"],
Cell[87522, 2229, 1783, 39, 52, "Input"],
Cell[89308, 2270, 1836, 40, 52, "Input"],
Cell[91147, 2312, 1837, 40, 52, "Input"],
Cell[92987, 2354, 1890, 41, 52, "Input"],
Cell[94880, 2397, 1833, 40, 52, "Input"],
Cell[96716, 2439, 1839, 40, 52, "Input"],
Cell[98558, 2481, 1887, 41, 52, "Input"],
Cell[100448, 2524, 1338, 36, 52, "Input"],
Cell[101789, 2562, 926, 26, 52, "Input"],
Cell[102718, 2590, 993, 27, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103748, 2622, 218, 4, 49, "Subsection"],
Cell[103969, 2628, 300, 7, 31, "Input"],
Cell[104272, 2637, 335, 8, 31, "Input"],
Cell[104610, 2647, 1009, 25, 52, "Input"],
Cell[105622, 2674, 1345, 33, 52, "Input"],
Cell[106970, 2709, 1343, 33, 52, "Input"],
Cell[108316, 2744, 1396, 34, 52, "Input"],
Cell[109715, 2780, 498, 13, 31, "Input"],
Cell[110216, 2795, 552, 13, 31, "Input"],
Cell[110771, 2810, 1138, 28, 52, "Input"],
Cell[111912, 2840, 1119, 32, 52, "Input"],
Cell[113034, 2874, 1117, 32, 52, "Input"],
Cell[114154, 2908, 550, 13, 31, "Input"],
Cell[114707, 2923, 550, 13, 31, "Input"],
Cell[115260, 2938, 214, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[115499, 2946, 604, 11, 31, "Input"],
Cell[116106, 2959, 645, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116788, 2973, 475, 10, 31, "Input"],
Cell[117266, 2985, 1587, 23, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118890, 3013, 529, 11, 31, "Input"],
Cell[119422, 3026, 1097, 16, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120556, 3047, 271, 7, 31, "Input"],
Cell[120830, 3056, 1069, 16, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121936, 3077, 420, 9, 31, "Input"],
Cell[122359, 3088, 1488, 22, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123884, 3115, 517, 10, 31, "Input"],
Cell[124404, 3127, 1277, 21, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125718, 3153, 199, 4, 31, "Input"],
Cell[125920, 3159, 13413, 284, 74, "Output"]
}, Open  ]],
Cell[139348, 3446, 1032, 18, 31, "Input"],
Cell[140383, 3466, 1092, 19, 31, "Input"],
Cell[141478, 3487, 460, 10, 31, "Input"],
Cell[141941, 3499, 1084, 19, 31, "Input"],
Cell[143028, 3520, 511, 11, 31, "Input"],
Cell[143542, 3533, 1090, 19, 31, "Input"],
Cell[144635, 3554, 1133, 20, 31, "Input"],
Cell[145771, 3576, 1194, 20, 31, "Input"],
Cell[146968, 3598, 562, 12, 31, "Input"],
Cell[147533, 3612, 1094, 19, 31, "Input"],
Cell[148630, 3633, 1154, 20, 31, "Input"],
Cell[149787, 3655, 519, 11, 31, "Input"],
Cell[150309, 3668, 1146, 20, 31, "Input"],
Cell[151458, 3690, 568, 12, 31, "Input"],
Cell[152029, 3704, 1150, 20, 31, "Input"],
Cell[153182, 3726, 1146, 20, 31, "Input"],
Cell[154331, 3748, 1202, 20, 31, "Input"],
Cell[155536, 3770, 567, 12, 31, "Input"],
Cell[156106, 3784, 87, 1, 52, "Input"],
Cell[156196, 3787, 511, 11, 31, "Input"],
Cell[156710, 3800, 310, 8, 31, "Input"],
Cell[157023, 3810, 564, 12, 31, "Input"],
Cell[157590, 3824, 310, 8, 31, "Input"],
Cell[157903, 3834, 611, 12, 31, "Input"],
Cell[158517, 3848, 310, 8, 31, "Input"],
Cell[158830, 3858, 570, 12, 31, "Input"],
Cell[159403, 3872, 316, 8, 31, "Input"],
Cell[159722, 3882, 618, 12, 31, "Input"],
Cell[160343, 3896, 320, 8, 31, "Input"],
Cell[160666, 3906, 619, 12, 31, "Input"],
Cell[161288, 3920, 316, 8, 31, "Input"],
Cell[161607, 3930, 250, 6, 31, "Input"],
Cell[161860, 3938, 661, 16, 31, "Input"],
Cell[162524, 3956, 712, 17, 31, "Input"],
Cell[163239, 3975, 714, 17, 31, "Input"],
Cell[163956, 3994, 572, 15, 31, "Input"],
Cell[164531, 4011, 605, 17, 31, "Input"],
Cell[165139, 4030, 795, 23, 31, "Input"],
Cell[CellGroupData[{
Cell[165959, 4057, 725, 21, 31, "Input"],
Cell[166687, 4080, 326, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167050, 4092, 718, 21, 31, "Input"],
Cell[167771, 4115, 330, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168138, 4127, 695, 21, 31, "Input"],
Cell[168836, 4150, 281, 6, 31, "Output"]
}, Open  ]],
Cell[169132, 4159, 1962, 62, 132, "Input"],
Cell[171097, 4223, 963, 30, 72, "Input"],
Cell[172063, 4255, 980, 30, 72, "Input"],
Cell[173046, 4287, 978, 30, 72, "Input"],
Cell[174027, 4319, 2411, 45, 72, "Input"],
Cell[176441, 4366, 2408, 45, 72, "Input"],
Cell[178852, 4413, 2462, 46, 72, "Input"],
Cell[181317, 4461, 2415, 45, 72, "Input"],
Cell[183735, 4508, 2521, 47, 72, "Input"],
Cell[186259, 4557, 2521, 47, 72, "Input"],
Cell[188783, 4606, 2475, 46, 72, "Input"],
Cell[191261, 4654, 2583, 48, 72, "Input"],
Cell[193847, 4704, 2583, 48, 72, "Input"],
Cell[196433, 4754, 2525, 47, 72, "Input"],
Cell[198961, 4803, 2631, 48, 72, "Input"],
Cell[201595, 4853, 2579, 48, 72, "Input"],
Cell[204177, 4903, 2465, 46, 72, "Input"],
Cell[206645, 4951, 2465, 46, 72, "Input"],
Cell[209113, 4999, 2519, 47, 72, "Input"],
Cell[211635, 5048, 881, 25, 72, "Input"],
Cell[212519, 5075, 881, 25, 72, "Input"],
Cell[213403, 5102, 883, 25, 72, "Input"],
Cell[214289, 5129, 939, 26, 52, "Input"],
Cell[215231, 5157, 892, 25, 52, "Input"],
Cell[216126, 5184, 880, 25, 52, "Input"],
Cell[217009, 5211, 882, 25, 52, "Input"],
Cell[217894, 5238, 941, 26, 52, "Input"],
Cell[218838, 5266, 945, 26, 52, "Input"],
Cell[219786, 5294, 937, 26, 52, "Input"],
Cell[220726, 5322, 939, 26, 52, "Input"],
Cell[221668, 5350, 993, 26, 52, "Input"],
Cell[222664, 5378, 997, 26, 52, "Input"],
Cell[223664, 5406, 987, 26, 52, "Input"],
Cell[224654, 5434, 987, 26, 52, "Input"],
Cell[225644, 5462, 1305, 36, 72, "Input"],
Cell[226952, 5500, 673, 16, 72, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[227674, 5522, 265, 5, 111, "Section"],
Cell[CellGroupData[{
Cell[227964, 5531, 3874, 85, 112, "Input"],
Cell[231841, 5618, 118374, 2176, 371, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350252, 7799, 3903, 85, 112, "Input"],
Cell[354158, 7886, 110360, 2044, 371, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464555, 9935, 3847, 85, 112, "Input"],
Cell[468405, 10022, 114249, 2110, 371, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582691, 12137, 1460, 33, 72, "Input"],
Cell[584154, 12172, 72139, 1359, 282, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[656330, 13536, 1512, 34, 72, "Input"],
Cell[657845, 13572, 73003, 1379, 282, "Output"]
}, Open  ]],
Cell[730863, 14954, 244, 3, 31, "Input"],
Cell[731110, 14959, 295, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[731430, 14967, 1560, 36, 72, "Input"],
Cell[732993, 15005, 98942, 1843, 282, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[831972, 16853, 1830, 42, 92, "Input"],
Cell[833805, 16897, 81487, 1500, 282, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[915329, 18402, 1608, 36, 72, "Input"],
Cell[916940, 18440, 83074, 1552, 282, "Output"]
}, Open  ]],
Cell[1000029, 19995, 1362, 40, 72, "Input"],
Cell[CellGroupData[{
Cell[1001416, 20039, 1509, 34, 72, "Input"],
Cell[1002928, 20075, 73811, 1398, 282, "Output"]
}, Open  ]],
Cell[1076754, 21476, 840, 20, 72, "Input"],
Cell[1077597, 21498, 761, 18, 52, "Input"],
Cell[1078361, 21518, 628, 18, 31, "Input"],
Cell[1078992, 21538, 679, 18, 31, "Input"],
Cell[CellGroupData[{
Cell[1079696, 21560, 6201, 136, 212, "Input"],
Cell[1085900, 21698, 724, 12, 21, "Message"],
Cell[1086627, 21712, 29138, 577, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115802, 22294, 6143, 135, 212, "Input"],
Cell[1121948, 22431, 528, 10, 21, "Message"],
Cell[1122479, 22443, 28958, 575, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1151474, 23023, 150, 3, 31, "Input"],
Cell[1151627, 23028, 474, 9, 21, "Message"],
Cell[1152104, 23039, 55538, 1098, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1207679, 24142, 6994, 150, 212, "Input"],
Cell[1214676, 24294, 819, 14, 21, "Message"],
Cell[1215498, 24310, 29216, 579, 245, "Output"]
}, Open  ]],
Cell[1244729, 24892, 1949, 57, 172, "Input"],
Cell[CellGroupData[{
Cell[1246703, 24953, 5983, 147, 192, "Input"],
Cell[1252689, 25102, 547, 10, 21, "Message"],
Cell[1253239, 25114, 48323, 976, 429, "Output"]
}, Open  ]],
Cell[1301577, 26093, 2412, 69, 192, "Input"],
Cell[CellGroupData[{
Cell[1304014, 26166, 6123, 149, 192, "Input"],
Cell[1310140, 26317, 574, 11, 21, "Message"],
Cell[1310717, 26330, 47388, 964, 427, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1358142, 27299, 3367, 91, 152, "Input"],
Cell[1361512, 27392, 28499, 574, 247, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1390048, 27971, 10096, 247, 578, "Input"],
Cell[1400147, 28220, 697, 12, 21, "Message"],
Cell[1400847, 28234, 70405, 1404, 431, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1471289, 29643, 10048, 247, 578, "Input"],
Cell[1481340, 29892, 572, 10, 21, "Message"],
Cell[1481915, 29904, 70288, 1402, 431, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1552240, 31311, 10109, 247, 558, "Input"],
Cell[1562352, 31560, 549, 10, 21, "Message"],
Cell[1562904, 31572, 70201, 1402, 431, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
